@@ -5,15 +5,16 @@ OC.L10N.register(
     "Delete" : "Șterge",
     "Default" : "Implicită",
     "Edit" : "Editează",
+    "Unlimited" : "Nelimitată",
     "Name" : "Nume",
     "Host" : "Gazdă",
     "Enabled" : "Activat",
+    "More information" : "Mai multe informații",
     "Remove" : "Elimină",
     "From" : "De la",
     "To" : "Către",
     "Add" : "Adaugă",
     "Display name" : "Nume afișat",
-    "Disabled" : "Dezactivați",
     "Confirm" : "Confirmă",
     "Save" : "Salvează",
     "Register" : "Înregistrează-te",
