@@ -24,6 +24,8 @@ use OCA\AppAPI\Middleware\ExAppUiMiddleware;
 use OCA\AppAPI\Notifications\ExAppNotifier;
 use OCA\AppAPI\PublicCapabilities;
 use OCA\AppAPI\SetupChecks\DaemonCheck;
+use OCA\AppAPI\SetupChecks\HarpVersionCheck;
+use OCA\DAV\Events\SabrePluginAddEvent;
 use OCA\DAV\Events\SabrePluginAuthInitEvent;
 use OCA\Files\Event\LoadAdditionalScriptsEvent;
 use OCP\AppFramework\App;
@@ -32,7 +34,6 @@ use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Navigation\Events\LoadAdditionalEntriesEvent;
-use OCP\SabrePluginEvent;
 use OCP\Settings\Events\DeclarativeSettingsGetValueEvent;
 use OCP\Settings\Events\DeclarativeSettingsRegisterFormEvent;
 use OCP\Settings\Events\DeclarativeSettingsSetValueEvent;
@@ -42,6 +43,7 @@ class Application extends App implements IBootstrap {
 	public const APP_ID = 'app_api';
 	public const TEST_DEPLOY_APPID = 'test-deploy';
 	public const TEST_DEPLOY_INFO_XML = 'https://raw.githubusercontent.com/nextcloud/test-deploy/main/appinfo/info.xml';
+	public const MINIMUM_HARP_VERSION = '0.3.0';
 
 	public function __construct(array $urlParams = []) {
 		parent::__construct(self::APP_ID, $urlParams);
@@ -69,6 +71,7 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(DeclarativeSettingsSetValueEvent::class, SetValueListener::class);
 
 		$context->registerSetupCheck(DaemonCheck::class);
+		$context->registerSetupCheck(HarpVersionCheck::class);
 	}
 
 	public function boot(IBootContext $context): void {
@@ -77,9 +80,9 @@ class Application extends App implements IBootstrap {
 	public function registerDavAuth(): void {
 		$container = $this->getContainer();
 
-		$dispatcher = $container->query(IEventDispatcher::class);
-		$dispatcher->addListener('OCA\DAV\Connector\Sabre::addPlugin', function (SabrePluginEvent $event) use ($container) {
-			$event->getServer()->addPlugin($container->query(DavPlugin::class));
+		$dispatcher = $container->get(IEventDispatcher::class);
+		$dispatcher->addListener(SabrePluginAddEvent::class, function (SabrePluginAddEvent $event) use ($container) {
+			$event->getServer()->addPlugin($container->get(DavPlugin::class));
 		});
 	}
 }
