@@ -48,7 +48,7 @@ class ExAppProxyController extends Controller {
 		parent::__construct(Application::APP_ID, $request);
 	}
 
-	private function createProxyResponse(string $path, IResponse $response, $cache = true): ProxyResponse {
+	private function createProxyResponse(string $path, IResponse $response, bool $isHTML, $cache = true): ProxyResponse {
 		$headersToIgnore = ['aa-version', 'ex-app-id', 'authorization-app-api', 'ex-app-version', 'aa-request-id'];
 		$responseHeaders = [];
 		foreach ($response->getHeaders() as $key => $value) {
@@ -58,7 +58,6 @@ class ExAppProxyController extends Controller {
 		}
 		$content = $response->getBody();
 
-		$isHTML = pathinfo($path, PATHINFO_EXTENSION) === 'html';
 		if ($isHTML) {
 			$nonce = $this->nonceManager->getNonce();
 			$content = str_replace(
@@ -78,6 +77,11 @@ class ExAppProxyController extends Controller {
 			}
 		}
 
+		if (isset($responseHeaders['Transfer-Encoding'])
+			&& str_contains(strtolower($responseHeaders['Transfer-Encoding']), 'chunked')) {
+			unset($responseHeaders['Transfer-Encoding']);
+		}
+
 		$proxyResponse = new ProxyResponse($response->getStatusCode(), $responseHeaders, $content);
 		if ($cache && !$isHTML && empty($response->getHeader('cache-control'))
 			&& $response->getHeader('Content-Type') !== 'application/json'
@@ -98,9 +102,11 @@ class ExAppProxyController extends Controller {
 		if ($exApp === null) {
 			return new NotFoundResponse();
 		}
+		$isHTML = pathinfo($other, PATHINFO_EXTENSION) === 'html';
 
 		$response = $this->service->requestToExApp2(
 			$exApp, '/' . $other, $this->userId, 'GET', queryParams: $_GET, options: [
+				'stream' => !$isHTML, // Can't stream HTML
 				RequestOptions::COOKIES => $this->buildProxyCookiesJar($_COOKIE, $this->service->getExAppDomain($exApp)),
 				RequestOptions::HEADERS => $this->buildHeadersWithExclude($route, getallheaders()),
 				RequestOptions::TIMEOUT => 0,
@@ -112,7 +118,7 @@ class ExAppProxyController extends Controller {
 		}
 
 		$this->processBruteforce($bruteforceProtection, $delay, $response->getStatusCode());
-		return $this->createProxyResponse($other, $response);
+		return $this->createProxyResponse($other, $response, $isHTML);
 	}
 
 	#[PublicPage]
@@ -126,8 +132,10 @@ class ExAppProxyController extends Controller {
 		if ($exApp === null) {
 			return new NotFoundResponse();
 		}
+		$isHTML = pathinfo($other, PATHINFO_EXTENSION) === 'html';
 
 		$options = [
+			'stream' => !$isHTML,
 			RequestOptions::COOKIES => $this->buildProxyCookiesJar($_COOKIE, $this->service->getExAppDomain($exApp)),
 			RequestOptions::HEADERS => $this->buildHeadersWithExclude($route, getallheaders()),
 			RequestOptions::TIMEOUT => 0,
@@ -153,7 +161,7 @@ class ExAppProxyController extends Controller {
 		}
 
 		$this->processBruteforce($bruteforceProtection, $delay, $response->getStatusCode());
-		return $this->createProxyResponse($other, $response);
+		return $this->createProxyResponse($other, $response, $isHTML);
 	}
 
 	#[PublicPage]
@@ -167,9 +175,11 @@ class ExAppProxyController extends Controller {
 		if ($exApp === null) {
 			return new NotFoundResponse();
 		}
+		$isHTML = pathinfo($other, PATHINFO_EXTENSION) === 'html';
 
 		$stream = fopen('php://input', 'r');
 		$options = [
+			'stream' => !$isHTML,
 			RequestOptions::COOKIES => $this->buildProxyCookiesJar($_COOKIE, $this->service->getExAppDomain($exApp)),
 			RequestOptions::BODY => $stream,
 			RequestOptions::HEADERS => $this->buildHeadersWithExclude($route, getallheaders()),
@@ -185,7 +195,7 @@ class ExAppProxyController extends Controller {
 		}
 
 		$this->processBruteforce($bruteforceProtection, $delay, $response->getStatusCode());
-		return $this->createProxyResponse($other, $response);
+		return $this->createProxyResponse($other, $response, $isHTML);
 	}
 
 	#[PublicPage]
@@ -199,9 +209,11 @@ class ExAppProxyController extends Controller {
 		if ($exApp === null) {
 			return new NotFoundResponse();
 		}
+		$isHTML = pathinfo($other, PATHINFO_EXTENSION) === 'html';
 
 		$stream = fopen('php://input', 'r');
 		$options = [
+			'stream' => !$isHTML,
 			RequestOptions::COOKIES => $this->buildProxyCookiesJar($_COOKIE, $this->service->getExAppDomain($exApp)),
 			RequestOptions::BODY => $stream,
 			RequestOptions::HEADERS => $this->buildHeadersWithExclude($route, getallheaders()),
@@ -217,7 +229,7 @@ class ExAppProxyController extends Controller {
 		}
 
 		$this->processBruteforce($bruteforceProtection, $delay, $response->getStatusCode());
-		return $this->createProxyResponse($other, $response);
+		return $this->createProxyResponse($other, $response, $isHTML);
 	}
 
 	private function prepareProxy(
@@ -321,6 +333,8 @@ class ExAppProxyController extends Controller {
 
 	private function buildHeadersWithExclude(array $route, array $headers): array {
 		$headersToExclude = json_decode($route['headers_to_exclude'], true);
+		$headersToExclude = array_map('strtolower', $headersToExclude);
+
 		if (!in_array('x-origin-ip', $headersToExclude)) {
 			$headersToExclude[] = 'x-origin-ip';
 		}
