@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Lag",
     "You created the team {circle}" : "Du opprettet laget {circle}",
     "{author} created the team {circle}" : "{author} opprettet laget {circle}",
     "You deleted {circle}" : "Du slettet {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
     "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
     "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
+    "Teams" : "Lag",
     "On events happening in a <strong>team</strong> of which you are a member" : "På hendelser som skjer i et <strong>lag</strong> hvor du er medlem",
     "Any important event in a <strong>team</strong> you are moderating" : "Enhver viktig hendelse i et <strong>lag</strong> du modererer",
     "On global events happening in any <strong>team</strong>" : "På globale hendelser som skjer i ethvert <strong>lag</strong>",
@@ -76,7 +76,7 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloud-gruppe",
     "Email address" : "E-post adresse",
     "Contact" : "Kontakt",
-    "Circle" : "Sirkel",
+    "Team" : "Lag",
     "Nextcloud App" : "Nextcloud-app",
     "Member" : "Medlem",
     "Moderator" : "Moderator",
@@ -104,12 +104,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Initialisering av Circles App",
     "Fresh installation status" : "Status på fersk installasjon",
     "Building Local Database" : "Bygger lokal database",
-    "Testing Basic Circle Creation" : "Tester opprettelse av grunnleggende sirkel",
     "Adding local users and moderators" : "Legger til lokale brukere og moderatorer",
     "Show all teams" : "Vis alle lag",
     "Create a new team" : "Opprett et nytt lag",
     "Files" : "Filer",
-    "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
     "The team is not federated" : "Laget er ikke sammenknyttet",
     "You cannot join this team" : "Du kan ikke bli med i dette laget",
     "This member is not a moderator" : "Dette medlemmet er ikke en moderator",
@@ -117,19 +115,20 @@ OC.L10N.register(
     "This member does not exist" : "Dette medlemmet finnes ikke",
     "This member is the owner of the team" : "Medlemmet er eieren av laget",
     "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
-    "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
-    "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
-    "The account is already a member of this circle" : "Denne kontoren er allerede medlem av sirkelen",
-    "The account has already been invited into this circle" : "Denne kontoen har allerede blitt invitert til denne sirkelen",
     "%s (Team owned by %s)" : "%s (Lag eiet av %s)",
+    "You are now a member of the Team \"%2$s\"" : "Du er nå medlem av laget \"%2$s\"",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Du har blitt invitert av %1$s til laget \"%2$s\"",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s sendte en forespørsel om å bli medlem av laget \"%2$s\"",
     "Accept" : "Aksepter",
     "Refuse" : "Avvis",
+    "Leave the team" : "Forlat laget",
     "%s" : "%s",
     "Personal team" : "Personlig lag",
     "%s owned by %s" : "%s eid av %s",
     "You have no permission to create a new team" : "Du har ingen tillatelse til å opprette et nytt lag",
     "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
     "%s shared a file with you." : "%s delte en fil med deg.",
+    "Open %s" : "Åpne %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte innhold med deg.\nDu bør allerede ha mottatt en separat epist med en link for å få tilgang til det.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delte innhold med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
     "Password to access content shared with you by %1$s" : "Passord for å få tilgang til innhold som deles med deg av %1$s",
@@ -137,21 +136,18 @@ OC.L10N.register(
     "This item is already shared with this team" : "Dette elementet er allerede delt med dette laget",
     "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Lag lar folk lage sine egne grupper av mennesker / kolleger / venner.\nDisse persongruppene kan deretter brukes av en hvilken som helst annen app til delingsformål.",
+    "https://…" : "https://…",
+    "Try again" : "Prøv igjen",
+    "No teams found" : "Ingen lag funnet",
+    "Join or create teams to see them here." : "Bli med eller opprett lag for å se dem her.",
+    "Create your first team" : "Opprett ditt første lag",
+    "Loading…" : "Laster...",
+    "More teams" : "Flere lag",
     "No files in here" : "Ingen filer her",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Name" : "Navn",
     "Size" : "Størrelse",
     "Modified" : "Endret",
-    "Teams' files" : "Lags filer",
-    "Select team to filter by" : "Velg lag å filtrere etter",
-    "No teams found" : "Ingen lag funnet",
-    "Please select teams to filter by" : "Vennligst velg lag å filtrere etter",
-    "No files found for the selected teams" : "Ingen filer funnet for valgte lag",
-    "{author} added team {member} has been added as member to {circle}" : "{author} la til lag-{member} er blitt lagt til medlem til {circle}",
-    "Shared to Circles" : "Delt til Sirkler",
-    "You are now a member of the Circle \"%2$s\"" : "Du er nå medlem av sirkelen \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blitt invitert av %1$s til sirkelen \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendte en forespørsel om å bli medlem av sirkelen \"%2$s\"",
-    "Leave the circle" : "Forlat sirkelen"
+    "Shared to Circles" : "Delt til Sirkler"
 },
 "nplurals=2; plural=(n != 1);");
