@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s alishiriki baadhi ya maudhui na wewe. Unapaswa kuwa tayari umepokea barua pepe tofauti iliyo na kiungo ili kuifikia. ",
     "Password to access content shared with you by %1$s" : "Nenosiri la kufikia maudhui yaliyoshirikiwa nawe %1$s",
     "Password to access content" : "Nenosiri la kufikia yaliyomo",
+    "Federated Teams" : "Timu Zilizoshirikishwa",
     "This item is already shared with this team" : "Kipengee hiki tayari kimeshirikiwa na timu hii",
     "Bring cloud-users closer together." : "Walete watumiaji wa cloud karibu pamoja.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Timu huruhusu watu kuunda vikundi vyao vya watu/wenzake/marafiki.\nVikundi hivyo vya watu vinaweza kutumiwa na programu nyingine yoyote kwa madhumuni ya kushiriki.",
+    "Unable to update federated teams config" : "Imeshindwa kusasisha usanidi wa timu zilizoshirikishwa",
+    "Invalid URL format. Please provide a valid URL." : "Umbizo la URL si sahihi. Tafadhali toa URL halali.",
+    "Changed frontal cloud URL" : "Kubadilisha URL ya wingu la mbele",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Shirikisho hukuruhusu kushiriki timu na seva zingine zinazoaminika na kuzifanya ziweze kutambulika katika matukio yote.",
+    "Enable federated teams" : "Washa timu zilizoshirikishwa",
+    "Frontal URL" : "URL ya mbele",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "URL ya umma inayotumiwa na matukio mengine kugundua na kuunganisha kwa timu zako.",
     "Failed to load teams" : "Imeshindwa kupakia timu",
     "Try again" : "Jaribu tena",
     "No teams found" : "Hakuna timu zilizopatikana",
