@@ -28,7 +28,7 @@ OC.L10N.register(
     "You left {circle}" : "Ви залишили {circle}",
     "{member} left {circle}" : "{member} залишив {circle}",
     "You declined the invitation to join {circle}" : "Ви відхилили запрошення приєднатися до {circle}",
-    "{member} declined an invitation to join {circle}" : "{member} відхилив запрошення приєднатися до {circle}",
+    "{member} declined an invitation to join {circle}" : "{member} відхилив(-ла) запрошення приєднатися до {circle}",
     "You cancelled your request to join {circle}" : "Ви скасували свій запит на приєднання до {circle}",
     "{member} cancelled a request to join {circle}" : "{member} скасував(-ла) запит на приєднання до {circle}",
     "You have been removed from {circle} by {author}" : "{author} вилучив вас із {circle}",
@@ -37,19 +37,19 @@ OC.L10N.register(
     "{external} has been removed from {circle} by {author}" : "{external} вилучено з кола {circle} автором {author}",
     "You cancelled {member}'s invitation to join {circle}" : "Ви скасували запрошення користувача {member} приєднатися до {circle}",
     "Your invitation to join {circle} has been cancelled by {author}" : "Ваше запрошення приєднатися до {circle} було скасовано {author}",
-    "{author} cancelled {member}'s invitation to join {circle}" : "{author} скасував запрошення {member} приєднатися до {circle}",
+    "{author} cancelled {member}'s invitation to join {circle}" : "{author} скасував(-ла) запрошення {member} приєднатися до {circle}",
     "You dismissed {member}'s request to join {circle}" : "Ви відхилили запит {member} приєднатися до {circle}",
     "Your request to join {circle} has been dismissed by {author}" : "Ваш запит на приєднання до {circle} відхилено {author}",
     "{member}'s request to join {circle} has been dismissed by {author}" : "{author} відхилив запит {member} на приєднання до {circle}",
     "You invited {member} to join {circle}" : "Ви запросили {member} приєднатися до {circle}",
     "You have been invited to join {circle} by {author}" : "{author} запросив вас приєднатися до {circle}",
-    "{member} has been invited to join {circle} by {author}" : "{member} отримав запрошення приєднатися до {circle} від {author}",
+    "{member} has been invited to join {circle} by {author}" : "{member} отримав(-ла) запрошення приєднатися до {circle} від {author}",
     "You changed {member}'s level in {circle} to %1$s" : "Ви змінили рівень участи {member} у колі {circle} на %1$s",
     "{author} changed your level in {circle} to %1$s" : "{author} змінив(-ла) ваш рівень участі у колі {circle} на %1$s",
     "{author} changed {member}'s level in {circle} to %1$s" : "{author} змінив(-ла) ваш рівень участі у колі {circle} на %1$s",
     "You sent a request to join {circle}" : "Ви надіслали запит на приєднання до {circle}",
-    "{member} sent a request to join {circle}" : "{member} надіслав запит на приєднання до {circle}",
-    "You are the new owner of {circle}" : "Ви новий власник {circle}",
+    "{member} sent a request to join {circle}" : "{member} надіслав(-ла) запит на приєднання до {circle}",
+    "You are the new owner of {circle}" : "Ви є новим власником {circle}",
     "{member} is the new owner of {circle}" : "{member} є новим власником {circle}",
     "Teams" : "Команди",
     "On events happening in a <strong>team</strong> of which you are a member" : "При настанні подій у <strong>команді </strong>, до якої ви входите",
@@ -143,9 +143,18 @@ OC.L10N.register(
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поділив(-ла-)ся з вами деяким вмістом. На вашу ел.скриньку було надіслано лист із посиланням для доступу до вмісту.",
     "Password to access content shared with you by %1$s" : "Пароль для доступу до вмісту, яким з вами поділив(-ла-)ся %1$s",
     "Password to access content" : "Пароль для доступу до вмісту",
+    "Federated Teams" : "Команди об'єднаних хмар",
     "This item is already shared with this team" : "Цей ресурс вже у спільному доступі з цією командою",
     "Bring cloud-users closer together." : "Зближіть користувачів хмари.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Команди дозволяють користувачам створювати власні групи з друзів, колег, знайомих.\nЗ цими групами людей подалі можна буде обмінюватися даними в різних застосунках.",
+    "Unable to update federated teams config" : "Не вдалося оновити налаштування команд об'єднаних хмар",
+    "Invalid URL format. Please provide a valid URL." : "Недійсний формат URL. Надайте посилання у правильному форматі.",
+    "Changed frontal cloud URL" : "Змінено фронтальне посилання на хмару",
+    "Federation allows you to share teams with other trusted servers and make them discoverable across instances." : "Об'єднані хмари дозволяють надавати у спільний доступ ресурси команд іншим довіреним хмарним сервісам, робити так, щоб їх можна було виявити користувачами інших примірників хмар Nextcloud.",
+    "Enable federated teams" : "Увімкнути команди об'єднаних хмар",
+    "Frontal URL" : "Посилання спільного доступу до хмари",
+    "https://…" : "https://…",
+    "The public URL used by other instances to discover and connect to your teams." : "Публічне посилання, яке використовується іншими примірниками для пошуку та з'єднання з вашими командами.",
     "Failed to load teams" : "Не вдалося завантажити команди",
     "Try again" : "Спробуйте ще раз",
     "No teams found" : "Жодної команди не знайдено",
