@@ -51,7 +51,7 @@ class CircleRequest extends CircleRequestBuilder {
 			->setValue('settings', $qb->createNamedParameter(json_encode($circle->getSettings())))
 			->setValue('config', $qb->createNamedParameter($circle->getConfig()));
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -67,7 +67,7 @@ class CircleRequest extends CircleRequestBuilder {
 
 		$qb->limitToUniqueId($circle->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 	/**
@@ -83,7 +83,7 @@ class CircleRequest extends CircleRequestBuilder {
 
 		$qb->limitToUniqueId($circle->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -112,7 +112,7 @@ class CircleRequest extends CircleRequestBuilder {
 
 		$qb->limitToUniqueId($singleId);
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -125,7 +125,7 @@ class CircleRequest extends CircleRequestBuilder {
 
 		$qb->limitToUniqueId($circle->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -137,7 +137,7 @@ class CircleRequest extends CircleRequestBuilder {
 		$qb->set('settings', $qb->createNamedParameter(json_encode($circle->getSettings())));
 		$qb->limitToUniqueId($circle->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -296,6 +296,7 @@ class CircleRequest extends CircleRequestBuilder {
 
 		$aliasMembership = $qb->generateAlias(CoreQueryBuilder::CIRCLE, CoreQueryBuilder::MEMBERSHIPS);
 
+		$aliasInitiator = null;
 		if (is_null($initiator)) {
 			// to get unique result, enforce a limit on level=owner
 			$limit = $qb->exprLimitInt('level', Member::LEVEL_OWNER, $aliasMembership);
@@ -305,10 +306,15 @@ class CircleRequest extends CircleRequestBuilder {
 				$initiator->getSingleId(),
 				$aliasMembership
 			);
-			$qb->completeProbeWithInitiator(CoreQueryBuilder::CIRCLE, 'single_id', $aliasMembership);
+			$aliasInitiator = $qb->completeProbeWithInitiator(CoreQueryBuilder::CIRCLE, 'single_id', $aliasMembership);
 		}
 
 		$qb->andWhere($limit);
+		if (!is_null($aliasInitiator)) {
+			// ensure initiator is not null (desync memberships/members)
+			$qb->filterNull('single_id', alias: $aliasInitiator);
+		}
+
 		$qb->resetSqlPath();
 
 		return $qb;
@@ -513,7 +519,7 @@ class CircleRequest extends CircleRequestBuilder {
 		$qb = $this->getCircleDeleteSql();
 		$qb->limitToUniqueId($circle->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -524,6 +530,6 @@ class CircleRequest extends CircleRequestBuilder {
 		$qb = $this->getCircleDeleteSql();
 		$qb->limitToUniqueId($federatedUser->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 }
