@@ -345,6 +345,30 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		$this->limitInt('file_source', $nodeId);
 	}
 
+	public function limitToFileTarget(string $target, string $alias): void {
+		$this->andWhere(
+			$this->expr()->orX(
+				$this->exprLimit('file_target', $target, $alias),
+				$this->expr()->andX(
+					$this->exprLimitNull('file_target', false, $alias),
+					$this->exprLimit('file_target', $target),
+				),
+			),
+		);
+	}
+
+	public function limitToFileTargetLike(string $target, string $alias): void {
+		$this->andWhere(
+			$this->expr()->orX(
+				$this->exprLike('file_target', $target, $alias),
+				$this->expr()->andX(
+					$this->exprLimitNull('file_target', false, $alias),
+					$this->exprLike('file_target', $target),
+				),
+			),
+		);
+	}
+
 	/**
 	 * @param array $files
 	 */
@@ -798,9 +822,6 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		if (!is_null($initiator)) {
 			$this->leftJoinInitiator($aliasBasedOn, $initiator);
 			$this->leftJoinOwner($aliasBasedOn);
-
-			$aliasInitiatorMemberships = $this->generateAlias($aliasBasedOn, self::MEMBERSHIPS);
-			$this->andWhere($expr->gt($aliasInitiatorMemberships . '.level', $this->createNamedParameter(0, self::PARAM_INT)));
 		}
 	}
 
@@ -1271,15 +1292,15 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		string $alias,
 		string $field = 'single_id',
 		string $helperAlias = '',
-	): void {
+	): ?string {
 		if ($this->getType() !== QueryBuilder::SELECT) {
-			return;
+			return null;
 		}
 
 		try {
 			$aliasInitiator = $this->generateAlias($alias, self::INITIATOR);
 		} catch (RequestBuilderException $e) {
-			return;
+			return null;
 		}
 
 		$helperAlias = ($helperAlias === '') ? $alias : $helperAlias;
@@ -1293,8 +1314,8 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 					$expr->eq($aliasInitiator . '.' . $field, $helperAlias . '.inheritance_first'),
 				)
 			);
-		//
-		//		$this->leftJoinBasedOn($aliasInitiator);
+
+		return $aliasInitiator;
 	}
 
 	/**
@@ -1468,9 +1489,11 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 	 * @param string $aliasShare
 	 * @param string $aliasShareMemberships
 	 *
+	 * @return string the alias generated for the join
+	 *
 	 * @throws RequestBuilderException
 	 */
-	public function leftJoinShareChild(string $aliasShare, string $aliasShareMemberships = '') {
+	public function leftJoinShareChild(string $aliasShare, string $aliasShareMemberships = ''): string {
 		$expr = $this->expr();
 
 		$aliasShareChild = $this->generateAlias($aliasShare, self::SHARE);
@@ -1494,6 +1517,7 @@ class CoreQueryBuilder extends ExtendedQueryBuilder {
 		);
 
 		//		$this->selectAlias($aliasShareParent . '.permissions', 'parent_perms');
+		return $aliasShareChild;
 	}
 
 
