@@ -42,6 +42,8 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		$qb = $this->getShareInsertSql();
 		$qb->setValue('attributes', $qb->createNamedParameter($this->formatShareAttributes($share->getAttributes())))
 			->setValue('share_type', $qb->createNamedParameter($share->getShareType()))
+			->setValue('mail_send', $qb->createNamedParameter($share->getMailSend()))
+			->setValue('note', $qb->createNamedParameter($share->getNote()))
 			->setValue('item_type', $qb->createNamedParameter($share->getNodeType()))
 			->setValue('item_source', $qb->createNamedParameter($share->getNodeId()))
 			->setValue('file_source', $qb->createNamedParameter($share->getNodeId()))
@@ -54,13 +56,13 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			->setValue('password', $qb->createNamedParameter(''))
 			->setValue('permissions', $qb->createNamedParameter($share->getPermissions()))
 			->setValue('token', $qb->createNamedParameter($share->getToken()))
-			->setValue('stime', $qb->createFunction('UNIX_TIMESTAMP()'));
+			->setValue('stime', (string)$qb->createFunction('UNIX_TIMESTAMP()'));
 
 		if ($parentId > 0) {
 			$qb->setValue('parent', $qb->createNamedParameter($parentId));
 		}
 
-		$qb->execute();
+		$qb->executeStatement();
 		$id = $qb->getLastInsertId();
 		try {
 			$share->setId((string)$id);
@@ -90,7 +92,23 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 
 		$qb->limitToId((int)$shareWrapper->getId());
 
-		$qb->execute();
+		$qb->executeStatement();
+	}
+
+	/**
+	 * update permissions and attributes from child
+	 */
+	public function updateChildPermissions(ShareWrapper $shareWrapper): void {
+		$qb = $this->getShareUpdateSql();
+		$shareAttributes = $this->formatShareAttributes($shareWrapper->getAttributes());
+
+		$qb->set('permissions', $qb->createNamedParameter($shareWrapper->getPermissions()))
+			->set('attributes', $qb->createNamedParameter($shareAttributes));
+
+		$qb->limitToShareParent((int)$shareWrapper->getId());
+		$qb->gt('permissions', 0);
+
+		$qb->executeStatement();
 	}
 
 
@@ -102,7 +120,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		$qb->limitToShareWith($membership->getCircleId());
 		$qb->limit('uid_initiator', $membership->getSingleId());
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
@@ -163,6 +181,24 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 	}
 
 
+	/**
+	 * @param string $circleId
+	 * @param FederatedUser|null $shareRecipient
+	 * @param FederatedUser|null $shareInitiator
+	 * @param bool $completeDetails
+	 *
+	 * @return ShareWrapper[]
+	 * @throws RequestBuilderException
+	 */
+	public function getSharesToCircles(array $circleIds): array {
+		$qb = $this->getShareSelectSql();
+		$qb->limitNull('parent', false);
+		$qb->expr()->in('share_with', $qb->createNamedParameter($circleIds, IQueryBuilder::PARAM_STR_ARRAY));
+		return $this->getItemsFromRequest($qb);
+	}
+
+
+
 	/**
 	 * @param int $shareId
 	 * @param FederatedUser|null $federatedUser
@@ -323,6 +359,46 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		return $this->getItemsFromRequest($qb);
 	}
 
+	public function getSharedWithByPath(
+		FederatedUser $federatedUser,
+		string $path,
+		bool $forChildren,
+		CircleProbe $probe,
+	): array {
+		$qb = $this->getShareSelectSql();
+		$qb->setOptions(
+			[CoreQueryBuilder::SHARE],
+			array_merge(
+				$probe->getAsOptions(),
+				['getData' => true]
+			)
+		);
+
+		$qb->leftJoinCircle(CoreQueryBuilder::SHARE, null, 'share_with');
+
+		$aliasCircle = $qb->generateAlias(CoreQueryBuilder::SHARE, CoreQueryBuilder::CIRCLE);
+		$qb->limitToFederatedUserMemberships(CoreQueryBuilder::SHARE, $aliasCircle, $federatedUser);
+
+		$qb->leftJoinFileCache(CoreQueryBuilder::SHARE);
+		$qb->limitNull('parent', false);
+		$childAlias = $qb->leftJoinShareChild(CoreQueryBuilder::SHARE);
+
+		if ($forChildren) {
+			$userId = $federatedUser->getUserId();
+			$path = str_replace('/' . $userId . '/files', '', $path);
+			$path = rtrim($path, '/');
+			$childPathTemplate = $this->getQueryBuilder()->getConnection()->escapeLikeParameter($path) . '/_%';
+
+			$qb->limitToFileTargetLike($childPathTemplate, $childAlias);
+		} else {
+			$nonChildPath = $path === '' ? '/' : $path;
+			$qb->limitToFileTarget($nonChildPath, $childAlias);
+		}
+
+		$qb->chunk($probe->getItemsOffset(), $probe->getItemsLimit());
+
+		return $this->getItemsFromRequest($qb);
+	}
 
 	/**
 	 * @param FederatedUser $federatedUser
@@ -439,7 +515,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			)
 		);
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 	/**
@@ -476,7 +552,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 		$qb->limitNull('id', false, 'p');
 
 		$ids = [];
-		$cursor = $qb->execute();
+		$cursor = $qb->executeQuery();
 		while ($data = $cursor->fetch()) {
 			$ids[] = $data['id'];
 		}
@@ -498,7 +574,7 @@ class ShareWrapperRequest extends ShareWrapperRequestBuilder {
 			)
 		);
 
-		$qb->execute();
+		$qb->executeStatement();
 	}
 
 
