@@ -51,6 +51,8 @@ use OCA\Circles\Tools\Traits\TArrayTools;
 use OCA\Circles\Tools\Traits\TDeserialize;
 use OCA\Circles\Tools\Traits\TNCLogger;
 use OCA\Circles\Tools\Traits\TStringTools;
+use OCA\Files_Sharing\Event\UserShareAccessUpdatedEvent;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\ICache;
 use OCP\ICacheFactory;
 use OCP\IL10N;
@@ -124,6 +126,7 @@ class CircleService {
 		MemberService $memberService,
 		PermissionService $permissionService,
 		ConfigService $configService,
+		private readonly IEventDispatcher $eventDispatcher,
 	) {
 		$this->l10n = $l10n;
 		$this->hasher = $hasher;
@@ -363,6 +366,17 @@ class CircleService {
 		return $event->getOutcome();
 	}
 
+	public function updateDisplayName(string $circleId, string $displayName): array {
+		$circle = $this->getCircle($circleId);
+
+		$event = new FederatedEvent(CircleEdit::class);
+		$event->setCircle($circle);
+		$event->setParams(new SimpleDataStore(['displayName' => $displayName]));
+		$this->federatedEventService->newEvent($event);
+
+		return $event->getOutcome();
+	}
+
 	/**
 	 * @param string $circleId
 	 * @param string $description
@@ -411,6 +425,8 @@ class CircleService {
 	 */
 	public function circleJoin(string $circleId): array {
 		$this->federatedUserService->mustHaveCurrentUser();
+		/** @var FederatedUser $currentUser */
+		$currentUser = $this->federatedUserService->getCurrentUser();
 
 		$probe = new CircleProbe();
 		$probe->includeNonVisibleCircles()
@@ -418,7 +434,7 @@ class CircleService {
 
 		$circle = $this->circleRequest->getCircle(
 			$circleId,
-			$this->federatedUserService->getCurrentUser(),
+			$currentUser,
 			$probe
 		);
 
@@ -431,6 +447,8 @@ class CircleService {
 
 		$this->federatedEventService->newEvent($event);
 
+		$this->eventDispatcher->dispatchTyped(new UserShareAccessUpdatedEvent($this->memberService->collectShareAccessUpdateUsers($currentUser)));
+
 		return $event->getOutcome();
 	}
 
@@ -454,6 +472,8 @@ class CircleService {
 	 */
 	public function circleLeave(string $circleId, bool $force = false): array {
 		$this->federatedUserService->mustHaveCurrentUser();
+		/** @var FederatedUser $currentUser */
+		$currentUser = $this->federatedUserService->getCurrentUser();
 
 		$probe = new CircleProbe();
 		$probe->includeNonVisibleCircles()
@@ -461,7 +481,7 @@ class CircleService {
 
 		$circle = $this->circleRequest->getCircle(
 			$circleId,
-			$this->federatedUserService->getCurrentUser(),
+			$currentUser,
 			$probe
 		);
 
@@ -471,10 +491,11 @@ class CircleService {
 
 		$this->federatedEventService->newEvent($event);
 
+		$this->eventDispatcher->dispatchTyped(new UserShareAccessUpdatedEvent($this->memberService->collectShareAccessUpdateUsers($currentUser)));
+
 		return $event->getOutcome();
 	}
 
-
 	/**
 	 * @param string $circleId
 	 * @param CircleProbe|null $probe
@@ -800,4 +821,19 @@ class CircleService {
 			$dataProbe
 		);
 	}
+
+	/**
+	 * @return Circle[]
+	 */
+	public function probeCirclesByIds(array $ids, ?DataProbe $dataProbe = null): array {
+		if (empty($ids)) {
+			return [];
+		}
+		$this->federatedUserService->mustHaveCurrentUser();
+		return $this->circleRequest->probeCirclesByIds(
+			$this->federatedUserService->getCurrentUser(),
+			$ids,
+			$dataProbe ?? new DataProbe()
+		);
+	}
 }
