@@ -11,6 +11,7 @@ declare(strict_types=1);
 namespace OCA\Circles\Service;
 
 use OC;
+use OCA\Circles\ConfigLexicon;
 use OCA\Circles\Db\EventWrapperRequest;
 use OCA\Circles\Db\MemberRequest;
 use OCA\Circles\Db\RemoteRequest;
@@ -53,6 +54,8 @@ use OCA\Circles\Tools\Model\NCRequest;
 use OCA\Circles\Tools\Model\Request;
 use OCA\Circles\Tools\Traits\TNCRequest;
 use OCA\Circles\Tools\Traits\TStringTools;
+use OCP\AppFramework\Services\IAppConfig;
+use OCP\Server;
 use ReflectionClass;
 use ReflectionException;
 
@@ -65,64 +68,19 @@ class FederatedEventService extends NCSignature {
 	use TNCRequest;
 	use TStringTools;
 
-
-	/** @var EventWrapperRequest */
-	private $eventWrapperRequest;
-
-	/** @var RemoteRequest */
-	private $remoteRequest;
-
-	/** @var ShareLockRequest */
-	private $shareLockRequest;
-
-	/** @var MemberRequest */
-	private $memberRequest;
-
-	/** @var RemoteUpstreamService */
-	private $remoteUpstreamService;
-
-	/** @var EventService */
-	private $eventService;
-
-	/** @var InterfaceService */
-	private $interfaceService;
-
-	/** @var ConfigService */
-	private $configService;
-
-
-	/**
-	 * FederatedEventService constructor.
-	 *
-	 * @param EventWrapperRequest $eventWrapperRequest
-	 * @param RemoteRequest $remoteRequest
-	 * @param MemberRequest $memberRequest
-	 * @param ShareLockRequest $shareLockRequest
-	 * @param RemoteUpstreamService $remoteUpstreamService
-	 * @param InterfaceService $interfaceService
-	 * @param ConfigService $configService
-	 */
 	public function __construct(
-		EventWrapperRequest $eventWrapperRequest,
-		RemoteRequest $remoteRequest,
-		MemberRequest $memberRequest,
-		ShareLockRequest $shareLockRequest,
-		RemoteUpstreamService $remoteUpstreamService,
-		EventService $eventService,
-		InterfaceService $interfaceService,
-		ConfigService $configService,
+		private readonly IAppConfig $appConfig,
+		private readonly EventWrapperRequest $eventWrapperRequest,
+		private readonly RemoteRequest $remoteRequest,
+		private readonly MemberRequest $memberRequest,
+		private readonly ShareLockRequest $shareLockRequest,
+		private readonly RemoteUpstreamService $remoteUpstreamService,
+		private readonly EventService $eventService,
+		private readonly InterfaceService $interfaceService,
+		private readonly ConfigService $configService,
 	) {
-		$this->eventWrapperRequest = $eventWrapperRequest;
-		$this->remoteRequest = $remoteRequest;
-		$this->shareLockRequest = $shareLockRequest;
-		$this->memberRequest = $memberRequest;
-		$this->remoteUpstreamService = $remoteUpstreamService;
-		$this->eventService = $eventService;
-		$this->interfaceService = $interfaceService;
-		$this->configService = $configService;
 	}
 
-
 	/**
 	 * Called when creating a new Event.
 	 * This method will manage the event locally and upstream the payload if needed.
@@ -224,7 +182,7 @@ class FederatedEventService extends NCSignature {
 
 		if (!$event->canBypass(FederatedEvent::BYPASS_INITIATORMEMBERSHIP)
 			&& $circle->getInitiator()->getLevel() < Member::LEVEL_MEMBER) {
-			throw new InitiatorNotConfirmedException('Initiator must be a member of the Circle');
+			throw new InitiatorNotConfirmedException('Initiator must be a member of the Team');
 		}
 	}
 
@@ -248,7 +206,7 @@ class FederatedEventService extends NCSignature {
 			throw new FederatedEventException($class . ' does not implements IFederatedItem');
 		}
 
-		$item = OC::$server->get($class);
+		$item = Server::get($class);
 		if (!($item instanceof IFederatedItem)) {
 			throw new FederatedEventException($class . ' not an IFederatedItem');
 		}
@@ -396,9 +354,11 @@ class FederatedEventService extends NCSignature {
 		$wrapper->setCreation(time());
 		$wrapper->setSeverity($event->getSeverity());
 
+		$avoidDuplicate = [];
 		if ($event->isAsync()) {
 			$wrapper->setInstance($this->configService->getLoopbackInstance());
 			$this->eventWrapperRequest->save($wrapper);
+			$avoidDuplicate[] = $this->configService->getLoopbackInstance();
 		}
 
 		foreach ($instances as $instance) {
@@ -406,9 +366,20 @@ class FederatedEventService extends NCSignature {
 				break;
 			}
 
+			if ($instance->getInterface() === InterfaceService::IFACE_FRONTAL &&
+				!$this->appConfig->getAppValueBool(ConfigLexicon::FEDERATED_TEAMS_ENABLED)) {
+				break;
+			}
+
+			if (in_array($instance->getInstance(), $avoidDuplicate, true)) {
+				Server::get(\Psr\Log\LoggerInterface::class)->warning('duplicate instance, please verify the setup of Federated Teams', ['duplicate' => $avoidDuplicate, 'loopback' => $this->configService->getLoopbackInstance(), 'instance' => $instance->getInstance(), 'interface' => $instance->getInterface()]);
+				continue;
+			}
+
 			$wrapper->setInstance($instance->getInstance());
 			$wrapper->setInterface($instance->getInterface());
 			$this->eventWrapperRequest->save($wrapper);
+			$avoidDuplicate[] = $wrapper->getInstance();
 		}
 
 		$request = new NCRequest('', Request::TYPE_POST);
