@@ -56,8 +56,10 @@ use OCP\IUserManager;
 use OCP\Share\Exceptions\AlreadySharedException;
 use OCP\Share\Exceptions\IllegalIDChangeException;
 use OCP\Share\Exceptions\ShareNotFound;
+use OCP\Share\IPartialShareProvider;
 use OCP\Share\IShare;
 use OCP\Share\IShareProvider;
+use OCP\Share\IShareProviderGetUsers;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -65,7 +67,7 @@ use Psr\Log\LoggerInterface;
  *
  * @package OCA\Circles
  */
-class ShareByCircleProvider implements IShareProvider {
+class ShareByCircleProvider implements IShareProvider, IPartialShareProvider, IShareProviderGetUsers {
 	use TArrayTools;
 	use TStringTools;
 	use TNCLogger;
@@ -497,7 +499,12 @@ class ShareByCircleProvider implements IShareProvider {
 			return [];
 		}
 
-		$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
+		try {
+			$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
+		} catch (FederatedUserNotFoundException) {
+			return [];
+		}
+
 		$probe = new CircleProbe();
 		$probe->includePersonalCircles()
 			->includeSystemCircles()
@@ -522,6 +529,44 @@ class ShareByCircleProvider implements IShareProvider {
 		);
 	}
 
+	public function getSharedWithByPath(
+		string $userId,
+		int $shareType,
+		string $path,
+		bool $forChildren,
+		int $limit,
+		int $offset,
+	): iterable {
+		if ($shareType !== IShare::TYPE_CIRCLE) {
+			return [];
+		}
+
+		$federatedUser = $this->federatedUserService->getLocalFederatedUser($userId);
+		$probe = new CircleProbe();
+		$probe->includePersonalCircles()
+			->includeSystemCircles()
+			->mustBeMember()
+			->setItemsLimit($limit)
+			->setItemsOffset($offset);
+
+		$wrappedShares = $this->shareWrapperService->getSharedWithByPath(
+			$federatedUser,
+			$path,
+			$forChildren,
+			$probe,
+		);
+
+		/** @var array<string, IShare> */
+		return array_filter(
+			array_map(
+				function (ShareWrapper $wrapper) {
+					return $wrapper->getShare(
+						$this->rootFolder, $this->userManager, $this->urlGenerator, true
+					);
+				}, $wrappedShares
+			)
+		);
+	}
 
 	/**
 	 * @param string $token
@@ -791,7 +836,7 @@ class ShareByCircleProvider implements IShareProvider {
 		//				  )
 		//		   );
 		//
-		//		$cursor = $qb->execute();
+		//		$cursor = $qb->executeQuery();
 		//		while ($data = $cursor->fetch()) {
 		//			try {
 		//				yield $this->createShareObject($data);
@@ -801,4 +846,13 @@ class ShareByCircleProvider implements IShareProvider {
 		//		$cursor->closeCursor();
 		return [];
 	}
+
+	public function getUsersForShare(IShare $share): iterable {
+		$members = $this->shareWrapperService->getShareById((int)$share->getId())->getCircle()->getInheritedMembers();
+		foreach ($members as $member) {
+			if ($member->getUserType() === Member::TYPE_USER) {
+				yield $this->userManager->getExistingUser($member->getUserId());
+			}
+		}
+	}
 }
