@@ -18,10 +18,12 @@ use OCA\DAV\CalDAV\Reminder\NotificationProvider\AudioProvider;
 use OCA\DAV\CalDAV\Reminder\NotificationProvider\EmailProvider;
 use OCA\DAV\CalDAV\Reminder\NotificationProvider\PushProvider;
 use OCA\DAV\CalDAV\Reminder\NotificationProviderManager;
-use OCA\DAV\CalDAV\Reminder\Notifier;
+use OCA\DAV\CalDAV\Reminder\Notifier as NotifierCalDAV;
 use OCA\DAV\Capabilities;
 use OCA\DAV\CardDAV\ContactsManager;
+use OCA\DAV\CardDAV\Notification\Notifier as NotifierCardDAV;
 use OCA\DAV\CardDAV\SyncService;
+use OCA\DAV\ConfigLexicon;
 use OCA\DAV\Events\AddressBookCreatedEvent;
 use OCA\DAV\Events\AddressBookDeletedEvent;
 use OCA\DAV\Events\AddressBookShareUpdatedEvent;
@@ -64,6 +66,7 @@ use OCA\DAV\Search\EventsSearchProvider;
 use OCA\DAV\Search\TasksSearchProvider;
 use OCA\DAV\Settings\Admin\SystemAddressBookSettings;
 use OCA\DAV\SetupChecks\NeedsSystemAddressBookSync;
+use OCA\DAV\SetupChecks\SystemAddressBookSize;
 use OCA\DAV\SetupChecks\WebdavEndpoint;
 use OCA\DAV\UserMigration\CalendarMigrator;
 use OCA\DAV\UserMigration\ContactsMigrator;
@@ -73,7 +76,6 @@ use OCP\AppFramework\App;
 use OCP\AppFramework\Bootstrap\IBootContext;
 use OCP\AppFramework\Bootstrap\IBootstrap;
 use OCP\AppFramework\Bootstrap\IRegistrationContext;
-use OCP\AppFramework\IAppContainer;
 use OCP\Calendar\Events\CalendarObjectCreatedEvent;
 use OCP\Calendar\Events\CalendarObjectDeletedEvent;
 use OCP\Calendar\Events\CalendarObjectMovedEvent;
@@ -87,6 +89,8 @@ use OCP\Contacts\IManager as IContactsManager;
 use OCP\DB\Events\AddMissingIndicesEvent;
 use OCP\Federation\Events\TrustedServerRemovedEvent;
 use OCP\Federation\ICloudFederationProviderManager;
+use OCP\Group\Events\GroupDeletedEvent;
+use OCP\IURLGenerator;
 use OCP\IUserSession;
 use OCP\Server;
 use OCP\Settings\Events\DeclarativeSettingsGetValueEvent;
@@ -202,6 +206,7 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(UserCreatedEvent::class, UserEventsListener::class);
 		$context->registerEventListener(UserChangedEvent::class, UserEventsListener::class);
 		$context->registerEventListener(UserUpdatedEvent::class, UserEventsListener::class);
+		$context->registerEventListener(GroupDeletedEvent::class, UserEventsListener::class);
 
 		$context->registerEventListener(SabrePluginAuthInitEvent::class, SabrePluginAuthInitListener::class);
 
@@ -209,7 +214,8 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(CalendarObjectUpdatedEvent::class, CalendarFederationNotificationListener::class);
 		$context->registerEventListener(CalendarObjectDeletedEvent::class, CalendarFederationNotificationListener::class);
 
-		$context->registerNotifierService(Notifier::class);
+		$context->registerNotifierService(NotifierCalDAV::class);
+		$context->registerNotifierService(NotifierCardDAV::class);
 
 		$context->registerCalendarProvider(CalendarProvider::class);
 		$context->registerCalendarProvider(CachedSubscriptionProvider::class);
@@ -218,12 +224,15 @@ class Application extends App implements IBootstrap {
 		$context->registerUserMigrator(ContactsMigrator::class);
 
 		$context->registerSetupCheck(NeedsSystemAddressBookSync::class);
+		$context->registerSetupCheck(SystemAddressBookSize::class);
 		$context->registerSetupCheck(WebdavEndpoint::class);
 
 		// register admin settings form and listener(s)
 		$context->registerDeclarativeSettings(SystemAddressBookSettings::class);
 		$context->registerEventListener(DeclarativeSettingsGetValueEvent::class, DavAdminSettingsListener::class);
 		$context->registerEventListener(DeclarativeSettingsSetValueEvent::class, DavAdminSettingsListener::class);
+
+		$context->registerConfigLexicon(ConfigLexicon::class);
 	}
 
 	public function boot(IBootContext $context): void {
@@ -236,7 +245,7 @@ class Application extends App implements IBootstrap {
 		$context->injectFn($this->registerCloudFederationProvider(...));
 	}
 
-	public function registerContactsManager(IContactsManager $cm, IAppContainer $container): void {
+	public function registerContactsManager(IContactsManager $cm, ContainerInterface $container): void {
 		$cm->register(function () use ($container, $cm): void {
 			$user = Server::get(IUserSession::class)->getUser();
 			if (!is_null($user)) {
@@ -248,23 +257,21 @@ class Application extends App implements IBootstrap {
 	}
 
 	private function setupContactsProvider(IContactsManager $contactsManager,
-		IAppContainer $container,
+		ContainerInterface $container,
 		string $userID): void {
-		/** @var ContactsManager $cm */
-		$cm = $container->query(ContactsManager::class);
-		$urlGenerator = $container->getServer()->getURLGenerator();
+		$cm = $container->get(ContactsManager::class);
+		$urlGenerator = $container->get(IURLGenerator::class);
 		$cm->setupContactsProvider($contactsManager, $userID, $urlGenerator);
 	}
 
-	private function setupSystemContactsProvider(IContactsManager $contactsManager, IAppContainer $container): void {
-		/** @var ContactsManager $cm */
-		$cm = $container->query(ContactsManager::class);
-		$urlGenerator = $container->getServer()->getURLGenerator();
+	private function setupSystemContactsProvider(IContactsManager $contactsManager, ContainerInterface $container): void {
+		$cm = $container->get(ContactsManager::class);
+		$urlGenerator = $container->get(IURLGenerator::class);
 		$cm->setupSystemContactsProvider($contactsManager, null, $urlGenerator);
 	}
 
 	public function registerCalendarManager(ICalendarManager $calendarManager,
-		IAppContainer $container): void {
+		ContainerInterface $container): void {
 		$calendarManager->register(function () use ($container, $calendarManager): void {
 			$user = Server::get(IUserSession::class)->getUser();
 			if ($user !== null) {
@@ -274,9 +281,9 @@ class Application extends App implements IBootstrap {
 	}
 
 	private function setupCalendarProvider(ICalendarManager $calendarManager,
-		IAppContainer $container,
-		$userId) {
-		$cm = $container->query(CalendarManager::class);
+		ContainerInterface $container,
+		$userId): void {
+		$cm = $container->get(CalendarManager::class);
 		$cm->setupCalendarProvider($calendarManager, $userId);
 	}
 
