@@ -69,9 +69,8 @@ class ViewOnlyPlugin extends ServerPlugin {
 				// The version source file is relative to the owner storage.
 				// But we need the node from the current user perspective.
 				if ($node->getOwner()->getUID() !== $currentUserId) {
-					$nodes = $this->userFolder->getById($node->getId());
-					$node = array_pop($nodes);
-					if (!$node) {
+					$node = $this->userFolder->getFirstNodeById($node->getId());
+					if ($node === null) {
 						throw new NotFoundException('Version file not accessible by current user');
 					}
 				}
