@@ -1,17 +1,22 @@
 <?php
 
+declare(strict_types=1);
+
 /**
  * SPDX-FileCopyrightText: 2017-2024 Nextcloud GmbH and Nextcloud contributors
  * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
  * SPDX-License-Identifier: AGPL-3.0-only
  */
+
 namespace OCA\Encryption\Crypto;
 
 use OC\Encryption\Exceptions\DecryptionFailedException;
+use OC\Files\SetupManager;
 use OC\Files\View;
 use OCA\Encryption\KeyManager;
 use OCA\Encryption\Users\Setup;
 use OCA\Encryption\Util;
+use OCP\Files\FileInfo;
 use OCP\IConfig;
 use OCP\IL10N;
 use OCP\IUser;
@@ -30,40 +35,32 @@ use Symfony\Component\Console\Question\ConfirmationQuestion;
 
 class EncryptAll {
 
-	/** @var array */
-	protected $userPasswords;
-
-	/** @var OutputInterface */
-	protected $output;
-
-	/** @var InputInterface */
-	protected $input;
+	/** @var array<string, array{password: string, user: IUser}> $userCache store one time passwords for the users */
+	protected array $userCache = [];
+	protected OutputInterface $output;
+	protected InputInterface $input;
 
 	public function __construct(
-		protected Setup $userSetup,
-		protected IUserManager $userManager,
-		protected View $rootView,
-		protected KeyManager $keyManager,
-		protected Util $util,
-		protected IConfig $config,
-		protected IMailer $mailer,
-		protected IL10N $l,
-		protected IFactory $l10nFactory,
-		protected QuestionHelper $questionHelper,
-		protected ISecureRandom $secureRandom,
-		protected LoggerInterface $logger,
+		protected readonly Setup $userSetup,
+		protected readonly IUserManager $userManager,
+		protected readonly View $rootView,
+		protected readonly KeyManager $keyManager,
+		protected readonly Util $util,
+		protected readonly IConfig $config,
+		protected readonly IMailer $mailer,
+		protected readonly IL10N $l,
+		protected readonly IFactory $l10nFactory,
+		protected readonly QuestionHelper $questionHelper,
+		protected readonly ISecureRandom $secureRandom,
+		protected readonly LoggerInterface $logger,
+		protected readonly SetupManager $setupManager,
 	) {
-		// store one time passwords for the users
-		$this->userPasswords = [];
 	}
 
 	/**
 	 * start to encrypt all files
-	 *
-	 * @param InputInterface $input
-	 * @param OutputInterface $output
 	 */
-	public function encryptAll(InputInterface $input, OutputInterface $output) {
+	public function encryptAll(InputInterface $input, OutputInterface $output): void {
 		$this->input = $input;
 		$this->output = $output;
 
@@ -110,32 +107,24 @@ class EncryptAll {
 	/**
 	 * create key-pair for every user
 	 */
-	protected function createKeyPairs() {
+	protected function createKeyPairs(): void {
 		$this->output->writeln("\n");
 		$progress = new ProgressBar($this->output);
 		$progress->setFormat(" %message% \n [%bar%]");
 		$progress->start();
 
-		foreach ($this->userManager->getBackends() as $backend) {
-			$limit = 500;
-			$offset = 0;
-			do {
-				$users = $backend->getUsers('', $limit, $offset);
-				foreach ($users as $user) {
-					if ($this->keyManager->userHasKeys($user) === false) {
-						$progress->setMessage('Create key-pair for ' . $user);
-						$progress->advance();
-						$this->setupUserFS($user);
-						$password = $this->generateOneTimePassword($user);
-						$this->userSetup->setupUser($user, $password);
-					} else {
-						// users which already have a key-pair will be stored with a
-						// empty password and filtered out later
-						$this->userPasswords[$user] = '';
-					}
-				}
-				$offset += $limit;
-			} while (count($users) >= $limit);
+		foreach ($this->userManager->getSeenUsers() as $user) {
+			if ($this->keyManager->userHasKeys($user->getUID()) === false) {
+				$progress->setMessage('Create key-pair for ' . $user->getUID());
+				$progress->advance();
+				$this->setupUserFileSystem($user);
+				$password = $this->generateOneTimePassword($user);
+				$this->userSetup->setupUser($user->getUID(), $password);
+			} else {
+				// users which already have a key-pair will be stored with a
+				// empty password and filtered out later
+				$this->userCache[$user->getUID()] = ['password' => '', 'user' => $user];
+			}
 		}
 
 		$progress->setMessage('Key-pair created for all users');
@@ -145,19 +134,20 @@ class EncryptAll {
 	/**
 	 * iterate over all user and encrypt their files
 	 */
-	protected function encryptAllUsersFiles() {
+	protected function encryptAllUsersFiles(): void {
 		$this->output->writeln("\n");
 		$progress = new ProgressBar($this->output);
 		$progress->setFormat(" %message% \n [%bar%]");
 		$progress->start();
-		$numberOfUsers = count($this->userPasswords);
+		$numberOfUsers = count($this->userCache);
 		$userNo = 1;
 		if ($this->util->isMasterKeyEnabled()) {
 			$this->encryptAllUserFilesWithMasterKey($progress);
 		} else {
-			foreach ($this->userPasswords as $uid => $password) {
+			foreach ($this->userCache as $uid => $cache) {
+				['user' => $user, 'password' => $password] = $cache;
 				$userCount = "$uid ($userNo of $numberOfUsers)";
-				$this->encryptUsersFiles($uid, $progress, $userCount);
+				$this->encryptUsersFiles($user, $progress, $userCount);
 				$userNo++;
 			}
 		}
@@ -167,50 +157,41 @@ class EncryptAll {
 
 	/**
 	 * encrypt all user files with the master key
-	 *
-	 * @param ProgressBar $progress
 	 */
-	protected function encryptAllUserFilesWithMasterKey(ProgressBar $progress) {
+	protected function encryptAllUserFilesWithMasterKey(ProgressBar $progress): void {
 		$userNo = 1;
-		foreach ($this->userManager->getBackends() as $backend) {
-			$limit = 500;
-			$offset = 0;
-			do {
-				$users = $backend->getUsers('', $limit, $offset);
-				foreach ($users as $user) {
-					$userCount = "$user ($userNo)";
-					$this->encryptUsersFiles($user, $progress, $userCount);
-					$userNo++;
-				}
-				$offset += $limit;
-			} while (count($users) >= $limit);
+		foreach ($this->userManager->getSeenUsers() as $user) {
+			$userCount = $user->getUID() . " ($userNo)";
+			$this->encryptUsersFiles($user, $progress, $userCount);
+			$userNo++;
 		}
 	}
 
 	/**
 	 * encrypt files from the given user
-	 *
-	 * @param string $uid
-	 * @param ProgressBar $progress
-	 * @param string $userCount
 	 */
-	protected function encryptUsersFiles($uid, ProgressBar $progress, $userCount) {
-		$this->setupUserFS($uid);
+	protected function encryptUsersFiles(IUser $user, ProgressBar $progress, string $userCount): void {
+		$this->setupUserFileSystem($user);
+		$uid = $user->getUID();
 		$directories = [];
 		$directories[] = '/' . $uid . '/files';
 
 		while ($root = array_pop($directories)) {
 			$content = $this->rootView->getDirectoryContent($root);
 			foreach ($content as $file) {
-				$path = $root . '/' . $file['name'];
-				if ($this->rootView->is_dir($path)) {
+				$path = $root . '/' . $file->getName();
+				if ($file->isShared()) {
+					$progress->setMessage("Skip shared file/folder $path");
+					$progress->advance();
+					continue;
+				} elseif ($file->getType() === FileInfo::TYPE_FOLDER) {
 					$directories[] = $path;
 					continue;
 				} else {
 					$progress->setMessage("encrypt files for user $userCount: $path");
 					$progress->advance();
 					try {
-						if ($this->encryptFile($path) === false) {
+						if ($this->encryptFile($file, $path) === false) {
 							$progress->setMessage("encrypt files for user $userCount: $path (already encrypted)");
 							$progress->advance();
 						}
@@ -231,17 +212,9 @@ class EncryptAll {
 		}
 	}
 
-	/**
-	 * encrypt file
-	 *
-	 * @param string $path
-	 * @return bool
-	 */
-	protected function encryptFile($path) {
-
+	protected function encryptFile(FileInfo $fileInfo, string $path): bool {
 		// skip already encrypted files
-		$fileInfo = $this->rootView->getFileInfo($path);
-		if ($fileInfo !== false && $fileInfo->isEncrypted()) {
+		if ($fileInfo->isEncrypted()) {
 			return true;
 		}
 
@@ -271,14 +244,15 @@ class EncryptAll {
 	/**
 	 * output one-time encryption passwords
 	 */
-	protected function outputPasswords() {
+	protected function outputPasswords(): void {
 		$table = new Table($this->output);
 		$table->setHeaders(['Username', 'Private key password']);
 
 		//create rows
 		$newPasswords = [];
 		$unchangedPasswords = [];
-		foreach ($this->userPasswords as $uid => $password) {
+		foreach ($this->userCache as $uid => $cache) {
+			['user' => $user, 'password' => $password] = $cache;
 			if (empty($password)) {
 				$unchangedPasswords[] = $uid;
 			} else {
@@ -304,7 +278,7 @@ class EncryptAll {
 		$this->writePasswordsToFile($newPasswords);
 
 		$this->output->writeln('');
-		$question = new ConfirmationQuestion('Do you want to send the passwords directly to the users by mail? (y/n) ', false);
+		$question = new ConfirmationQuestion('Do you want to send the passwords directly to the users by mail? (y/n) ', true);
 		if ($this->questionHelper->ask($this->input, $this->output, $question)) {
 			$this->sendPasswordsByMail();
 		}
@@ -312,10 +286,8 @@ class EncryptAll {
 
 	/**
 	 * write one-time encryption passwords to a csv file
-	 *
-	 * @param array $passwords
 	 */
-	protected function writePasswordsToFile(array $passwords) {
+	protected function writePasswordsToFile(array $passwords): void {
 		$fp = $this->rootView->fopen('oneTimeEncryptionPasswords.csv', 'w');
 		foreach ($passwords as $pwd) {
 			fputcsv($fp, $pwd);
@@ -333,37 +305,35 @@ class EncryptAll {
 
 	/**
 	 * setup user file system
-	 *
-	 * @param string $uid
 	 */
-	protected function setupUserFS($uid) {
-		\OC_Util::tearDownFS();
-		\OC_Util::setupFS($uid);
+	protected function setupUserFileSystem(IUser $user): void {
+		$this->setupManager->tearDown();
+		$this->setupManager->setupForUser($user);
 	}
 
 	/**
 	 * generate one time password for the user and store it in a array
 	 *
-	 * @param string $uid
 	 * @return string password
 	 */
-	protected function generateOneTimePassword($uid) {
+	protected function generateOneTimePassword(IUser $user): string {
 		$password = $this->secureRandom->generate(16, ISecureRandom::CHAR_HUMAN_READABLE);
-		$this->userPasswords[$uid] = $password;
+		$this->userCache[$user->getUID()] = ['password' => $password, 'user' => $user];
 		return $password;
 	}
 
 	/**
 	 * send encryption key passwords to the users by mail
 	 */
-	protected function sendPasswordsByMail() {
+	protected function sendPasswordsByMail(): void {
 		$noMail = [];
 
 		$this->output->writeln('');
-		$progress = new ProgressBar($this->output, count($this->userPasswords));
+		$progress = new ProgressBar($this->output, count($this->userCache));
 		$progress->start();
 
-		foreach ($this->userPasswords as $uid => $password) {
+		foreach ($this->userCache as $uid => $cache) {
+			['user' => $user, 'password' => $password] = $cache;
 			$progress->advance();
 			if (!empty($password)) {
 				$recipient = $this->userManager->get($uid);
@@ -423,7 +393,7 @@ class EncryptAll {
 			$this->output->writeln("\n\nCould not send password to following users:\n");
 			$rows = [];
 			foreach ($noMail as $uid) {
-				$rows[] = [$uid, $this->userPasswords[$uid]];
+				$rows[] = [$uid, $this->userCache[$uid]['password']];
 			}
 			$table->setRows($rows);
 			$table->render();
