@@ -30,7 +30,7 @@ class Version1011Date20201120125158 extends SimpleMigrationStep {
 		if ($schema->hasTable('federated_reshares')) {
 			$table = $schema->getTable('federated_reshares');
 			$remoteIdColumn = $table->getColumn('remote_id');
-			if ($remoteIdColumn && $remoteIdColumn->getType()->getName() !== Types::STRING) {
+			if ($remoteIdColumn && Type::lookupName($remoteIdColumn->getType()) !== Types::STRING) {
 				$remoteIdColumn->setNotnull(false);
 				$remoteIdColumn->setType(Type::getType(Types::STRING));
 				$remoteIdColumn->setOptions(['length' => 255]);
@@ -47,6 +47,6 @@ class Version1011Date20201120125158 extends SimpleMigrationStep {
 		$qb->update('federated_reshares')
 			->set('remote_id', $qb->createNamedParameter(''))
 			->where($qb->expr()->eq('remote_id', $qb->createNamedParameter('-1')));
-		$qb->execute();
+		$qb->executeStatement();
 	}
 }
