@@ -6,18 +6,20 @@
  */
 namespace OCA\FederatedFileSharing\OCM;
 
-use NCU\Federation\ISignedCloudFederationProvider;
 use OC\AppFramework\Http;
 use OC\Files\Filesystem;
+use OC\Files\SetupManager;
 use OCA\FederatedFileSharing\AddressHandler;
 use OCA\FederatedFileSharing\FederatedShareProvider;
 use OCA\Federation\TrustedServers;
 use OCA\Files_Sharing\Activity\Providers\RemoteShares;
+use OCA\Files_Sharing\External\ExternalShare;
+use OCA\Files_Sharing\External\ExternalShareMapper;
 use OCA\Files_Sharing\External\Manager;
 use OCA\GlobalSiteSelector\Service\SlaveService;
+use OCA\Polls\Db\Share;
 use OCP\Activity\IManager as IActivityManager;
 use OCP\App\IAppManager;
-use OCP\AppFramework\QueryException;
 use OCP\Constants;
 use OCP\Federation\Exceptions\ActionNotSupportedException;
 use OCP\Federation\Exceptions\AuthenticationFailedException;
@@ -27,13 +29,14 @@ use OCP\Federation\ICloudFederationFactory;
 use OCP\Federation\ICloudFederationProviderManager;
 use OCP\Federation\ICloudFederationShare;
 use OCP\Federation\ICloudIdManager;
+use OCP\Federation\ISignedCloudFederationProvider;
 use OCP\Files\IFilenameValidator;
 use OCP\Files\NotFoundException;
 use OCP\HintException;
 use OCP\IConfig;
-use OCP\IDBConnection;
 use OCP\IGroupManager;
 use OCP\IURLGenerator;
+use OCP\IUser;
 use OCP\IUserManager;
 use OCP\Notification\IManager as INotificationManager;
 use OCP\Server;
@@ -42,54 +45,41 @@ use OCP\Share\IManager;
 use OCP\Share\IProviderFactory;
 use OCP\Share\IShare;
 use OCP\Util;
+use Override;
 use Psr\Log\LoggerInterface;
 use SensitiveParameter;
 
 class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
-	/**
-	 * CloudFederationProvider constructor.
-	 */
 	public function __construct(
-		private IAppManager $appManager,
-		private FederatedShareProvider $federatedShareProvider,
-		private AddressHandler $addressHandler,
-		private IUserManager $userManager,
-		private IManager $shareManager,
-		private ICloudIdManager $cloudIdManager,
-		private IActivityManager $activityManager,
-		private INotificationManager $notificationManager,
-		private IURLGenerator $urlGenerator,
-		private ICloudFederationFactory $cloudFederationFactory,
-		private ICloudFederationProviderManager $cloudFederationProviderManager,
-		private IDBConnection $connection,
-		private IGroupManager $groupManager,
-		private IConfig $config,
-		private Manager $externalShareManager,
-		private LoggerInterface $logger,
-		private IFilenameValidator $filenameValidator,
+		private readonly IAppManager $appManager,
+		private readonly FederatedShareProvider $federatedShareProvider,
+		private readonly AddressHandler $addressHandler,
+		private readonly IUserManager $userManager,
+		private readonly IManager $shareManager,
+		private readonly ICloudIdManager $cloudIdManager,
+		private readonly IActivityManager $activityManager,
+		private readonly INotificationManager $notificationManager,
+		private readonly IURLGenerator $urlGenerator,
+		private readonly ICloudFederationFactory $cloudFederationFactory,
+		private readonly ICloudFederationProviderManager $cloudFederationProviderManager,
+		private readonly IGroupManager $groupManager,
+		private readonly IConfig $config,
+		private readonly Manager $externalShareManager,
+		private readonly LoggerInterface $logger,
+		private readonly IFilenameValidator $filenameValidator,
 		private readonly IProviderFactory $shareProviderFactory,
+		private readonly SetupManager $setupManager,
+		private readonly ExternalShareMapper $externalShareMapper,
 	) {
 	}
 
-	/**
-	 * @return string
-	 */
-	public function getShareType() {
+	#[Override]
+	public function getShareType(): string {
 		return 'file';
 	}
 
-	/**
-	 * share received from another server
-	 *
-	 * @param ICloudFederationShare $share
-	 * @return string provider specific unique ID of the share
-	 *
-	 * @throws ProviderCouldNotAddShareException
-	 * @throws QueryException
-	 * @throws HintException
-	 * @since 14.0.0
-	 */
-	public function shareReceived(ICloudFederationShare $share) {
+	#[Override]
+	public function shareReceived(ICloudFederationShare $share): string {
 		if (!$this->isS2SEnabled(true)) {
 			throw new ProviderCouldNotAddShareException('Server does not support federated cloud sharing', '', Http::STATUS_SERVICE_UNAVAILABLE);
 		}
@@ -99,7 +89,8 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 			throw new ProviderCouldNotAddShareException('Unsupported protocol for data exchange.', '', Http::STATUS_NOT_IMPLEMENTED);
 		}
 
-		[$ownerUid, $remote] = $this->addressHandler->splitUserRemote($share->getOwner());
+		[, $remote] = $this->addressHandler->splitUserRemote($share->getOwner());
+
 		// for backward compatibility make sure that the remote url stored in the
 		// database ends with a trailing slash
 		if (!str_ends_with($remote, '/')) {
@@ -109,17 +100,15 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		$token = $share->getShareSecret();
 		$name = $share->getResourceName();
 		$owner = $share->getOwnerDisplayName() ?: $share->getOwner();
-		$sharedBy = $share->getSharedByDisplayName();
 		$shareWith = $share->getShareWith();
 		$remoteId = $share->getProviderId();
 		$sharedByFederatedId = $share->getSharedBy();
 		$ownerFederatedId = $share->getOwner();
 		$shareType = $this->mapShareTypeToNextcloud($share->getShareType());
 
-		// if no explicit information about the person who created the share was send
+		// if no explicit information about the person who created the share was sent
 		// we assume that the share comes from the owner
 		if ($sharedByFederatedId === null) {
-			$sharedBy = $owner;
 			$sharedByFederatedId = $ownerFederatedId;
 		}
 
@@ -128,7 +117,9 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 				throw new ProviderCouldNotAddShareException('The mountpoint name contains invalid characters.', '', Http::STATUS_BAD_REQUEST);
 			}
 
-			// FIXME this should be a method in the user management instead
+			$user = null;
+			$group = null;
+
 			if ($shareType === IShare::TYPE_USER) {
 				$this->logger->debug('shareWith before, ' . $shareWith, ['app' => 'files_sharing']);
 				Util::emitHook(
@@ -138,20 +129,32 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 				);
 				$this->logger->debug('shareWith after, ' . $shareWith, ['app' => 'files_sharing']);
 
-				if (!$this->userManager->userExists($shareWith)) {
+				$user = $this->userManager->get($shareWith);
+				if ($user === null) {
 					throw new ProviderCouldNotAddShareException('User does not exists', '', Http::STATUS_BAD_REQUEST);
 				}
 
-				\OC_Util::setupFS($shareWith);
+				$this->setupManager->setupForUser($user);
+			} else {
+				$group = $this->groupManager->get($shareWith);
+				if ($group === null) {
+					throw new ProviderCouldNotAddShareException('Group does not exists', '', Http::STATUS_BAD_REQUEST);
+				}
 			}
 
-			if ($shareType === IShare::TYPE_GROUP && !$this->groupManager->groupExists($shareWith)) {
-				throw new ProviderCouldNotAddShareException('Group does not exists', '', Http::STATUS_BAD_REQUEST);
-			}
+			$externalShare = new ExternalShare();
+			$externalShare->generateId();
+			$externalShare->setRemote($remote);
+			$externalShare->setRemoteId($remoteId);
+			$externalShare->setShareToken($token);
+			$externalShare->setPassword('');
+			$externalShare->setName($name);
+			$externalShare->setOwner($owner);
+			$externalShare->setShareType($shareType);
+			$externalShare->setAccepted(IShare::STATUS_PENDING);
 
 			try {
-				$this->externalShareManager->addShare($remote, $token, '', $name, $owner, $shareType, false, $shareWith, $remoteId);
-				$shareId = Server::get(IDBConnection::class)->lastInsertId('*PREFIX*share_external');
+				$this->externalShareManager->addShare($externalShare, $user ?: $group);
 
 				// get DisplayName about the owner of the share
 				$ownerDisplayName = $this->getUserDisplayName($ownerFederatedId);
@@ -166,41 +169,40 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 					}
 				}
 
-
 				if ($shareType === IShare::TYPE_USER) {
 					$event = $this->activityManager->generateEvent();
 					$event->setApp('files_sharing')
 						->setType('remote_share')
 						->setSubject(RemoteShares::SUBJECT_REMOTE_SHARE_RECEIVED, [$ownerFederatedId, trim($name, '/'), $ownerDisplayName])
 						->setAffectedUser($shareWith)
-						->setObject('remote_share', $shareId, $name);
+						->setObject('remote_share', (string)$externalShare->getId(), $name);
 					Server::get(IActivityManager::class)->publish($event);
-					$this->notifyAboutNewShare($shareWith, $shareId, $ownerFederatedId, $sharedByFederatedId, $name, $ownerDisplayName);
+					$this->notifyAboutNewShare($shareWith, (string)$externalShare->getId(), $ownerFederatedId, $sharedByFederatedId, $name, $ownerDisplayName);
 
 					// If auto-accept is enabled, accept the share
 					if ($this->federatedShareProvider->isFederatedTrustedShareAutoAccept() && $trustedServers?->isTrustedServer($remote) === true) {
-						$this->externalShareManager->acceptShare($shareId, $shareWith);
+						$this->externalShareManager->acceptShare($externalShare, $user);
 					}
 				} else {
-					$groupMembers = $this->groupManager->get($shareWith)->getUsers();
+					$groupMembers = $group->getUsers();
 					foreach ($groupMembers as $user) {
 						$event = $this->activityManager->generateEvent();
 						$event->setApp('files_sharing')
 							->setType('remote_share')
 							->setSubject(RemoteShares::SUBJECT_REMOTE_SHARE_RECEIVED, [$ownerFederatedId, trim($name, '/'), $ownerDisplayName])
 							->setAffectedUser($user->getUID())
-							->setObject('remote_share', $shareId, $name);
+							->setObject('remote_share', (string)$externalShare->getId(), $name);
 						Server::get(IActivityManager::class)->publish($event);
-						$this->notifyAboutNewShare($user->getUID(), $shareId, $ownerFederatedId, $sharedByFederatedId, $name, $ownerDisplayName);
+						$this->notifyAboutNewShare($user->getUID(), (string)$externalShare->getId(), $ownerFederatedId, $sharedByFederatedId, $name, $ownerDisplayName);
 
 						// If auto-accept is enabled, accept the share
 						if ($this->federatedShareProvider->isFederatedTrustedShareAutoAccept() && $trustedServers?->isTrustedServer($remote) === true) {
-							$this->externalShareManager->acceptShare($shareId, $user->getUID());
+							$this->externalShareManager->acceptShare($externalShare, $user);
 						}
 					}
 				}
 
-				return $shareId;
+				return (string)$externalShare->getId();
 			} catch (\Exception $e) {
 				$this->logger->error('Server can not add remote share.', [
 					'app' => 'files_sharing',
@@ -213,56 +215,28 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		throw new ProviderCouldNotAddShareException('server can not add remote share, missing parameter', '', HTTP::STATUS_BAD_REQUEST);
 	}
 
-	/**
-	 * notification received from another server
-	 *
-	 * @param string $notificationType (e.g. SHARE_ACCEPTED)
-	 * @param string $providerId id of the share
-	 * @param array $notification payload of the notification
-	 * @return array<string> data send back to the sender
-	 *
-	 * @throws ActionNotSupportedException
-	 * @throws AuthenticationFailedException
-	 * @throws BadRequestException
-	 * @throws HintException
-	 * @since 14.0.0
-	 */
-	public function notificationReceived($notificationType, $providerId, array $notification) {
-		switch ($notificationType) {
-			case 'SHARE_ACCEPTED':
-				return $this->shareAccepted($providerId, $notification);
-			case 'SHARE_DECLINED':
-				return $this->shareDeclined($providerId, $notification);
-			case 'SHARE_UNSHARED':
-				return $this->unshare($providerId, $notification);
-			case 'REQUEST_RESHARE':
-				return $this->reshareRequested($providerId, $notification);
-			case 'RESHARE_UNDO':
-				return $this->undoReshare($providerId, $notification);
-			case 'RESHARE_CHANGE_PERMISSION':
-				return $this->updateResharePermissions($providerId, $notification);
-		}
-
-
-		throw new BadRequestException([$notificationType]);
+	#[Override]
+	public function notificationReceived(string $notificationType, string $providerId, array $notification): array {
+		return match ($notificationType) {
+			'SHARE_ACCEPTED' => $this->shareAccepted($providerId, $notification),
+			'SHARE_DECLINED' => $this->shareDeclined($providerId, $notification),
+			'SHARE_UNSHARED' => $this->unshare($providerId, $notification),
+			'REQUEST_RESHARE' => $this->reshareRequested($providerId, $notification),
+			'RESHARE_UNDO' => $this->undoReshare($providerId, $notification),
+			'RESHARE_CHANGE_PERMISSION' => $this->updateResharePermissions($providerId, $notification),
+			default => throw new BadRequestException([$notificationType]),
+		};
 	}
 
 	/**
-	 * map OCM share type (strings) to Nextcloud internal share types (integer)
-	 *
-	 * @param string $shareType
-	 * @return int
+	 * Map OCM share type (strings) to Nextcloud internal share types (integer)
+	 * @return IShare::TYPE_GROUP|IShare::TYPE_USER
 	 */
-	private function mapShareTypeToNextcloud($shareType) {
-		$result = IShare::TYPE_USER;
-		if ($shareType === 'group') {
-			$result = IShare::TYPE_GROUP;
-		}
-
-		return $result;
+	private function mapShareTypeToNextcloud(string $shareType): int {
+		return $shareType === 'group' ? IShare::TYPE_GROUP : IShare::TYPE_USER;
 	}
 
-	private function notifyAboutNewShare($shareWith, $shareId, $ownerFederatedId, $sharedByFederatedId, $name, $displayName): void {
+	private function notifyAboutNewShare(string $shareWith, string $shareId, $ownerFederatedId, $sharedByFederatedId, string $name, string $displayName): void {
 		$notification = $this->notificationManager->createNotification();
 		$notification->setApp('files_sharing')
 			->setUser($shareWith)
@@ -286,15 +260,14 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * process notification that the recipient accepted a share
 	 *
-	 * @param string $id
-	 * @param array $notification
+	 * @param array{sharedSecret?: string} $notification
 	 * @return array<string>
 	 * @throws ActionNotSupportedException
 	 * @throws AuthenticationFailedException
 	 * @throws BadRequestException
 	 * @throws HintException
 	 */
-	private function shareAccepted($id, array $notification) {
+	private function shareAccepted(string $id, array $notification): array {
 		if (!$this->isS2SEnabled()) {
 			throw new ActionNotSupportedException('Server does not support federated cloud sharing');
 		}
@@ -333,21 +306,22 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	}
 
 	/**
-	 * @param IShare $share
 	 * @throws ShareNotFound
 	 */
-	protected function executeAcceptShare(IShare $share) {
+	protected function executeAcceptShare(IShare $share): void {
+		$user = $this->getCorrectUser($share);
+
 		try {
-			$fileId = (int)$share->getNode()->getId();
-			[$file, $link] = $this->getFile($this->getCorrectUid($share), $fileId);
-		} catch (\Exception $e) {
+			$fileId = $share->getNode()->getId();
+			[$file, $link] = $this->getFile($user, $fileId);
+		} catch (\Exception) {
 			throw new ShareNotFound();
 		}
 
 		$event = $this->activityManager->generateEvent();
 		$event->setApp('files_sharing')
 			->setType('remote_share')
-			->setAffectedUser($this->getCorrectUid($share))
+			->setAffectedUser($user->getUID())
 			->setSubject(RemoteShares::SUBJECT_REMOTE_SHARE_ACCEPTED, [$share->getSharedWith(), [$fileId => $file]])
 			->setObject('files', $fileId, $file)
 			->setLink($link);
@@ -357,8 +331,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * process notification that the recipient declined a share
 	 *
-	 * @param string $id
-	 * @param array $notification
+	 * @param array{sharedSecret?: string} $notification
 	 * @return array<string>
 	 * @throws ActionNotSupportedException
 	 * @throws AuthenticationFailedException
@@ -367,7 +340,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	 * @throws HintException
 	 *
 	 */
-	protected function shareDeclined($id, array $notification) {
+	protected function shareDeclined(string $id, array $notification): array {
 		if (!$this->isS2SEnabled()) {
 			throw new ActionNotSupportedException('Server does not support federated cloud sharing');
 		}
@@ -394,7 +367,6 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 					'sharedSecret' => $token,
 					'message' => 'Recipient declined the re-share'
 				]
-
 			);
 			$this->cloudFederationProviderManager->sendNotification($remote, $notification);
 		}
@@ -407,23 +379,24 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * delete declined share and create a activity
 	 *
-	 * @param IShare $share
 	 * @throws ShareNotFound
 	 */
-	protected function executeDeclineShare(IShare $share) {
+	protected function executeDeclineShare(IShare $share): void {
 		$this->federatedShareProvider->removeShareFromTable($share);
 
+		$user = $this->getCorrectUser($share);
+
 		try {
-			$fileId = (int)$share->getNode()->getId();
-			[$file, $link] = $this->getFile($this->getCorrectUid($share), $fileId);
-		} catch (\Exception $e) {
+			$fileId = $share->getNode()->getId();
+			[$file, $link] = $this->getFile($user, $fileId);
+		} catch (\Exception) {
 			throw new ShareNotFound();
 		}
 
 		$event = $this->activityManager->generateEvent();
 		$event->setApp('files_sharing')
 			->setType('remote_share')
-			->setAffectedUser($this->getCorrectUid($share))
+			->setAffectedUser($user->getUID())
 			->setSubject(RemoteShares::SUBJECT_REMOTE_SHARE_DECLINED, [$share->getSharedWith(), [$fileId => $file]])
 			->setObject('files', $fileId, $file)
 			->setLink($link);
@@ -433,13 +406,12 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * received the notification that the owner unshared a file from you
 	 *
-	 * @param string $id
-	 * @param array $notification
+	 * @param array{sharedSecret?: string} $notification
 	 * @return array<string>
 	 * @throws AuthenticationFailedException
 	 * @throws BadRequestException
 	 */
-	private function undoReshare($id, array $notification) {
+	private function undoReshare(string $id, array $notification): array {
 		if (!isset($notification['sharedSecret'])) {
 			throw new BadRequestException(['sharedSecret']);
 		}
@@ -455,13 +427,12 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * unshare file from self
 	 *
-	 * @param string $id
-	 * @param array $notification
+	 * @param array{sharedSecret?: string} $notification
 	 * @return array<string>
 	 * @throws ActionNotSupportedException
 	 * @throws BadRequestException
 	 */
-	private function unshare($id, array $notification) {
+	private function unshare(string $id, array $notification): array {
 		if (!$this->isS2SEnabled(true)) {
 			throw new ActionNotSupportedException('incoming shares disabled!');
 		}
@@ -471,56 +442,29 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		}
 		$token = $notification['sharedSecret'];
 
-		$qb = $this->connection->getQueryBuilder();
-		$qb->select('*')
-			->from('share_external')
-			->where(
-				$qb->expr()->andX(
-					$qb->expr()->eq('remote_id', $qb->createNamedParameter($id)),
-					$qb->expr()->eq('share_token', $qb->createNamedParameter($token))
-				)
-			);
+		$share = $this->externalShareMapper->getShareByRemoteIdAndToken($id, $token);
 
-		$result = $qb->executeQuery();
-		$share = $result->fetch();
-		$result->closeCursor();
+		if ($token && $id && $share !== null) {
+			$remote = $this->cleanupRemote($share->getRemote());
 
-		if ($token && $id && !empty($share)) {
-			$remote = $this->cleanupRemote($share['remote']);
+			$owner = $this->cloudIdManager->getCloudId($share->getOwner(), $remote);
+			$mountpoint = $share->getMountpoint();
+			$user = $share->getUser();
 
-			$owner = $this->cloudIdManager->getCloudId($share['owner'], $remote);
-			$mountpoint = $share['mountpoint'];
-			$user = $share['user'];
-
-			$qb = $this->connection->getQueryBuilder();
-			$qb->delete('share_external')
-				->where(
-					$qb->expr()->andX(
-						$qb->expr()->eq('remote_id', $qb->createNamedParameter($id)),
-						$qb->expr()->eq('share_token', $qb->createNamedParameter($token))
-					)
-				);
-
-			$qb->executeStatement();
-
-			// delete all child in case of a group share
-			$qb = $this->connection->getQueryBuilder();
-			$qb->delete('share_external')
-				->where($qb->expr()->eq('parent', $qb->createNamedParameter((int)$share['id'])));
-			$qb->executeStatement();
+			$this->externalShareMapper->delete($share);
 
 			$ownerDisplayName = $this->getUserDisplayName($owner->getId());
 
-			if ((int)$share['share_type'] === IShare::TYPE_USER) {
-				if ($share['accepted']) {
+			if ($share->getShareType() === IShare::TYPE_USER) {
+				if ($share->getAccepted()) {
 					$path = trim($mountpoint, '/');
 				} else {
-					$path = trim($share['name'], '/');
+					$path = trim($share->getName(), '/');
 				}
 				$notification = $this->notificationManager->createNotification();
 				$notification->setApp('files_sharing')
-					->setUser($share['user'])
-					->setObject('remote_share', (string)$share['id']);
+					->setUser($share->getUser())
+					->setObject('remote_share', (string)$share->getId());
 				$this->notificationManager->markProcessed($notification);
 
 				$event = $this->activityManager->generateEvent();
@@ -528,7 +472,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 					->setType('remote_share')
 					->setSubject(RemoteShares::SUBJECT_REMOTE_SHARE_UNSHARED, [$owner->getId(), $path, $ownerDisplayName])
 					->setAffectedUser($user)
-					->setObject('remote_share', (int)$share['id'], $path);
+					->setObject('remote_share', $share->getId(), $path);
 				Server::get(IActivityManager::class)->publish($event);
 			}
 		}
@@ -536,7 +480,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		return [];
 	}
 
-	private function cleanupRemote($remote) {
+	private function cleanupRemote(string $remote): string {
 		$remote = substr($remote, strpos($remote, '://') + 3);
 
 		return rtrim($remote, '/');
@@ -545,15 +489,14 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	/**
 	 * recipient of a share request to re-share the file with another user
 	 *
-	 * @param string $id
-	 * @param array $notification
+	 * @param array{sharedSecret?: string, shareWith?: string, senderId?: string} $notification
 	 * @return array<string>
 	 * @throws AuthenticationFailedException
 	 * @throws BadRequestException
 	 * @throws ProviderCouldNotAddShareException
 	 * @throws ShareNotFound
 	 */
-	protected function reshareRequested($id, array $notification) {
+	protected function reshareRequested(string $id, array $notification) {
 		if (!isset($notification['sharedSecret'])) {
 			throw new BadRequestException(['sharedSecret']);
 		}
@@ -595,7 +538,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 			$share->setSharedBy($share->getSharedWith());
 			$share->setSharedWith($shareWith);
 			$result = $this->federatedShareProvider->create($share);
-			$this->federatedShareProvider->storeRemoteId((int)$result->getId(), $senderId);
+			$this->federatedShareProvider->storeRemoteId($result->getId(), $senderId);
 			return ['token' => $result->getToken(), 'providerId' => $result->getId()];
 		} else {
 			throw new ProviderCouldNotAddShareException('resharing not allowed for share: ' . $id);
@@ -603,71 +546,22 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	}
 
 	/**
-	 * update permission of a re-share so that the share dialog shows the right
+	 * Update permission of a re-share so that the share dialog shows the right
 	 * permission if the owner or the sender changes the permission
 	 *
-	 * @param string $id
-	 * @param array $notification
-	 * @return array<string>
+	 * @return string[]
 	 * @throws AuthenticationFailedException
 	 * @throws BadRequestException
 	 */
-	protected function updateResharePermissions($id, array $notification) {
+	protected function updateResharePermissions(string $id, array $notification): array {
 		throw new HintException('Updating reshares not allowed');
 	}
 
 	/**
-	 * translate OCM Permissions to Nextcloud permissions
-	 *
-	 * @param array $ocmPermissions
-	 * @return int
-	 * @throws BadRequestException
+	 * @return list{?string, string} with internal path of the file and a absolute link to it
 	 */
-	protected function ocmPermissions2ncPermissions(array $ocmPermissions) {
-		$ncPermissions = 0;
-		foreach ($ocmPermissions as $permission) {
-			switch (strtolower($permission)) {
-				case 'read':
-					$ncPermissions += Constants::PERMISSION_READ;
-					break;
-				case 'write':
-					$ncPermissions += Constants::PERMISSION_CREATE + Constants::PERMISSION_UPDATE;
-					break;
-				case 'share':
-					$ncPermissions += Constants::PERMISSION_SHARE;
-					break;
-				default:
-					throw new BadRequestException(['permission']);
-			}
-		}
-
-		return $ncPermissions;
-	}
-
-	/**
-	 * update permissions in database
-	 *
-	 * @param IShare $share
-	 * @param int $permissions
-	 */
-	protected function updatePermissionsInDatabase(IShare $share, $permissions) {
-		$query = $this->connection->getQueryBuilder();
-		$query->update('share')
-			->where($query->expr()->eq('id', $query->createNamedParameter($share->getId())))
-			->set('permissions', $query->createNamedParameter($permissions))
-			->executeStatement();
-	}
-
-
-	/**
-	 * get file
-	 *
-	 * @param string $user
-	 * @param int $fileSource
-	 * @return array with internal path of the file and a absolute link to it
-	 */
-	private function getFile($user, $fileSource) {
-		\OC_Util::setupFS($user);
+	private function getFile(IUser $user, int $fileSource): array {
+		$this->setupManager->setupForUser($user);
 
 		try {
 			$file = Filesystem::getPath($fileSource);
@@ -681,30 +575,26 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 	}
 
 	/**
-	 * check if we are the initiator or the owner of a re-share and return the correct UID
-	 *
-	 * @param IShare $share
-	 * @return string
+	 * Check if we are the initiator or the owner of a re-share and return the correct UID
 	 */
-	protected function getCorrectUid(IShare $share) {
-		if ($this->userManager->userExists($share->getShareOwner())) {
-			return $share->getShareOwner();
+	protected function getCorrectUser(IShare $share): IUser {
+		if ($user = $this->userManager->get($share->getShareOwner())) {
+			return $user;
 		}
 
-		return $share->getSharedBy();
+		$user = $this->userManager->get($share->getSharedBy());
+		if ($user === null) {
+			throw new \RuntimeException('Neither the share owner or the share initiator exist');
+		}
+		return $user;
 	}
 
-
-
 	/**
 	 * check if we got the right share
 	 *
-	 * @param IShare $share
-	 * @param string $token
-	 * @return bool
 	 * @throws AuthenticationFailedException
 	 */
-	protected function verifyShare(IShare $share, $token) {
+	protected function verifyShare(IShare $share, string $token): bool {
 		if (
 			$share->getShareType() === IShare::TYPE_REMOTE
 			&& $share->getToken() === $token
@@ -728,12 +618,9 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 
 
 	/**
-	 * check if server-to-server sharing is enabled
-	 *
-	 * @param bool $incoming
-	 * @return bool
+	 * Check if server-to-server sharing is enabled
 	 */
-	private function isS2SEnabled($incoming = false) {
+	private function isS2SEnabled(bool $incoming = false): bool {
 		$result = $this->appManager->isEnabledForUser('files_sharing');
 
 		if ($incoming) {
@@ -745,19 +632,11 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		return $result;
 	}
 
-
-	/**
-	 * get the supported share types, e.g. "user", "group", etc.
-	 *
-	 * @return array
-	 *
-	 * @since 14.0.0
-	 */
-	public function getSupportedShareTypes() {
+	#[Override]
+	public function getSupportedShareTypes(): array {
 		return ['user', 'group'];
 	}
 
-
 	public function getUserDisplayName(string $userId): string {
 		// check if gss is enabled and available
 		if (!$this->appManager->isEnabledForAnyone('globalsiteselector')
@@ -768,7 +647,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		try {
 			$slaveService = Server::get(SlaveService::class);
 		} catch (\Throwable $e) {
-			Server::get(LoggerInterface::class)->error(
+			$this->logger->error(
 				$e->getMessage(),
 				['exception' => $e]
 			);
@@ -778,13 +657,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 		return $slaveService->getUserDisplayName($this->cloudIdManager->removeProtocolFromUrl($userId), false);
 	}
 
-	/**
-	 * @inheritDoc
-	 *
-	 * @param string $sharedSecret
-	 * @param array $payload
-	 * @return string
-	 */
+	#[Override]
 	public function getFederationIdFromSharedSecret(
 		#[SensitiveParameter]
 		string $sharedSecret,
@@ -800,7 +673,7 @@ class CloudFederationProviderFiles implements ISignedCloudFederationProvider {
 				return '';
 			}
 
-			return $share['user'] . '@' . $share['remote'];
+			return $share->getUser() . '@' . $share->getRemote();
 		}
 
 		// if uid_owner is a local account, the request comes from the recipient
