@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Reload current directory",
     "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
     "Current directory path" : "Current directory path",
+    "Share" : "Share",
+    "Reload content" : "Reload content",
     "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
     "You do not have permission to upload or create files here." : "You do not have permission to upload or create files here.",
     "Drag and drop files here to upload" : "Drag and drop files here to upload",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "This node is unavailable",
     "Another entry with the same name already exists." : "Another entry with the same name already exists.",
     "Invalid filename." : "Invalid filename.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
     "Rename file" : "Rename file",
     "Folder" : "Folder",
     "Unknown file type" : "Unknown file type",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "Pending",
     "Unknown date" : "Unknown date",
-    "Clear filter" : "Clear filter",
-    "Modified" : "Modified",
-    "Search everywhere" : "Search everywhere",
-    "Type" : "Type",
     "Active filters" : "Active filters",
     "Remove filter" : "Remove filter",
+    "Today" : "Today",
+    "Last 7 days" : "Last 7 days",
+    "Last 30 days" : "Last 30 days",
+    "This year ({year})" : "This year ({year})",
+    "Last year ({year})" : "Last year ({year})",
+    "Custom range" : "Custom range",
+    "Custom date range" : "Custom date range",
+    "Search everywhere" : "Search everywhere",
+    "Documents" : "Documents",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentations",
+    "PDFs" : "PDFs",
+    "Folders" : "Folders",
+    "Audio" : "Audio",
+    "Images" : "Images",
+    "Videos" : "Videos",
+    "Filters" : "Filters",
+    "Back to filters" : "Back to filters",
     "Appearance" : "Appearance",
     "Show hidden files" : "Show hidden files",
     "Show file type column" : "Show file type column",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Go right in grid",
     "View" : "View",
     "Toggle grid view" : "Toggle grid view",
-    "Open file sidebar" : "Open file sidebar",
     "Show those shortcuts" : "Show those shortcuts",
     "Warnings" : "Warnings",
     "Warn before changing a file extension" : "Warn before changing a file extension",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Name",
     "File type" : "File type",
     "Size" : "Size",
+    "Modified" : "Modified",
     "{displayName}: failed on some elements" : "{displayName}: failed on some elements",
     "{displayName}: done" : "{displayName}: done",
     "{displayName}: failed" : "{displayName}: failed",
@@ -160,6 +175,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
     "_{count} selected_::_{count} selected_" : ["{count} selected","{count} selected"],
+    "Views" : "Views",
     "Search everywhere …" : "Search everywhere …",
     "Search here …" : "Search here …",
     "Search scope options" : "Search scope options",
@@ -218,12 +234,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Removing the file extension \"{old}\" may render the file unreadable.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Adding the file extension \"{new}\" may render the file unreadable.",
     "Do not show this dialog again." : "Do not show this dialogue again.",
+    "Rename file to hidden" : "Rename file to hidden",
+    "Prefixing a filename with a dot may render the file hidden." : "Prefixing a filename with a dot may render the file hidden.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Are you sure you want to rename the file to \"{filename}\"?",
+    "Cancel" : "Cancel",
+    "Rename" : "Rename",
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose {file}" : "Choose {file}",
     "Files settings" : "Files settings",
-    "Share" : "Share",
-    "Shared by link" : "Shared by link",
-    "Shared" : "Shared",
     "Switch to list view" : "Switch to list view",
     "Switch to grid view" : "Switch to grid view",
     "The file could not be found" : "The file could not be found",
@@ -233,12 +251,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "Error during upload: {message}",
     "Error during upload, status code {status}" : "Error during upload, status code {status}",
     "Unknown error during upload" : "Unknown error during upload",
+    "File list is reloading" : "File list is reloading",
     "Loading current folder" : "Loading current folder",
     "Retry" : "Retry",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "Go back" : "Go back",
-    "Views" : "Views",
     "Loading …" : "Loading …",
     "Your files" : "Your files",
     "Open in files" : "Open in files",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","You are about to permanently delete {count} items"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","You are about to delete {count} items"],
     "Confirm deletion" : "Confirm deletion",
-    "Cancel" : "Cancel",
     "Download" : "Download",
     "The requested file is not available." : "The requested file is not available.",
     "The requested files are not available." : "The requested files are not available.",
     "Add to favorites" : "Add to favourites",
     "Remove from favorites" : "Remove from favourites",
     "Add or remove favorite" : "Add or remove favorite",
-    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Move" : "Move",
+    "Copy" : "Copy",
+    "Move or copy" : "Move or copy",
     "Destination is not a folder" : "Destination is not a folder",
     "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
-    "(copy)" : "(copy)",
-    "(copy %n)" : "(copy %n)",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
     "The files are locked" : "The files are locked",
     "The file does not exist anymore" : "The file does not exist anymore",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Moving {count} files to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Copying {count} files to \"{destination}\" …",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "Copy to {target}",
-    "Copy" : "Copy",
     "Move to {target}" : "Move to {target}",
-    "Move" : "Move",
     "Move or copy operation failed" : "Move or copy operation failed",
-    "Move or copy" : "Move or copy",
     "Open folder" : "Open folder",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
@@ -318,29 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
     "Retry and close" : "Retry and close",
     "Open online" : "Open online",
-    "Rename" : "Rename",
     "Details" : "Details",
+    "Open the details sidebar" : "Open the details sidebar",
     "Unfavorite" : "Unfavourite",
     "View in folder" : "View in folder",
-    "Today" : "Today",
-    "Last 7 days" : "Last 7 days",
-    "Last 30 days" : "Last 30 days",
-    "This year ({year})" : "This year ({year})",
-    "Last year ({year})" : "Last year ({year})",
-    "Documents" : "Documents",
-    "Spreadsheets" : "Spreadsheets",
-    "Presentations" : "Presentations",
-    "PDFs" : "PDFs",
-    "Folders" : "Folders",
-    "Audio" : "Audio",
-    "Images" : "Images",
-    "Videos" : "Videos",
+    "Type" : "Type",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Create templates folder" : "Create templates folder",
     "Templates" : "Templates",
     "New template folder" : "New template folder",
     "In folder" : "In folder",
+    "Pick folder to search in" : "Pick folder to search in",
     "Search in all files" : "Search in all files",
     "Search in folder: {folder}" : "Search in folder: {folder}",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
@@ -350,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Some files could not be uploaded",
     "Files uploaded successfully" : "Files uploaded successfully",
     "No files to process" : "No files to process",
-    "Some files could not be copied" : "Some files could not be copied",
-    "Some files could not be moved" : "Some files could not be moved",
     "Files copied successfully" : "Files copied successfully",
     "Files moved successfully" : "Files moved successfully",
+    "Some files could not be copied" : "Some files could not be copied",
+    "Some files could not be moved" : "Some files could not be moved",
     "Conflicts resolution skipped" : "Conflicts resolution skipped",
     "Upload cancelled" : "Upload cancelled",
     "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
@@ -394,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Upload (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
+    "Clear filter" : "Clear filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
     "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Submitting fields …" : "Submitting fields …",
+    "Shared by link" : "Shared by link",
+    "Shared" : "Shared",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "Filter file names …" : "Filter file names …",
     "Clipboard is not available" : "Clipboard is not available",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Edit locally",
     "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
     "Move cancelled" : "Move cancelled",
     "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
     "Cancelled move or copy operation" : "Cancelled move or copy operation",
@@ -447,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "New folder creation cancelled",
     "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "All folders" : "All folders",
+    "Open file sidebar" : "Open file sidebar",
     "Search everywhere …" : "Search everywhere …",
     "Search here …" : "Search here …",
     "Preparing …" : "Preparing …"
