@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "دایرکتوری فعلی را دوباره بارگیری کنید",
     "Go to the \"{dir}\" directory" : "به دایرکتوری \"{dir}\" بروید",
     "Current directory path" : "Current directory path",
+    "Share" : "اشتراک‌گذاری",
     "Your have used your space quota and cannot upload files anymore" : "سهمیه فضای شما تمام شده و دیگر نمی‌توانید فایل آپلود کنید.",
     "You do not have permission to upload or create files here." : "شما اینجا اجازه آپلود یا ایجاد فایل ندارید.",
     "Drag and drop files here to upload" : "برای بارگذاری، فایل‌ها را بکشید و اینجا بیاندازید",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "گره شما در دسترس نیست",
     "Another entry with the same name already exists." : "یک مطلب دیگر با همین نام از قبل وجود دارد.",
     "Invalid filename." : "نام فایل نامعتبر.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "تغییر نام \"{oldName}\" به \"{newName}\"",
     "Rename file" : "تغییر نام فایل",
     "Folder" : "پوشه",
     "Unknown file type" : "فرمت فایل نامعتبر",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} متن",
     "Pending" : "در انتظار",
     "Unknown date" : "تاریخ نامعلوم",
-    "Clear filter" : "پاک کردن پالایه",
-    "Modified" : "تاریخ",
-    "Search everywhere" : "جستجو در هر کجا.",
-    "Type" : "نوع",
     "Active filters" : "فیلترهای فعال",
     "Remove filter" : "فیلتر را بردارید",
+    "Today" : "امروز",
+    "Last 7 days" : "۷ روز گذشته",
+    "Last 30 days" : "۳۰ روز گذشته",
+    "This year ({year})" : "This year ({year})",
+    "Last year ({year})" : "Last year ({year})",
+    "Custom date range" : "بازه تاریخی سفارشی.",
+    "Search everywhere" : "جستجو در هر کجا.",
+    "Documents" : "سندها",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentations",
+    "PDFs" : "PDFs",
+    "Folders" : "پوشه‌ها",
+    "Audio" : "صدا",
+    "Images" : "تصاویر",
+    "Videos" : "فیلم ها ",
+    "Filters" : "Filters",
     "Appearance" : "ظاهر",
     "Show hidden files" : "نمایش پرونده‌های مخفی",
     "Show file type column" : "نمایش ستون نوع فایل",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "رفتن به راست ساختار",
     "View" : "نمایش",
     "Toggle grid view" : "نمای دریچه را تغییر دهید",
-    "Open file sidebar" : "بازکردن نواربغل فایل‌",
     "Show those shortcuts" : "نمایش میانبرها",
     "Warnings" : "هشدارها",
     "Warn before changing a file extension" : "هشدار قبل از عوض‌کردن فرمت فایل",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "نام",
     "File type" : "نوع فایل",
     "Size" : "اندازه",
+    "Modified" : "تاریخ",
     "{displayName}: failed on some elements" : "{displayName}: در برخی از عناصر ناموفق بود",
     "{displayName}: done" : "{displayName}: انجام شد",
     "{displayName}: failed" : "{displayName}:ناموفق بود",
@@ -160,6 +172,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "این لیست به دلایل عملکرد به طور کامل ارائه نشده است. در حین حرکت در لیست، فایل ها ارائه می شوند.",
     "File not found" : "فایل یافت نشد",
     "_{count} selected_::_{count} selected_" : ["{count} انتخاب شده","{count} انتخاب شده"],
+    "Views" : "بازدیدها",
     "Search everywhere …" : "جستجو در همه‌جا ...",
     "Search here …" : "جستجو ...",
     "Search scope options" : "گزینه‌های محدوده جستجو",
@@ -218,12 +231,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "حذف پسوند فایل \"{old}\" ممکن است فایل را غیرقابل خواندن کند.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "افزودن پسوند فایل \"{new}\" ممکن است فایل را غیرقابل خواندن کند.",
     "Do not show this dialog again." : "این کادر محاوره‌ای را دیگر نمایش نده.",
+    "Cancel" : "لغو",
+    "Rename" : "تغییرنام",
     "Select file or folder to link to" : "فایل یا پوشه را برای پیوند انتخاب کنید",
     "Choose {file}" : "انتخاب {file}",
     "Files settings" : "تنظیمات پرونده‌ها",
-    "Share" : "اشتراک‌گذاری",
-    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
-    "Shared" : "به اشتراک گذاشته شده ",
     "Switch to list view" : "تغییر به نمای لیست",
     "Switch to grid view" : "تغییر به نمای شبکه‌ای",
     "The file could not be found" : "فایل پیدا نشد",
@@ -238,7 +250,6 @@ OC.L10N.register(
     "No files in here" : "هیچ فایلی اینجا وجود ندارد",
     "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
     "Go back" : "برگرد",
-    "Views" : "بازدیدها",
     "Loading …" : "بارگیری",
     "Your files" : "فایل‌های شما",
     "Open in files" : "باز کردن در فایل‌ها",
@@ -283,30 +294,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","شما در شرف حذف دائمی {count} مورد هستید."],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","شما در حال حذف {count} مورد هستید."],
     "Confirm deletion" : "تأیید حذف",
-    "Cancel" : "لغو",
     "Download" : "دانلود",
     "The requested file is not available." : "فایل مورد نظر موجود نیست.",
     "The requested files are not available." : "فایل‌های درخواستی در دسترس نیستند.",
     "Add to favorites" : "اضافه کردن به برگزیده ها",
     "Remove from favorites" : "حذف کردن از برگزیده ها",
     "Add or remove favorite" : "اضافه کردن یا حذف کردن موارد دلخواه",
-    "Moving \"{source}\" to \"{destination}\" …" : "انتقال «{source}» به «{destination}»",
-    "Copying \"{source}\" to \"{destination}\" …" : "کپی کردن \"{source}\" به \"{destination}\" ...",
+    "Move" : "انتقال",
+    "Copy" : "رونوشت",
+    "Move or copy" : "انتقال یا رونوشت",
     "Destination is not a folder" : "مقصد یک پوشه نیست",
     "This file/folder is already in that directory" : "این فایل/پوشه از قبل در آن دایرکتوری وجود دارد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "شما نمی‌توانید یک فایل/پوشه را به داخل خودش یا به زیرپوشه‌ای از خودش منتقل کنید",
-    "(copy)" : "(کپی)",
-    "(copy %n)" : "(کپی %n)",
     "A file or folder with that name already exists in this folder" : "یک فایل یا پوشه با آن نام از قبل در این پوشه وجود دارد",
     "The files are locked" : "فایل‌ها قفل شده‌اند",
     "The file does not exist anymore" : "فایل دیگه وجود نداره",
+    "Moving \"{source}\" to \"{destination}\" …" : "انتقال «{source}» به «{destination}»",
+    "Copying \"{source}\" to \"{destination}\" …" : "کپی کردن \"{source}\" به \"{destination}\" ...",
     "Choose destination" : "مقصد را انتخاب کنید",
     "Copy to {target}" : "رونوشت به {target}",
-    "Copy" : "رونوشت",
     "Move to {target}" : "جابجایی به {target}",
-    "Move" : "انتقال",
     "Move or copy operation failed" : "عملیات انتقال یا کپی ناموفق بود",
-    "Move or copy" : "انتقال یا رونوشت",
     "Open folder" : "پوشه را بازکن",
     "Open folder {displayName}" : "باز کردن پوشه {displayName}",
     "Open in Files" : "در فایل باز کنید",
@@ -316,22 +324,9 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "اکنون فایل باید روی دستگاه شما باز شود. اگر اینطور نیست، لطفاً بررسی کنید که برنامه دسکتاپ را نصب کرده‌اید.",
     "Retry and close" : "دوباره امتحان کنید و ببندید",
     "Open online" : "آنلاین باز کنید",
-    "Rename" : "تغییرنام",
     "Details" : "جزئیات",
     "View in folder" : "مشاهده در پوشه",
-    "Today" : "امروز",
-    "Last 7 days" : "۷ روز گذشته",
-    "Last 30 days" : "۳۰ روز گذشته",
-    "This year ({year})" : "This year ({year})",
-    "Last year ({year})" : "Last year ({year})",
-    "Documents" : "سندها",
-    "Spreadsheets" : "Spreadsheets",
-    "Presentations" : "Presentations",
-    "PDFs" : "PDFs",
-    "Folders" : "پوشه‌ها",
-    "Audio" : "صدا",
-    "Images" : "تصاویر",
-    "Videos" : "فیلم ها ",
+    "Type" : "نوع",
     "Created new folder \"{name}\"" : "پوشه جدید \"{name}\" ایجاد شد",
     "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
     "Create templates folder" : "ایجاد پوشه قالب‌ها",
@@ -347,10 +342,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "بعضی از فایل‌ها آپلود نشدند",
     "Files uploaded successfully" : "فایل‌ها با موفقیت آپلود شدند",
     "No files to process" : "هیچ فایلی برای پردازش وجود ندارد",
-    "Some files could not be copied" : "بعضی از فایل‌ها کپی نمی‌شدند",
-    "Some files could not be moved" : "برخی از پرونده‌ها قابل انتقال نیستند",
     "Files copied successfully" : "فایل‌ها با موفقیت کپی شدند",
     "Files moved successfully" : "فایل‌ها با موفقیت منتقل شدند",
+    "Some files could not be copied" : "بعضی از فایل‌ها کپی نمی‌شدند",
+    "Some files could not be moved" : "برخی از پرونده‌ها قابل انتقال نیستند",
     "Conflicts resolution skipped" : "حل اختلافات متوقف شد",
     "Upload cancelled" : "آپلود لغو شد",
     "Could not rename \"{oldName}\", it does not exist any more" : "نمی‌توان نام «{oldName}» را تغییر داد، دیگر وجود ندارد",
@@ -391,10 +386,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "پس از فعال کردن نام فایل‌های سازگار با ویندوز، فایل‌های موجود دیگر قابل تغییر نیستند، اما می‌توانند توسط مالکشان به نام‌های جدید معتبر تغییر نام دهند.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "همچنین پس از فعال کردن این تنظیم، امکان انتقال خودکار فایل‌ها وجود دارد، لطفاً به مستندات مربوط به دستور occ مراجعه کنید.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "تغییر نام \"{oldName}\" به \"{newName}\"",
+    "Clear filter" : "پاک کردن پالایه",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" در برخی از عناصر ناموفق بود",
     "\"{displayName}\" batch action executed successfully" : "عملکرد دسته‌ای \"{displayName}\" با موفقیت اجرا شد",
     "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
     "Submitting fields …" : "Submitting fields …",
+    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
+    "Shared" : "به اشتراک گذاشته شده ",
     "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
     "Filter file names …" : "فیلتر کردن نام فایل‌ها…",
     "Clipboard is not available" : "کلیپ بورد در دسترس نیست",
@@ -436,6 +435,8 @@ OC.L10N.register(
     "Edit locally" : "ویرایش محلی",
     "Moving \"{source}\" to \"{destination}\" …" : "انتقال «{source}» به «{destination}» ...",
     "Copying \"{source}\" to \"{destination}\" …" : "کپی کردن \"{source}\" به \"{destination}\" ...",
+    "(copy)" : "(کپی)",
+    "(copy %n)" : "(کپی %n)",
     "Move cancelled" : "حرکت لغو شد",
     "Cancelled move or copy of \"{filename}\"." : "انتقال یا کپی \"{filename}\" لغو شد.",
     "Cancelled move or copy operation" : "عملیات انتقال یا کپی لغو شد",
@@ -444,6 +445,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "ایجاد پوشه جدید لغو شد",
     "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
     "All folders" : "همه پوشه‌ها",
+    "Open file sidebar" : "بازکردن نواربغل فایل‌",
     "Search everywhere …" : "جستجو در همه‌جا",
     "Search here …" : "جستجو ...",
     "Preparing …" : "درحال آماده‌سازی"
