@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "カレントディレクトリの再読み込み",
     "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
     "Current directory path" : "現在のディレクトリパス",
+    "Share" : "共有",
+    "Reload content" : "コンテンツを再読み込み",
     "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
     "You do not have permission to upload or create files here." : "ここにファイルをアップロードまたは作成する権限がありません。",
     "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "このノードは利用できません",
     "Another entry with the same name already exists." : "同じ名前の別のエントリがすでに存在しています。",
     "Invalid filename." : "無効なファイル名。",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
     "Rename file" : "ファイル名の変更",
     "Folder" : "フォルダー",
     "Unknown file type" : "不明なファイルタイプ",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext}テキスト",
     "Pending" : "保留中",
     "Unknown date" : "不明な日付",
-    "Clear filter" : "フィルターをクリア",
-    "Modified" : "更新日時",
-    "Search everywhere" : "あらゆる場所を検索",
-    "Type" : "タイプ",
     "Active filters" : "有効なフィルター",
     "Remove filter" : "フィルターを削除",
+    "Today" : "今日",
+    "Last 7 days" : "7日以内",
+    "Last 30 days" : "30日以内",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Custom range" : "カスタム範囲",
+    "Custom date range" : "カスタム日付の範囲",
+    "Search everywhere" : "あらゆる場所を検索",
+    "Documents" : "ドキュメント",
+    "Spreadsheets" : "スプレッドシート",
+    "Presentations" : "プレゼンテーション",
+    "PDFs" : "PDF",
+    "Folders" : "フォルダー",
+    "Audio" : "オーディオ",
+    "Images" : "画像",
+    "Videos" : "動画",
+    "Filters" : "フィルター",
+    "Back to filters" : "フィルターに戻る",
     "Appearance" : "表示",
     "Show hidden files" : "隠しファイルを表示",
     "Show file type column" : "ファイルの種類のカラムを表示する",
@@ -116,6 +131,7 @@ OC.L10N.register(
     "General" : "一般",
     "Sort favorites first" : "お気に入りを最初に並べる",
     "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
+    "Enable folder tree view" : "フォルダーツリー表示を有効にする",
     "Default view" : "デフォルト表示",
     "All files" : "すべてのファイル",
     "Personal files" : "個人ファイル",
@@ -135,17 +151,20 @@ OC.L10N.register(
     "Go right in grid" : "グリッド内を右に移動",
     "View" : "表示",
     "Toggle grid view" : "グリッド表示の切り替え",
-    "Open file sidebar" : "ファイルサイドバーを開く",
     "Show those shortcuts" : "これらのショートカットを表示する",
     "Warnings" : "警告",
     "Warn before changing a file extension" : "ファイル拡張子を変更する前に警告する",
+    "Warn before deleting a file" : "ファイルを削除する前に警告する",
     "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "アプリパスワードを作成する",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "このアカウントでは二要素認証が有効化されているため、WebDAV認証に必要です。",
     "How to access files using WebDAV" : "WebDAVを使用してファイルにアクセスする方法",
     "Total rows summary" : "総行数のサマリー",
     "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
     "Name" : "名前",
     "File type" : "ファイルの種類",
     "Size" : "サイズ",
+    "Modified" : "更新日時",
     "{displayName}: failed on some elements" : "{displayName}: いくつかの要素で失敗しました",
     "{displayName}: done" : "{displayName}: 完了",
     "{displayName}: failed" : "{displayName}: 失敗",
@@ -156,6 +175,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
     "File not found" : "ファイルが見つかりません",
     "_{count} selected_::_{count} selected_" : ["{count}選択済み"],
+    "Views" : "表示",
     "Search everywhere …" : "あらゆる場所を検索 …",
     "Search here …" : "ここを検索 …",
     "Search scope options" : "検索範囲オプション",
@@ -214,12 +234,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "ファイル拡張子 \"{old}\" を削除すると、ファイルが読み取れなくなる可能性があります。",
     "Adding the file extension \"{new}\" may render the file unreadable." : "ファイル拡張子 \"{new}\" を追加すると、ファイルが読み取れなくなる可能性があります。",
     "Do not show this dialog again." : "このダイアログを二度と表示しない。",
+    "Rename file to hidden" : "ファイルを隠しファイルに名前を変更する",
+    "Prefixing a filename with a dot may render the file hidden." : "ファイル名の先頭にドットを付けると、そのファイルが非表示になる場合があります。",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "ファイル名を\"{filename}\"に変更してもよろしいですか？",
+    "Cancel" : "キャンセル",
+    "Rename" : "名前の変更",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
     "Choose {file}" : "{file}を選択",
     "Files settings" : "ファイルの設定",
-    "Share" : "共有",
-    "Shared by link" : "URLリンクで共有中",
-    "Shared" : "共有中",
     "Switch to list view" : "リスト表示へ切り替え",
     "Switch to grid view" : "グリッド表示へ切り替え",
     "The file could not be found" : "ファイルが見つかりませんでした",
@@ -229,12 +251,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
     "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
     "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
+    "File list is reloading" : "ファイルリストを再読み込み中",
     "Loading current folder" : "現在のフォルダの読み込み中",
     "Retry" : "リトライ",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
     "Go back" : "戻る",
-    "Views" : "表示",
     "Loading …" : "読み込み中…",
     "Your files" : "あなたのファイル",
     "Open in files" : "ファイルで開く",
@@ -281,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}アイテムを完全に削除しようとしています"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["あなたは {count} 個のアイテムを削除しようとしています"],
     "Confirm deletion" : "削除の確認",
-    "Cancel" : "キャンセル",
     "Download" : "ダウンロード",
     "The requested file is not available." : "要求されたファイルは使用できません。",
     "The requested files are not available." : "要求されたファイルは使用できません。",
     "Add to favorites" : "お気に入りに追加",
     "Remove from favorites" : "お気に入りから削除",
     "Add or remove favorite" : "お気に入りを追加または削除",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "Move" : "移動",
+    "Copy" : "コピー",
+    "Move or copy" : "移動またはコピー",
     "Destination is not a folder" : "宛先がフォルダではありません",
     "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
-    "(copy)" : "(copy)",
-    "(copy %n)" : "(copy %n)",
     "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
     "The files are locked" : "ファイルはロックされています",
     "The file does not exist anymore" : "ファイルはもう存在しません",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
+    "Moving {count} files to \"{destination}\" …" : "{count} 個のファイルを \"{destination}\" に移動中…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "Copying {count} files to \"{destination}\" …" : "{count}個のファイルを \"{destination}\" にコピー中…",
     "Choose destination" : "移動先を選択",
     "Copy to {target}" : "{target} にコピー",
-    "Copy" : "コピー",
     "Move to {target}" : "{target} に移動",
-    "Move" : "移動",
     "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
-    "Move or copy" : "移動またはコピー",
     "Open folder" : "フォルダーを開く",
     "Open folder {displayName}" : "フォルダ {displayName} を開く",
     "Open in Files" : "ファイルアプリで開く",
@@ -314,28 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "ファイルがデバイス上で開くはずです。開かない場合は、デスクトップアプリがインストールされているかご確認ください。",
     "Retry and close" : "再試行して閉じる",
     "Open online" : "オンラインで開く",
-    "Rename" : "名前の変更",
     "Details" : "詳細",
+    "Open the details sidebar" : "詳細サイドバーを開く",
+    "Unfavorite" : "お気に入りから外す",
     "View in folder" : "フォルダー内で表示",
-    "Today" : "今日",
-    "Last 7 days" : "7日以内",
-    "Last 30 days" : "30日以内",
-    "This year ({year})" : "今年 ({year})",
-    "Last year ({year})" : "去年 ({year})",
-    "Documents" : "ドキュメント",
-    "Spreadsheets" : "スプレッドシート",
-    "Presentations" : "プレゼンテーション",
-    "PDFs" : "PDF",
-    "Folders" : "フォルダー",
-    "Audio" : "オーディオ",
-    "Images" : "画像",
-    "Videos" : "動画",
+    "Type" : "タイプ",
     "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
     "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
     "Create templates folder" : "テンプレートフォルダーの作成",
     "Templates" : "テンプレート",
     "New template folder" : "新しいテンプレートフォルダ",
     "In folder" : "フォルダ内",
+    "Pick folder to search in" : "検索対象のフォルダーを選択してください",
     "Search in all files" : "すべてのファイルを検索",
     "Search in folder: {folder}" : "フォルダ内を検索: {folder}",
     "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
@@ -345,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
     "Files uploaded successfully" : "ファイルが正常にアップロードされました",
     "No files to process" : "処理するファイルがありません",
-    "Some files could not be copied" : "いくつかのファイルがコピーできません",
-    "Some files could not be moved" : "いくつかのファイルが移動できません",
     "Files copied successfully" : "ファイルが正常にコピーされました",
     "Files moved successfully" : "ファイルの移動に成功しました",
+    "Some files could not be copied" : "いくつかのファイルがコピーできません",
+    "Some files could not be moved" : "いくつかのファイルが移動できません",
     "Conflicts resolution skipped" : "コンフリクトの解決はスキップされました",
     "Upload cancelled" : "アップロードはキャンセルされました",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
@@ -389,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "この設定を有効にした後、自動的にファイルを移行することも可能です。occコマンドに関するドキュメントを参照してください。",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
+    "Clear filter" : "フィルターをクリア",
     "\"{displayName}\" failed on some elements" : "いくつかの要素で \"{displayName}\" が失敗しました。",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
     "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
     "Submitting fields …" : "フィールドを送信中…",
+    "Shared by link" : "URLリンクで共有中",
+    "Shared" : "共有中",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行されました",
     "Filter file names …" : "ファイルネームフィルター…",
     "Clipboard is not available" : "クリップボードは利用できません",
@@ -434,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "ローカルで編集",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
     "Move cancelled" : "移動はキャンセルされました",
     "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
     "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
@@ -442,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "新しいフォルダーの作成がキャンセルされました",
     "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
     "All folders" : "全てのフォルダー",
+    "Open file sidebar" : "ファイルサイドバーを開く",
     "Search everywhere …" : "あらゆる場所を検索 …",
     "Search here …" : "ここを検索 …",
     "Preparing …" : "準備中 …"
