@@ -54,7 +54,7 @@ OC.L10N.register(
     "Limit must be a positive integer." : "Предел должен быть положительным целым числом.",
     "The replacement character may only be a single character." : "Заменяющий символ может состоять только из одного символа.",
     "Filename sanitization already started." : "Очистка имени файла уже начата.",
-    "No filename sanitization inprogress." : "В процессе работы не выполняется очистка имени файла.",
+    "No filename sanitization in progress." : "В процессе работы не выполняется очистка имени файла.",
     "Favorite files" : "Избранные файлы",
     "No favorites" : "Нет избранного",
     "More favorites" : "Больше избранного",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Обновить текущий каталог",
     "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
     "Current directory path" : "Текущий путь к каталогу",
+    "Share" : "Поделиться",
+    "Reload content" : "Обновить содержимое",
     "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
     "You do not have permission to upload or create files here." : "У вас нет прав загружать или создавать здесь файлы.",
     "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Этот узел недоступен",
     "Another entry with the same name already exists." : "Другая запись с таким же именем уже существует.",
     "Invalid filename." : "Недопустимое имя файла.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
     "Rename file" : "Переименовать файл",
     "Folder" : "Каталог",
     "Unknown file type" : "Неизвестный тип файла",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "{ext} текст",
     "Pending" : "Ожидается",
     "Unknown date" : "Неизвестная дата",
-    "Clear filter" : "Сбросить фильтр",
-    "Modified" : "Изменён",
-    "Search everywhere" : "Искать везде",
-    "Type" : "Тип",
     "Active filters" : "Активные фильтры",
     "Remove filter" : "Удалить фильтр",
+    "Today" : "Сегодня",
+    "Last 7 days" : "Последние 7 дней",
+    "Last 30 days" : "Последние 30 дней",
+    "This year ({year})" : "Этот год ({year})",
+    "Last year ({year})" : "Последний год ({year})",
+    "Custom range" : "Настраиваемый период",
+    "Custom date range" : "Настраиваемый диапазон дат",
+    "Search everywhere" : "Искать везде",
+    "Documents" : "Документы",
+    "Spreadsheets" : "Таблицы",
+    "Presentations" : "Презентации",
+    "PDFs" : "PDFs",
+    "Folders" : "Папки",
+    "Audio" : "Звук",
+    "Images" : "Изображения",
+    "Videos" : "Видео",
+    "Filters" : "Фильтры",
+    "Back to filters" : "Вернуться к фильтрам",
+    "Appearance" : "Внешний вид",
+    "Show hidden files" : "Показывать скрытые файлы",
+    "Show file type column" : "Показать колонку с типом файла",
+    "Show file extensions" : "Показать расширения файлов",
+    "Crop image previews" : "Обрезать пред. просмотр",
+    "General" : "Основные",
+    "Sort favorites first" : "Сначала избранное",
+    "Sort folders before files" : "Начинать список с папок",
+    "Enable folder tree view" : "Включить просмотр дерева папок",
+    "Default view" : "Вид по умолчанию",
+    "All files" : "Все файлы",
+    "Personal files" : "Личные файлы",
+    "Additional settings" : "Дополнительные параметры",
+    "Actions" : "Действия",
+    "File actions" : "Сценарии файла",
+    "Selection" : "Выбор",
+    "Select all files" : "Выбрать все файлы",
+    "Deselect all" : "Снять выбор со всех",
+    "Select or deselect" : "Выбрать или отменить выбор",
+    "Select a range" : "Выберите диапазон",
+    "Navigation" : "Навигация",
+    "Go to parent folder" : "Перейти в родительскую папку",
+    "Go to file above" : "Перейдите к файлу, указанному выше",
+    "Go to file below" : "Перейдите к файлу ниже",
+    "Go left in grid" : "Идите налево по сетке",
+    "Go right in grid" : "Идите направо по сетке",
+    "View" : "Режим просмотра",
+    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
+    "Show those shortcuts" : "Показать ярлыки",
+    "Warnings" : "Предупреждения",
+    "Warn before changing a file extension" : "Предупреждать перед изменением расширения файла",
+    "Warn before deleting a file" : "Предупреждать перед удалением файлов",
+    "WebDAV URL" : "Ссылка WebDAV",
+    "Create an app password" : "Создать пароль приложения",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Требуется для подключения по протоколу WebDAV, т.к. для этой учётной записи включена двухфакторная аутентификация.",
+    "How to access files using WebDAV" : "Как получить доступ к файлам с помощью WebDAV",
     "Total rows summary" : "Количество строк в общем",
     "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
     "Name" : "Имя",
     "File type" : "Тип файла",
     "Size" : "Размер",
+    "Modified" : "Изменён",
     "{displayName}: failed on some elements" : "{displayName}: не удалось выполнить некоторые элементы",
     "{displayName}: done" : "{displayName}: сделано",
     "{displayName}: failed" : "{displayName}: сбой",
-    "Actions" : "Действия",
     "(selected)" : "(выбранный)",
     "List of files and folders." : "Список файлов и каталогов.",
     "You have used your space quota and cannot upload files anymore." : "Вы использовали свою квоту свободного места и больше не можете загружать файлы.",
@@ -124,10 +175,12 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "File not found" : "Файл не найден",
     "_{count} selected_::_{count} selected_" : ["Выбран {count}","Выбрано {count}","Выбрано {count}","Выбрано {count} "],
-    "Search everywhere …" : "Искать везде …",
-    "Search here …" : "Искать здесь …",
+    "Views" : "Представления",
+    "Search everywhere …" : "Искать везде…",
+    "Search here …" : "Искать здесь…",
     "Search scope options" : "Настройки области поиска",
     "Search here" : "Искать здесь",
+    "Owner" : "Владелец",
     "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
     "{used} of {quota} used" : "использовано {used} из {quota}",
     "{relative}% used" : "Использовано {relative}%",
@@ -144,7 +197,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Не удалось обновить статус очистки имени файла.",
     "Filename sanitization in progress." : "Выполняется очистка имени файла.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "В настоящее время {processedUsers} из {totalUsers}учётных записей обработаны.",
-    "Preparing …" : "Подготовка…",
+    "Preparing …" : "Подготовка …",
     "Refresh" : "Обновить",
     "All files have been santized for Windows filename support." : "Все файлы были очищены для поддержки имен файлов Windows.",
     "Some files could not be sanitized, please check your logs." : "Некоторые файлы не удалось очистить, проверьте журналы.",
@@ -159,7 +212,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Очистить имена файлов",
     "(starting)" : "(старт)",
     "Fill template fields" : "Заполните поля шаблона",
-    "Submitting fields …" : "Отправка полей…",
+    "Submitting fields …" : "Отправка полей …",
     "Submit" : "Отправить ответ",
     "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
     "Transfer" : "Передать",
@@ -181,11 +234,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Удаление расширения файла \"{old}\" может сделать файл нечитаемым.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Добавление расширения файла \"{new}\" может сделать его нечитаемым.",
     "Do not show this dialog again." : "Больше не показывать это диалоговое окно.",
+    "Cancel" : "Отменить",
+    "Rename" : "Переименовать",
     "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
     "Choose {file}" : "Выберан {file}",
-    "Share" : "Поделиться",
-    "Shared by link" : "Доступные по ссылке",
-    "Shared" : "Опубликованное",
+    "Files settings" : "Настройки файлов",
     "Switch to list view" : "Переключение в режим просмотра списка",
     "Switch to grid view" : "Переключиться на режим просмотра сеткой",
     "The file could not be found" : "Файл не найден.",
@@ -195,96 +248,45 @@ OC.L10N.register(
     "Error during upload: {message}" : "Ошибка при загрузке: {message}",
     "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
     "Unknown error during upload" : "Неизвестная ошибка при загрузке",
+    "File list is reloading" : "Повторная загрузка списка файлов…",
     "Loading current folder" : "Загрузка текущей папки",
     "Retry" : "Попробовать снова",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "Go back" : "Назад",
-    "Views" : "Представления",
-    "Files settings" : "Настройки файлов",
+    "Loading …" : "Загрузка…",
     "Your files" : "Ваши файлы",
     "Open in files" : "Открыть в приложении Файлы",
     "File cannot be accessed" : "Не удалось получить доступ к файлу",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
     "No search results for “{query}”" : "Нет результатов поиска по запросу «{query}»",
     "Search for files" : "Поиск файлов",
-    "Clipboard is not available" : "Буфер обмена недоступен",
-    "WebDAV URL copied" : "URL-адрес WebDAV скопирован ",
-    "General" : "Основные",
-    "Default view" : "Вид по умолчанию",
-    "All files" : "Все файлы",
-    "Personal files" : "Личные файлы",
-    "Sort favorites first" : "Сначала избранное",
-    "Sort folders before files" : "Начинать список с папок",
-    "Folder tree" : "Дерево папок",
-    "Appearance" : "Внешний вид",
-    "Show hidden files" : "Показывать скрытые файлы",
-    "Show file type column" : "Показать колонку с типом файла",
-    "Show file extensions" : "Показать расширения файлов",
-    "Crop image previews" : "Обрезать пред. просмотр",
-    "Additional settings" : "Дополнительные параметры",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "Ссылка WebDAV",
-    "Copy" : "Копировать",
-    "How to access files using WebDAV" : "Как получить доступ к файлам с помощью WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Для вашего аккаунта включена двухфакторная аутентификация, поэтому вам необходимо использовать пароль приложения чтобы подключить внешний WebDAV клиент.",
-    "Warnings" : "Предупреждения",
-    "Warn before changing a file extension" : "Предупреждать перед изменением расширения файла",
-    "Warn before deleting files" : "Предупреждать перед удалением файлов",
-    "Keyboard shortcuts" : "Сочетания клавиш",
-    "File actions" : "Сценарии файла",
-    "Rename" : "Переименовать",
-    "Delete" : "Удалить",
-    "Add or remove favorite" : "Добавление или удаление избранного",
-    "Manage tags" : "Управление метками",
-    "Selection" : "Выбор",
-    "Select all files" : "Выбрать все файлы",
-    "Deselect all" : "Снять выбор со всех",
-    "Select or deselect" : "Выбрать или отменить выбор",
-    "Select a range" : "Выберите диапазон",
-    "Navigation" : "Навигация",
-    "Go to parent folder" : "Перейти в родительскую папку",
-    "Go to file above" : "Перейдите к файлу, указанному выше",
-    "Go to file below" : "Перейдите к файлу ниже",
-    "Go left in grid" : "Идите налево по сетке",
-    "Go right in grid" : "Идите направо по сетке",
-    "View" : "Режим просмотра",
-    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
-    "Open file sidebar" : "Открыть боковую панель файлов",
-    "Show those shortcuts" : "Показать ярлыки",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Разрешить ограничения на имена файлов для обеспечения возможности их синхронизации со всеми клиентами. По умолчанию разрешены все имена файлов, допустимые в POSIX (например, в Linux или macOS).",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
     "Failed to toggle Windows filename support" : "Не удалось включить поддержку имен файлов в Windows",
     "Files compatibility" : "Совместимость файлов",
     "Enforce Windows compatibility" : "Обеспечить совместимость с Windows",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Это позволит блокировать имена файлов, недопустимые в системах Windows, например, использующие зарезервированные имена или специальные символы. Однако это не обеспечит совместимость в части чувствительности к регистру.",
-    "You" : "Вы",
-    "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
-    "Unable to change the favorite state of the file" : "Невозможно изменить избранное состояние файла",
-    "Error while loading the file data" : "Не удалось загрузить данные файла",
-    "Owner" : "Владелец",
-    "Remove from favorites" : "Удалить из избранных",
-    "Add to favorites" : "Добавить в избранное",
-    "Tags" : "Метки",
     "Blank" : "Пустой",
     "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
     "Pick a template for {name}" : "Выбрать шаблон для {name}",
     "Create a new file with the selected template" : "Создать файл на основе шаблона",
     "Creating file" : "Создание файла",
     "Save as {displayName}" : "Сохранить как {displayName}",
-    "Save as …" : "Сохранить как…",
-    "Converting files …" : "Преобразование файлов…",
+    "Save as …" : "Сохранить как…",
+    "Converting files …" : "Преобразование файлов…",
     "Failed to convert files: {message}" : "Не удалось преобразовать файлы: {message}",
     "All files failed to be converted" : "Не удалось преобразовать все файлы",
     "One file could not be converted: {message}" : "Один файл не удалось преобразовать: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Файл не удалось преобразовать","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы","%n файлы не могут быть преобразованы"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Файл успешно преобразован","%n файлы успешно преобразованы","%n файлы успешно преобразованы","%n файлы успешно преобразованы"],
-    "Files successfully converted" : "Файлы успешно конвертированы",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n файл не может быть преобразован","%n файла не могут быть преобразованы","%n файлов не могут быть преобразованы","%n файлов не могут быть преобразованы"],
+    "_%n file converted_::_%n files converted_" : ["%n файл преобразован","%n файла преобразованы","%n файлов преобразованы","%n файлов преобразованы"],
+    "Files converted" : "Файлы преобразованы",
     "Failed to convert files" : "Не удалось преобразовать файлы",
-    "Converting file …" : "Преобразование файла…",
+    "Converting file …" : "Преобразование файла…",
     "File successfully converted" : "Файл успешно преобразован",
     "Failed to convert file: {message}" : "Не удалось преобразовать файл: {message}",
     "Failed to convert file" : "Не удалось преобразовать файл",
+    "Delete" : "Удалить",
     "Leave this share" : "Перестать использовать общий ресурс",
     "Leave these shares" : "Отказаться от доступа к общим ресурсам",
     "Disconnect storage" : "Отсоединить хранилище",
@@ -298,26 +300,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы собираетесь безвозвратно удалить {count} элемент","Вы собираетесь безвозвратно удалить {count} элемента","Вы собираетесь безвозвратно удалить {count} элементов","Вы собираетесь безвозвратно удалить {count} элементов"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Подтвердите удаление {count} объекта.","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов"],
     "Confirm deletion" : "Подтвердить удаление",
-    "Cancel" : "Отменить",
     "Download" : "Скачать",
     "The requested file is not available." : "Запрошенный файл недоступен.",
     "The requested files are not available." : "Запрошенные файлы недоступны.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
+    "Add to favorites" : "Добавить в избранное",
+    "Remove from favorites" : "Удалить из избранных",
+    "Add or remove favorite" : "Добавление или удаление избранного",
+    "Move" : "Переместить",
+    "Copy" : "Копировать",
+    "Move or copy" : "Переместить или копировать",
     "Destination is not a folder" : "Указанное назначение не является папкой",
     "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
-    "(copy)" : "(копия)",
-    "(copy %n)" : "(копия %n)",
     "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
     "The files are locked" : "Файлы заблокированы",
     "The file does not exist anymore" : "Файл больше не существует",
+    "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
     "Choose destination" : "Выберите место назначения",
     "Copy to {target}" : "Скопировать в «{target}»",
     "Move to {target}" : "Переместить в «{target}»",
-    "Move" : "Переместить",
     "Move or copy operation failed" : "Ошибка перемещение или копирования",
-    "Move or copy" : "Переместить или копировать",
+    "Open folder" : "Открыть папку",
     "Open folder {displayName}" : "Открыть папку «{displayName}»",
     "Open in Files" : "Открыть в приложении «Файлы»",
     "Open locally" : "Открыть локально",
@@ -327,26 +331,17 @@ OC.L10N.register(
     "Retry and close" : "Повторить попытку и закрыть",
     "Open online" : "Открыть онлайн",
     "Details" : "Подробно",
+    "Open the details sidebar" : "Открыть боковую панель с подробными сведениями",
+    "Unfavorite" : "Убрать из избранного",
     "View in folder" : "Посмотреть в каталоге",
-    "Today" : "Сегодня",
-    "Last 7 days" : "Последние 7 дней",
-    "Last 30 days" : "Последние 30 дней",
-    "This year ({year})" : "Этот год ({year})",
-    "Last year ({year})" : "Последний год ({year})",
-    "Documents" : "Документы",
-    "Spreadsheets" : "Таблицы",
-    "Presentations" : "Презентации",
-    "PDFs" : "PDFs",
-    "Folders" : "Папки",
-    "Audio" : "Звук",
-    "Images" : "Изображения",
-    "Videos" : "Видео",
+    "Type" : "Тип",
     "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
     "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "Create templates folder" : "Создать папку шаблонов",
     "Templates" : "Шаблоны",
     "New template folder" : "Новая папка шаблонов",
     "In folder" : "В папке",
+    "Pick folder to search in" : "Выбрать папку для поиска",
     "Search in all files" : "Поиск во всех файлах",
     "Search in folder: {folder}" : "Поиск в папке: «{folder}»",
     "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
@@ -356,14 +351,14 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Не удалось загрузить некоторые файлы",
     "Files uploaded successfully" : "Файлы успешно обновлены",
     "No files to process" : "Нет файлов для обработки",
-    "Some files could not be copied" : "Не удалось скопировать некоторые файлы",
-    "Some files could not be moved" : "Не удалось переместить некоторые файлы",
     "Files copied successfully" : "Файлы успешно скопированы",
     "Files moved successfully" : "Файлы успешно перемещены",
+    "Some files could not be copied" : "Не удалось скопировать некоторые файлы",
+    "Some files could not be moved" : "Не удалось переместить некоторые файлы",
     "Conflicts resolution skipped" : "Разрешение конфликтов пропущено",
     "Upload cancelled" : "Передача на сервер отменена",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
-    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{newName}» уже используется в папке «{dir}». Выберите другое имя.",
     "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
     "This operation is forbidden" : "Операция запрещена",
     "This folder is unavailable, please try again later or contact the administration" : "Эта папка недоступна, пожалуйста, повторите попытку позже или свяжитесь с администрацией",
@@ -381,6 +376,7 @@ OC.L10N.register(
     "No favorites yet" : "В избранное ещё ничего не добавлено ",
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
     "List of your files and folders." : "Список ваших файлов и каталогов.",
+    "Folder tree" : "Дерево папок",
     "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
     "No personal files found" : "Личные файлы не найдены",
     "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
@@ -394,119 +390,32 @@ OC.L10N.register(
     "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
-    "File could not be found" : "Невозможно найти файл",
-    "Show list view" : "Просмотр списком",
-    "Show grid view" : "Просмотр сеткой",
-    "Close" : "Закрыть",
-    "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
-    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
-    "Upload cancelled." : "Отправка отменена.",
-    "Processing files …" : "Обработка файлов…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно передать «{filename}», так как это либо каталог, либо файл нулевого размера",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
-    "An unknown error has occurred" : "Произошла неизвестная ошибка",
-    "File could not be uploaded" : "Файл не может быть загружен",
-    "Uploading …" : "Передача…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Загрузка … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
-    "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
-    "Choose target folder" : "Выбор папки назначения",
-    "Set reminder" : "Установить напоминание",
-    "Edit locally" : "Редактировать локально",
-    "Open" : "Открыть",
-    "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Выберите метки для назначения выбранным объектам",
-    "Apply tag(s) to selection" : "Назначить метки выбранным объектам",
-    "Select directory \"{dirName}\"" : "Выберите каталог \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Выберите файл \"{fileName}\"",
-    "Unable to determine date" : "Невозможно определить дату",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
-    "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
-    "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
-    "copy" : "копия",
-    "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
-    "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
-    "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
-    "{newName} already exists" : "«{newName}» уже существует",
-    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
-    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
-    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
-    "Could not fetch file details \"{file}\"" : "Не удалось получить сведения о файле «{file}»",
-    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Введите более двух символов для поиска в других каталогах",
-    "{dirs} and {files}" : "{dirs} и {files}",
-    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
-    "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
-    "_Uploading %n file_::_Uploading %n files_" : ["Передача %n файла","Передача %n файлов","Передача %n файлов","Передача %n файлов"],
-    "New" : "Новый",
-    "New file/folder menu" : "Меню создания файла или папки",
-    "Select file range" : "Выбор диапазона файлов",
-    "{used}%" : "{used}%",
-    "{used} used" : "Использовано {used}",
-    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
-    "File name cannot be empty." : "Имя файла не может быть пустым.",
-    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
-    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы не могут быть обновлены или синхронизированы.",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Папки группы «{mountPoint}» заполнена, файлы не могут быть обновлены или синхронизированы.",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Внешнее хранилище «{mountPoint}» заполнено, файлы не могут быть обновлены или синхронизированы.",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше хранилище заполнено, файлы не могут быть обновлены или синхронизированы.",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Хранилище пользователя {owner} почти заполнено (использовано {usedSpacePercent} %).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Папка группы «{mountPoint}» почти заполнена (использовано ({usedSpacePercent} %).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Внешнее хранилище «{mountPoint}» почти заполнено (использовано {usedSpacePercent} %).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых уже есть доступ к этому файлу или папке. ",
-    "Path" : "Путь",
-    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
-    "Favored" : "Избранные",
-    "Favor" : "Услуга",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Копировать прямую ссылку (она сработает только для пользователей, у которых уже есть доступ к этому файлу или каталогу)",
-    "Upload file" : "Загрузить файл",
-    "Not favored" : "Не одобрен",
-    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
+    "%1$s (renamed)" : "%1$s (переименовано)",
+    "renamed file" : "переименованный файл",
     "Upload (max. %s)" : "Загрузка (максимум %s)",
-    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
-    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Также возможно мигрировать файлы автоматически после включения этой настройки, пожалуйста, обратитесь к документации о команде occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
+    "Clear filter" : "Сбросить фильтр",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" не удалось выполнить некоторые элементы",
     "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
-    "Submitting fields…" : "Отправка полей…",
-    "Filter filenames…" : "Фильтровать имена файлов…",
+    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
+    "Submitting fields …" : "Отправка полей…",
+    "Shared by link" : "Доступные по ссылке",
+    "Shared" : "Опубликованное",
+    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
+    "Filter file names …" : "Фильтровать имена файлов…",
+    "Clipboard is not available" : "Буфер обмена недоступен",
     "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
     "Enable the grid view" : "Включить режим просмотра сеткой",
     "Enable folder tree" : "Включить дерево папок",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Копировать в буфер",
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
-    "Deletion cancelled" : "Удаление отменено",
-    "Move cancelled" : "Перемещение отменено",
-    "Cancelled move or copy of \"{filename}\"." : "Отменено перемещение или копирование \"{filename}\".",
-    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
-    "Open details" : "Открыть подробности",
-    "Photos and images" : "Фотографии и изображения",
-    "New folder creation cancelled" : "Создание новой папки отменено",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки","{folderCount} папок","{folderCount} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файла","{fileCount} файлов","{fileCount} файла"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
-    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
-    "All folders" : "Все папки",
-    "Personal Files" : "Личные файлы",
-    "Text file" : "Текстовый файл",
-    "New text file.txt" : "Новый текстовый файл.txt",
-    "%1$s (renamed)" : "%1$s (переименовано)",
-    "renamed file" : "переименованный файл",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Также возможно мигрировать файлы автоматически после включения этой настройки, пожалуйста, обратитесь к документации о команде occ.",
-    "Filter file names …" : "Фильтровать имена файлов…",
     "Prevent warning dialogs from open or reenable them." : "Предотвратить открытие диалоговых окон с предупреждениями или включить их повторно.",
     "Show a warning dialog when changing a file extension." : "Показать диалоговое окно предупреждения при изменении расширения файла.",
+    "Keyboard shortcuts" : "Сочетания клавиш",
     "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
     "Open the actions menu for a file" : "Открыть меню действий для файла",
     "Rename a file" : "Переименовать файл",
@@ -522,6 +431,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Перейдите к файлу слева (в режиме сетки)",
     "Navigate to the file on the right (in grid mode)" : "Перейдите к файлу справа (в режиме сетки)",
     "Toggle the grid view" : "Переключение вида сетки",
-    "Open the sidebar for a file" : "Откройте боковую панель для поиска файла"
+    "Open the sidebar for a file" : "Откройте боковую панель для поиска файла",
+    "You" : "Вы",
+    "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
+    "Unable to change the favorite state of the file" : "Невозможно изменить избранное состояние файла",
+    "Error while loading the file data" : "Не удалось загрузить данные файла",
+    "Tags" : "Метки",
+    "Save as …" : "Сохранить как…",
+    "Converting files …" : "Преобразование файлов…",
+    "Converting file …" : "Преобразование файла…",
+    "Deletion cancelled" : "Удаление отменено",
+    "Edit locally" : "Редактировать локально",
+    "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
+    "(copy)" : "(копия)",
+    "(copy %n)" : "(копия %n)",
+    "Move cancelled" : "Перемещение отменено",
+    "Cancelled move or copy of \"{filename}\"." : "Отменено перемещение или копирование \"{filename}\".",
+    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
+    "Open details" : "Открыть подробности",
+    "Photos and images" : "Фотографии и изображения",
+    "New folder creation cancelled" : "Создание новой папки отменено",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
+    "All folders" : "Все папки",
+    "Open file sidebar" : "Открыть боковую панель файлов",
+    "Search everywhere …" : "Искать везде…",
+    "Search here …" : "Искать здесь…",
+    "Preparing …" : "Подготовка…"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
