@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Znova načítať súčasný adresár",
     "Go to the \"{dir}\" directory" : "Ísť do \"{dir}\" adresára",
     "Current directory path" : "Aktuálna cesta k adresáru",
+    "Share" : "Zdieľať",
+    "Reload content" : "Znovu načítať obsah",
     "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
     "You do not have permission to upload or create files here." : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory.",
     "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Uzol nie je k dispozícií",
     "Another entry with the same name already exists." : "Iná položka s rovnakým menom už existuje.",
     "Invalid filename." : "Chybný názov súboru.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
     "Rename file" : "Premenovať súbor",
     "Folder" : "Priečinok",
     "Unknown file type" : "Neznámy typ súboru",
@@ -102,12 +103,26 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "Čaká",
     "Unknown date" : "Neznámy dátum",
-    "Clear filter" : "Vyčistiť filter",
-    "Modified" : "Upravené",
-    "Search everywhere" : "Hľadať všade",
-    "Type" : "Typ",
     "Active filters" : "Aktívne filtre",
     "Remove filter" : "Odstrániť filter",
+    "Today" : "Dnes",
+    "Last 7 days" : "Posledných 7 dní",
+    "Last 30 days" : "Posledných 30 dní",
+    "This year ({year})" : "Tento rok ({year})",
+    "Last year ({year})" : "Minulý rok ({year})",
+    "Custom range" : "Vlastný rozsah",
+    "Custom date range" : "Vlastné rozpätie dátumov",
+    "Search everywhere" : "Hľadať všade",
+    "Documents" : "Dokumenty",
+    "Spreadsheets" : "Tabuľky",
+    "Presentations" : "Prezentácie",
+    "PDFs" : "PDFká",
+    "Folders" : "Priečinky",
+    "Audio" : "Zvuk",
+    "Images" : "Obrázky",
+    "Videos" : "Videá",
+    "Filters" : "Filtre",
+    "Back to filters" : "Späť k filtrom",
     "Appearance" : "Vzhľad",
     "Show hidden files" : "Zobraziť skryté súbory",
     "Show file type column" : "Zobraziť stĺpec typu súboru",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "Prejsť doprava v mriežke",
     "View" : "Zobraziť",
     "Toggle grid view" : "Prepnúť zobrazenie mriežky",
-    "Open file sidebar" : "Otvoriť bočný panel súboru",
     "Show those shortcuts" : "Zobraziť klávesové skratky",
     "Warnings" : "Upozornenia",
     "Warn before changing a file extension" : "Upozorniť pred zmenou prípony súboru",
@@ -150,6 +164,7 @@ OC.L10N.register(
     "Name" : "Názov",
     "File type" : "Typ súboru",
     "Size" : "Veľkosť",
+    "Modified" : "Upravené",
     "{displayName}: failed on some elements" : "{displayName}: zlyhalo na niektorých prvkoch",
     "{displayName}: done" : "{displayName}: hotovo",
     "{displayName}: failed" : "{displayName}: zlyhalo",
@@ -160,6 +175,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
     "File not found" : "Súbor nenájdený",
     "_{count} selected_::_{count} selected_" : ["{count} vybraný","{count} vybrané","{count} vybraných","{count} vybraných"],
+    "Views" : "Zobrazenia",
     "Search everywhere …" : "Hľadať všade ...",
     "Search here …" : "Hľadať tu …",
     "Search scope options" : "Možnosti rozsahu vyhľadávania",
@@ -218,12 +234,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Odstránenie prípony súboru „{old}“ môže spôsobiť, že súbor bude nečitateľný.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Pridanie prípony súboru „{new}“ môže spôsobiť, že súbor bude nečitateľný.",
     "Do not show this dialog again." : "Toto dialógové okno už nezobrazovať.",
+    "Rename file to hidden" : "Premenovať súbor na skrytie",
+    "Prefixing a filename with a dot may render the file hidden." : "Predpona názvu súboru bodkou môže spôsobiť, že súbor bude skrytý.",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "Ste si istí, že chcete premenovať súbor na \"{filename}\"?",
+    "Cancel" : "Zrušiť",
+    "Rename" : "Premenovať",
     "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
     "Choose {file}" : "Vyberte {file}",
     "Files settings" : "Nastavenia súborov",
-    "Share" : "Zdieľať",
-    "Shared by link" : "Sprístupnené odkazom",
-    "Shared" : "Sprístupnené",
     "Switch to list view" : "Prepnúť na zobrazenie v zozname",
     "Switch to grid view" : "Prepnúť na zobrazenie v mriežke",
     "The file could not be found" : "Súbor nebol nájdený",
@@ -233,12 +251,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
     "Error during upload, status code {status}" : "Chyba počas nahrávania, chybový kód {status}",
     "Unknown error during upload" : "Neznáma chyba počas nahrávania",
+    "File list is reloading" : "Zoznam súborov sa znova načítava",
     "Loading current folder" : "Načítavanie súčasného priečinka",
     "Retry" : "Zopakovať",
     "No files in here" : "Nie sú tu žiadne súbory",
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
     "Go back" : "Ísť späť",
-    "Views" : "Zobrazenia",
     "Loading …" : "Načítava sa …",
     "Your files" : "Vaše súbory",
     "Open in files" : "Otvoriť v súboroch",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte sa permanentne vymazať {count} položku","Chystáte sa permanentne vymazať {count} položky","Chystáte sa permanentne vymazať {count} položiek","Chystáte sa permanentne vymazať {count} položiek"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte sa vymazať {count} položku","Chystáte sa vymazať {count} položky","Chystáte sa vymazať {count} položiek","Chystáte sa vymazať {count} položiek"],
     "Confirm deletion" : "Potvrdiť vymazanie",
-    "Cancel" : "Zrušiť",
     "Download" : "Stiahnuť",
     "The requested file is not available." : "Požadovaný súbor nie je k dispozícii.",
     "The requested files are not available." : "Požadované súbory nie sú k dispozícii.",
     "Add to favorites" : "Pridať do obľúbených",
     "Remove from favorites" : "Odstrániť z obľúbených",
     "Add or remove favorite" : "Pridať alebo odstrániť obľúbené",
-    "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
+    "Move" : "Presunúť",
+    "Copy" : "Kopírovať",
+    "Move or copy" : "Presunúť alebo kopírovať",
     "Destination is not a folder" : "Cieľ nie je priečinok",
     "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
-    "(copy)" : "(kopírovať)",
-    "(copy %n)" : "(kopírovať %n)",
     "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
     "The files are locked" : "Súbory sú uzamknuté.",
     "The file does not exist anymore" : "Súbor už neexistuje",
+    "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
+    "Moving {count} files to \"{destination}\" …" : "Presúvanie {count} súborov do \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
+    "Copying {count} files to \"{destination}\" …" : "Kopírovanie {count} súborov do \"{destination}\" …",
     "Choose destination" : "Vyberte cieľ",
     "Copy to {target}" : "Kopírovať do {target}",
-    "Copy" : "Kopírovať",
     "Move to {target}" : "Presunúť do {target}",
-    "Move" : "Presunúť",
     "Move or copy operation failed" : "Operácia presunu alebo kopírovania zlyhala",
-    "Move or copy" : "Presunúť alebo kopírovať",
     "Open folder" : "Otvoriť priečinok",
     "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
     "Open in Files" : "Otvoriť v súboroch",
@@ -318,28 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Súbor by sa mal teraz otvoriť v zariadení. Ak sa tak nestane, skontrolujte, či máte nainštalovanú aplikáciu pre počítače.",
     "Retry and close" : "Skúsiť znova a zatvoriť",
     "Open online" : "Otvoriť online",
-    "Rename" : "Premenovať",
     "Details" : "Podrobnosti",
+    "Open the details sidebar" : "Otvoriť bočný panel s podrobnosťami",
+    "Unfavorite" : "Odobrať z obľúbených",
     "View in folder" : "Zobraziť v priečinku",
-    "Today" : "Dnes",
-    "Last 7 days" : "Posledných 7 dní",
-    "Last 30 days" : "Posledných 30 dní",
-    "This year ({year})" : "Tento rok ({year})",
-    "Last year ({year})" : "Minulý rok ({year})",
-    "Documents" : "Dokumenty",
-    "Spreadsheets" : "Tabuľky",
-    "Presentations" : "Prezentácie",
-    "PDFs" : "PDFká",
-    "Folders" : "Priečinky",
-    "Audio" : "Zvuk",
-    "Images" : "Obrázky",
-    "Videos" : "Videá",
+    "Type" : "Typ",
     "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
     "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
     "Create templates folder" : "Vytvoriť adresár pre šablóny",
     "Templates" : "Šablóny",
     "New template folder" : "Nový adresár šablóny",
     "In folder" : "V adresári",
+    "Pick folder to search in" : "Vybrať priečinok na vyhľadávanie",
     "Search in all files" : "Hľadať vo všetkých súboroch",
     "Search in folder: {folder}" : "Hľadať v adresári: {folder}",
     "One of the dropped files could not be processed" : "Jeden z vložených súborov nemohol byť spracovaný.",
@@ -349,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Niektoré súbory nebolo možné nahrať.",
     "Files uploaded successfully" : "Súbory boli úspešne nahrané.",
     "No files to process" : "Žiadne súbory pre spracovanie",
-    "Some files could not be copied" : "Niektoré súbory nebolo možné skopírovať",
-    "Some files could not be moved" : "Niektoré súbory nebolo možné presunúť",
     "Files copied successfully" : "Súbory boli úspešne skopírované",
     "Files moved successfully" : "Súbory boli úspešne presunuté",
+    "Some files could not be copied" : "Niektoré súbory nebolo možné skopírovať",
+    "Some files could not be moved" : "Niektoré súbory nebolo možné presunúť",
     "Conflicts resolution skipped" : "Riešenie konfliktov bolo preskočené",
     "Upload cancelled" : "Odosielanie bolo zrušené",
     "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
@@ -393,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Nahrať (max. %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po povolení názvov súborov kompatibilných s Windows už nie je možné upravovať existujúce súbory, ale ich vlastník ich môže premenovať na platné nové názvy.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Je tiež možné automaticky migrovať súbory po povolení tohto nastavenia, prosím, prečítajte si dokumentáciu o príkaze occ.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
+    "Clear filter" : "Vyčistiť filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" zlyhalo na niektorých prvkoch.",
     "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
     "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
     "Submitting fields …" : "Položky sa odosielajú ...",
+    "Shared by link" : "Sprístupnené odkazom",
+    "Shared" : "Sprístupnené",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
     "Filter file names …" : "Filtrovať názvy súborov ...",
     "Clipboard is not available" : "Schránka nie je prístupná",
@@ -438,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "Editovať lokálne",
     "Moving \"{source}\" to \"{destination}\" …" : "Presúvanie \"{source}\" do \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Kopírovanie \"{source}\" do \"{destination}\" …",
+    "(copy)" : "(kopírovať)",
+    "(copy %n)" : "(kopírovať %n)",
     "Move cancelled" : "Presun zrušený",
     "Cancelled move or copy of \"{filename}\"." : "Zrušené kopírovanie alebo presun \"{filename}\".",
     "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
@@ -446,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Vytvorenie adresára bolo zrušené",
     "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
     "All folders" : "Všetky adresáre",
+    "Open file sidebar" : "Otvoriť bočný panel súboru",
     "Search everywhere …" : "Hľadať všade ...",
     "Search here …" : "Hľadať tu …",
     "Preparing …" : "Pripravuje sa …"
