@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "Ladda om nuvarande mapp",
     "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
     "Current directory path" : "Aktuell katalogsökväg",
+    "Share" : "Dela",
+    "Reload content" : "Ladda om innehåll",
     "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
     "You do not have permission to upload or create files here." : "Du har inte behörighet att ladda upp eller skapa filer här.",
     "Drag and drop files here to upload" : "Dra och släpp filer här för att ladda upp",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "Den här noden är inte tillgänglig",
     "Another entry with the same name already exists." : "En annan post med samma namn finns redan.",
     "Invalid filename." : "Ogiltigt filnamn.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "Bytte namn på \"{oldName}\" till \"{newName}\"",
     "Rename file" : "Byt namn på fil",
     "Folder" : "Mapp",
     "Unknown file type" : "Okänd filtyp",
@@ -102,21 +103,70 @@ OC.L10N.register(
     "{ext} text" : "{ext} text",
     "Pending" : "Väntar",
     "Unknown date" : "Okänt datum",
-    "Clear filter" : "Rensa filter",
-    "Modified" : "Ändrad",
-    "Search everywhere" : "Sök överallt",
-    "Type" : "Typ",
     "Active filters" : "Aktiva filter",
     "Remove filter" : "Ta bort filter",
+    "Today" : "Idag",
+    "Last 7 days" : "Senaste 7 dagarna",
+    "Last 30 days" : "Senaste 30 dagarna",
+    "This year ({year})" : "I år ({year})",
+    "Last year ({year})" : "Förra året ({year})",
+    "Custom date range" : "Anpassat datumintervall",
+    "Search everywhere" : "Sök överallt",
+    "Documents" : "Dokument",
+    "Spreadsheets" : "Kalkylblad",
+    "Presentations" : "Presentationer",
+    "PDFs" : "PDF-filer",
+    "Folders" : "Mappar",
+    "Audio" : "Ljud",
+    "Images" : "Bilder",
+    "Videos" : "Videor",
+    "Filters" : "Filter",
+    "Back to filters" : "Tillbaka till filter",
+    "Appearance" : "Utseende",
+    "Show hidden files" : "Visa dolda filer",
+    "Show file type column" : "Visa kolumn för filtyp",
+    "Show file extensions" : "Visa filändelser",
+    "Crop image previews" : "Beskär förhandsgranskningar för bilder",
+    "General" : "Allmänt",
+    "Sort favorites first" : "Sortera favoriter först",
+    "Sort folders before files" : "Sortera mappar före filer",
+    "Enable folder tree view" : "Aktivera trädvy för mappar",
+    "Default view" : "Standardvy",
+    "All files" : "Alla filer",
+    "Personal files" : "Personliga filer",
+    "Additional settings" : "Övriga inställningar",
+    "Actions" : "Funktioner",
+    "File actions" : "Filåtgärder",
+    "Selection" : "Markerade",
+    "Select all files" : "Välj alla filer",
+    "Deselect all" : "Avmarkera alla",
+    "Select or deselect" : "Markera eller avmarkera",
+    "Select a range" : "Markera ett intervall",
+    "Navigation" : "Navigering",
+    "Go to parent folder" : "Gå till överordnad mapp",
+    "Go to file above" : "Gå till filen ovanför",
+    "Go to file below" : "Gå till filen nedanför",
+    "Go left in grid" : "Gå åt vänster i rutnätet",
+    "Go right in grid" : "Gå åt höger i rutnätet",
+    "View" : "Visa",
+    "Toggle grid view" : "Växla rutnätsvy",
+    "Show those shortcuts" : "Visa dessa genvägar",
+    "Warnings" : "Varningar",
+    "Warn before changing a file extension" : "Varna innan en filändelse ändras",
+    "Warn before deleting a file" : "Varna innan en fil tas bort",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "Skapa ett applösenord",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Krävs för WebDAV-autentisering eftersom tvåfaktorsautentisering är aktiverad för detta konto.",
+    "How to access files using WebDAV" : "Hur du får åtkomst till filer via WebDAV",
     "Total rows summary" : "Sammanfattning antal rader",
     "Toggle selection for all files and folders" : "Växla markering för alla filer och mappar",
     "Name" : "Namn",
     "File type" : "Filtyp",
     "Size" : "Storlek",
+    "Modified" : "Ändrad",
     "{displayName}: failed on some elements" : "{displayName}: misslyckades för vissa element",
     "{displayName}: done" : "{displayName}: klar",
     "{displayName}: failed" : "{displayName}: misslyckades",
-    "Actions" : "Funktioner",
     "(selected)" : "(vald)",
     "List of files and folders." : "Lista över filer och mappar.",
     "You have used your space quota and cannot upload files anymore." : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer.",
@@ -124,10 +174,12 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
     "File not found" : "Filen kunde inte hittas",
     "_{count} selected_::_{count} selected_" : ["{count} vald","{count} valda"],
-    "Search everywhere …" : "Sök överallt …",
-    "Search here …" : "Sök här …",
+    "Views" : "Vyer",
+    "Search everywhere …" : "Sök överallt …",
+    "Search here …" : "Sök här …",
     "Search scope options" : "Alternativ för sökomfång",
     "Search here" : "Sök här",
+    "Owner" : "Ägare",
     "{usedQuotaByte} used" : "{usedQuotaByte} använt",
     "{used} of {quota} used" : "{used} av {quota} använt",
     "{relative}% used" : "{relative}% använt",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Kunde inte uppdatera status för filnamnssanering.",
     "Filename sanitization in progress." : "Filnamnssanering pågår.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "För närvarande har {processedUsers} av {totalUsers} konton redan behandlats.",
-    "Preparing …" : "Förbereder …",
+    "Preparing …" : "Förbereder …",
     "Refresh" : "Uppdatera",
     "All files have been santized for Windows filename support." : "Alla filer har sanerats för att stödja filnamn i Windows.",
     "Some files could not be sanitized, please check your logs." : "Vissa filer kunde inte saneras, kontrollera loggarna.",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Sanera filnamn",
     "(starting)" : "(startar)",
     "Fill template fields" : "Fyll mallfält",
-    "Submitting fields …" : "Skickar fält ...",
+    "Submitting fields …" : "Skickar fält …",
     "Submit" : "Skicka",
     "Choose a file or folder to transfer" : "Välj en fil eller mapp att överföra",
     "Transfer" : "Överför",
@@ -181,11 +233,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Att ta bort filtillägget \"{old}\" kan göra filen oläsbar.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Att lägga till filtillägget \"{new}\" kan göra filen oläsbar.",
     "Do not show this dialog again." : "Visa inte denna dialog igen.",
+    "Cancel" : "Avbryt",
+    "Rename" : "Byt namn",
     "Select file or folder to link to" : "Välj fil eller mapp att länka till",
     "Choose {file}" : "Välj {file}",
-    "Share" : "Dela",
-    "Shared by link" : "Delad via länk",
-    "Shared" : "Delad",
+    "Files settings" : "Filinställningar",
     "Switch to list view" : "Växla till listvy",
     "Switch to grid view" : "Växla till rutnätsvy",
     "The file could not be found" : "Filen kunde inte hittas",
@@ -195,96 +247,45 @@ OC.L10N.register(
     "Error during upload: {message}" : "Fel vid uppladdning: {message}",
     "Error during upload, status code {status}" : "Fel vid uppladdning, statuskod {status}",
     "Unknown error during upload" : "Okänt fel under uppladdning",
+    "File list is reloading" : "Fillista hämtas",
     "Loading current folder" : "Laddar aktuell mapp",
     "Retry" : "Försök igen",
     "No files in here" : "Inga filer kunde hittas",
     "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
     "Go back" : "Gå tillbaks",
-    "Views" : "Vyer",
-    "Files settings" : "Filinställningar",
+    "Loading …" : "Laddar …",
     "Your files" : "Dina filer",
     "Open in files" : "Öppna i filer",
     "File cannot be accessed" : "Det går inte att komma åt filen",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunde inte hittas eller så har du inte behörighet att visa den. Be avsändaren att dela den.",
     "No search results for “{query}”" : "Inget sökresultat för “{query}”",
     "Search for files" : "Sök efter filer",
-    "Clipboard is not available" : "Urklipp är inte tillgängligt",
-    "WebDAV URL copied" : "WebDAV-adress kopierad",
-    "General" : "Allmänt",
-    "Default view" : "Standardvy",
-    "All files" : "Alla filer",
-    "Personal files" : "Personliga filer",
-    "Sort favorites first" : "Sortera favoriter först",
-    "Sort folders before files" : "Sortera mappar före filer",
-    "Folder tree" : "Mappträd",
-    "Appearance" : "Utseende",
-    "Show hidden files" : "Visa dolda filer",
-    "Show file type column" : "Visa kolumn för filtyp",
-    "Show file extensions" : "Visa filändelser",
-    "Crop image previews" : "Beskär förhandsgranskningar för bilder",
-    "Additional settings" : "Övriga inställningar",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "Kopiera",
-    "How to access files using WebDAV" : "Hur du får åtkomst till filer via WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Tvåfaktorsautentisering är aktiverad för ditt konto och därför måste du använda ett applösenord för att ansluta en extern WebDAV-klient.",
-    "Warnings" : "Varningar",
-    "Warn before changing a file extension" : "Varna innan en filändelse ändras",
-    "Warn before deleting files" : "Varna innan filer tas bort",
-    "Keyboard shortcuts" : "Tangentbordsgenvägar",
-    "File actions" : "Filåtgärder",
-    "Rename" : "Byt namn",
-    "Delete" : "Radera",
-    "Add or remove favorite" : "Lägg till eller ta bort favorit",
-    "Manage tags" : "Hantera taggar",
-    "Selection" : "Markerade",
-    "Select all files" : "Välj alla filer",
-    "Deselect all" : "Avmarkera alla",
-    "Select or deselect" : "Markera eller avmarkera",
-    "Select a range" : "Markera ett intervall",
-    "Navigation" : "Navigering",
-    "Go to parent folder" : "Gå till överordnad mapp",
-    "Go to file above" : "Gå till filen ovanför",
-    "Go to file below" : "Gå till filen nedanför",
-    "Go left in grid" : "Gå åt vänster i rutnätet",
-    "Go right in grid" : "Gå åt höger i rutnätet",
-    "View" : "Visa",
-    "Toggle grid view" : "Växla rutnätsvy",
-    "Open file sidebar" : "Öppna filens sidofält",
-    "Show those shortcuts" : "Visa dessa genvägar",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Tillåt att begränsa filnamn för att säkerställa att filer kan synkroniseras med alla klienter. Som standard är alla filnamn som är giltiga på POSIX (t.ex. Linux eller macOS) tillåtna.",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "När Windows-kompatibla filnamn har aktiverats kan befintliga filer inte längre ändras, men de kan byta namn till giltiga nya namn av sin ägare.",
     "Failed to toggle Windows filename support" : "Kunde inte växla stöd för filnamn i Windows",
     "Files compatibility" : "Filkompatibilitet",
     "Enforce Windows compatibility" : "Tvinga Windows-kompatibilitet",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Detta kommer att blockera filnamn som inte är giltiga på Windows-system, som att använda reserverade namn eller specialtecken. Men detta kommer inte att framtvinga kompatibiliteten för skiftlägeskänslighet.",
-    "You" : "Du",
-    "Shared multiple times with different people" : "Delad flera gånger med olika personer",
-    "Unable to change the favorite state of the file" : "Kan inte ändra filens favoritstatus",
-    "Error while loading the file data" : "Fel vid inläsning av fildata",
-    "Owner" : "Ägare",
-    "Remove from favorites" : "Ta bort från favoriter",
-    "Add to favorites" : "Lägg till i favoriter",
-    "Tags" : "Taggar",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kunde inte skapa fil från mall",
     "Pick a template for {name}" : "Välj en mall för {name}",
     "Create a new file with the selected template" : "Skapa en ny fil med den valda mallen",
     "Creating file" : "Skapar fil",
     "Save as {displayName}" : "Spara som {displayName}",
-    "Save as …" : "Spara som …",
-    "Converting files …" : "Konverterar filer ...",
+    "Save as …" : "Spara som …",
+    "Converting files …" : "Konverterar filer …",
     "Failed to convert files: {message}" : "Kunde inte konvertera filer: {message}",
     "All files failed to be converted" : "Alla filer misslyckades med att konverteras",
     "One file could not be converted: {message}" : "En fil kunde inte konverteras: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["En fil kunde inte konverteras","%n filer kunde inte konverteras"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["En fil har konverterats","%n filer har konverterats"],
-    "Files successfully converted" : "Filerna har konverterats",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n fil kunde inte konverteras","%n filer kunde inte konverteras"],
+    "_%n file converted_::_%n files converted_" : ["%n fil konverterad","%n filer konverterade"],
+    "Files converted" : "Filer konverterade",
     "Failed to convert files" : "Det gick inte att konvertera filer",
-    "Converting file …" : "Konverterar fil ...",
+    "Converting file …" : "Konverterar fil …",
     "File successfully converted" : "Filen har konverterats",
     "Failed to convert file: {message}" : "Kunde inte konvertera filen: {message}",
     "Failed to convert file" : "Kunde inte konvertera filen",
+    "Delete" : "Radera",
     "Leave this share" : "Lämna denna delning",
     "Leave these shares" : "Lämna dessa delningar",
     "Disconnect storage" : "Koppla bort lagring",
@@ -298,26 +299,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Du är på väg att permanent ta bort {count} objekt","Du är på väg att permanent ta bort {count} objekt"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Du är på väg att ta bort {count} objekt","Du är på väg att ta bort {count} objekt"],
     "Confirm deletion" : "Bekräfta radering",
-    "Cancel" : "Avbryt",
     "Download" : "Hämta",
     "The requested file is not available." : "Den begärda filen är inte tillgänglig.",
     "The requested files are not available." : "De begärda filerna är inte tillgängliga.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Flyttar \"{source}\" till \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Kopierar \"{source}\" till \"{destination}\" …",
+    "Add to favorites" : "Lägg till i favoriter",
+    "Remove from favorites" : "Ta bort från favoriter",
+    "Add or remove favorite" : "Lägg till eller ta bort favorit",
+    "Move" : "Flytta",
+    "Copy" : "Kopiera",
+    "Move or copy" : "Flytta eller kopiera",
     "Destination is not a folder" : "Destinationen är inte en mapp",
     "This file/folder is already in that directory" : "Den här filen/mappen finns redan i den katalogen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan inte flytta en fil/mapp till sig själv eller till en undermapp till sig själv",
-    "(copy)" : "(kopia)",
-    "(copy %n)" : "(kopia %n)",
     "A file or folder with that name already exists in this folder" : "En fil eller mapp med det namnet finns redan i den här mappen",
     "The files are locked" : "Filerna är låsta",
     "The file does not exist anymore" : "Filen finns inte längre",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flyttar \"{source}\" till \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopierar \"{source}\" till \"{destination}\" …",
     "Choose destination" : "Välj destination",
     "Copy to {target}" : "Kopiera till {target}",
     "Move to {target}" : "Flytta till {target}",
-    "Move" : "Flytta",
     "Move or copy operation failed" : "Flytta eller kopiera misslyckades",
-    "Move or copy" : "Flytta eller kopiera",
+    "Open folder" : "Öppna mapp",
     "Open folder {displayName}" : "Öppna mappen {displayName}",
     "Open in Files" : "Öppna i Filer",
     "Open locally" : "Öppna lokalt",
@@ -328,19 +331,7 @@ OC.L10N.register(
     "Open online" : "Öppna online",
     "Details" : "Detaljer",
     "View in folder" : "Utforska i mapp",
-    "Today" : "Idag",
-    "Last 7 days" : "Senaste 7 dagarna",
-    "Last 30 days" : "Senaste 30 dagarna",
-    "This year ({year})" : "I år ({year})",
-    "Last year ({year})" : "Förra året ({year})",
-    "Documents" : "Dokument",
-    "Spreadsheets" : "Kalkylblad",
-    "Presentations" : "Presentationer",
-    "PDFs" : "PDF-filer",
-    "Folders" : "Mappar",
-    "Audio" : "Ljud",
-    "Images" : "Bilder",
-    "Videos" : "Videor",
+    "Type" : "Typ",
     "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
     "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
     "Create templates folder" : "Skapa mallmapp",
@@ -356,10 +347,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Vissa filer kunde inte laddas upp",
     "Files uploaded successfully" : "Filerna uppladdade",
     "No files to process" : "Inga filer att bearbeta",
-    "Some files could not be copied" : "Vissa filer kunde inte kopieras",
-    "Some files could not be moved" : "Vissa filer kunde inte flyttas",
     "Files copied successfully" : "Filerna kopierade",
     "Files moved successfully" : "Filerna flyttade",
+    "Some files could not be copied" : "Vissa filer kunde inte kopieras",
+    "Some files could not be moved" : "Vissa filer kunde inte flyttas",
     "Conflicts resolution skipped" : "Konfliktlösning hoppades över",
     "Upload cancelled" : "Uppladdning avbruten",
     "Could not rename \"{oldName}\", it does not exist any more" : "Kunde inte byta namn på \"{oldName}\", den finns inte längre",
@@ -381,6 +372,7 @@ OC.L10N.register(
     "No favorites yet" : "Inga favoriter ännu",
     "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
     "List of your files and folders." : "Lista över dina filer och mappar.",
+    "Folder tree" : "Mappträd",
     "List of your files and folders that are not shared." : "Lista över dina filer och mappar som inte delas.",
     "No personal files found" : "Inga personliga filer hittades",
     "Files that are not shared will show up here." : "Filer som inte delas kommer att visas här.",
@@ -394,119 +386,32 @@ OC.L10N.register(
     "Select all" : "Välj allt",
     "Upload too large" : "För stor uppladdning",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
-    "File could not be found" : "Fil kunde inte hittas",
-    "Show list view" : "Visa listvy",
-    "Show grid view" : "Visa rutnätsvy",
-    "Close" : "Stäng",
-    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
-    "This will stop your current uploads." : "Detta kommer att stoppa nuvarande uppladdningar.",
-    "Upload cancelled." : "Uppladdning avbruten.",
-    "Processing files …" : "Bearbetar filer ...",
-    "…" : "...",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
-    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
-    "An unknown error has occurred" : "Ett okänt fel uppstod",
-    "File could not be uploaded" : "Filen kunde inte laddas upp",
-    "Uploading …" : "Laddar upp ..",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Laddar upp … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
-    "Error when assembling chunks, status code {status}" : "Fel vid ihopsättning av bitarna: statuskod:  {status}",
-    "Choose target folder" : "Välj målmapp",
-    "Set reminder" : "Ställ in påminnelse",
-    "Edit locally" : "Redigera lokalt",
-    "Open" : "Öppna",
-    "Could not load info for file \"{file}\"" : "Kunde inte läsa in information för filen \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Vänligen välj tagg(ar) att lägga till i ditt urval",
-    "Apply tag(s) to selection" : "Lägg till tagg(ar) i ditt urval",
-    "Select directory \"{dirName}\"" : "Välj mapp \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Välj fil \"{fileName}\"",
-    "Unable to determine date" : "Misslyckades avgöra datum",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
-    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
-    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
-    "copy" : "kopia",
-    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
-    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
-    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
-    "{newName} already exists" : "{newName} existerar redan",
-    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
-    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
-    "Could not fetch file details \"{file}\"" : "Kunde inte hämta filinformation \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Ange mer än två tecken för att söka i andra mappar",
-    "{dirs} and {files}" : "{dirs} och {files}",
-    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n dold","inkluderar %n dolda"],
-    "You do not have permission to upload or create files here" : "Du har inte behörighet att ladda upp eller skapa filer här",
-    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
-    "New" : "Ny",
-    "New file/folder menu" : "Ny fil/mapp -meny",
-    "Select file range" : "Välj filintervall",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} använt",
-    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
-    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
-    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppmapp \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Extern lagring \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppmapp \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Extern lagring \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matcha \"{filter}\"","matcha \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
-    "Path" : "Sökväg",
-    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
-    "Favored" : "Favoriserad",
-    "Favor" : "Favorisera",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil/mapp)",
-    "Upload file" : "Ladda upp fil",
-    "Not favored" : "Inte favoriserad",
-    "An error occurred while trying to update the tags" : "Fel vid uppdatering av taggarna",
+    "%1$s (renamed)" : "%1$s (omdöpt)",
+    "renamed file" : "omdöpt fil",
     "Upload (max. %s)" : "Ladda upp (högst %s)",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
-    "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "När Windows-kompatibla filnamn har aktiverats kan befintliga filer inte längre ändras, men de kan byta namn till giltiga nya namn av sin ägare.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det är också möjligt att migrera filer automatiskt efter att den här inställningen har aktiverats. Se dokumentationen om kommandot occ för mer information.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Bytte namn på \"{oldName}\" till \"{newName}\"",
+    "Clear filter" : "Rensa filter",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" misslyckades med vissa element",
     "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
-    "Submitting fields…" : "Skickar fält...",
-    "Filter filenames…" : "Filtrera filnamn...",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
+    "Submitting fields …" : "Skickar fält ...",
+    "Shared by link" : "Delad via länk",
+    "Shared" : "Delad",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
+    "Filter file names …" : "Filtrera filnamn …",
+    "Clipboard is not available" : "Urklipp är inte tillgängligt",
     "WebDAV URL copied to clipboard" : "WebDAV URL kopierad till urklipp",
     "Enable the grid view" : "Aktivera rutnätsvy",
     "Enable folder tree" : "Aktivera mappträd",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiera till urklipp",
     "Use this address to access your Files via WebDAV" : "Använd denna adress för att komma åt dina filer med WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Om du har aktiverat 2FA måste du skapa och använda ett nytt applösenord genom att klicka här.",
-    "Deletion cancelled" : "Radering avbruten",
-    "Move cancelled" : "Flytt avbruten",
-    "Cancelled move or copy of \"{filename}\"." : "Avbröt flytt eller kopiering av \"{filename}\".",
-    "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
-    "Open details" : "Öppna detaljer",
-    "Photos and images" : "Foton och bilder",
-    "New folder creation cancelled" : "Skapandet av ny mapp avbröts",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapp","{folderCount} mappar"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil och {folderCount} mapp","1 fil och {folderCount} mappar"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil och 1 mapp","{fileCount} filer och 1 mapp"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} filer och {folderCount} mappar",
-    "All folders" : "Alla mappar",
-    "Personal Files" : "Personliga filer",
-    "Text file" : "Textfil",
-    "New text file.txt" : "Ny textfil.txt",
-    "%1$s (renamed)" : "%1$s (omdöpt)",
-    "renamed file" : "omdöpt fil",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "När Windows-kompatibla filnamn har aktiverats kan befintliga filer inte längre ändras, men de kan byta namn till giltiga nya namn av sin ägare.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Det är också möjligt att migrera filer automatiskt efter att den här inställningen har aktiverats. Se dokumentationen om kommandot occ för mer information.",
-    "Filter file names …" : "Filtrera filnamn …",
     "Prevent warning dialogs from open or reenable them." : "Förhindra varningsdialoger från att öppnas eller aktivera dem igen.",
     "Show a warning dialog when changing a file extension." : "Visa en varningsdialog vid ändring av filändelse.",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Speed up your Files experience with these quick shortcuts." : "Snabba upp din upplevelse i Filer med dessa smarta genvägar.",
     "Open the actions menu for a file" : "Öppna åtgärdsmenyn för en fil",
     "Rename a file" : "Byt namn på en fil",
@@ -522,6 +427,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Gå till filen till vänster (i rutnätsvy)",
     "Navigate to the file on the right (in grid mode)" : "Gå till filen till höger (i rutnätsvy)",
     "Toggle the grid view" : "Växla rutnätsvy",
-    "Open the sidebar for a file" : "Öppna sidofältet för en fil"
+    "Open the sidebar for a file" : "Öppna sidofältet för en fil",
+    "You" : "Du",
+    "Shared multiple times with different people" : "Delad flera gånger med olika personer",
+    "Unable to change the favorite state of the file" : "Kan inte ändra filens favoritstatus",
+    "Error while loading the file data" : "Fel vid inläsning av fildata",
+    "Tags" : "Taggar",
+    "Save as …" : "Spara som …",
+    "Converting files …" : "Konverterar filer ...",
+    "Converting file …" : "Konverterar fil ...",
+    "Deletion cancelled" : "Radering avbruten",
+    "Edit locally" : "Redigera lokalt",
+    "Moving \"{source}\" to \"{destination}\" …" : "Flyttar \"{source}\" till \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Kopierar \"{source}\" till \"{destination}\" …",
+    "(copy)" : "(kopia)",
+    "(copy %n)" : "(kopia %n)",
+    "Move cancelled" : "Flytt avbruten",
+    "Cancelled move or copy of \"{filename}\"." : "Avbröt flytt eller kopiering av \"{filename}\".",
+    "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
+    "Open details" : "Öppna detaljer",
+    "Photos and images" : "Foton och bilder",
+    "New folder creation cancelled" : "Skapandet av ny mapp avbröts",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
+    "All folders" : "Alla mappar",
+    "Open file sidebar" : "Öppna filens sidofält",
+    "Search everywhere …" : "Sök överallt …",
+    "Search here …" : "Sök här …",
+    "Preparing …" : "Förbereder …"
 },
 "nplurals=2; plural=(n != 1);");
