@@ -78,6 +78,7 @@ OC.L10N.register(
     "Reload current directory" : "Geçerli klasörü yeniden yükle",
     "Go to the \"{dir}\" directory" : "\"{dir}\" klasörüne git",
     "Current directory path" : "Geçerli klasör yolu",
+    "Share" : "Paylaş",
     "Your have used your space quota and cannot upload files anymore" : "Depolama alanınızın tümünü kullandığınız için başka dosya yüklemezsiniz",
     "You do not have permission to upload or create files here." : "Buraya dosya yükleme ya da ekleme izniniz yok.",
     "Drag and drop files here to upload" : "Yüklemek istediğiniz dosyaları sürükleyip buraya bırakın",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Bu düğüm kullanılamıyor",
     "Another entry with the same name already exists." : "Aynı adlı bir kayıt zaten var.",
     "Invalid filename." : "Dosya adı geçersiz.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
     "Rename file" : "Dosyayı yeniden adlandır",
     "Folder" : "Klasör",
     "Unknown file type" : "Dosya türü bilinmiyor",
@@ -102,12 +102,24 @@ OC.L10N.register(
     "{ext} text" : "{ext} yazı",
     "Pending" : "Bekliyor",
     "Unknown date" : "Tarih bilinmiyor",
-    "Clear filter" : "Süzgeci temizle",
-    "Modified" : "Değiştirilme",
-    "Search everywhere" : "Her yerde ara",
-    "Type" : "Tür",
     "Active filters" : "Etkin süzgeçler",
     "Remove filter" : "Süzgeci kaldır",
+    "Today" : "Bugün",
+    "Last 7 days" : "Önceki 7 gün",
+    "Last 30 days" : "Önceki 30 gün",
+    "This year ({year})" : "Bu yıl ({year})",
+    "Last year ({year})" : "Önceki yıl ({year})",
+    "Custom date range" : "Özel tarih aralığı",
+    "Search everywhere" : "Her yerde ara",
+    "Documents" : "Belgeler",
+    "Spreadsheets" : "Çalışma sayfaları",
+    "Presentations" : "Sunumlar",
+    "PDFs" : "PDF dosyaları",
+    "Folders" : "Klasörler",
+    "Audio" : "Ses",
+    "Images" : "Görseller",
+    "Videos" : "Görüntüler",
+    "Filters" : "Süzgeçler",
     "Appearance" : "Görünüm",
     "Show hidden files" : "Gizli dosyaları görüntüle",
     "Show file type column" : "Dosya türü sütunu görüntülensin",
@@ -136,7 +148,6 @@ OC.L10N.register(
     "Go right in grid" : "Izgarada sağa git",
     "View" : "Görüntüle",
     "Toggle grid view" : "Tablo görünümünü aç/kapat",
-    "Open file sidebar" : "Dosya kenar çubuğunu aç",
     "Show those shortcuts" : "Bu kısayolları görüntüler",
     "Warnings" : "Uyarılar",
     "Warn before changing a file extension" : "Dosya uzantıları değiştirilmeden önce uyarı görüntülensin",
@@ -150,6 +161,7 @@ OC.L10N.register(
     "Name" : "Ad",
     "File type" : "Dosya türü",
     "Size" : "Boyut",
+    "Modified" : "Değiştirilme",
     "{displayName}: failed on some elements" : "{displayName}: Bazı bileşenlerde tamamlanamadı",
     "{displayName}: done" : "{displayName}: Tamamlandı",
     "{displayName}: failed" : "{displayName}: Tamamlanamadı",
@@ -160,6 +172,7 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Başarımı olumsuz etkilememek için listenin tümü görüntülenmiyor. Listede ilerledikçe dosyalar görüntülenecek.",
     "File not found" : "Dosya bulunamadı",
     "_{count} selected_::_{count} selected_" : ["{count} seçilmiş","{count} seçilmiş"],
+    "Views" : "Görünümler",
     "Search everywhere …" : "Her yerde ara…",
     "Search here …" : "Burada ara…",
     "Search scope options" : "Arama kapsamı seçenekleri",
@@ -218,12 +231,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "\"{old}\" dosya uzantısının kaldırılması dosyayı okunamaz yapabilir.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "\"{new}\" dosya uzantısının eklenmesi dosyayı okunamaz yapabilir.",
     "Do not show this dialog again." : "Bu ileti bir daha görüntülenmesin.",
+    "Cancel" : "İptal",
+    "Rename" : "Yeniden adlandır",
     "Select file or folder to link to" : "Bağlantı verilecek dosya ya da klasörü seçin",
     "Choose {file}" : "{file} seçin",
     "Files settings" : "Dosyalar ayarları",
-    "Share" : "Paylaş",
-    "Shared by link" : "Bağlantı ile paylaşılmış",
-    "Shared" : "Paylaşılan",
     "Switch to list view" : "Liste görünümüne geç",
     "Switch to grid view" : "Tablo görünümüne geç",
     "The file could not be found" : "Dosya bulunamadı",
@@ -238,7 +250,6 @@ OC.L10N.register(
     "No files in here" : "Burada herhangi bir dosya yok",
     "Upload some content or sync with your devices!" : "Bir şeyler yükleyin ya da aygıtlarınızla eşitleyin!",
     "Go back" : "Geri dön",
-    "Views" : "Görünümler",
     "Loading …" : "Yükleniyor…",
     "Your files" : "Dosyalarınız",
     "Open in files" : "Dosyalar uygulamasında aç",
@@ -285,30 +296,27 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count} ögeyi kalıcı olarak silmek üzeresiniz","{count} ögeyi kalıcı olarak silmek üzeresiniz"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["{count} ögeyi silmek üzeresiniz","{count} ögeyi silmek üzeresiniz"],
     "Confirm deletion" : "Silmeyi onaylayın",
-    "Cancel" : "İptal",
     "Download" : "İndir",
     "The requested file is not available." : "İstenilen dosya kullanılamıyor.",
     "The requested files are not available." : "İstenilen dosyalar kullanılamıyor.",
     "Add to favorites" : "Sık kullanılanlara ekle",
     "Remove from favorites" : "Sık kullanılanlardan kaldır",
     "Add or remove favorite" : "Sık kullanılanlara ekle ya da kaldır",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
+    "Move" : "Taşı",
+    "Copy" : "Kopyala",
+    "Move or copy" : "Taşı ya da kopyala",
     "Destination is not a folder" : "Hedef bir klasör değil",
     "This file/folder is already in that directory" : "Dosya ya da klasör bu klasörde zaten var",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bir dosyayı ya da klasörü kendi üzerine veya kendisinin alt klasörüne taşıyamazsınız",
-    "(copy)" : "(kopya)",
-    "(copy %n)" : "(%n kopyası)",
     "A file or folder with that name already exists in this folder" : "Bu klasörde aynı adlı bir dosya ya da klasör zaten var",
     "The files are locked" : "Dosyalar kilitli",
     "The file does not exist anymore" : "Dosya artık yok",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine taşınıyor…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" üzerine kopyalanıyor…",
     "Choose destination" : "Hedefi seçin",
     "Copy to {target}" : "{target} içine kopyala",
-    "Copy" : "Kopyala",
     "Move to {target}" : "{target} içine taşı",
-    "Move" : "Taşı",
     "Move or copy operation failed" : "Taşıma ya da kopyalama yapılamadı",
-    "Move or copy" : "Taşı ya da kopyala",
     "Open folder" : "Klasörü aç",
     "Open folder {displayName}" : "{displayName} klasörünü aç",
     "Open in Files" : "Dosyalar uygulamasında aç",
@@ -318,23 +326,11 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Dosya artık aygıtınızda açılmalıdır. Açılmazsa lütfen bilgisayar uygulamasının kurulu olduğundan emin olun.",
     "Retry and close" : "Yeniden deneyip kapat",
     "Open online" : "Çevrim içi aç",
-    "Rename" : "Yeniden adlandır",
     "Details" : "Ayrıntılar",
+    "Open the details sidebar" : "Ayrıntılar kenar çubuğunu aç",
     "Unfavorite" : "Sık kullanılanlardan kaldır",
     "View in folder" : "Klasörde görüntüle",
-    "Today" : "Bugün",
-    "Last 7 days" : "Önceki 7 gün",
-    "Last 30 days" : "Önceki 30 gün",
-    "This year ({year})" : "Bu yıl ({year})",
-    "Last year ({year})" : "Önceki yıl ({year})",
-    "Documents" : "Belgeler",
-    "Spreadsheets" : "Çalışma sayfaları",
-    "Presentations" : "Sunumlar",
-    "PDFs" : "PDF dosyaları",
-    "Folders" : "Klasörler",
-    "Audio" : "Ses",
-    "Images" : "Görseller",
-    "Videos" : "Görüntüler",
+    "Type" : "Tür",
     "Created new folder \"{name}\"" : "\"{name}\" yeni klasörü oluşturuldu",
     "Unable to initialize the templates directory" : "Kalıp klasörü hazırlanamadı",
     "Create templates folder" : "Kalıplar klasörü oluştur",
@@ -350,10 +346,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Bazı dosyalar yüklenemedi",
     "Files uploaded successfully" : "Dosyalar yüklendi",
     "No files to process" : "İşlenecek bir dosya yok",
-    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
-    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
     "Files copied successfully" : "Dosyalar kopyalandı",
     "Files moved successfully" : "Dosyalar taşındı",
+    "Some files could not be copied" : "Bazı dosyalar kopyalanamadı",
+    "Some files could not be moved" : "Bazı dosyalar taşınamadı",
     "Conflicts resolution skipped" : "Çakışma çözümleme atlandı",
     "Upload cancelled" : "Yükleme iptal edildi",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" adı artık olmadığından değiştirilemedi. ",
@@ -394,10 +390,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "Yükle (en büyük: %s)",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows uyumlu dosya adları açıldıktan sonra, var olan dosyalar artık değiştirilemez. Ancak sahipleri tarafından geçerli yeni adlarla yeniden adlandırılabilir.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Bu ayarı açtıktan sonra dosyaları otomatik olarak da aktarılabilir. Lütfen occ komutuyla ilgili belgelere bakın.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" adı \"{newName}\" olarak değiştirildi",
+    "Clear filter" : "Süzgeci temizle",
     "\"{displayName}\" failed on some elements" : "\"{displayName}\" bazı bileşenlerde tamamlanamadı",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" toplu işlemi tamamlandı",
     "\"{displayName}\" action failed" : "\"{displayName}\" işlemi tamamlanamadı",
     "Submitting fields …" : "Alanlar gönderiliyor…",
+    "Shared by link" : "Bağlantı ile paylaşılmış",
+    "Shared" : "Paylaşılan",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" işlemi tamamlandı",
     "Filter file names …" : "Dosya adlarını süz…",
     "Clipboard is not available" : "Pano kullanılamıyor",
@@ -439,6 +439,8 @@ OC.L10N.register(
     "Edit locally" : "Yerel olarak düzenle",
     "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine taşınıyor…",
     "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\", \"{destination}\" hedefine kopyalanıyor…",
+    "(copy)" : "(kopya)",
+    "(copy %n)" : "(%n kopyası)",
     "Move cancelled" : "Taşıma iptal edildi",
     "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" dosyasını taşıma ya da kopyalama işlemi iptal edildi",
     "Cancelled move or copy operation" : "Taşıma ya da kopyalama işlemi iptal edildi",
@@ -447,6 +449,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "Yeni klasör oluşturma işlemi iptal edildi",
     "This directory is unavailable, please check the logs or contact the administrator" : "Bu klasör yazılabilir değil. Lütfen günlük kayıtlarına bakın ya da BT yöneticiniz ile görüşün",
     "All folders" : "Tüm klasörler",
+    "Open file sidebar" : "Dosya kenar çubuğunu aç",
     "Search everywhere …" : "Her yerde ara…",
     "Search here …" : "Burada ara…",
     "Preparing …" : "Hazırlanıyor…"
