@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "重新加載目前目錄",
     "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
     "Current directory path" : "目前目錄途徑",
+    "Share" : "分享",
+    "Reload content" : "重新加載內容",
     "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
     "You do not have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
     "Drag and drop files here to upload" : "將檔案拖拽到此處即可上傳",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "此節點不可用",
     "Another entry with the same name already exists." : "另一個同名的條目已經存在。",
     "Invalid filename." : "檔案名稱無效。",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Rename file" : "重新命名檔案",
     "Folder" : "資料夾",
     "Unknown file type" : "檔案類型不詳",
@@ -102,15 +103,29 @@ OC.L10N.register(
     "{ext} text" : "{ext} 文字",
     "Pending" : "待定的",
     "Unknown date" : "日期不詳",
-    "Clear filter" : "清空過濾器",
-    "Modified" : "修改時間",
-    "Search everywhere" : "到處搜尋",
-    "Type" : "類型",
     "Active filters" : "有效的過濾器",
     "Remove filter" : "移除過濾",
+    "Today" : "今日",
+    "Last 7 days" : "過去7日",
+    "Last 30 days" : "過去30日",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Custom range" : "自訂範圍",
+    "Custom date range" : "自訂日期範圍",
+    "Search everywhere" : "到處搜尋",
+    "Documents" : "文件",
+    "Spreadsheets" : "試算表",
+    "Presentations" : "簡報",
+    "PDFs" : "PDF",
+    "Folders" : "資料夾",
+    "Audio" : "音頻",
+    "Images" : "圖像",
+    "Videos" : "影片",
+    "Filters" : "過濾",
+    "Back to filters" : "回到篩選器",
     "Appearance" : "外觀",
     "Show hidden files" : "顯示隱藏檔案",
-    "Show file type column" : "顯示檔案類型縱列",
+    "Show file type column" : "顯示檔案類型直欄",
     "Show file extensions" : "顯示副檔名",
     "Crop image previews" : "圖片裁剪預覽",
     "General" : "一般",
@@ -136,7 +151,6 @@ OC.L10N.register(
     "Go right in grid" : "在網格中向右",
     "View" : "檢視",
     "Toggle grid view" : "切換網格檢視",
-    "Open file sidebar" : "開啟檔案側邊欄",
     "Show those shortcuts" : "顯示這些快捷鍵",
     "Warnings" : "警告",
     "Warn before changing a file extension" : "變更副檔名前警告",
@@ -145,21 +159,23 @@ OC.L10N.register(
     "Create an app password" : "建立應用程式密碼",
     "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "因為此帳號已啟用雙重驗證，故需進行 WebDAV 驗證。",
     "How to access files using WebDAV" : "如何使用 WebDAV 存取檔案",
-    "Total rows summary" : "總列摘要",
+    "Total rows summary" : "資料列總覽",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選擇",
     "Name" : "名稱",
     "File type" : "檔案類型",
     "Size" : "大小",
+    "Modified" : "修改時間",
     "{displayName}: failed on some elements" : "{displayName}：在部份元素上失敗",
     "{displayName}: done" : "{displayName}：完成",
     "{displayName}: failed" : "{displayName}：失敗",
     "(selected)" : "（已選擇）",
     "List of files and folders." : "檔案與資料夾清單。",
     "You have used your space quota and cannot upload files anymore." : "您已用完您的空間配額，無法再上傳檔案。",
-    "Column headers with buttons are sortable." : "具有按鈕的縱列標題可排序。",
+    "Column headers with buttons are sortable." : "具有按鈕的直欄標題可排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
     "_{count} selected_::_{count} selected_" : ["已選擇 {count} 項"],
+    "Views" : "視圖",
     "Search everywhere …" : "搜尋各處 ……",
     "Search here …" : "搜尋此處 ……",
     "Search scope options" : "搜尋範圍選項",
@@ -218,12 +234,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
     "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
     "Do not show this dialog again." : "不要再次顯示此對話框。",
+    "Rename file to hidden" : "將檔案重新命名為隱藏檔案",
+    "Prefixing a filename with a dot may render the file hidden." : "在檔案名稱前加點號可能會導致檔案隱藏。",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "您確定要重新命名檔案為「{filename}」嗎？",
+    "Cancel" : "取消",
+    "Rename" : "重新命名",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
     "Choose {file}" : "選擇 {file}",
     "Files settings" : "檔案設定",
-    "Share" : "分享",
-    "Shared by link" : "由連結分享",
-    "Shared" : "已分享",
     "Switch to list view" : "切換到列表檢視",
     "Switch to grid view" : "切換到網格檢視",
     "The file could not be found" : "找不到檔案",
@@ -233,12 +251,12 @@ OC.L10N.register(
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
+    "File list is reloading" : "正在重新載入檔案清單",
     "Loading current folder" : "目前資料夾加載中",
     "Retry" : "重試",
     "No files in here" : "沒有任何檔案",
     "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
     "Go back" : "返回",
-    "Views" : "視圖",
     "Loading …" : "正在載入 …",
     "Your files" : "您的檔案",
     "Open in files" : "在「檔案」應用程式中打開",
@@ -285,30 +303,29 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您即將永久刪除 {count} 個項目"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您即將刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
-    "Cancel" : "取消",
     "Download" : "下載",
     "The requested file is not available." : "無法取得所要求的檔案。",
     "The requested files are not available." : "無法取得所要求的檔案。",
     "Add to favorites" : "加到我的最愛",
     "Remove from favorites" : "從最愛中移除",
     "Add or remove favorite" : "新增或移除最愛",
-    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」 ……",
-    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」 ……",
+    "Move" : "移動",
+    "Copy" : "複製",
+    "Move or copy" : "移動或複製",
     "Destination is not a folder" : "目標地不是資料夾",
     "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
-    "(copy)" : "（複本）",
-    "(copy %n)" : "（複本 %n）",
     "A file or folder with that name already exists in this folder" : "此資料夾中已存在同名的檔案或資料夾",
     "The files are locked" : "檔案已被上鎖",
     "The file does not exist anymore" : "檔案已不存在",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」 ……",
+    "Moving {count} files to \"{destination}\" …" : "正在將 {count} 個檔案移動到「{destination}」 …",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」 ……",
+    "Copying {count} files to \"{destination}\" …" : "正在將 {count} 個檔案複製到「{destination}」 …",
     "Choose destination" : "選擇目標地",
     "Copy to {target}" : "複製到 {target}",
-    "Copy" : "複製",
     "Move to {target}" : "移動到 {target}",
-    "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
-    "Move or copy" : "移動或複製",
     "Open folder" : "開啟資料夾",
     "Open folder {displayName}" : "打開資料夾 {displayName}",
     "Open in Files" : "在「檔案」應用程式中打開",
@@ -318,29 +335,18 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該在您的裝置上打開。如果沒有，請檢查您是否已安裝桌面應用程式。",
     "Retry and close" : "重試和關閉",
     "Open online" : "線上開啟",
-    "Rename" : "重新命名",
     "Details" : "詳細資料",
+    "Open the details sidebar" : "開啟細節側邊欄",
     "Unfavorite" : "取消收藏",
     "View in folder" : "在資料夾中檢視",
-    "Today" : "今日",
-    "Last 7 days" : "過去7日",
-    "Last 30 days" : "過去30日",
-    "This year ({year})" : "今年 ({year})",
-    "Last year ({year})" : "去年 ({year})",
-    "Documents" : "文件",
-    "Spreadsheets" : "試算表",
-    "Presentations" : "簡報",
-    "PDFs" : "PDF",
-    "Folders" : "資料夾",
-    "Audio" : "音頻",
-    "Images" : "圖像",
-    "Videos" : "影片",
+    "Type" : "類型",
     "Created new folder \"{name}\"" : "創建了新資料夾 \"{name}\"",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
     "Create templates folder" : "創建模板資料夾",
     "Templates" : "模板",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
+    "Pick folder to search in" : "請挑選要搜尋的資料夾",
     "Search in all files" : "在所有檔案中搜尋",
     "Search in folder: {folder}" : "搜尋資料夾： {folder}",
     "One of the dropped files could not be processed" : "無法處理其中一個投放的檔案",
@@ -350,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "無法上傳某些檔案",
     "Files uploaded successfully" : "成功上傳檔案",
     "No files to process" : "沒有要處理的檔案",
-    "Some files could not be copied" : "無法複製部份檔案",
-    "Some files could not be moved" : "有些檔案無法被移動",
     "Files copied successfully" : "檔案複製成功",
     "Files moved successfully" : "檔案移動成功",
+    "Some files could not be copied" : "無法複製部份檔案",
+    "Some files could not be moved" : "有些檔案無法被移動",
     "Conflicts resolution skipped" : "已略過衝突解決",
     "Upload cancelled" : "上傳已取消",
     "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
@@ -394,10 +400,14 @@ OC.L10N.register(
     "Upload (max. %s)" : "上傳（上限 %s）",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，還可以自動遷移檔案，請參考有關 occ 指令的說明書。",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
+    "Clear filter" : "清空過濾器",
     "\"{displayName}\" failed on some elements" : "“{displayName}” 在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
     "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
     "Submitting fields …" : "正在遞交欄位 …",
+    "Shared by link" : "由連結分享",
+    "Shared" : "已分享",
     "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
     "Filter file names …" : "過濾檔案名稱 …",
     "Clipboard is not available" : "剪貼板不可用",
@@ -439,6 +449,8 @@ OC.L10N.register(
     "Edit locally" : "在近端編輯",
     "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」…",
     "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」…",
+    "(copy)" : "（複本）",
+    "(copy %n)" : "（複本 %n）",
     "Move cancelled" : "移動已取消",
     "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
     "Cancelled move or copy operation" : "已取消移動或複製操作",
@@ -447,6 +459,7 @@ OC.L10N.register(
     "New folder creation cancelled" : "已取消建立新資料夾",
     "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
     "All folders" : "所有資料夾",
+    "Open file sidebar" : "開啟檔案側邊欄",
     "Search everywhere …" : "搜尋各處 …",
     "Search here …" : "搜尋此處 …",
     "Preparing …" : "正在準備 …"
