@@ -1,10 +1,6 @@
 OC.L10N.register(
     "files_external",
     {
-    "Grant access" : "Salli pääsy",
-    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
-    "Generate keys" : "Luo avaimet",
-    "Error generating key pair" : "Virhe luotaessa avainparia",
     "You are not logged in" : "Et ole kirjautuneena sisään",
     "Permission denied" : "Ei käyttöoikeutta",
     "Storage with ID \"%d\" not found" : "Tallennustilaa tunnisteella \"%d\" ei löytynyt",
@@ -17,14 +13,10 @@ OC.L10N.register(
     "Unsatisfied backend parameters" : "Riittämättömät tietovaraston parametrit",
     "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
     "Insufficient data: %s" : "Puutteellinen data: %s",
-    "%s" : "%s",
     "Access key" : "Pääsyavain",
     "Secret key" : "Salainen avain",
     "Builtin" : "Sisäänrakennettu",
     "None" : "Ei mitään",
-    "OAuth2" : "OAuth2",
-    "Client ID" : "Asiakkaan tunniste",
-    "Client secret" : "Asiakassalaisuus",
     "OpenStack v2" : "OpenStack v2",
     "Login" : "Kirjaudu sisään",
     "Password" : "Salasana",
@@ -46,6 +38,7 @@ OC.L10N.register(
     "Bucket" : "Bucket",
     "Hostname" : "Isäntänimi",
     "Port" : "Portti",
+    "Proxy" : "Välityspalvelin",
     "Region" : "Alue",
     "Enable SSL" : "Käytä SSL:ää",
     "Enable Path Style" : "Aktivoi polun tyyli",
@@ -71,52 +64,75 @@ OC.L10N.register(
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "Service name" : "Palvelun nimi",
     "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
-    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
-    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
-    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" on asentamatta. Kohdetta %2$s ei voi liittää. Pyydä järjestemän ylläpitäjää asentamaan puuttuvat osat.",
     "External storage" : "Erillinen tallennustila",
     "External storage support" : "Erillisen tallennustilan tuki",
     "Adds basic external storage support" : "Lisää perusmuotoisen tuen erillisille tallennustiloille",
+    "Add storage" : "Lisää tallennustila",
+    "Folder name" : "Kansion nimi",
+    "Authentication" : "Tunnistautuminen",
+    "Cancel" : "Peruuta",
+    "Edit" : "Muokkaa",
+    "Create" : "Luo",
+    "Never" : "Ei koskaan",
+    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
+    "Always" : "Aina",
+    "Read only" : "Vain luku",
+    "Enable previews" : "Käytä esikatseluja",
+    "Enable sharing" : "Käytä jakamista",
+    "Enable encryption" : "Käytä salausta",
+    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
+    "External storages" : "Erilliset tallennustilat",
+    "Status" : "Tila",
+    "Actions" : "Toiminnot",
+    "Delete" : "Poista",
+    "Saved" : "Tallennettu",
+    "Error while saving" : "Virhe tallentaessa",
+    "Error generating key pair" : "Virhe luotaessa avainparia",
+    "Key size" : "Avaimen koko",
+    "Generate keys" : "Luo avaimet",
     "Confirm" : "Vahvista",
+    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja.",
+    "Saving …" : "Tallennetaan …",
+    "Save" : "Tallenna",
     "Open in Files" : "Avaa tiedostosovelluksessa",
     "External mount error" : "Erillisen liitosvirhe",
+    "Ignore" : "Ohita",
     "Storage type" : "Tallennustilan tyyppi",
     "Unknown" : "Tuntematon",
     "Scope" : "Näkyvyysalue",
     "Personal" : "Henkilökohtainen",
     "System" : "Järjestelmä",
+    "Connected" : "Yhdistetty",
+    "Error" : "Virhe",
+    "Unauthorized" : "Ei valtuuksia",
+    "Network error" : "Verkkovirhe",
+    "Grant access" : "Salli pääsy",
+    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
+    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
+    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
+    "%s" : "%s",
+    "OAuth1" : "OAuth1",
+    "App key" : "Sovellusavain",
+    "App secret" : "Sovellussalaisuus",
+    "OAuth2" : "OAuth2",
+    "Client ID" : "Asiakkaan tunniste",
+    "Client secret" : "Asiakassalaisuus",
+    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cULR tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
+    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP tuki PHPsta ei ole aktivoitu tai asennettu. Kohteen %s liittäminen ei ole mahdollista. Ota yhteyttä järjestelmänvalvojaan asentaaksesi puuttuvan osan.",
+    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" on asentamatta. Kohdetta %2$s ei voi liittää. Pyydä järjestemän ylläpitäjää asentamaan puuttuvat osat.",
     "Type to select account or group." : "Kirjoita valitaksesi tilin tai ryhmän.",
     "(Group)" : "(Ryhmä)",
-    "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
-    "Enable encryption" : "Käytä salausta",
-    "Enable previews" : "Käytä esikatseluja",
-    "Enable sharing" : "Käytä jakamista",
     "Check for changes" : "Tarkista muutokset",
-    "Never" : "Ei koskaan",
-    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
-    "Read only" : "Vain luku",
     "Disconnect" : "Katkaise yhteys",
     "Admin defined" : "Ylläpitäjän määrittämä",
     "Delete storage?" : "Poistetaanko tallennustila?",
     "Click to recheck the configuration" : "Napsauta tarkistaaksesi uudelleen määritykset",
-    "Saved" : "Tallennettu",
-    "Saving …" : "Tallennetaan …",
-    "Save" : "Tallenna",
+    "Saving …" : "Tallennetaan…",
     "No external storage configured or you don't have the permission to configure them" : "Erillistä tallennustilaa ei ole määritelty tai sinulla ei ole oikeuksia määrittää erillisiä tallennustiloja",
     "Open documentation" : "Avaa dokumentaatio",
-    "Folder name" : "Kansion nimi",
-    "Authentication" : "Tunnistautuminen",
     "Configuration" : "Asetukset",
     "Available for" : "Saatavuus",
-    "Add storage" : "Lisää tallennustila",
     "All people" : "Kaikki ihmiset",
-    "Advanced settings" : "Lisäasetukset",
-    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja.",
-    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
-    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
-    "OAuth1" : "OAuth1",
-    "App key" : "Sovellusavain",
-    "App secret" : "Sovellussalaisuus",
-    "Saving …" : "Tallennetaan…"
+    "Advanced settings" : "Lisäasetukset"
 },
 "nplurals=2; plural=(n != 1);");
