@@ -16,8 +16,9 @@ use OCA\Files_External\Lib\StorageConfig;
 use OCA\Files_External\MountConfig;
 use OCA\Files_External\Service\UserGlobalStoragesService;
 use OCA\Files_External\Service\UserStoragesService;
-use OCP\AppFramework\QueryException;
+use OCP\Files\Config\IAuthoritativeMountProvider;
 use OCP\Files\Config\IMountProvider;
+use OCP\Files\Config\IPartialMountProvider;
 use OCP\Files\Mount\IMountPoint;
 use OCP\Files\ObjectStore\IObjectStore;
 use OCP\Files\Storage\IConstructableStorage;
@@ -26,13 +27,15 @@ use OCP\Files\Storage\IStorageFactory;
 use OCP\Files\StorageNotAvailableException;
 use OCP\IUser;
 use OCP\Server;
+use Override;
 use Psr\Clock\ClockInterface;
+use Psr\Container\ContainerExceptionInterface;
 use Psr\Log\LoggerInterface;
 
 /**
  * Make the old files_external config work with the new public mount config api
  */
-class ConfigAdapter implements IMountProvider {
+class ConfigAdapter implements IMountProvider, IAuthoritativeMountProvider, IPartialMountProvider {
 	public function __construct(
 		private UserStoragesService $userStoragesService,
 		private UserGlobalStoragesService $userGlobalStoragesService,
@@ -56,7 +59,7 @@ class ConfigAdapter implements IMountProvider {
 	/**
 	 * Process storage ready for mounting
 	 *
-	 * @throws QueryException
+	 * @throws ContainerExceptionInterface
 	 */
 	private function prepareStorageConfig(StorageConfig &$storage, IUser $user): void {
 		foreach ($storage->getBackendOptions() as $option => $value) {
@@ -73,10 +76,13 @@ class ConfigAdapter implements IMountProvider {
 		$storage->getBackend()->manipulateStorageConfig($storage, $user);
 	}
 
+	public function constructStorageForUser(IUser $user, StorageConfig $storage) {
+		$this->prepareStorageConfig($storage, $user);
+		return $this->constructStorage($storage);
+	}
+
 	/**
 	 * Construct the storage implementation
-	 *
-	 * @param StorageConfig $storageConfig
 	 */
 	private function constructStorage(StorageConfig $storageConfig): IStorage {
 		$class = $storageConfig->getBackend()->getStorageClass();
@@ -93,20 +99,14 @@ class ConfigAdapter implements IMountProvider {
 	}
 
 	/**
-	 * Get all mountpoints applicable for the user
-	 *
-	 * @return IMountPoint[]
+	 * @param list<StorageConfig> $storageConfigs
+	 * @return array
+	 * @throws ContainerExceptionInterface
 	 */
-	public function getMountsForUser(IUser $user, IStorageFactory $loader) {
-		$this->userStoragesService->setUser($user);
-		$this->userGlobalStoragesService->setUser($user);
-
-		$storageConfigs = $this->userGlobalStoragesService->getAllStoragesForUser();
-
-		$storages = array_map(function (StorageConfig $storageConfig) use ($user) {
+	private function getAvailableStorages(array $storageConfigs, IUser $user): array {
+		$storages = array_map(function (StorageConfig $storageConfig) use ($user): IStorage {
 			try {
-				$this->prepareStorageConfig($storageConfig, $user);
-				return $this->constructStorage($storageConfig);
+				return $this->constructStorageForUser($user, $storageConfig);
 			} catch (\Exception $e) {
 				// propagate exception into filesystem
 				return new FailedStorage(['exception' => $e]);
@@ -118,12 +118,12 @@ class ConfigAdapter implements IMountProvider {
 			return $storage->getId();
 		}, $storages));
 
-		$availableStorages = array_map(function (IStorage $storage, StorageConfig $storageConfig): IStorage {
+		return array_map(function (IStorage $storage, StorageConfig $storageConfig): IStorage {
 			try {
 				$availability = $storage->getAvailability();
 				if (!$availability['available'] && !Availability::shouldRecheck($availability)) {
 					$storage = new FailedStorage([
-						'exception' => new StorageNotAvailableException('Storage with mount id ' . $storageConfig->getId() . ' is not available')
+						'exception' => new StorageNotAvailableException('Storage with mount id ' . $storageConfig->getId() . ' is not available'),
 					]);
 				}
 			} catch (\Exception $e) {
@@ -132,35 +132,23 @@ class ConfigAdapter implements IMountProvider {
 			}
 			return $storage;
 		}, $storages, $storageConfigs);
+	}
+
+	/**
+	 * Get all mountpoints applicable for the user
+	 *
+	 * @return IMountPoint[]
+	 */
+	public function getMountsForUser(IUser $user, IStorageFactory $loader): array {
+		$this->userStoragesService->setUser($user);
+		$this->userGlobalStoragesService->setUser($user);
+
+		$storageConfigs = $this->userGlobalStoragesService->getAllStoragesForUser();
+		$availableStorages = $this->getAvailableStorages($storageConfigs, $user);
 
 		$mounts = array_map(function (StorageConfig $storageConfig, IStorage $storage) use ($user, $loader) {
-			$storage->setOwner($user->getUID());
-			if ($storageConfig->getType() === StorageConfig::MOUNT_TYPE_PERSONAL) {
-				return new PersonalMount(
-					$this->userStoragesService,
-					$storageConfig,
-					$storageConfig->getId(),
-					new KnownMtime([
-						'storage' => $storage,
-						'clock' => $this->clock,
-					]),
-					'/' . $user->getUID() . '/files' . $storageConfig->getMountPoint(),
-					null,
-					$loader,
-					$storageConfig->getMountOptions(),
-					$storageConfig->getId()
-				);
-			} else {
-				return new SystemMountPoint(
-					$storageConfig,
-					$storage,
-					'/' . $user->getUID() . '/files' . $storageConfig->getMountPoint(),
-					null,
-					$loader,
-					$storageConfig->getMountOptions(),
-					$storageConfig->getId()
-				);
-			}
+			$mountpoint = '/' . $user->getUID() . '/files' . $storageConfig->getMountPoint();
+			return $this->storageConfigToMount($user, $mountpoint, $loader, $storage, $storageConfig);
 		}, $storageConfigs, $availableStorages);
 
 		$this->userStoragesService->resetUser();
@@ -168,4 +156,65 @@ class ConfigAdapter implements IMountProvider {
 
 		return $mounts;
 	}
+
+	#[Override]
+	public function getMountsForPath(string $setupPathHint, bool $forChildren, array $mountProviderArgs, IStorageFactory $loader): array {
+		$user = $mountProviderArgs[0]->mountInfo->getUser();
+
+		if (!$forChildren) {
+			// override path with mount point when fetching without children
+			$setupPathHint = $mountProviderArgs[0]->mountInfo->getMountPoint();
+		}
+
+		$this->userStoragesService->setUser($user);
+		$this->userGlobalStoragesService->setUser($user);
+
+		$storageConfigs = $this->userGlobalStoragesService->getAllStoragesForUserWithPath($setupPathHint, $forChildren);
+		$availableStorages = $this->getAvailableStorages($storageConfigs, $user);
+
+		$mounts = [];
+
+		$i = 0;
+		foreach ($storageConfigs as $storageConfig) {
+			$storage = $availableStorages[$i];
+			$i++;
+			$mountPoint = '/' . $user->getUID() . '/files' . $storageConfig->getMountPoint();
+			$mounts[$mountPoint] = $this->storageConfigToMount($user, $mountPoint, $loader, $storage, $storageConfig);
+		}
+
+		$this->userStoragesService->resetUser();
+		$this->userGlobalStoragesService->resetUser();
+
+		return $mounts;
+	}
+
+	private function storageConfigToMount(IUser $user, string $mountPoint, IStorageFactory $loader, IStorage $storage, StorageConfig $storageConfig): IMountPoint {
+		$storage->setOwner($user->getUID());
+		if ($storageConfig->getType() === StorageConfig::MOUNT_TYPE_PERSONAL) {
+			return new PersonalMount(
+				$this->userStoragesService,
+				$storageConfig,
+				$storageConfig->getId(),
+				new KnownMtime([
+					'storage' => $storage,
+					'clock' => $this->clock,
+				]),
+				$mountPoint,
+				null,
+				$loader,
+				$storageConfig->getMountOptions(),
+				$storageConfig->getId()
+			);
+		} else {
+			return new SystemMountPoint(
+				$storageConfig,
+				$storage,
+				$mountPoint,
+				null,
+				$loader,
+				$storageConfig->getMountOptions(),
+				$storageConfig->getId()
+			);
+		}
+	}
 }
