@@ -8,13 +8,27 @@
 
 namespace OCA\Files_External\Service;
 
-use Doctrine\DBAL\Exception\UniqueConstraintViolationException;
+use OCP\DB\Exception;
+use OCP\DB\QueryBuilder\IParameter;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use OCP\Security\ICrypto;
 
 /**
  * Stores the mount config in the database
+ *
+ * @psalm-type ApplicableConfig = array{type: int, value: string}
+ * @psalm-type ExternalMountInfo = array{
+ *      mount_id: int,
+ *      mount_point: string,
+ *      storage_backend: string,
+ *      auth_backend: string,
+ *      priority: int,
+ *      type: self::MOUNT_TYPE_ADMIN|self::MOUNT_TYPE_PERSONAL,
+ *      applicable: list<ApplicableConfig>,
+ *      config: array,
+ *      options: array,
+ *  }
  */
 class DBConfigService {
 	public const MOUNT_TYPE_ADMIN = 1;
@@ -32,6 +46,9 @@ class DBConfigService {
 	) {
 	}
 
+	/**
+	 * @return ?ExternalMountInfo
+	 */
 	public function getMountById(int $mountId): ?array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->select(['mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'type'])
@@ -48,33 +65,104 @@ class DBConfigService {
 	/**
 	 * Get all configured mounts
 	 *
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getAllMounts() {
+	public function getAllMounts(): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->select(['mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'type'])
 			->from('external_mounts');
 		return $this->getMountsFromQuery($query);
 	}
 
-	public function getMountsForUser($userId, $groupIds) {
+	public function getMountsForUser(string $userId, array $groupIds): array {
+		$builder = $this->getSelectQueryBuilder();
+		$builder = $builder->where($builder->expr()->orX(
+			$builder->expr()->andX( // global mounts
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GLOBAL, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->isNull('a.value'),
+			),
+			$builder->expr()->andX( // mounts for user
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_USER, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->eq('a.value', $builder->createNamedParameter($userId)),
+			),
+			$builder->expr()->andX( // mounts for group
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GROUP, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->in('a.value', $builder->createNamedParameter($groupIds, IQueryBuilder::PARAM_STR_ARRAY)),
+			),
+		));
+
+		return $this->getMountsFromQuery($builder);
+	}
+
+	/**
+	 * @param list<string> $groupIds
+	 * @return list<ExternalMountInfo>
+	 */
+	public function getMountsForGroups(array $groupIds): array {
+		$builder = $this->getSelectQueryBuilder();
+		$builder = $builder->where($builder->expr()->andX( // mounts for group
+			$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GROUP, IQueryBuilder::PARAM_INT)),
+			$builder->expr()->in('a.value', $builder->createNamedParameter($groupIds, IQueryBuilder::PARAM_STR_ARRAY)),
+		));
+
+		return $this->getMountsFromQuery($builder);
+	}
+
+	private function getSelectQueryBuilder(): IQueryBuilder {
+		$builder = $this->connection->getQueryBuilder();
+		return $builder->select(['m.mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'm.type'])
+			->from('external_mounts', 'm')
+			->innerJoin('m', 'external_applicable', 'a', $builder->expr()->eq('m.mount_id', 'a.mount_id'));
+	}
+
+	/*
+	 * @return list<ExternalMountInfo>
+	 */
+	public function getMountsForUserAndPath(string $userId, array $groupIds, string $path, bool $forChildren): array {
+		$path = str_replace('/' . $userId . '/files', '', $path);
+		$path = rtrim($path, '/');
+		if ($path === '') {
+			$nonChildPath = '/';
+		} else {
+			$nonChildPath = $path;
+		}
+
+		$builder = $this->getSelectQueryBuilder();
+		$pathFilter = $forChildren
+			? $builder->expr()->like('m.mount_point', $builder->createNamedParameter($this->connection->escapeLikeParameter($path) . '/_%', IQueryBuilder::PARAM_STR))
+			: $builder->expr()->eq('m.mount_point', $builder->createNamedParameter($nonChildPath, IQueryBuilder::PARAM_STR));
+		$builder->where($builder->expr()->orX(
+			$builder->expr()->andX( // global mounts
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GLOBAL, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->isNull('a.value'),
+				$pathFilter,
+			),
+			$builder->expr()->andX( // mounts for user
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_USER, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->eq('a.value', $builder->createNamedParameter($userId)),
+				$pathFilter,
+			),
+			$builder->expr()->andX( // mounts for group
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GROUP, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->in('a.value', $builder->createNamedParameter($groupIds, IQueryBuilder::PARAM_STR_ARRAY)),
+				$pathFilter,
+			),
+		));
+
+		return $this->getMountsFromQuery($builder);
+	}
+
+	/**
+	 * @return list<ExternalMountInfo>
+	 */
+	public function getGlobalMounts(): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->select(['m.mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'm.type'])
 			->from('external_mounts', 'm')
 			->innerJoin('m', 'external_applicable', 'a', $builder->expr()->eq('m.mount_id', 'a.mount_id'))
-			->where($builder->expr()->orX(
-				$builder->expr()->andX( // global mounts
-					$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GLOBAL, IQueryBuilder::PARAM_INT)),
-					$builder->expr()->isNull('a.value'),
-				),
-				$builder->expr()->andX( // mounts for user
-					$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_USER, IQueryBuilder::PARAM_INT)),
-					$builder->expr()->eq('a.value', $builder->createNamedParameter($userId)),
-				),
-				$builder->expr()->andX( // mounts for group
-					$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GROUP, IQueryBuilder::PARAM_INT)),
-					$builder->expr()->in('a.value', $builder->createNamedParameter($groupIds, IQueryBuilder::PARAM_STR_ARRAY)),
-				),
+			->where($builder->expr()->andX( // global mounts
+				$builder->expr()->eq('a.type', $builder->createNamedParameter(self::APPLICABLE_TYPE_GLOBAL, IQueryBuilder::PARAM_INT)),
+				$builder->expr()->isNull('a.value'),
 			));
 
 		return $this->getMountsFromQuery($query);
@@ -100,7 +188,7 @@ class DBConfigService {
 			)
 			->groupBy(['a.mount_id']);
 		$stmt = $query->executeQuery();
-		$result = $stmt->fetchAll();
+		$result = $stmt->fetchAllAssociative();
 		$stmt->closeCursor();
 
 		foreach ($result as $row) {
@@ -115,9 +203,9 @@ class DBConfigService {
 	/**
 	 * Get admin defined mounts
 	 *
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getAdminMounts() {
+	public function getAdminMounts(): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->select(['mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'type'])
 			->from('external_mounts')
@@ -125,19 +213,17 @@ class DBConfigService {
 		return $this->getMountsFromQuery($query);
 	}
 
-	protected function getForQuery(IQueryBuilder $builder, $type, $value) {
-		$query = $builder->select(['m.mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'm.type'])
-			->from('external_mounts', 'm')
-			->innerJoin('m', 'external_applicable', 'a', $builder->expr()->eq('m.mount_id', 'a.mount_id'))
-			->where($builder->expr()->eq('a.type', $builder->createNamedParameter($type, IQueryBuilder::PARAM_INT)));
+	protected function getForQuery(IQueryBuilder $builder, int $type, ?string $value): IQueryBuilder {
+		$builder = $this->getSelectQueryBuilder();
+		$builder = $builder->where($builder->expr()->eq('a.type', $builder->createNamedParameter($type, IQueryBuilder::PARAM_INT)));
 
 		if (is_null($value)) {
-			$query = $query->andWhere($builder->expr()->isNull('a.value'));
+			$builder = $builder->andWhere($builder->expr()->isNull('a.value'));
 		} else {
-			$query = $query->andWhere($builder->expr()->eq('a.value', $builder->createNamedParameter($value)));
+			$builder = $builder->andWhere($builder->expr()->eq('a.value', $builder->createNamedParameter($value)));
 		}
 
-		return $query;
+		return $builder;
 	}
 
 	/**
@@ -145,9 +231,9 @@ class DBConfigService {
 	 *
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string|null $value user_id, group_id or null for global mounts
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getMountsFor($type, $value) {
+	public function getMountsFor(int $type, ?string $value): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $this->getForQuery($builder, $type, $value);
 
@@ -159,9 +245,9 @@ class DBConfigService {
 	 *
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string|null $value user_id, group_id or null for global mounts
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getAdminMountsFor($type, $value) {
+	public function getAdminMountsFor(int $type, ?string $value): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $this->getForQuery($builder, $type, $value);
 		$query->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_ADMIN, IQueryBuilder::PARAM_INT)));
@@ -174,22 +260,20 @@ class DBConfigService {
 	 *
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string[] $values user_ids or group_ids
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getAdminMountsForMultiple($type, array $values) {
-		$builder = $this->connection->getQueryBuilder();
-		$params = array_map(function ($value) use ($builder) {
+	public function getAdminMountsForMultiple(int $type, array $values): array {
+		$builder = $this->getSelectQueryBuilder();
+		$params = array_map(function (string $value) use ($builder): IParameter {
 			return $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR);
 		}, $values);
 
-		$query = $builder->select(['m.mount_id', 'mount_point', 'storage_backend', 'auth_backend', 'priority', 'm.type'])
-			->from('external_mounts', 'm')
-			->innerJoin('m', 'external_applicable', 'a', $builder->expr()->eq('m.mount_id', 'a.mount_id'))
+		$builder = $builder
 			->where($builder->expr()->eq('a.type', $builder->createNamedParameter($type, IQueryBuilder::PARAM_INT)))
 			->andWhere($builder->expr()->in('a.value', $params));
-		$query->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_ADMIN, IQueryBuilder::PARAM_INT)));
+		$builder->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_ADMIN, IQueryBuilder::PARAM_INT)));
 
-		return $this->getMountsFromQuery($query);
+		return $this->getMountsFromQuery($builder);
 	}
 
 	/**
@@ -197,9 +281,9 @@ class DBConfigService {
 	 *
 	 * @param int $type any of the self::APPLICABLE_TYPE_ constants
 	 * @param string|null $value user_id, group_id or null for global mounts
-	 * @return array
+	 * @return list<ExternalMountInfo>
 	 */
-	public function getUserMountsFor($type, $value) {
+	public function getUserMountsFor(int $type, ?string $value): array {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $this->getForQuery($builder, $type, $value);
 		$query->andWhere($builder->expr()->eq('m.type', $builder->expr()->literal(self::MOUNT_TYPE_PERSONAL, IQueryBuilder::PARAM_INT)));
@@ -210,14 +294,10 @@ class DBConfigService {
 	/**
 	 * Add a mount to the database
 	 *
-	 * @param string $mountPoint
-	 * @param string $storageBackend
-	 * @param string $authBackend
-	 * @param int $priority
-	 * @param int $type self::MOUNT_TYPE_ADMIN or self::MOUNT_TYPE_PERSONAL
+	 * @param self::MOUNT_TYPE_ADMIN|self::MOUNT_TYPE_PERSONAL $type
 	 * @return int the id of the new mount
 	 */
-	public function addMount($mountPoint, $storageBackend, $authBackend, $priority, $type) {
+	public function addMount(string $mountPoint, string $storageBackend, string $authBackend, ?int $priority, int $type): int {
 		if (!$priority) {
 			$priority = 100;
 		}
@@ -236,10 +316,8 @@ class DBConfigService {
 
 	/**
 	 * Remove a mount from the database
-	 *
-	 * @param int $mountId
 	 */
-	public function removeMount($mountId) {
+	public function removeMount(int $mountId): void {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_mounts')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)));
@@ -261,11 +339,7 @@ class DBConfigService {
 		$query->executeStatement();
 	}
 
-	/**
-	 * @param int $mountId
-	 * @param string $newMountPoint
-	 */
-	public function setMountPoint($mountId, $newMountPoint) {
+	public function setMountPoint(int $mountId, string $newMountPoint): void {
 		$builder = $this->connection->getQueryBuilder();
 
 		$query = $builder->update('external_mounts')
@@ -275,11 +349,7 @@ class DBConfigService {
 		$query->executeStatement();
 	}
 
-	/**
-	 * @param int $mountId
-	 * @param string $newAuthBackend
-	 */
-	public function setAuthBackend($mountId, $newAuthBackend) {
+	public function setAuthBackend(int $mountId, string $newAuthBackend): void {
 		$builder = $this->connection->getQueryBuilder();
 
 		$query = $builder->update('external_mounts')
@@ -289,12 +359,7 @@ class DBConfigService {
 		$query->executeStatement();
 	}
 
-	/**
-	 * @param int $mountId
-	 * @param string $key
-	 * @param string $value
-	 */
-	public function setConfig($mountId, $key, $value) {
+	public function setConfig(int $mountId, string $key, string $value): void {
 		if ($key === 'password') {
 			$value = $this->encryptValue($value);
 		}
@@ -305,8 +370,11 @@ class DBConfigService {
 				->setValue('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT))
 				->setValue('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR))
 				->setValue('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR))
-				->execute();
-		} catch (UniqueConstraintViolationException $e) {
+				->executeStatement();
+		} catch (Exception $e) {
+			if ($e->getReason() !== Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+				throw $e;
+			}
 			$builder = $this->connection->getQueryBuilder();
 			$query = $builder->update('external_config')
 				->set('value', $builder->createNamedParameter($value, IQueryBuilder::PARAM_STR))
@@ -316,20 +384,18 @@ class DBConfigService {
 		}
 	}
 
-	/**
-	 * @param int $mountId
-	 * @param string $key
-	 * @param string $value
-	 */
-	public function setOption($mountId, $key, $value) {
+	public function setOption(int $mountId, string $key, string $value): void {
 		try {
 			$builder = $this->connection->getQueryBuilder();
 			$builder->insert('external_options')
 				->setValue('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT))
 				->setValue('key', $builder->createNamedParameter($key, IQueryBuilder::PARAM_STR))
 				->setValue('value', $builder->createNamedParameter(json_encode($value), IQueryBuilder::PARAM_STR))
-				->execute();
-		} catch (UniqueConstraintViolationException $e) {
+				->executeStatement();
+		} catch (Exception $e) {
+			if ($e->getReason() !== Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+				throw $e;
+			}
 			$builder = $this->connection->getQueryBuilder();
 			$query = $builder->update('external_options')
 				->set('value', $builder->createNamedParameter(json_encode($value), IQueryBuilder::PARAM_STR))
@@ -339,20 +405,23 @@ class DBConfigService {
 		}
 	}
 
-	public function addApplicable($mountId, $type, $value) {
+	public function addApplicable(int $mountId, int $type, ?string $value): void {
 		try {
 			$builder = $this->connection->getQueryBuilder();
 			$builder->insert('external_applicable')
 				->setValue('mount_id', $builder->createNamedParameter($mountId))
 				->setValue('type', $builder->createNamedParameter($type))
 				->setValue('value', $builder->createNamedParameter($value))
-				->execute();
-		} catch (UniqueConstraintViolationException $e) {
+				->executeStatement();
+		} catch (Exception $e) {
 			// applicable exists already
+			if ($e->getReason() !== Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+				throw $e;
+			}
 		}
 	}
 
-	public function removeApplicable($mountId, $type, $value) {
+	public function removeApplicable(int $mountId, int $type, ?string $value): void {
 		$builder = $this->connection->getQueryBuilder();
 		$query = $builder->delete('external_applicable')
 			->where($builder->expr()->eq('mount_id', $builder->createNamedParameter($mountId, IQueryBuilder::PARAM_INT)))
@@ -367,9 +436,14 @@ class DBConfigService {
 		$query->executeStatement();
 	}
 
-	private function getMountsFromQuery(IQueryBuilder $query) {
+	/**
+	 * @return list<ExternalMountInfo>
+	 * @throws Exception
+	 */
+	private function getMountsFromQuery(IQueryBuilder $query): array {
 		$result = $query->executeQuery();
-		$mounts = $result->fetchAll();
+		/** @var \Generator<array{mount_id: int, mount_point: string, storage_backend: string, auth_backend: string, priority: mixed, type: int}> $mounts */
+		$mounts = $result->iterateAssociative();
 		$uniqueMounts = [];
 		foreach ($mounts as $mount) {
 			$id = $mount['mount_id'];
@@ -379,7 +453,7 @@ class DBConfigService {
 		}
 		$uniqueMounts = array_values($uniqueMounts);
 
-		$mountIds = array_map(function ($mount) {
+		$mountIds = array_map(function (array $mount): int {
 			return $mount['mount_id'];
 		}, $uniqueMounts);
 		$mountIds = array_values(array_unique($mountIds));
@@ -388,8 +462,10 @@ class DBConfigService {
 		$config = $this->getConfigForMounts($mountIds);
 		$options = $this->getOptionsForMounts($mountIds);
 
-		return array_map(function ($mount, $applicable, $config, $options) {
-			$mount['type'] = (int)$mount['type'];
+		return array_map(function (array $mount, array $applicable, array $config, array $options): array {
+			$mountType = (int)$mount['type'];
+			assert($mountType === self::MOUNT_TYPE_ADMIN || $mountType === self::MOUNT_TYPE_PERSONAL);
+			$mount['type'] = $mountType;
 			$mount['priority'] = (int)$mount['priority'];
 			$mount['applicable'] = $applicable;
 			$mount['config'] = $config;
@@ -401,26 +477,23 @@ class DBConfigService {
 	/**
 	 * Get mount options from a table grouped by mount id
 	 *
-	 * @param string $table
 	 * @param string[] $fields
 	 * @param int[] $mountIds
-	 * @return array [$mountId => [['field1' => $value1, ...], ...], ...]
+	 * @return array<int, list<array>> [$mountId => [['field1' => $value1, ...], ...], ...]
 	 */
-	private function selectForMounts($table, array $fields, array $mountIds) {
+	private function selectForMounts(string $table, array $fields, array $mountIds): array {
 		if (count($mountIds) === 0) {
 			return [];
 		}
 		$builder = $this->connection->getQueryBuilder();
 		$fields[] = 'mount_id';
-		$placeHolders = array_map(function ($id) use ($builder) {
-			return $builder->createPositionalParameter($id, IQueryBuilder::PARAM_INT);
-		}, $mountIds);
+		$placeHolders = array_map(fn ($id) => $builder->createPositionalParameter($id, IQueryBuilder::PARAM_INT), $mountIds);
 		$query = $builder->select($fields)
 			->from($table)
 			->where($builder->expr()->in('mount_id', $placeHolders));
 
 		$result = $query->executeQuery();
-		$rows = $result->fetchAll();
+		$rows = $result->fetchAllAssociative();
 		$result->closeCursor();
 
 		$result = [];
@@ -438,26 +511,28 @@ class DBConfigService {
 
 	/**
 	 * @param int[] $mountIds
-	 * @return array [$id => [['type' => $type, 'value' => $value], ...], ...]
+	 * @return array<int, list<array{type: mixed, value: string}>> [$id => [['type' => $type, 'value' => $value], ...], ...]
 	 */
-	public function getApplicableForMounts($mountIds) {
-		return $this->selectForMounts('external_applicable', ['type', 'value'], $mountIds);
+	public function getApplicableForMounts(array $mountIds): array {
+		/** @var array<int, list<array{type: mixed, value: string}>> $result */
+		$result = $this->selectForMounts('external_applicable', ['type', 'value'], $mountIds);
+		return $result;
 	}
 
 	/**
 	 * @param int[] $mountIds
-	 * @return array [$id => ['key1' => $value1, ...], ...]
+	 * @return array<int, array> [$id => ['key1' => $value1, ...], ...]
 	 */
-	public function getConfigForMounts($mountIds) {
+	public function getConfigForMounts(array $mountIds): array {
 		$mountConfigs = $this->selectForMounts('external_config', ['key', 'value'], $mountIds);
 		return array_map([$this, 'createKeyValueMap'], $mountConfigs);
 	}
 
 	/**
 	 * @param int[] $mountIds
-	 * @return array [$id => ['key1' => $value1, ...], ...]
+	 * @return array<int, array> [$id => ['key1' => $value1, ...], ...]
 	 */
-	public function getOptionsForMounts($mountIds) {
+	public function getOptionsForMounts(array $mountIds): array {
 		$mountOptions = $this->selectForMounts('external_options', ['key', 'value'], $mountIds);
 		$optionsMap = array_map([$this, 'createKeyValueMap'], $mountOptions);
 		return array_map(function (array $options) {
@@ -468,10 +543,10 @@ class DBConfigService {
 	}
 
 	/**
-	 * @param array $keyValuePairs [['key'=>$key, 'value=>$value], ...]
+	 * @param list<array{key: string, value: string}> $keyValuePairs [['key'=>$key, 'value=>$value], ...]
 	 * @return array ['key1' => $value1, ...]
 	 */
-	private function createKeyValueMap(array $keyValuePairs) {
+	private function createKeyValueMap(array $keyValuePairs): array {
 		$decryptedPairts = array_map(function ($pair) {
 			if ($pair['key'] === 'password') {
 				$pair['value'] = $this->decryptValue($pair['value']);
@@ -488,14 +563,14 @@ class DBConfigService {
 		return array_combine($keys, $values);
 	}
 
-	private function encryptValue($value) {
+	private function encryptValue(string $value): string {
 		return $this->crypto->encrypt($value);
 	}
 
-	private function decryptValue($value) {
+	private function decryptValue(string $value): string {
 		try {
 			return $this->crypto->decrypt($value);
-		} catch (\Exception $e) {
+		} catch (\Exception) {
 			return $value;
 		}
 	}
@@ -510,6 +585,6 @@ class DBConfigService {
 			->where($builder->expr()->eq('mount_point', $builder->createNamedParameter('/')))
 			->setMaxResults(1);
 		$result = $query->executeQuery();
-		return count($result->fetchAll()) > 0;
+		return count($result->fetchAllAssociative()) > 0;
 	}
 }
