@@ -6,9 +6,6 @@ OC.L10N.register(
     "View file" : "查看文件",
     "View folder" : "查看文件夹",
     "Set file reminders" : "设置文件提醒",
-    "Set reminder for \"{fileName}\"" : "设置文件 “{fileName}” 的提醒",
-    "Set reminder at custom date & time" : "设置自定义日期&时间提醒",
-    "Clear reminder" : "移除提醒",
     "Please choose a valid date & time" : "请选择一个有效的日期&时间",
     "Reminder set for \"{fileName}\"" : "文件 “{fileName}” 的提醒设置",
     "Failed to set reminder" : "无法设置提醒",
@@ -16,9 +13,9 @@ OC.L10N.register(
     "Failed to clear reminder" : "无法清除文件提醒",
     "We will remind you of this file" : "我们将会提醒你该文件",
     "Cancel" : "取消",
+    "Clear reminder" : "移除提醒",
     "Set reminder" : "设置提醒",
     "Reminder set" : "提醒设置",
-    "Set custom reminder" : "设置自定义提醒",
     "Later today" : "今日稍晚",
     "Set reminder for later today" : "今日稍晚提醒",
     "Tomorrow" : "明天",
@@ -26,6 +23,9 @@ OC.L10N.register(
     "This weekend" : "本周末",
     "Set reminder for this weekend" : "本周末提醒",
     "Next week" : "下周",
-    "Set reminder for next week" : "下周提醒"
+    "Set reminder for next week" : "下周提醒",
+    "Set reminder for \"{fileName}\"" : "设置文件 “{fileName}” 的提醒",
+    "Set reminder at custom date & time" : "设置自定义日期&时间提醒",
+    "Set custom reminder" : "设置自定义提醒"
 },
 "nplurals=1; plural=0;");
