@@ -98,8 +98,8 @@ OC.L10N.register(
     "Remember to upload the files to %s" : "Muista lähettää tiedostot kansioon %s",
     "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Muistutamme, ettet ole lähettänyt yhtäkään tiedostoa jaettuun kansioon.",
     "Open \"%s\"" : "Avaa \"%s\"",
-    "People" : "Ihmiset",
     "Filter accounts" : "Suodata tilejä",
+    "you" : "sinä",
     "The request will be password protected." : "Pyyntö suojataan salasanalla.",
     "When should the request expire?" : "Milloin pyynnön tulee vanhentua?",
     "Expiration date" : "Vanhenemispäivä",
@@ -170,6 +170,7 @@ OC.L10N.register(
     "File request ({label})" : "Tiedostopyyntö ({label})",
     "Mail share ({label})" : "Sähköpostijako ({label})",
     "Share link ({label})" : "Jaa linkki ({label})",
+    "Mail share" : "Sähköpostijako",
     "Share link ({index})" : "Jaa linkki ({index})",
     "Create public link" : "Luo julkinen linkki",
     "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
@@ -177,6 +178,8 @@ OC.L10N.register(
     "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
     "Link share created" : "Linkkijako luotu",
     "Error while creating the share" : "Virhe jakoa luotaessa",
+    "Your browser does not support copying, please copy the link manually:" : "Selaimesi ei tue kopiointia. Kopioi linkki:",
+    "Successfully copied public link" : "Julkinen linkki kopioitu",
     "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
     "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
     "Password protection" : "Salasanasuojaus",
@@ -190,6 +193,8 @@ OC.L10N.register(
     "Can edit" : "Voi muokata",
     "Custom permissions" : "Mukautetut oikeudet",
     "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
+    "Name or email …" : "Nimi tai sähköposti …",
+    "Searching …" : "Haetaan …",
     "No elements found." : "Elementtejä ei löytynyt.",
     "Search everywhere" : "Etsi kaikkialta",
     "Guest" : "Vieras",
@@ -205,6 +210,7 @@ OC.L10N.register(
     "By uploading files, you agree to the terms of service." : "Lähettämällä tiedostot hyväksyt käyttöehdot.",
     "View terms of service" : "Näytä käyttöehdot",
     "Terms of service" : "Käyttöehdot",
+    "Share with {user}" : "Jaa käyttäjän {user} kanssa",
     "Share with group" : "Jaa ryhmän kanssa",
     "Share in conversation" : "Jaa keskustelussa",
     "Share with remote group" : "Jaa etäryhmän kanssa",
@@ -218,11 +224,13 @@ OC.L10N.register(
     "Delete" : "Poista",
     "Password field cannot be empty" : "Salasanakenttä ei voi olla tyhjä",
     "Replace current password" : "Korvaa nykyinen salasana",
+    "Failed to generate a new token" : "Uuden poletin luominen epäonnistui",
     "Allow upload and editing" : "Salli lähetys ja muokkaus",
     "Allow editing" : "Salli muokkaus",
     "Advanced settings" : "Lisäasetukset",
     "Share label" : "Jaon nimi",
     "Generating…" : "Luodaan…",
+    "Generate new token" : "Luo uusi poletti",
     "Set password" : "Aseta salasana",
     "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
     "Password expired" : "Salasana vanheni",
@@ -230,6 +238,7 @@ OC.L10N.register(
     "Expiration date (enforced)" : "Vanhenemispäivä (pakotettu)",
     "Set expiration date" : "Aseta vanhenemispäivä",
     "Hide download" : "Piilota lataus",
+    "Allow download and sync" : "Salli lataus ja synkronointi",
     "Note to recipient" : "Huomio vastaanottajalle",
     "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
     "Show files in grid view" : "Näytä tiedostot ruudukkonäkymässä",
@@ -256,6 +265,7 @@ OC.L10N.register(
     "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
     "Sharing options" : "Jakamisen valinnat",
     "Shared with others" : "Jaettu muiden kanssa",
+    "People" : "Ihmiset",
     "Create file request" : "Luo tiedostopyyntö",
     "Upload files to {foldername}" : "Lähetä tiedostot kansioon {foldername}",
     "Public file share" : "Julkinen tiedostojako",
@@ -287,16 +297,19 @@ OC.L10N.register(
     "List of unapproved shares." : "Luettelo hyväksymättömistä jaoista.",
     "No pending shares" : "Ei odottavia jakoja",
     "Shares you have received but not approved will show up here" : "Vastaanottamasi jaot, joita ei ole hyväksytty, näkyvät täällä",
+    "Error deleting the share" : "Virhe jakoa poistaessa",
     "Error updating the share: {errorMessage}" : "Virhe päivittäessä jakoa: {errorMessage}",
     "Error updating the share" : "Virhe jakoa päivittäessä",
     "File \"{path}\" has been unshared" : "Tiedoston \"{path}\" jakaminen on lopetettu",
     "Folder \"{path}\" has been unshared" : "Kansion \"{path}\" jakaminen on lopetettu",
+    "Could not update share" : "Jakoa ei voitu päivittää",
     "Share saved" : "Jako tallennettu",
     "Share password saved" : "Jaon salasana tallennettu",
     "Share permissions saved" : "Jaon oikeudet tallennettu",
     "Upload files to {folder}" : "Lähetä tiedostot kansioon {folder}",
     "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} jakoi kansion kanssasi.",
     "Names must not be empty." : "Nimet eivät voi olla tyhjiä.",
+    "Names must not start with a dot." : "Nimi ei voi alkaa pisteellä.",
     "Invalid name." : "Virheellinen nimi.",
     "Password created successfully" : "Salasana luotu onnistuneesti",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
