@@ -71,7 +71,6 @@ OC.L10N.register(
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Sharing %1$s failed because the back end does not allow shares from type %2$s",
     "Please specify a valid federated group ID" : "Please specify a valid federated group ID",
     "Sharing %s failed because the back end does not support room shares" : "Sharing %s failed because the back end does not support room shares",
-    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Sharing %s failed because the back end does not support ScienceMesh shares",
     "Unknown share type" : "Unknown share type",
     "Not a directory" : "Not a directory",
     "Could not lock node" : "Could not lock node",
@@ -95,7 +94,6 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "You received {share} to group {group} as a share by {user}",
     "Accept" : "Accept",
     "Decline" : "Decline",
-    "People" : "People",
     "Expiration date" : "Expiration date",
     "Password" : "Password",
     "Link copied" : "Link copied",
@@ -150,9 +148,6 @@ OC.L10N.register(
     "Can edit" : "Can edit",
     "Custom permissions" : "Custom permissions",
     "Resharing is not allowed" : "Resharing is not allowed",
-    "Name or email …" : "Name or email …",
-    "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
-    "Searching …" : "Searching …",
     "No elements found." : "No elements found.",
     "Search everywhere" : "მოძებნე ყველგან",
     "Guest" : "Guest",
@@ -207,6 +202,7 @@ OC.L10N.register(
     "Shared" : "Shared",
     "Shared by {ownerDisplayName}" : "Shared by {ownerDisplayName}",
     "Shared with others" : "Shared with others",
+    "People" : "People",
     "Overview of shared files." : "Overview of shared files.",
     "No shares" : "No shares",
     "Files and folders you shared or have been shared with you will show up here" : "Files and folders you shared or have been shared with you will show up here",
@@ -233,8 +229,6 @@ OC.L10N.register(
     "Error updating the share" : "Error updating the share",
     "File \"{path}\" has been unshared" : "File \"{path}\" has been unshared",
     "Folder \"{path}\" has been unshared" : "Folder \"{path}\" has been unshared",
-    "Shared by" : "Shared by",
-    "Shared with" : "Shared with",
     "Password created successfully" : "Password created successfully",
     "Error generating password from password policy" : "Error generating password from password policy",
     "Shared with you and the group {group} by {owner}" : "Shared with you and the group {group} by {owner}",
@@ -244,34 +238,28 @@ OC.L10N.register(
     "Share not found" : "Share not found",
     "Back to %s" : "Back to %s",
     "Add to your Nextcloud" : "Add to your Nextcloud",
-    "Waiting…" : "Waiting…",
-    "error" : "error",
-    "finished" : "finished",
-    "This will stop your current uploads." : "This will stop your current uploads.",
-    "Move or copy" : "Move or copy",
-    "You can upload into this folder" : "You can upload into this folder",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "No compatible server found at {remote}" : "No compatible server found at {remote}",
-    "Invalid server URL" : "Invalid server URL",
-    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
-    "Download all files" : "Download all files",
+    "Sharing %s failed because the back end does not support ScienceMesh shares" : "Sharing %s failed because the back end does not support ScienceMesh shares",
     "Copy to clipboard" : "Copy to clipboard",
     "Copy internal link to clipboard" : "Copy internal link to clipboard",
     "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
+    "Name or email …" : "Name or email …",
+    "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
+    "Searching …" : "Searching …",
     "Search globally" : "Search globally",
-    "Search for share recipients" : "Search for share recipients",
-    "No recommendations. Start typing." : "No recommendations. Start typing.",
+    "Name" : "სახელი",
     "Enter your name" : "Enter your name",
     "Share with {userName}" : "Share with {userName}",
     "Show sharing options" : "Show sharing options",
+    "Shared by" : "Shared by",
+    "Shared with" : "Shared with",
     "Share note" : "Share note",
+    "Show list view" : "Show list view",
+    "Show grid view" : "Show grid view",
     "Upload files to %s" : "Upload files to %s",
     "Note" : "Note",
     "Select or drop files" : "Select or drop files",
     "Uploading files" : "Uploading files",
     "Uploaded files:" : "Uploaded files:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s.",
-    "Name" : "სახელი"
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s."
 },
 "nplurals=2; plural=(n!=1);");
