@@ -11,6 +11,7 @@ namespace OCA\Files_Sharing\Controller;
 use Generator;
 use OC\Collaboration\Collaborators\SearchResult;
 use OC\Share\Share;
+use OCA\FederatedFileSharing\FederatedShareProvider;
 use OCA\Files_Sharing\ResponseDefinitions;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Http;
@@ -39,14 +40,11 @@ use function usort;
  */
 class ShareesAPIController extends OCSController {
 
-	/** @var int */
-	protected $offset = 0;
-
-	/** @var int */
-	protected $limit = 10;
+	protected int $offset = 0;
+	protected int $limit = 10;
 
 	/** @var Files_SharingShareesSearchResult */
-	protected $result = [
+	protected array $result = [
 		'exact' => [
 			'users' => [],
 			'groups' => [],
@@ -67,8 +65,6 @@ class ShareesAPIController extends OCSController {
 		'lookupEnabled' => false,
 	];
 
-	protected $reachedEndFor = [];
-
 	public function __construct(
 		string $appName,
 		IRequest $request,
@@ -77,6 +73,7 @@ class ShareesAPIController extends OCSController {
 		protected IURLGenerator $urlGenerator,
 		protected IManager $shareManager,
 		protected ISearch $collaboratorSearch,
+		protected FederatedShareProvider $federatedShareProvider,
 	) {
 		parent::__construct($appName, $request);
 	}
@@ -146,10 +143,16 @@ class ShareesAPIController extends OCSController {
 			if ($this->shareManager->shareProviderExists(IShare::TYPE_ROOM)) {
 				$shareTypes[] = IShare::TYPE_ROOM;
 			}
-
-			if ($this->shareManager->shareProviderExists(IShare::TYPE_SCIENCEMESH)) {
-				$shareTypes[] = IShare::TYPE_SCIENCEMESH;
+		} elseif ($itemType === 'teams') {
+			if ($this->shareManager->allowGroupSharing()) {
+				$shareTypes[] = IShare::TYPE_GROUP;
 			}
+
+			if ($this->federatedShareProvider->isOutgoingServer2serverShareEnabled()) {
+				$shareTypes[] = IShare::TYPE_REMOTE;
+			}
+
+			$shareTypes[] = IShare::TYPE_EMAIL;
 		} else {
 			if ($this->shareManager->allowGroupSharing()) {
 				$shareTypes[] = IShare::TYPE_GROUP;
@@ -162,10 +165,6 @@ class ShareesAPIController extends OCSController {
 			$shareTypes[] = IShare::TYPE_CIRCLE;
 		}
 
-		if ($this->shareManager->shareProviderExists(IShare::TYPE_SCIENCEMESH)) {
-			$shareTypes[] = IShare::TYPE_SCIENCEMESH;
-		}
-
 		if ($itemType === 'calendar') {
 			$shareTypes[] = IShare::TYPE_REMOTE;
 		}
