@@ -10,23 +10,17 @@ namespace OCA\Files_Sharing\External;
 use OC\Files\Mount\MountPoint;
 use OC\Files\Mount\MoveableMount;
 use OC\Files\Storage\Storage;
+use OC\Files\Storage\StorageFactory;
 use OCA\Files_Sharing\ISharedMountPoint;
+use Override;
 
 class Mount extends MountPoint implements MoveableMount, ISharedMountPoint {
-
-	/**
-	 * @param string|Storage $storage
-	 * @param string $mountpoint
-	 * @param array $options
-	 * @param \OCA\Files_Sharing\External\Manager $manager
-	 * @param \OC\Files\Storage\StorageFactory $loader
-	 */
 	public function __construct(
-		$storage,
-		$mountpoint,
-		$options,
-		protected $manager,
-		$loader = null,
+		string|Storage $storage,
+		string $mountpoint,
+		array $options,
+		protected Manager $manager,
+		?StorageFactory $loader = null,
 	) {
 		parent::__construct($storage, $mountpoint, $options, $loader, null, null, MountProvider::class);
 	}
@@ -35,9 +29,8 @@ class Mount extends MountPoint implements MoveableMount, ISharedMountPoint {
 	 * Move the mount point to $target
 	 *
 	 * @param string $target the target mount point
-	 * @return bool
 	 */
-	public function moveMount($target) {
+	public function moveMount($target): bool {
 		$result = $this->manager->setMountPoint($this->mountPoint, $target);
 		$this->setMountPoint($target);
 
@@ -51,13 +44,8 @@ class Mount extends MountPoint implements MoveableMount, ISharedMountPoint {
 		return $this->manager->removeShare($this->mountPoint);
 	}
 
-	/**
-	 * Get the type of mount point, used to distinguish things like shares and external storage
-	 * in the web interface
-	 *
-	 * @return string
-	 */
-	public function getMountType() {
+	#[Override]
+	public function getMountType(): string {
 		return 'shared';
 	}
 }
