@@ -9,16 +9,22 @@ namespace OCA\Files_Sharing;
 
 use OC\Files\Filesystem;
 use OC\Files\View;
+use OCP\IUserManager;
 use OCP\Server;
 
 class Hooks {
-	public static function deleteUser($params) {
-		$manager = Server::get(External\Manager::class);
+	public static function deleteUser(array $params): void {
+		$userManager = Server::get(IUserManager::class);
+		$user = $userManager->get($params['uid']);
+		if ($user === null) {
+			return;
+		}
 
-		$manager->removeUserShares($params['uid']);
+		$manager = Server::get(External\Manager::class);
+		$manager->removeUserShares($user);
 	}
 
-	public static function unshareChildren($params) {
+	public static function unshareChildren(array $params): void {
 		$path = Filesystem::getView()->getAbsolutePath($params['path']);
 		$view = new View('/');
 
