@@ -3,34 +3,22 @@
 declare(strict_types=1);
 
 /**
- * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2017 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Notifications;
 
 use GuzzleHttp\Exception\ClientException;
 use GuzzleHttp\Exception\ServerException;
-use OC\Authentication\Exceptions\InvalidTokenException;
 use OC\Authentication\Token\IProvider;
 use OC\Security\IdentityProof\Key;
 use OC\Security\IdentityProof\Manager;
+use OCA\Notifications\AppInfo\Application;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\Authentication\Exceptions\InvalidTokenException;
+use OCP\Authentication\Token\IToken;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\Http\Client\IClientService;
 use OCP\ICache;
@@ -39,8 +27,11 @@ use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\IUser;
 use OCP\L10N\IFactory;
+use OCP\Notification\AlreadyProcessedException;
 use OCP\Notification\IManager as INotificationManager;
+use OCP\Notification\IncompleteParsedNotificationException;
 use OCP\Notification\INotification;
+use OCP\Security\ISecureRandom;
 use OCP\UserStatus\IManager as IUserStatusManager;
 use OCP\UserStatus\IUserStatus;
 use OCP\Util;
@@ -48,69 +39,54 @@ use Psr\Log\LoggerInterface;
 use Symfony\Component\Console\Output\OutputInterface;
 
 class Push {
-	/** @var IDBConnection */
-	protected $db;
-	/** @var INotificationManager */
-	protected $notificationManager;
-	/** @var IConfig */
-	protected $config;
-	/** @var IProvider */
-	protected $tokenProvider;
-	/** @var Manager */
-	private $keyManager;
-	/** @var IClientService */
-	protected $clientService;
-	/** @var ICache */
-	protected $cache;
-	/** @var IUserStatusManager */
-	protected $userStatusManager;
-	/** @var IFactory */
-	protected $l10nFactory;
-	/** @var LoggerInterface */
-	protected $log;
-	/** @var OutputInterface */
-	protected $output;
-	/** @var array */
-	protected $payloadsToSend = [];
-
-	/** @var bool */
-	protected $deferPreparing = false;
-	/** @var bool */
-	protected $deferPayloads = false;
-	/** @var array[] */
-	protected $deletesToPush = [];
+	protected ICache $cache;
+	protected ?OutputInterface $output = null;
+	/**
+	 * @psalm-var array<string, list<string>>
+	 */
+	protected array $payloadsToSend = [];
+	protected bool $deferPreparing = false;
+	protected bool $deferPayloads = false;
+	/**
+	 * @var array[] $userId => $appId => $notificationIds
+	 * @psalm-var array<string|int, array<string, list<int>>>
+	 */
+	protected array $deletesToPush = [];
+	/**
+	 * @psalm-var array<string|int, bool>
+	 */
+	protected array $deleteAllsToPush = [];
 	/** @var INotification[] */
-	protected $notificationsToPush = [];
+	protected array $notificationsToPush = [];
 
-	/** @var null[]|IUserStatus[] */
-	protected $userStatuses = [];
-	/** @var array[] */
-	protected $userDevices = [];
+	/**
+	 * @psalm-var array<string, ?IUserStatus>
+	 */
+	protected array $userStatuses = [];
+	/**
+	 * @psalm-var array<string, list<array{id: int, uid: string, token: int, deviceidentifier: string, devicepublickey: string, devicepublickeyhash: string, pushtokenhash: string, proxyserver: string, apptype: string}>>
+	 */
+	protected array $userDevices = [];
 	/** @var string[] */
-	protected $loadDevicesForUsers = [];
+	protected array $loadDevicesForUsers = [];
 	/** @var string[] */
-	protected $loadStatusForUsers = [];
+	protected array $loadStatusForUsers = [];
 
-	public function __construct(IDBConnection $connection,
-								INotificationManager $notificationManager,
-								IConfig $config,
-								IProvider $tokenProvider,
-								Manager $keyManager,
-								IClientService $clientService,
-								ICacheFactory $cacheFactory,
-								IUserStatusManager $userStatusManager,
-								IFactory $l10nFactory,
-								LoggerInterface $log) {
-		$this->db = $connection;
-		$this->notificationManager = $notificationManager;
-		$this->config = $config;
-		$this->tokenProvider = $tokenProvider;
-		$this->keyManager = $keyManager;
-		$this->clientService = $clientService;
+	public function __construct(
+		protected IDBConnection $db,
+		protected INotificationManager $notificationManager,
+		protected IConfig $config,
+		protected IProvider $tokenProvider,
+		protected Manager $keyManager,
+		protected IClientService $clientService,
+		ICacheFactory $cacheFactory,
+		protected IUserStatusManager $userStatusManager,
+		protected IFactory $l10nFactory,
+		protected ITimeFactory $timeFactory,
+		protected ISecureRandom $random,
+		protected LoggerInterface $log,
+	) {
 		$this->cache = $cacheFactory->createDistributed('pushtokens');
-		$this->userStatusManager = $userStatusManager;
-		$this->l10nFactory = $l10nFactory;
-		$this->log = $log;
 	}
 
 	public function setOutput(OutputInterface $output): void {
@@ -162,9 +138,24 @@ class Push {
 			$this->notificationsToPush = [];
 		}
 
+		if (!empty($this->deleteAllsToPush)) {
+			foreach ($this->deleteAllsToPush as $userId => $bool) {
+				$this->pushDeleteToDevice((string)$userId, null);
+			}
+			$this->deleteAllsToPush = [];
+		}
+
 		if (!empty($this->deletesToPush)) {
-			foreach ($this->deletesToPush as $id => $data) {
-				$this->pushDeleteToDevice($data['userId'], $id, $data['app']);
+			foreach ($this->deletesToPush as $userId => $data) {
+				foreach ($data as $client => $notificationIds) {
+					if ($client === 'talk') {
+						$this->pushDeleteToDevice((string)$userId, $notificationIds, $client);
+					} else {
+						foreach ($notificationIds as $notificationId) {
+							$this->pushDeleteToDevice((string)$userId, [$notificationId], $client);
+						}
+					}
+				}
 			}
 			$this->deletesToPush = [];
 		}
@@ -173,15 +164,18 @@ class Push {
 		$this->sendNotificationsToProxies();
 	}
 
+	/**
+	 * @param array $devices
+	 * @psalm-param $devices list<array{id: int, uid: string, token: int, deviceidentifier: string, devicepublickey: string, devicepublickeyhash: string, pushtokenhash: string, proxyserver: string, apptype: string}>
+	 * @param string $app
+	 * @return array
+	 * @psalm-return list<array{id: int, uid: string, token: int, deviceidentifier: string, devicepublickey: string, devicepublickeyhash: string, pushtokenhash: string, proxyserver: string, apptype: string}>
+	 */
 	public function filterDeviceList(array $devices, string $app): array {
 		$isTalkNotification = \in_array($app, ['spreed', 'talk', 'admin_notification_talk'], true);
 
-		$talkDevices = array_filter($devices, static function ($device) {
-			return $device['apptype'] === 'talk';
-		});
-		$otherDevices = array_filter($devices, static function ($device) {
-			return $device['apptype'] !== 'talk';
-		});
+		$talkDevices = array_filter($devices, static fn ($device) => $device['apptype'] === 'talk');
+		$otherDevices = array_filter($devices, static fn ($device) => $device['apptype'] !== 'talk');
 
 		$this->printInfo('Identified ' . count($talkDevices) . ' Talk devices and ' . count($otherDevices) . ' others.');
 
@@ -204,6 +198,8 @@ class Push {
 
 	public function pushToDevice(int $id, INotification $notification, ?OutputInterface $output = null): void {
 		if (!$this->config->getSystemValueBool('has_internet_connection', true)) {
+			$this->printInfo('<error>Internet connectivity is disabled in configuration file - no push notifications will be sent</error>');
+
 			return;
 		}
 
@@ -226,7 +222,9 @@ class Push {
 
 		if (isset($this->userStatuses[$notification->getUser()])) {
 			$userStatus = $this->userStatuses[$notification->getUser()];
-			if ($userStatus->getStatus() === IUserStatus::DND) {
+			if ($userStatus instanceof IUserStatus
+				&& $userStatus->getStatus() === IUserStatus::DND
+				&& !$notification->isPriorityNotification()) {
 				$this->printInfo('<error>User status is set to DND - no push notifications will be sent</error>');
 				return;
 			}
@@ -240,23 +238,24 @@ class Push {
 		}
 
 		if (empty($devices)) {
-			$this->printInfo('No devices found for user');
+			$this->printInfo('<comment>No devices found for user</comment>');
 			return;
 		}
 
-		$this->printInfo('Trying to push to ' . count($devices) . ' devices');
-		$this->printInfo('');
+		if (!$notification->isValidParsed()) {
+			$language = $this->l10nFactory->getUserLanguage($user);
+			$this->printInfo('Language is set to ' . $language);
 
-		$language = $this->l10nFactory->getUserLanguage($user);
-		$this->printInfo('Language is set to ' . $language);
-
-		try {
-			$this->notificationManager->setPreparingPushNotification(true);
-			$notification = $this->notificationManager->prepare($notification, $language);
-		} catch (\InvalidArgumentException $e) {
-			return;
-		} finally {
-			$this->notificationManager->setPreparingPushNotification(false);
+			try {
+				$this->notificationManager->setPreparingPushNotification(true);
+				$notification = $this->notificationManager->prepare($notification, $language);
+			} catch (AlreadyProcessedException|IncompleteParsedNotificationException|\InvalidArgumentException $e) {
+				// FIXME remove \InvalidArgumentException in Nextcloud 39
+				$this->printInfo('Error when preparing notification for push: ' . get_class($e));
+				return;
+			} finally {
+				$this->notificationManager->setPreparingPushNotification(false);
+			}
 		}
 
 		$userKey = $this->keyManager->getKey($user);
@@ -264,19 +263,24 @@ class Push {
 		$this->printInfo('Private user key size: ' . strlen($userKey->getPrivate()));
 		$this->printInfo('Public user key size: ' . strlen($userKey->getPublic()));
 
+
+		$this->printInfo('');
+		$this->printInfo('Found ' . count($devices) . ' devices registered for push notifications');
 		$isTalkNotification = \in_array($notification->getApp(), ['spreed', 'talk', 'admin_notification_talk'], true);
 		$devices = $this->filterDeviceList($devices, $notification->getApp());
 		if (empty($devices)) {
+			$this->printInfo('<comment>No devices left after filtering</comment>');
 			return;
 		}
+		$this->printInfo('Trying to push to ' . count($devices) . ' devices');
 
 		// We don't push to devices that are older than 60 days
 		$maxAge = time() - 60 * 24 * 60 * 60;
 
 		foreach ($devices as $device) {
-			$device['token'] = (int) $device['token'];
+			$device['token'] = (int)$device['token'];
 			$this->printInfo('');
-			$this->printInfo('Device token:' . $device['token']);
+			$this->printInfo('Device token: ' . $device['token']);
 
 			if (!$this->validateToken($device['token'], $maxAge)) {
 				// Token does not exist anymore
@@ -284,35 +288,68 @@ class Push {
 			}
 
 			try {
-				$payload = json_encode($this->encryptAndSign($userKey, $device, $id, $notification, $isTalkNotification));
+				$payload = json_encode($this->encryptAndSign($userKey, $device, $id, $notification, $isTalkNotification), JSON_THROW_ON_ERROR);
 
 				$proxyServer = rtrim($device['proxyserver'], '/');
 				if (!isset($this->payloadsToSend[$proxyServer])) {
 					$this->payloadsToSend[$proxyServer] = [];
 				}
 				$this->payloadsToSend[$proxyServer][] = $payload;
-			} catch (\InvalidArgumentException $e) {
+			} catch (\JsonException $e) {
+				$this->log->error('JSON error while encoding push notification: ' . $e->getMessage(), ['exception' => $e]);
+			} catch (\InvalidArgumentException) {
 				// Failed to encrypt message for device: public key is invalid
 				$this->deletePushToken($device['token']);
 			}
 		}
+		$this->printInfo('');
 
 		if (!$this->deferPayloads) {
 			$this->sendNotificationsToProxies();
 		}
 	}
 
-	public function pushDeleteToDevice(string $userId, int $notificationId, string $app = ''): void {
+	/**
+	 * @param string $userId
+	 * @param ?int[] $notificationIds
+	 * @param string $app
+	 */
+	public function pushDeleteToDevice(string $userId, ?array $notificationIds, string $app = ''): void {
 		if (!$this->config->getSystemValueBool('has_internet_connection', true)) {
 			return;
 		}
 
 		if ($this->deferPreparing) {
-			$this->deletesToPush[$notificationId] = ['userId' => $userId, 'app' => $app];
+			if ($notificationIds === null) {
+				$this->deleteAllsToPush[$userId] = true;
+				if (isset($this->deletesToPush[$userId])) {
+					unset($this->deletesToPush[$userId]);
+				}
+			} else {
+				if (isset($this->deleteAllsToPush[$userId])) {
+					return;
+				}
+
+				$isTalkNotification = \in_array($app, ['spreed', 'talk', 'admin_notification_talk'], true);
+				$clientGroup = $isTalkNotification ? 'talk' : 'files';
+
+				if (!isset($this->deletesToPush[$userId])) {
+					$this->deletesToPush[$userId] = [];
+				}
+				if (!isset($this->deletesToPush[$userId][$clientGroup])) {
+					$this->deletesToPush[$userId][$clientGroup] = [];
+				}
+
+				foreach ($notificationIds as $notificationId) {
+					$this->deletesToPush[$userId][$clientGroup][] = $notificationId;
+				}
+			}
 			$this->loadDevicesForUsers[] = $userId;
 			return;
 		}
 
+		$deleteAll = $notificationIds === null;
+
 		$user = $this->createFakeUserObject($userId);
 
 		if (!array_key_exists($userId, $this->userDevices)) {
@@ -322,8 +359,8 @@ class Push {
 			$devices = $this->userDevices[$userId];
 		}
 
-		if ($notificationId !== 0 && $app !== '') {
-			// Only filter when it's not a single delete
+		if (!$deleteAll) {
+			// Only filter when it's not delete-all
 			$devices = $this->filterDeviceList($devices, $app);
 		}
 		if (empty($devices)) {
@@ -335,21 +372,39 @@ class Push {
 
 		$userKey = $this->keyManager->getKey($user);
 		foreach ($devices as $device) {
-			$device['token'] = (int) $device['token'];
+			$device['token'] = (int)$device['token'];
 			if (!$this->validateToken($device['token'], $maxAge)) {
 				// Token does not exist anymore
 				continue;
 			}
 
 			try {
-				$payload = json_encode($this->encryptAndSignDelete($userKey, $device, $notificationId));
-
 				$proxyServer = rtrim($device['proxyserver'], '/');
 				if (!isset($this->payloadsToSend[$proxyServer])) {
 					$this->payloadsToSend[$proxyServer] = [];
 				}
-				$this->payloadsToSend[$proxyServer][] = $payload;
-			} catch (\InvalidArgumentException $e) {
+
+				if ($deleteAll) {
+					$data = $this->encryptAndSignDelete($userKey, $device, null);
+					try {
+						$this->payloadsToSend[$proxyServer][] = json_encode($data['payload'], JSON_THROW_ON_ERROR);
+					} catch (\JsonException $e) {
+						$this->log->error('JSON error while encoding push notification: ' . $e->getMessage(), ['exception' => $e]);
+					}
+				} else {
+					$temp = $notificationIds;
+
+					while (!empty($temp)) {
+						$data = $this->encryptAndSignDelete($userKey, $device, $temp);
+						$temp = $data['remaining'];
+						try {
+							$this->payloadsToSend[$proxyServer][] = json_encode($data['payload'], JSON_THROW_ON_ERROR);
+						} catch (\JsonException $e) {
+							$this->log->error('JSON error while encoding push notification: ' . $e->getMessage(), ['exception' => $e]);
+						}
+					}
+				}
+			} catch (\InvalidArgumentException) {
 				// Failed to encrypt message for device: public key is invalid
 				$this->deletePushToken($device['token']);
 			}
@@ -376,6 +431,17 @@ class Push {
 			return;
 		}
 
+		$subscriptionAwareServer = rtrim($this->config->getAppValue(Application::APP_ID, 'subscription_aware_server', 'https://push-notifications.nextcloud.com'), '/');
+		if ($subscriptionAwareServer === 'https://push-notifications.nextcloud.com') {
+			$subscriptionKey = $this->config->getAppValue('support', 'subscription_key');
+		} else {
+			$subscriptionKey = $this->config->getAppValue(Application::APP_ID, 'push_subscription_key');
+			if ($subscriptionKey === '') {
+				$subscriptionKey = $this->createPushSubscriptionKey();
+				$this->config->setAppValue(Application::APP_ID, 'push_subscription_key', $subscriptionKey);
+			}
+		}
+
 		$client = $this->clientService->newClient();
 		foreach ($pushNotifications as $proxyServer => $notifications) {
 			try {
@@ -385,23 +451,28 @@ class Push {
 					],
 				];
 
-				if ($proxyServer === 'https://push-notifications.nextcloud.com') {
-					$subscriptionKey = $this->config->getAppValue('support', 'subscription_key');
-					if ($subscriptionKey) {
-						$requestData['headers']['X-Nextcloud-Subscription-Key'] = $subscriptionKey;
-					}
+				if ($subscriptionKey !== '' && $proxyServer === $subscriptionAwareServer) {
+					$requestData['headers']['X-Nextcloud-Subscription-Key'] = $subscriptionKey;
 				}
 
 				$response = $client->post($proxyServer . '/notifications', $requestData);
 				$status = $response->getStatusCode();
-				$body = $response->getBody();
-				$bodyData = json_decode($body, true);
+				$body = (string)$response->getBody();
+				try {
+					$bodyData = json_decode($body, true);
+				} catch (\JsonException) {
+					$bodyData = null;
+				}
 			} catch (ClientException $e) {
 				// Server responded with 4xx (400 Bad Request mostlikely)
 				$response = $e->getResponse();
 				$status = $response->getStatusCode();
 				$body = $response->getBody()->getContents();
-				$bodyData = json_decode($body, true);
+				try {
+					$bodyData = json_decode($body, true);
+				} catch (\JsonException) {
+					$bodyData = null;
+				}
 			} catch (ServerException $e) {
 				// Server responded with 5xx
 				$response = $e->getResponse();
@@ -414,7 +485,7 @@ class Push {
 					'app' => 'notifications',
 				]);
 
-				$this->printInfo('Could not send notification to push server [' . $proxyServer . ']: ' . $error);
+				$this->printInfo('<error>Could not send notification to push server [' . $proxyServer . ']: ' . $error . '</error>');
 				continue;
 			} catch (\Exception $e) {
 				$this->log->error($e->getMessage(), [
@@ -422,7 +493,7 @@ class Push {
 				]);
 
 				$error = $e->getMessage() ?: 'no reason given';
-				$this->printInfo('Could not send notification to push server [' . get_class($e) . ']: ' . $error);
+				$this->printInfo('<error>Could not send notification to push server [' . $e::class . ']: ' . $error . '</error>');
 				continue;
 			}
 
@@ -430,19 +501,22 @@ class Push {
 				if (is_array($bodyData['unknown'])) {
 					// Proxy returns null when the array is empty
 					foreach ($bodyData['unknown'] as $unknownDevice) {
-						$this->printInfo('Deleting device because it is unknown by the push server: ' . $unknownDevice);
-						$this->deletePushTokenByDeviceIdentifier($unknownDevice);
+						$this->printInfo('<comment>Deleting device because it is unknown by the push server [' . $proxyServer . ']: ' . $unknownDevice . '</comment>');
+						$this->deletePushTokenByDeviceIdentifier($proxyServer, $unknownDevice);
 					}
 				}
 
 				if ($bodyData['failed'] !== 0) {
-					$this->printInfo('Push notification sent, but ' . $bodyData['failed'] . ' failed');
+					$this->printInfo('<comment>Push notification sent, but ' . $bodyData['failed'] . ' failed</comment>');
 				} else {
-					$this->printInfo('Push notification sent successfully');
+					$this->printInfo('<info>Push notification sent successfully</info>');
 				}
 			} elseif ($status !== Http::STATUS_OK) {
+				if ($status === Http::STATUS_TOO_MANY_REQUESTS) {
+					$this->config->setAppValue(Application::APP_ID, 'rate_limit_reached', (string)$this->timeFactory->getTime());
+				}
 				$error = $body && $bodyData === null ? $body : 'no reason given';
-				$this->printInfo('Could not send notification to push server [' . $proxyServer . ']: ' . $error);
+				$this->printInfo('<error>Could not send notification to push server [' . $proxyServer . ']: ' . $error . '</error>');
 				$this->log->warning('Could not send notification to push server [{url}]: {error}', [
 					'error' => $error,
 					'url' => $proxyServer,
@@ -450,7 +524,7 @@ class Push {
 				]);
 			} else {
 				$error = $body && $bodyData === null ? $body : 'no reason given';
-				$this->printInfo('Push notification sent but response was not parsable, using an outdated push proxy? [' . $proxyServer . ']: ' . $error);
+				$this->printInfo('<comment>Push notification sent but response was not parsable, using an outdated push proxy? [' . $proxyServer . ']: ' . $error . '</comment>');
 				$this->log->info('Push notification sent but response was not parsable, using an outdated push proxy? [{url}]: {error}', [
 					'error' => $error,
 					'url' => $proxyServer,
@@ -462,27 +536,61 @@ class Push {
 
 	protected function validateToken(int $tokenId, int $maxAge): bool {
 		$age = $this->cache->get('t' . $tokenId);
-		if ($age !== null) {
-			return $age > $maxAge;
+
+		if ($age === null) {
+			try {
+				// Check if the token is still valid...
+				$token = $this->tokenProvider->getTokenById($tokenId);
+				$type = $this->callSafelyForToken($token, 'getType');
+				if ($type === IToken::WIPE_TOKEN) {
+					// Token does not exist any more, should drop the push device entry
+					$this->printInfo('Device token is marked for remote wipe');
+					$this->deletePushToken($tokenId);
+					$this->cache->set('t' . $tokenId, 0, 600);
+					return false;
+				}
+
+				$age = $token->getLastCheck();
+				$lastActivity = $this->callSafelyForToken($token, 'getLastActivity');
+				if ($lastActivity) {
+					$age = max($age, $lastActivity);
+				}
+				$this->cache->set('t' . $tokenId, $age, 600);
+			} catch (InvalidTokenException) {
+				// Token does not exist any more, should drop the push device entry
+				$this->printInfo('<error>InvalidTokenException is thrown</error>');
+				$this->deletePushToken($tokenId);
+				$this->cache->set('t' . $tokenId, 0, 600);
+				return false;
+			}
 		}
 
-		try {
-			// Check if the token is still valid...
-			$token = $this->tokenProvider->getTokenById($tokenId);
-			$this->cache->set('t' . $tokenId, $token->getLastCheck(), 600);
-			if ($token->getLastCheck() > $maxAge) {
-				$this->printInfo('Device token is valid');
-			} else {
-				$this->printInfo('Device token "last checked" is older than 60 days: ' . $token->getLastCheck());
-			}
-			return $token->getLastCheck() > $maxAge;
-		} catch (InvalidTokenException $e) {
-			// Token does not exist anymore, should drop the push device entry
-			$this->printInfo('InvalidTokenException is thrown');
-			$this->deletePushToken($tokenId);
-			$this->cache->set('t' . $tokenId, 0, 600);
-			return false;
+		if ($age > $maxAge) {
+			$this->printInfo('Device token is valid');
+			return true;
 		}
+
+		$this->printInfo('<comment>Device token "last checked" is older than 60 days: ' . $age . '</comment>');
+		return false;
+	}
+
+	/**
+	 * The functions are not part of public API so we are a bit more careful
+	 * @param IToken $token
+	 * @param 'getLastActivity'|'getType' $method
+	 * @return int|null
+	 */
+	protected function callSafelyForToken(IToken $token, string $method): ?int {
+		if (method_exists($token, $method) || method_exists($token, '__call')) {
+			try {
+				$result = $token->$method();
+				if (is_int($result)) {
+					return $result;
+				}
+			} catch (\BadFunctionCallException) {
+			}
+		}
+		return null;
 	}
 
 	/**
@@ -492,6 +600,7 @@ class Push {
 	 * @param INotification $notification
 	 * @param bool $isTalkNotification
 	 * @return array
+	 * @psalm-return array{deviceIdentifier: string, pushTokenHash: string, subject: string, signature: string, priority: string, type: string}
 	 * @throws InvalidTokenException
 	 * @throws \InvalidArgumentException
 	 */
@@ -529,14 +638,14 @@ class Push {
 		if (!openssl_public_encrypt(json_encode($data), $encryptedSubject, $device['devicepublickey'], OPENSSL_PKCS1_PADDING)) {
 			$error = openssl_error_string();
 			$this->log->error($error, ['app' => 'notifications']);
-			$this->printInfo('Error while encrypting data: "' . $error . '"');
+			$this->printInfo('<error>Error while encrypting data: "' . $error . '"</error>');
 			throw new \InvalidArgumentException('Failed to encrypt message for device');
 		}
 
 		if (openssl_sign($encryptedSubject, $signature, $userKey->getPrivate(), OPENSSL_ALGO_SHA512)) {
 			$this->printInfo('Signed encrypted push subject');
 		} else {
-			$this->printInfo('Failed to signed encrypted push subject');
+			$this->printInfo('<error>Failed to signed encrypted push subject</error>');
 		}
 		$base64EncryptedSubject = base64_encode($encryptedSubject);
 		$base64Signature = base64_encode($signature);
@@ -554,21 +663,29 @@ class Push {
 	/**
 	 * @param Key $userKey
 	 * @param array $device
-	 * @param int $id
+	 * @param ?int[] $ids
 	 * @return array
+	 * @psalm-return array{remaining: list<int>, payload: array{deviceIdentifier: string, pushTokenHash: string, subject: string, signature: string, priority: string, type: string}}
 	 * @throws InvalidTokenException
 	 * @throws \InvalidArgumentException
 	 */
-	protected function encryptAndSignDelete(Key $userKey, array $device, int $id): array {
-		if ($id === 0) {
+	protected function encryptAndSignDelete(Key $userKey, array $device, ?array $ids): array {
+		$remainingIds = [];
+		if ($ids === null) {
 			$data = [
 				'delete-all' => true,
 			];
-		} else {
+		} elseif (count($ids) === 1) {
 			$data = [
-				'nid' => $id,
+				'nid' => array_pop($ids),
 				'delete' => true,
 			];
+		} else {
+			$remainingIds = array_splice($ids, 10);
+			$data = [
+				'nids' => $ids,
+				'delete-multiple' => true,
+			];
 		}
 
 		if (!openssl_public_encrypt(json_encode($data), $encryptedSubject, $device['devicepublickey'], OPENSSL_PKCS1_PADDING)) {
@@ -581,18 +698,22 @@ class Push {
 		$base64Signature = base64_encode($signature);
 
 		return [
-			'deviceIdentifier' => $device['deviceidentifier'],
-			'pushTokenHash' => $device['pushtokenhash'],
-			'subject' => $base64EncryptedSubject,
-			'signature' => $base64Signature,
-			'priority' => 'normal',
-			'type' => 'background',
+			'remaining' => $remainingIds,
+			'payload' => [
+				'deviceIdentifier' => $device['deviceidentifier'],
+				'pushTokenHash' => $device['pushtokenhash'],
+				'subject' => $base64EncryptedSubject,
+				'signature' => $base64Signature,
+				'priority' => 'normal',
+				'type' => 'background',
+			]
 		];
 	}
 
 	/**
 	 * @param string $uid
 	 * @return array[]
+	 * @psalm-return list<array{id: int, uid: string, token: int, deviceidentifier: string, devicepublickey: string, devicepublickeyhash: string, pushtokenhash: string, proxyserver: string, apptype: string}>
 	 */
 	protected function getDevicesForUser(string $uid): array {
 		$query = $this->db->getQueryBuilder();
@@ -610,6 +731,7 @@ class Push {
 	/**
 	 * @param string[] $userIds
 	 * @return array[]
+	 * @psalm-return array<string, list<array{id: int, uid: string, token: int, deviceidentifier: string, devicepublickey: string, devicepublickeyhash: string, pushtokenhash: string, proxyserver: string, apptype: string}>>
 	 */
 	protected function getDevicesForUsers(array $userIds): array {
 		$query = $this->db->getQueryBuilder();
@@ -647,10 +769,11 @@ class Push {
 	 * @param string $deviceIdentifier
 	 * @return bool
 	 */
-	protected function deletePushTokenByDeviceIdentifier(string $deviceIdentifier): bool {
+	protected function deletePushTokenByDeviceIdentifier(string $proxyServer, string $deviceIdentifier): bool {
 		$query = $this->db->getQueryBuilder();
 		$query->delete('notifications_pushhash')
-			->where($query->expr()->eq('deviceidentifier', $query->createNamedParameter($deviceIdentifier)));
+			->where($query->expr()->eq('proxyserver', $query->createNamedParameter($proxyServer)))
+			->andWhere($query->expr()->eq('deviceidentifier', $query->createNamedParameter($deviceIdentifier)));
 
 		return $query->executeStatement() !== 0;
 	}
@@ -658,4 +781,9 @@ class Push {
 	protected function createFakeUserObject(string $userId): IUser {
 		return new FakeUser($userId);
 	}
+
+	protected function createPushSubscriptionKey(): string {
+		$key = $this->random->generate(25, ISecureRandom::CHAR_ALPHANUMERIC);
+		return implode('-', str_split($key, 5));
+	}
 }
