@@ -4,36 +4,45 @@ OC.L10N.register(
     "Photos" : "Ảnh",
     "Your memories under your control" : "Các ký ức của bạn dưới sự kiểm soát của bạn",
     "Videos" : "Phim",
+    "Albums" : "Albums",
     "People" : "Mọi người",
     "Folders" : "Thư mục",
     "Favorites" : "Ưa thích",
     "Shared with you" : "Đã chia sẻ với bạn",
     "Tags" : "Nhãn",
     "Photos settings" : "Cài đặt Ảnh",
+    "This name is already in use." : "Tên này đã được sử dụng.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" không được phép bên trong tên tệp.",
+    "Invalid filename." : "Tên tập tin không hợp lệ.",
     "Back" : "Quay lại",
     "Save" : "Lưu",
     "Shared by" : "Đã chia sẽ bởi",
     "No recommendations. Start typing." : "Không có khuyến nghị. Bắt đầu gõ.",
-    "Group" : "Nhóm",
     "Copy public link" : "Sao chép liên kết công khai",
     "An error occurred" : "Có lỗi đã xảy ra",
     "Favorite" : "Ưa thích",
     "Open the full size \"{name}\" image" : "Mở kích thước đủ của ảnh \"{name}\"",
     "Go back" : "Quay lại",
-    "Enable squared photos view" : "Bật chế độ xem theo ô",
     "All folders" : "All folders",
     "Home" : "Trang chủ",
-    "View" : "Xem",
+    "General" : "Cài đặt chung",
     "Unselect all" : "Bỏ chọn tất cả",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "This folder does not exist" : "Thư mục này không tồn tại",
+    "Loading folders…" : "Đang tải thư mục",
     "No photos in here" : "Không có ảnh nào trong này",
     "No tags yet" : "Chưa gắn nhãn",
     "Photos with tags will show up here" : "Ảnh đã gắn nhãn sẽ được cho thấy trên này",
     "Tagged photos" : "Ảnh gắn nhãn",
+    "Last week" : "Tuần trước",
     "Details" : "Chi tiết",
+    "Cancel" : "Cancel",
+    "Confirm" : "Xác nhận",
+    "Group" : "Nhóm",
     "Back to {folder}" : "Trở về {folder}",
     "Share this folder" : "Chia sẻ thư mục này",
+    "Enable squared photos view" : "Bật chế độ xem theo ô",
+    "View" : "Xem",
     "Add" : "Thêm"
 },
 "nplurals=1; plural=0;");
