@@ -78,10 +78,10 @@ class GroupsController extends AUserDataOCSController {
 	#[NoAdminRequired]
 	public function getGroups(string $search = '', ?int $limit = null, int $offset = 0): DataResponse {
 		$groups = $this->groupManager->search($search, $limit, $offset);
-		$groups = array_values(array_map(function ($group) {
+		$groups = array_map(function ($group) {
 			/** @var IGroup $group */
 			return $group->getGID();
-		}, $groups));
+		}, $groups);
 
 		return new DataResponse(['groups' => $groups]);
 	}
@@ -101,7 +101,7 @@ class GroupsController extends AUserDataOCSController {
 	#[AuthorizedAdminSetting(settings: Users::class)]
 	public function getGroupsDetails(string $search = '', ?int $limit = null, int $offset = 0): DataResponse {
 		$groups = $this->groupManager->search($search, $limit, $offset);
-		$groups = array_values(array_map(function ($group) {
+		$groups = array_map(function ($group) {
 			/** @var IGroup $group */
 			return [
 				'id' => $group->getGID(),
@@ -111,7 +111,7 @@ class GroupsController extends AUserDataOCSController {
 				'canAdd' => $group->canAddUser(),
 				'canRemove' => $group->canRemoveUser(),
 			];
-		}, $groups));
+		}, $groups);
 
 		return new DataResponse(['groups' => $groups]);
 	}
