@@ -66,12 +66,14 @@ OC.L10N.register(
     "PHP" : "PHP",
     "Version:" : "Verze:",
     "Memory limit:" : "Limit paměti:",
+    "MB" : "MB",
     "Max execution time:" : "Nejdelší umožněný čas vykonávání:",
     "seconds" : "sekund",
     "Upload max size:" : "Nejvyšší umožněná velikost nahrávaného souboru:",
     "OPcache Revalidate Frequency:" : "Četnost opětovného ověřování platnosti OPcache mezipaměti:",
     "Extensions:" : "Rozšíření:",
     "Unable to list extensions" : "Nepodařilo se vypsat rozšíření",
+    "PHP Info:" : "Informace o PHP:",
     "Show phpinfo" : "Zobrazit phpinfo",
     "FPM worker pool" : "Fond procesů zpracovávajících FPM",
     "Pool name:" : "Název fondu:",
