@@ -1,20 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privata",
-    "Local" : "Loka",
-    "Federated" : "Federated",
-    "Verify" : "Kontroli",
-    "Verifying …" : "Kontrolado...",
-    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
-    "Very weak password" : "Tre malforta pasvorto",
-    "Weak password" : "Malforta pasvorto",
-    "So-so password" : "Mezbona pasvorto",
-    "Good password" : "Bona pasvorto",
-    "Strong password" : "Forta pasvorto",
-    "Groups" : "Grupoj",
-    "Group list is empty" : "Gruplisto malpenas",
-    "Unable to retrieve the group list" : "Ne eblis ricevi grupliston",
     "{actor} added you to group {group}" : "{actor} aldonis vin al grupo {group}",
     "You added {user} to group {group}" : "Vi aldonis uzanton {user} al grupo {group}",
     "{actor} added {user} to group {group}" : "{actor} aldonis uzanton {user} al grupo {group}",
@@ -45,6 +31,7 @@ OC.L10N.register(
     "Settings" : "Agordoj",
     "Wrong password" : "Neĝusta pasvorto",
     "Saved" : "Konservita",
+    "Unable to change password" : "Ne eblis ŝanĝi la pasvorton",
     "Authentication error" : "Aŭtentiga eraro",
     "Wrong admin recovery password. Please check the password and try again." : "Neĝusta reekhava pasvorto de administranto. Bv. kontroli la pasvorton kaj reprovi.",
     "Administrator documentation" : "Dokumentaro por administranto",
@@ -95,6 +82,8 @@ OC.L10N.register(
     "Background jobs" : "Fonaj taskoj",
     "Unlimited" : "Senlima",
     "Verifying" : "Kontrolado",
+    "Verifying …" : "Kontrolado...",
+    "Verify" : "Kontroli",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
     "Disabled" : "Malkapabligita",
@@ -129,6 +118,7 @@ OC.L10N.register(
     "Featured" : "Elstaraj",
     "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Elstaraj aplikaĵoj estas programataj de kaj ene de la komunumo. Ili alportas kernajn trajtojn kaj ili povas tuj uziĝi.",
+    "Learn more" : "Scii pli",
     "Disable all" : "Malŝalti ĉiujn",
     "Icon" : "Piktogramo",
     "Name" : "Nomo",
@@ -137,10 +127,10 @@ OC.L10N.register(
     "Actions" : "Agoj",
     "Results from other categories" : "Rezultoj el aliaj kategorioj",
     "No apps found for your version" : "Neniu aplikaĵo trovita por via versio",
+    "Groups" : "Grupoj",
     "Group name" : "Gruponomo",
     "Loading" : "Ŝargado",
     "Type" : "Tipo",
-    "Learn more" : "Scii pli",
     "Confirm" : "Konfirmi",
     "Cancel" : "Nuligi",
     "Description" : "Priskribo",
@@ -152,8 +142,6 @@ OC.L10N.register(
     "All" : "Ĉiuj",
     "Limit app usage to groups" : "Limigi aplikaĵan uzon al grupoj",
     "Update to {version}" : "Ĝisdatigi al {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Tiu aplikaĵo ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas:",
     "Categories" : "Kategorioj",
     "Resources" : "Rimedoj",
@@ -202,11 +190,12 @@ OC.L10N.register(
     "Picture provided by original account" : "Bildo el la origina konto",
     "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
     "No email address set" : "Neniu retpoŝta adreso agordita",
+    "No language set" : "Neniu lingvo agordita",
     "Languages" : "Lingvoj",
     "Help translate" : "Helpu traduki",
-    "No language set" : "Neniu lingvo agordita",
     "Week starts on {firstDayOfWeek}" : "Semajno komencas je {firstDayOfWeek}",
     "Your phone number" : "Via telefonnumero",
+    "Timezone" : "Horzono",
     "Change" : "Ŝanĝi",
     "Delete" : "Forigi",
     "Default language" : "Defaŭlta lingvo",
@@ -223,7 +212,6 @@ OC.L10N.register(
     "{size} used" : "{size} uzataj",
     "Delete account" : "Forigi konton",
     "Resend welcome email" : "Resendi bonvenan retpoŝtmesaĝon",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Okaze de perdo de aparato aŭ eliro de la organizaĵo, tio povas defore forviŝi la datumojn de Nextcloud el ĉiuj aparatoj ligitaj per {userid}. Nur funkcias, se la aparatoj estas konektitaj  al interreto.",
     "Remote wipe of devices" : "Defora forviŝado de aparatoj",
     "Wipe {userid}'s devices" : "Forviŝi la aparatojn de {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Forigi la tuton de la konto de {userid}, inkluzive de ĉiuj ties personaj dosieroj, datumoj el aplikaĵoj, k.t.p.",
@@ -237,10 +225,27 @@ OC.L10N.register(
     "Send email" : "Sendi retpoŝtmesaĝon",
     "Default quota" : "Defaŭlta kvoto",
     "Select default quota" : "Elekti defaŭltan kvoton",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Gravas agordi tiun ĉi servilon por povi sendi retpoŝtmesaĝojn, ekz. por restarigo de pasvorto aŭ sciigoj.",
+    "Send mode" : "Kiel sendi",
+    "Encryption" : "Ĉifrado",
+    "Sendmail mode" : "Sendmail-reĝimo",
+    "Disable certificate verification (insecure)" : "Ne kontroli atestilon (nesekura)",
+    "From address" : "El adreso",
+    "Domain" : "Domajno",
+    "Server address" : "Servila adreso",
+    "Host" : "Gastigo",
+    "Port" : "Pordo",
+    "Authentication" : "Aŭtentigo",
+    "Authentication required" : "Aŭtentiĝo nepras",
+    "Saving…" : "Konservado...",
+    "Save settings" : "Konservi agordojn",
+    "Security & setup warnings" : "Avertoj pri sekureco kaj agordoj",
+    "All checks passed." : "Ĉiuj testoj sukcese trapasitaj.",
+    "There are some errors regarding your setup." : "Estas kelkaj eraroj pri via instalaĵo.",
+    "There are some warnings regarding your setup." : "Estas kelkaj avertoj pri via instalaĵo.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
+    "Apply" : "Validigi",
     "Admins" : "Administrantoj",
-    "Sending…" : "Sendado...",
-    "Email sent" : "La retpoŝtaĵo sendiĝis",
     "Location" : "Loko",
     "Profile picture" : "Profila bildo",
     "About" : "Pri",
@@ -248,6 +253,9 @@ OC.L10N.register(
     "Phone number" : "Telefonnumero",
     "Website" : "Retejo",
     "Locale" : "Lokaĵaro",
+    "Private" : "Privata",
+    "Local" : "Loka",
+    "Federated" : "Federated",
     "Your apps" : "Viaj aplikaĵoj",
     "Active apps" : "Aktivaj aplikaĵoj",
     "Disabled apps" : "Malŝaltitaj aplikaĵoj",
@@ -256,7 +264,6 @@ OC.L10N.register(
     "Hide" : "Malmontri",
     "Download and enable" : "Elŝuti kaj ŝalti",
     "Disable" : "Malŝalti",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
     "Unknown" : "Nekonata",
     "Never" : "Neniam",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplikaĵo estis ŝaltita, sed ĝi bezonas ĝisdatiĝi. Vi estos direktita al ĝisdatiga paĝon post 5 sekundoj.",
@@ -270,35 +277,34 @@ OC.L10N.register(
     "Forum" : "Forumo",
     "Legal notice" : "Leĝa regularo",
     "Privacy policy" : "Privateca regularo",
-    "SSL" : "SSL",
-    "Open documentation" : "Malfermi la dokumentaron",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Gravas agordi tiun ĉi servilon por povi sendi retpoŝtmesaĝojn, ekz. por restarigo de pasvorto aŭ sciigoj.",
-    "Send mode" : "Kiel sendi",
-    "Encryption" : "Ĉifrado",
-    "Sendmail mode" : "Sendmail-reĝimo",
-    "From address" : "El adreso",
-    "Server address" : "Servila adreso",
-    "Port" : "Pordo",
-    "Authentication" : "Aŭtentigo",
-    "Authentication required" : "Aŭtentiĝo nepras",
-    "Credentials" : "Aŭtentigiloj",
-    "SMTP Password" : "SMTP-pasvorto",
-    "Save" : "Konservi",
-    "Security & setup warnings" : "Avertoj pri sekureco kaj agordoj",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Gravas por sekureco kaj rapideco de via servilo, ke ĉio estu agordita bone. Por helpi vin pri tio, ni faras kelkajn aŭtomatajn testojn. Bv. vidi la dokumentaron por pli da informoj.",
-    "All checks passed." : "Ĉiuj testoj sukcese trapasitaj.",
-    "There are some errors regarding your setup." : "Estas kelkaj eraroj pri via instalaĵo.",
-    "There are some warnings regarding your setup." : "Estas kelkaj avertoj pri via instalaĵo.",
-    "Checking for system and security issues." : "Kontrolado de problemoj pri sistemo kaj sekurigo.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bv. zorgeme kontroli la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">manlibroj pri instalaĵo ↗</a>, kaj kontroli avertojn kaj erarojn en la <a href=\"%2$s\">protokolo</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrolu sekurecon de via servilo Nextcloud pere de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nia sekureca ekzameno ↗</a>.",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Programita de la {communityopen}Nextcloud-komunumo{linkclose}, la {githubopen}fontkodo{linkclose} havas {licenseopen}AGPL{linkclose}-permesilon.",
     "Like our Facebook page" : "Ŝatu nian Facebook-paĝon",
     "Follow us on Mastodon" : "Sekvu nin per Mastodon",
     "Check out our blog" : "Vizitu nian blogon",
     "Subscribe to our newsletter" : "Aboni nian retan bultenon",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
+    "Open documentation" : "Malfermi la dokumentaron",
     "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
-    "You are using <strong>{usage}</strong>" : "Vi uzas <strong>{usage}</strong>"
+    "Very weak password" : "Tre malforta pasvorto",
+    "Weak password" : "Malforta pasvorto",
+    "So-so password" : "Mezbona pasvorto",
+    "Good password" : "Bona pasvorto",
+    "Strong password" : "Forta pasvorto",
+    "Group list is empty" : "Gruplisto malpenas",
+    "Unable to retrieve the group list" : "Ne eblis ricevi grupliston",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Okaze de perdo de aparato aŭ eliro de la organizaĵo, tio povas defore forviŝi la datumojn de Nextcloud el ĉiuj aparatoj ligitaj per {userid}. Nur funkcias, se la aparatoj estas konektitaj  al interreto.",
+    "Sending…" : "Sendado...",
+    "Email sent" : "La retpoŝtaĵo sendiĝis",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
+    "SSL" : "SSL",
+    "Credentials" : "Aŭtentigiloj",
+    "SMTP Password" : "SMTP-pasvorto",
+    "Save" : "Konservi",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Gravas por sekureco kaj rapideco de via servilo, ke ĉio estu agordita bone. Por helpi vin pri tio, ni faras kelkajn aŭtomatajn testojn. Bv. vidi la dokumentaron por pli da informoj.",
+    "Checking for system and security issues." : "Kontrolado de problemoj pri sistemo kaj sekurigo.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bv. zorgeme kontroli la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">manlibroj pri instalaĵo ↗</a>, kaj kontroli avertojn kaj erarojn en la <a href=\"%2$s\">protokolo</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrolu sekurecon de via servilo Nextcloud pere de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nia sekureca ekzameno ↗</a>."
 },
 "nplurals=2; plural=(n != 1);");
