@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Einka",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Einungis sýnilegt fólki sem samsvarar samþættum símanúmerum í gegnum Talk-forritið á farsímum",
-    "Local" : "Staðvært",
-    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
-    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
-    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
-    "Published" : "Útgefið",
-    "Synchronize to trusted servers and the global and public address book" : "Samstilla við treysta þjóna og víðværar og opinberar vistfangaskrár",
-    "Verify" : "Sannreyna",
-    "Verifying …" : "Sannreyni …",
-    "Unable to change password" : "Ekki tókst að breyta lykilorði",
-    "Very weak password" : "Mjög veikt lykilorð",
-    "Weak password" : "Veikt lykilorð",
-    "So-so password" : "Svo-svo lykilorð",
-    "Good password" : "Gott lykilorð",
-    "Strong password" : "Sterkt lykilorð",
-    "Groups" : "Hópar",
-    "Group list is empty" : "Listi yfir hópa er tómur",
-    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
     "{actor} added you to group {group}" : "{actor} bætti þér við hópinn {group}",
     "You added {user} to group {group}" : "Þú bættir {user} við hópinn {group}",
     "{actor} added {user} to group {group}" : "{actor} bætti {user} við hópinn {group}",
@@ -57,6 +38,7 @@ OC.L10N.register(
     "Unable to change personal password" : "Ekki tókst að breyta persónulegu lykilorði",
     "Saved" : "Vistað",
     "No Login supplied" : "Ekkert innskráningarnafn gefið",
+    "Unable to change password" : "Ekki tókst að breyta lykilorði",
     "Unable to change password. Password too long." : "Ekki tókst að breyta lykilorði. Lykilorðið er of langt.",
     "Authentication error" : "Villa við auðkenningu",
     "Please provide an admin recovery password; otherwise, all account data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll gögn aðgangsins tapast.",
@@ -129,6 +111,8 @@ OC.L10N.register(
     "Background jobs" : "Verk í bakgrunni",
     "Unlimited" : "ótakmörkuðu",
     "Verifying" : "Sannreyni",
+    "Verifying …" : "Sannreyni …",
+    "Verify" : "Sannreyna",
     "Allowed admin IP ranges" : "Leyfð svið IP-vistfanga stjórnenda",
     "Admin IP filtering is correctly configured." : "Síun IP-vistfanga stjórnenda er rétt stillt.",
     "App directories owner" : "Eigandi forritamappa",
@@ -232,8 +216,6 @@ OC.L10N.register(
     "Shares with guessable tokens may be accessed easily" : "Aðgangur er greiður að sameignum með teikn sem auðvelt er að giska á",
     "Limit sharing based on groups" : "Takmarka deilingu út frá hópum",
     "Allow sharing for everyone (default)" : "Leyfa deilingu fyrir alla (sjálfgefið)",
-    "Exclude some groups from sharing" : "Undanskilja suma hópa frá því að deila",
-    "Limit sharing to some groups" : "Takmarka deilingu við suma hópa",
     "Groups allowed to share" : "Hópar með heimild til að deila",
     "Groups excluded from sharing" : "Hópar undanskildir frá því að deila",
     "Enforce expiration date" : "Krefjast dagsetningar á gildistíma",
@@ -271,6 +253,7 @@ OC.L10N.register(
     "This app is supported via your current Nextcloud subscription." : "Þetta forrit er stutt í gegnum fyrirliggjandi Nextcloud-áskrift þína.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Forrit í deiglunni eru þróuð af og innan samfélagsins. Þau bjóða upp á ýmsa kjarnaeiginleika og eru tilbúin til notkunar í raunvinnslu.",
     "Community rating: {score}/5" : "Einkunnir frá samfélaginu: {score}/5",
+    "Learn more" : "Læra meira",
     "Disable all" : "Gera allt óvirkt",
     "Download and enable all" : "Sækja og virkja allt",
     "All apps are up-to-date." : "Öll forrit eru af nýjustu útgáfu.",
@@ -284,6 +267,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n forrit er með tiltæka uppfærslu","%n forrit eru með tiltæka uppfærslu"],
     "_Update_::_Update all_" : ["Uppfæra","Uppfæra allt"],
     "Failed to create group" : "Mistókst að búa til hóp",
+    "Groups" : "Hópar",
     "Creating group…" : "Bý til hóp …",
     "Create group" : "Búa til hóp",
     "Group name" : "Heiti hóps",
@@ -303,7 +287,6 @@ OC.L10N.register(
     "Display Name" : "Birtingarnafn",
     "GPUs support" : "Stuðningur við GPUs-skjáörgjörva",
     "Compute device" : "Reiknitæki",
-    "Learn more" : "Læra meira",
     "Environment variables" : "Umhverfisbreytur",
     "No environment variables defined" : "Engar umhverfisbreytur skilgreindar",
     "Mounts" : "Tengipunktar",
@@ -440,6 +423,9 @@ OC.L10N.register(
     "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Þú ert að nota {s}{usage}{/s} af {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Þú ert meðlimur eftirfarandi hópa:",
     "Your full name" : "Fullt nafn þitt",
+    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
+    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
+    "No email address set" : "Ekkert tölvupóstfang sett",
     "Email options" : "Tölvupóststillingar",
     "Options for additional email address {index}" : "Valkostir fyrir aukalegt tölvupóstfang {index}",
     "Remove primary email" : "Fjarlægja aðaltölvupóstfang",
@@ -449,25 +435,22 @@ OC.L10N.register(
     "Set as primary email" : "Gera að aðaltölvupóstfangi",
     "Additional email address {index}" : "Aukalegt tölvupóstfang {index}",
     "Unable to delete primary email address" : "Get ekki eytt aðaltölvupóstfangi",
-    "Unable to update primary email address" : "Get ekki uppfært aðaltölvupóstfang",
     "Unable to add additional email address" : "Get ekki bætt við aukatölvupóstfangi",
     "Unable to update additional email address" : "Get ekki uppfært aukatölvupóstfang",
-    "Unable to delete additional email address" : "Get ekki eytt aukatölvupóstfangi",
     "Primary email for password reset and notifications" : "Aðallykilorð fyrir tilkynningar og endurstillingu lykilorðs",
-    "No email address set" : "Ekkert tölvupóstfang sett",
     "Your handle" : "Auðkennið þitt",
     "Derived from your locale ({weekDayName})" : "Ákvarðað af staðfærslu kerfisins ({weekDayName})",
     "Unable to update first day of week" : "Mistókst að uppfæra fyrsta dag viku",
     "Day to use as the first day of week" : "Dagurinn sem á að nota sem fyrsta dag vikunnar",
     "Your headline" : "Fyrirsögnin þín",
+    "No language set" : "Ekkert tungumál skilgreint",
     "Unable to update language" : "Tókst ekki að uppfæra tungumál",
     "Languages" : "Tungumál",
     "Help translate" : "Hjálpa við þýðingu",
-    "No language set" : "Ekkert tungumál skilgreint",
+    "No locale set" : "Engin staðfærsla tilgreind",
     "Unable to update locale" : "Tókst ekki að uppfæra staðfærslu",
     "Locales" : "Staðfærslur",
     "Week starts on {firstDayOfWeek}" : "Vika byrjar á {firstDayOfWeek}",
-    "No locale set" : "Engin staðfærsla tilgreind",
     "Your city" : "Borg/sveitarfélag",
     "Your organisation" : "Fyrirtækið þitt",
     "Your phone number" : "Símanúmerið þitt",
@@ -501,7 +484,6 @@ OC.L10N.register(
     "Other languages" : "Önnur tungumál",
     "Password change is disabled because the master key is disabled" : "Lykilorðabreyting er óvirk vegna þess að aðallykill er óvirkur",
     "No accounts" : "Engir aðgangar",
-    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
     "List of accounts. This list is not fully rendered for performance reasons. The accounts will be rendered as you navigate through the list." : "Listi yfir notendaaðganga. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendaaðgangar munu birtast eftir því sem farið er í gegnum listann.",
     "Manager" : "Stjórnandi",
     "Set line manager" : "Settu línustjórnanda",
@@ -517,7 +499,6 @@ OC.L10N.register(
     "Member of the following groups" : "Meðlimur eftirfarandi hópa",
     "Set account groups" : "Setja hópa notandaaðgangs",
     "Admin of the following groups" : "Stjórnandi eftirfarandi hópa",
-    "Set account as admin for …" : "Setja notandaaðganginn sem stjórnanda fyrir …",
     "Quota" : "Kvóti",
     "Set account quota" : "Settu kvóta notandaaðgangs",
     "Language" : "Tungumál",
@@ -549,7 +530,6 @@ OC.L10N.register(
     "Password was successfully changed" : "Það tókst að breyta lykilorðinu",
     "Email was successfully changed" : "Það tókst að breyta tölvupóstfanginu",
     "Welcome mail sent!" : "Kveðjupóstur sendur!",
-    "Loading account …" : "Hleð inn notandaaðgangi …",
     "Change display name" : "Breyta birtingarnafni",
     "Set new password" : "Stilla nýtt lykilorð",
     "You do not have permissions to see the details of this account" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notandaaðgang",
@@ -581,14 +561,28 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Lykilorðalaus auðkenning krefst öruggrar tengingar.",
     "Add WebAuthn device" : "Bæta við WebAuthn-tæki",
     "Please authorize your WebAuthn device." : "Auðkenndu WebAuthn-tækið þitt.",
-    "Adding your device …" : "Bæti við tækinu þínu …",
     "Unnamed device" : "Nafnlaust tæki",
     "Passwordless Authentication" : "Lykilorðalaus auðkenning",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Settu aðganginn þinn upp fyrir lykilorðalausa auðkenningu byggða á FIDO2-staðlinum.",
     "No devices configured." : "Engin tæki skilgreind.",
     "The following devices are configured for your account:" : "Eftirfarandi tæki eru uppsett fyrir notandaaðganginn þinn:",
     "Your browser does not support WebAuthn." : "Vafrinn þinn styður ekki WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Það er mikilvægt að setja þennan vefþjón upp þannig að hann getir sent tölvupóst, eins og fyrir endurstillingu lykilorða og útsendingu tilkynninga.",
+    "Send mode" : "Sendihamur",
+    "Encryption" : "Dulritun",
+    "Sendmail mode" : "Sendmail-hamur",
+    "Disable certificate verification (insecure)" : "Gera sannvottun skilríkja óvirka (óöruggt)",
+    "From address" : "Frá vistfangi",
+    "Domain" : "Lén",
+    "Server address" : "Vistfang þjóns",
+    "Host" : "Þjónn",
+    "Port" : "Gátt",
+    "Authentication" : "Auðkenning",
+    "Authentication required" : "Auðkenningar krafist",
+    "Saving…" : "Vista…",
+    "Save settings" : "Vista stillingar",
     "Security & setup warnings" : "Öryggi og aðvaranir vegna uppsetningar",
+    "Try again" : "Reyndu aftur",
     "All checks passed." : "Stóðst allar prófanir.",
     "There are some errors regarding your setup." : "Það komu upp villur varðandi uppsetninguna þína.",
     "There are some warnings regarding your setup." : "Það komu upp viðvaranir varðandi uppsetninguna þína.",
@@ -597,7 +591,6 @@ OC.L10N.register(
     "App Store" : "Forritasafn",
     "Loading app list" : "Hleð inn forritalista",
     "Loading categories" : "Hleð inn flokkum",
-    "Developer documentation ↗" : "Hjálparskjöl þróunaraðila↗",
     "Version {version}, {license}-licensed" : "Útgáfa {version}, {license}-notkunarleyfi",
     "Version {version}" : "Útgáfa {version}",
     "Apply" : "Virkja",
@@ -605,8 +598,6 @@ OC.L10N.register(
     "Admins" : "Kerfisstjórar",
     "Account group: {group}" : "Hópur notendaaðganga: {group}",
     "Account management" : "Umsýsla notandaaðgangs",
-    "Sending…" : "Sendi...",
-    "Email sent" : "Tölvupóstur sendur",
     "Location" : "Staðsetning",
     "Profile picture" : "Einkennismynd",
     "About" : "Um hugbúnaðinn",
@@ -620,12 +611,21 @@ OC.L10N.register(
     "Pronouns" : "Fornöfn",
     "Role" : "Role",
     "X (formerly Twitter)" : "X (fyrrum Twitter)",
+    "Bluesky" : "Bluesky",
     "Website" : "Vefsvæði",
     "Profile visibility" : "Sýnileiki notandasniðs",
     "Locale" : "Staðfærsla",
     "First day of week" : "Fyrsti dagur viku",
+    "Private" : "Einka",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Einungis sýnilegt fólki sem samsvarar samþættum símanúmerum í gegnum Talk-forritið á farsímum",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Er ekki tiltækt þar sem þessi eiginleiki er nauðsynlegur fyrir kjarnavirkni á borð við skráadeilingu og boð í dagatölum",
+    "Local" : "Staðvært",
+    "Only visible to people on this instance and guests" : "Einungis sýnilegt staðværum notendum og gestum",
+    "Federated" : "Deilt milli þjóna (skýjasambandssameign)",
+    "Only synchronize to trusted servers" : "Aðeins samstilla við treysta þjóna",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
+    "Published" : "Útgefið",
+    "Synchronize to trusted servers and the global and public address book" : "Samstilla við treysta þjóna og víðværar og opinberar vistfangaskrár",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
     "Your apps" : "Forritin þín",
     "Active apps" : "Virk forrit",
@@ -637,8 +637,6 @@ OC.L10N.register(
     "Show to everyone" : "Birta öllum",
     "Show to logged in accounts only" : "Birta einungis hjá innskráðum notendaaðgöngum",
     "Hide" : "Fela",
-    "{progress}% Deploying …" : "{progress}% Sett í gang …",
-    "{progress}% Initializing …" : "{progress}% Frumstilling …",
     "Health checking" : "Ástandsskoðun",
     "Download and enable" : "Sækja og virkja",
     "Disable" : "Gera óvirkt",
@@ -662,46 +660,46 @@ OC.L10N.register(
     "General documentation" : "Almenn hjálparskjöl",
     "Legal notice" : "Lagaleg atriði",
     "Privacy policy" : "Meðferð persónulegra gagna",
+    "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
+    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
+    "Follow us on Mastodon" : "Fylgstu með okkur á Mastodon",
+    "Check out our blog" : "Kíktu á bloggið okkar",
+    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
+    "Open documentation" : "Opna hjálparskjöl",
+    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
+    "Very weak password" : "Mjög veikt lykilorð",
+    "Weak password" : "Veikt lykilorð",
+    "So-so password" : "Svo-svo lykilorð",
+    "Good password" : "Gott lykilorð",
+    "Strong password" : "Sterkt lykilorð",
+    "Group list is empty" : "Listi yfir hópa er tómur",
+    "Unable to retrieve the group list" : "Tókst ekki að ná í lista yfir hópinn",
+    "Logged in account must be a subadmin" : "Innskráður aðgangur verður að vera undirstjórnandi (subadmin)",
+    "Exclude some groups from sharing" : "Undanskilja suma hópa frá því að deila",
+    "Limit sharing to some groups" : "Takmarka deilingu við suma hópa",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
+    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
+    "Set account as admin for …" : "Setja notandaaðganginn sem stjórnanda fyrir …",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
+    "Loading account …" : "Hleð inn notandaaðgangi …",
+    "Adding your device …" : "Bæti við tækinu þínu …",
+    "Developer documentation ↗" : "Hjálparskjöl þróunaraðila↗",
+    "Sending…" : "Sendi...",
+    "Email sent" : "Tölvupóstur sendur",
+    "{progress}% Deploying …" : "{progress}% Sett í gang …",
+    "{progress}% Initializing …" : "{progress}% Frumstilling …",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "None/STARTTLS" : "Ekkert/STARTTLS",
     "SSL" : "SSL",
-    "Open documentation" : "Opna hjálparskjöl",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Það er mikilvægt að setja þennan vefþjón upp þannig að hann getir sent tölvupóst, eins og fyrir endurstillingu lykilorða og útsendingu tilkynninga.",
-    "Send mode" : "Sendihamur",
-    "Encryption" : "Dulritun",
-    "Sendmail mode" : "Sendmail-hamur",
-    "From address" : "Frá vistfangi",
-    "Server address" : "Vistfang þjóns",
-    "Port" : "Gátt",
-    "Authentication" : "Auðkenning",
-    "Authentication required" : "Auðkenningar krafist",
     "Credentials" : "Auðkenni",
     "SMTP Login" : "SMTP-innskráning",
     "SMTP Password" : "SMTP-lykilorð",
     "Save" : "Vista",
     "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar",
-    "Reasons to use Nextcloud in your organization" : "Ástæður til að nota Nextcloud á vinnustaðnum þínum",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Þróað af {communityopen}Nextcloud samfélaginu{linkclose}, {githubopen}grunnkóðinn{linkclose} er gefinn út með {licenseopen}AGPL{linkclose} notkunarleyfinu.",
-    "Like our Facebook page" : "Líkaðu við Facebook-síðuna okkar",
-    "Follow us on X" : "Fylgstu með okkur á X",
-    "Follow us on Mastodon" : "Fylgstu með okkur á Mastodon",
-    "Check out our blog" : "Kíktu á bloggið okkar",
-    "Subscribe to our newsletter" : "Gerstu áskrifandi að fréttabréfinu okkar",
-    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
-    "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
-    "Logged in account must be a subadmin" : "Innskráður aðgangur verður að vera undirstjórnandi (subadmin)",
-    "File locking" : "Skráalæsing",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Færslulæsing skráa (transactional file locking) er óvirk, þetta gæti leitt til vandamála út frá forgangsskilyrðum (race conditions). Virkjaðu 'filelocking.enabled' í config.php til að forðast slík vandamál.",
-    "The PHP memory limit is below the recommended value of %s." : "Minnismörk PHP eru lægri en gildið sem mælt er með; %s.",
-    "Set default expiration date for shares" : "Setja sjálfgefinn gildistíma fyrir sameignir",
-    "Restrict account name autocompletion to users based on phone number integration" : "Leyfa sjálfklárun á heiti notendaaðganga á notendum byggt á samþættingu símanúmera",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina lágmarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Þetta vorrit er ekki með tiltekna neina hámarksútgáfu Nextcloud. Þetta mun gefa villu í framtíðinni.",
-    "Your biography" : "Æviágrip þitt",
-    "You are using <strong>{usage}</strong>" : "Þú ert að nota <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Þú ert að nota <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Það er mikilvægt fyrir öryggi og afköst uppsetningarinnar þinnar að allt sé rétt stillt. Til að hjálpa við að svo sé, eru gerðar ýmsar sjálfvirkar prófanir. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
     "Checking for system and security issues." : "Athuga með kerfis- og öryggisvandamál.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Yfirfarðu vandlega <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">uppsetningarleiðbeiningarnar ↗</a>, og athugaðu hvort nokkrar villumeldingar eða aðvaranir séu í <a href=\"%2$s\">annálnum</a>.",
