@@ -1,25 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Private",
-    "Only visible to people matched via phone number integration through Talk on mobile" : "Only visible to people matched via phone number integration through Talk on mobile",
-    "Local" : "Local",
-    "Only visible to people on this instance and guests" : "Only visible to people on this instance and guests",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "Only synchronize to trusted servers",
-    "Published" : "Published",
-    "Synchronize to trusted servers and the global and public address book" : "Synchronize to trusted servers and the global and public address book",
-    "Verify" : "Verify",
-    "Verifying …" : "Verifying …",
-    "Unable to change password" : "Unable to change password",
-    "Very weak password" : "Very weak password",
-    "Weak password" : "Weak password",
-    "So-so password" : "So-so password",
-    "Good password" : "Good password",
-    "Strong password" : "Strong password",
-    "Groups" : "Groups",
-    "Group list is empty" : "Group list is empty",
-    "Unable to retrieve the group list" : "Unable to retrieve the group list",
     "{actor} added you to group {group}" : "{actor} added you to group {group}",
     "You added {user} to group {group}" : "You added {user} to group {group}",
     "{actor} added {user} to group {group}" : "{actor} added {user} to group {group}",
@@ -56,6 +37,7 @@ OC.L10N.register(
     "Wrong password" : "Wrong password",
     "Unable to change personal password" : "Unable to change personal password",
     "Saved" : "Saved",
+    "Unable to change password" : "Unable to change password",
     "Unable to change password. Password too long." : "Unable to change password. Password too long.",
     "Authentication error" : "Authentication error",
     "Wrong admin recovery password. Please check the password and try again." : "Wrong admin recovery password. Please check the password and try again.",
@@ -115,6 +97,8 @@ OC.L10N.register(
     "Background jobs" : "Background jobs",
     "Unlimited" : "Unlimited",
     "Verifying" : "Verifying",
+    "Verifying …" : "Verifying …",
+    "Verify" : "Verify",
     "Brute-force Throttle" : "Brute-force Throttle",
     "Your remote address could not be determined." : "Your remote address could not be determined.",
     "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly.",
@@ -256,6 +240,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app has an update available","%n apps have an update available"],
     "_Update_::_Update all_" : ["Update","Update all"],
     "Failed to create group" : "Failed to create group",
+    "Groups" : "Groups",
     "Create group" : "Create group",
     "Group name" : "Group name",
     "Please enter a valid group name" : "Please enter a valid group name",
@@ -369,6 +354,9 @@ OC.L10N.register(
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Please note that it can take up to 24 hours for your profile picture to be updated everywhere.",
     "You are a member of the following groups:" : "You are a member of the following groups:",
     "Your full name" : "Your full name",
+    "Unable to update primary email address" : "Unable to update primary email address",
+    "Unable to delete additional email address" : "Unable to delete additional email address",
+    "No email address set" : "No email address set",
     "Email options" : "Email options",
     "Remove primary email" : "Remove primary email",
     "Delete email" : "Delete email",
@@ -377,20 +365,17 @@ OC.L10N.register(
     "Set as primary email" : "Set as primary email",
     "Additional email address {index}" : "Additional email address {index}",
     "Unable to delete primary email address" : "Unable to delete primary email address",
-    "Unable to update primary email address" : "Unable to update primary email address",
     "Unable to add additional email address" : "Unable to add additional email address",
     "Unable to update additional email address" : "Unable to update additional email address",
-    "Unable to delete additional email address" : "Unable to delete additional email address",
     "Primary email for password reset and notifications" : "Primary email for password reset and notifications",
-    "No email address set" : "No email address set",
     "Your handle" : "Your handle",
     "Your headline" : "Your headline",
+    "No language set" : "No language set",
     "Unable to update language" : "Unable to update language",
     "Help translate" : "Help translate",
-    "No language set" : "No language set",
+    "No locale set" : "No locale set",
     "Unable to update locale" : "Unable to update locale",
     "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
-    "No locale set" : "No locale set",
     "Your city" : "Your city",
     "Your organisation" : "Your organisation",
     "Your phone number" : "Your phone number",
@@ -467,13 +452,25 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
     "Add WebAuthn device" : "Add WebAuthn device",
     "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
-    "Adding your device …" : "Adding your device …",
     "Unnamed device" : "Unnamed device",
     "Passwordless Authentication" : "Passwordless Authentication",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
     "No devices configured." : "No devices configured.",
     "The following devices are configured for your account:" : "The following devices are configured for your account:",
     "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "It is important to set up this server to be able to send emails, like for password reset and notifications.",
+    "Send mode" : "Send mode",
+    "Encryption" : "Encryption",
+    "Sendmail mode" : "Sendmail mode",
+    "Disable certificate verification (insecure)" : "Disable certificate verification (insecure)",
+    "From address" : "From address",
+    "Domain" : "Domain",
+    "Server address" : "Server address",
+    "Host" : "Host",
+    "Port" : "Port",
+    "Authentication" : "Authentication",
+    "Authentication required" : "Authentication required",
+    "Saving…" : "Saving…",
     "Security & setup warnings" : "Security & setup warnings",
     "All checks passed." : "All checks passed.",
     "There are some errors regarding your setup." : "There are some errors regarding your setup.",
@@ -481,8 +478,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "As admin you can fine-tune the sharing behavior. Please see the documentation for more information.",
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
     "Admins" : "Admins",
-    "Sending…" : "Sending…",
-    "Email sent" : "Email sent",
     "Location" : "Location",
     "Profile picture" : "Profile picture",
     "About" : "About",
@@ -497,7 +492,15 @@ OC.L10N.register(
     "Website" : "Website",
     "Profile visibility" : "Profile visibility",
     "Locale" : "Locale",
+    "Private" : "Private",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Only visible to people matched via phone number integration through Talk on mobile",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
+    "Local" : "Local",
+    "Only visible to people on this instance and guests" : "Only visible to people on this instance and guests",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "Only synchronize to trusted servers",
+    "Published" : "Published",
+    "Synchronize to trusted servers and the global and public address book" : "Synchronize to trusted servers and the global and public address book",
     "Your apps" : "Your apps",
     "Active apps" : "Active apps",
     "Disabled apps" : "Disabled apps",
@@ -530,22 +533,6 @@ OC.L10N.register(
     "General documentation" : "General documentation",
     "Legal notice" : "Legal notice",
     "Privacy policy" : "Privacy policy",
-    "None/STARTTLS" : "None/STARTTLS",
-    "SSL" : "SSL",
-    "Open documentation" : "Open documentation",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "It is important to set up this server to be able to send emails, like for password reset and notifications.",
-    "Send mode" : "Send mode",
-    "Encryption" : "Encryption",
-    "Sendmail mode" : "Sendmail mode",
-    "From address" : "From address",
-    "Server address" : "Server address",
-    "Port" : "Port",
-    "Authentication" : "Authentication",
-    "Authentication required" : "Authentication required",
-    "Credentials" : "Credentials",
-    "SMTP Password" : "SMTP Password",
-    "Save" : "Save",
-    "Test and verify email settings" : "Test and verify email settings",
     "Reasons to use Nextcloud in your organization" : "Reasons to use Nextcloud in your organization",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Like our Facebook page",
@@ -553,21 +540,29 @@ OC.L10N.register(
     "Check out our blog" : "Check out our blog",
     "Subscribe to our newsletter" : "Subscribe to our newsletter",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
+    "Open documentation" : "Open documentation",
     "Use a second factor besides your password to increase security for your account." : "Use a second factor besides your password to increase security for your account.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
-    "File locking" : "File locking",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems.",
-    "The PHP memory limit is below the recommended value of %s." : "The PHP memory limit is below the recommended value of %s.",
-    "Set default expiration date for shares" : "Set default expiration date for shares",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
-    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
+    "Very weak password" : "Very weak password",
+    "Weak password" : "Weak password",
+    "So-so password" : "So-so password",
+    "Good password" : "Good password",
+    "Strong password" : "Strong password",
+    "Group list is empty" : "Group list is empty",
+    "Unable to retrieve the group list" : "Unable to retrieve the group list",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will be an error in the future.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will be an error in the future.",
-    "Your biography" : "Your biography",
-    "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
+    "Adding your device …" : "Adding your device …",
+    "Sending…" : "Sending…",
+    "Email sent" : "Email sent",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
+    "None/STARTTLS" : "None/STARTTLS",
+    "SSL" : "SSL",
+    "Credentials" : "Credentials",
+    "SMTP Password" : "SMTP Password",
+    "Save" : "Save",
+    "Test and verify email settings" : "Test and verify email settings",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
     "Checking for system and security issues." : "Checking for system and security issues.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>.",
