@@ -27,7 +27,11 @@ use OCP\IUser;
 use OCP\IUserManager;
 use OCP\L10N\IFactory;
 use OCP\Notification\IManager;
+use OCP\Server;
 use OCP\Settings\ISettings;
+use OCP\Teams\ITeamManager;
+use OCP\Teams\Team;
+use OCP\Util;
 
 class PersonalInfo implements ISettings {
 
@@ -38,6 +42,7 @@ class PersonalInfo implements ISettings {
 		private IConfig $config,
 		private IUserManager $userManager,
 		private IGroupManager $groupManager,
+		private ITeamManager $teamManager,
 		private IAccountManager $accountManager,
 		ProfileManager $profileManager,
 		private IAppManager $appManager,
@@ -55,7 +60,7 @@ class PersonalInfo implements ISettings {
 		$lookupServerUploadEnabled = false;
 		if ($federatedFileSharingEnabled) {
 			/** @var FederatedShareProvider $shareProvider */
-			$shareProvider = \OC::$server->query(FederatedShareProvider::class);
+			$shareProvider = Server::get(FederatedShareProvider::class);
 			$lookupServerUploadEnabled = $shareProvider->isLookupServerUploadEnabled();
 		}
 
@@ -70,7 +75,7 @@ class PersonalInfo implements ISettings {
 		if ($storageInfo['quota'] === FileInfo::SPACE_UNLIMITED) {
 			$totalSpace = $this->l->t('Unlimited');
 		} else {
-			$totalSpace = \OC_Helper::humanFileSize($storageInfo['total']);
+			$totalSpace = Util::humanFileSize($storageInfo['total']);
 		}
 
 		$messageParameters = $this->getMessageParameters($account);
@@ -85,9 +90,10 @@ class PersonalInfo implements ISettings {
 			'userId' => $uid,
 			'avatar' => $this->getProperty($account, IAccountManager::PROPERTY_AVATAR),
 			'groups' => $this->getGroups($user),
+			'teams' => $this->getTeamMemberships($user),
 			'quota' => $storageInfo['quota'],
 			'totalSpace' => $totalSpace,
-			'usage' => \OC_Helper::humanFileSize($storageInfo['used']),
+			'usage' => Util::humanFileSize($storageInfo['used']),
 			'usageRelative' => round($storageInfo['relative']),
 			'displayName' => $this->getProperty($account, IAccountManager::PROPERTY_DISPLAYNAME),
 			'emailMap' => $this->getEmailMap($account),
@@ -96,6 +102,7 @@ class PersonalInfo implements ISettings {
 			'location' => $this->getProperty($account, IAccountManager::PROPERTY_ADDRESS),
 			'website' => $this->getProperty($account, IAccountManager::PROPERTY_WEBSITE),
 			'twitter' => $this->getProperty($account, IAccountManager::PROPERTY_TWITTER),
+			'bluesky' => $this->getProperty($account, IAccountManager::PROPERTY_BLUESKY),
 			'fediverse' => $this->getProperty($account, IAccountManager::PROPERTY_FEDIVERSE),
 			'languageMap' => $this->getLanguageMap($user),
 			'localeMap' => $this->getLocaleMap($user),
@@ -107,12 +114,14 @@ class PersonalInfo implements ISettings {
 			'biography' => $this->getProperty($account, IAccountManager::PROPERTY_BIOGRAPHY),
 			'birthdate' => $this->getProperty($account, IAccountManager::PROPERTY_BIRTHDATE),
 			'firstDayOfWeek' => $this->config->getUserValue($uid, 'core', AUserDataOCSController::USER_FIELD_FIRST_DAY_OF_WEEK),
+			'timezone' => $this->config->getUserValue($uid, 'core', 'timezone', ''),
 			'pronouns' => $this->getProperty($account, IAccountManager::PROPERTY_PRONOUNS),
 		];
 
 		$accountParameters = [
 			'avatarChangeSupported' => $user->canChangeAvatar(),
 			'displayNameChangeSupported' => $user->canChangeDisplayName(),
+			'emailChangeSupported' => $user->canChangeEmail(),
 			'federationEnabled' => $federationEnabled,
 			'lookupServerUploadEnabled' => $lookupServerUploadEnabled,
 		];
@@ -187,6 +196,20 @@ class PersonalInfo implements ISettings {
 		return $groups;
 	}
 
+	/**
+	 * returns a list of the user's team memberships, sorted alphabetically
+	 * @return list<string> team names
+	 */
+	private function getTeamMemberships(IUser $user): array {
+		$teams = array_map(
+			static fn (Team $team): string => $team->getDisplayName(),
+			$this->teamManager->getTeamsForUser($user->getUID())
+		);
+		sort($teams);
+
+		return $teams;
+	}
+
 	/**
 	 * returns the primary email and additional emails in an
 	 * associative array
@@ -237,11 +260,11 @@ class PersonalInfo implements ISettings {
 		$languages = $this->l10nFactory->getLanguages();
 
 		// associate the user language with the proper array
-		$userLangIndex = array_search($userConfLang, array_column($languages['commonLanguages'], 'code'));
+		$userLangIndex = array_search($userConfLang, array_column($languages['commonLanguages'], 'code'), true);
 		$userLang = $languages['commonLanguages'][$userLangIndex];
 		// search in the other languages
 		if ($userLangIndex === false) {
-			$userLangIndex = array_search($userConfLang, array_column($languages['otherLanguages'], 'code'));
+			$userLangIndex = array_search($userConfLang, array_column($languages['otherLanguages'], 'code'), true);
 			$userLang = $languages['otherLanguages'][$userLangIndex];
 		}
 		// if user language is not available but set somehow: show the actual code as name
