@@ -53,7 +53,7 @@ class LoginAddressAggregatedMapper extends QBMapper {
 				$qb->expr()->lte('first_seen', $qb->createNamedParameter($start))
 			));
 
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$count = (int)$result->fetchColumn();
 		$result->closeCursor();
 
@@ -110,7 +110,7 @@ class LoginAddressAggregatedMapper extends QBMapper {
 				$qb->expr()->lte('first_seen', $qb->createNamedParameter($start))
 			));
 
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$count = (int)$result->fetchColumn();
 		$result->closeCursor();
 
@@ -122,7 +122,7 @@ class LoginAddressAggregatedMapper extends QBMapper {
 
 		$qb->select($qb->func()->count('*'))
 			->from($this->getTableName());
-		$result = $qb->execute();
+		$result = $qb->executeQuery();
 		$cnt = $result->fetchColumn();
 		$result->closeCursor();
 
@@ -134,7 +134,7 @@ class LoginAddressAggregatedMapper extends QBMapper {
 
 		$qb->select($qb->func()->sum('seen'))
 			->from($this->getTableName());
-		$result = $qb->execute();
+		$result = $qb->executeQuery();
 		$cnt = $result->fetchColumn();
 		$result->closeCursor();
 
