@@ -65,10 +65,10 @@ OC.L10N.register(
     "Delete" : "Elimina",
     "Reset" : "Ripristina",
     "Loading …" : "Caricamento in corso...",
-    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} verrà impostato e {tag2} verrà rimosso da 1 files.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} files.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} files."],
+    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} verrà impostato e {tag2} verrà rimosso da 1 file.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} file.","{tag1} verrà impostato e {tag2} verrà rimosso da {count} file."],
     "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} verrà impostato a 1 files.","{tag} verrà impostato a {count} files.","{tag} verrà impostato a {count} files."],
     "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} verrà rimosso da 1 file.","{tag} verrà rimosso da {count} files.","{tag} verrà rimosso da {count} files."],
-    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} verranno impostati a 1 file.","{tags} e {lastTag} verranno impostati a {count} files.","{tags} e {lastTag} verranno impostati a {count} files."],
+    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} verranno impostati a 1 file.","{tags} e {lastTag} verranno impostati a {count} file.","{tags} e {lastTag} verranno impostati a {count} file."],
     "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} verranno rimossi da 1 file.","{tags} e {lastTag} verranno rimossi da {count} files.","{tags} e {lastTag} verranno rimossi da {count} files."],
     "{displayName} (hidden)" : "{displayName} (nascosto)",
     "{displayName} (restricted)" : "{displayName} (limitato)",
@@ -97,6 +97,7 @@ OC.L10N.register(
     "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se abilitato, solo gli amministratori possono creare e modificare le etichette. Gli account possono comunque assegnarli e rimuoverli dai file.",
     "Restrict tag creation and editing to administrators" : "Limitare la creazione e la modifica delle etichette agli amministratori",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
+    "Add tags" : "Aggiungi etichette",
     "Assigned collaborative tags" : "Etichette collaborative assegnate",
     "Open in Files" : "Apri in File",
     "List of tags and their associated files and folders." : "Lista di etichette e dei loro file e cartelle associati.",
