@@ -65,6 +65,9 @@ OC.L10N.register(
     "Unsaved changes" : "未保存の変更点",
     "Save document" : "ファイルを保存する",
     "Last saved" : "最終保存",
+    "Close table of contents" : "目次を閉じる",
+    "Pin table of contents" : "目次をピン留めする",
+    "Table of contents" : "目次",
     "Formatting and shortcuts" : "書式とショートカット",
     "Speed up your writing with simple shortcuts." : "シンプルなショートカットを使って文書作成をスピードアップ！",
     "Just type the Markdown syntax or use keyboard shortcuts from below." : "Markdown記法で入力するか、下に示すキーボードショートカットを使ってみましょう。",
@@ -117,6 +120,9 @@ OC.L10N.register(
     "Save changes" : "変更を保存",
     "Cancel" : "キャンセル",
     "URL" : "URL",
+    "Edit block formula" : "ブロック式を編集",
+    "Edit inline formula" : "インライン式の編集",
+    "LaTeX formula" : "LaTeX式",
     "Save" : "保存する",
     "Disabled because you are currently offline." : "現在オフラインのため無効です。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "このファイルは別のクラウドから共有されているため、添付ファイルの作成やアップロードはできません。",
@@ -202,6 +208,8 @@ OC.L10N.register(
     "Increase indentation" : "インデントを増やす",
     "Decrease indentation" : "インデントを減らす",
     "Blocks" : "ブロック",
+    "Inline math" : "インライン数式",
+    "Block math" : "ブロック数学",
     "Info callout" : "情報コールアウト",
     "Success callout" : "成功コールアウト",
     "Warning callout" : "警告コールアウト",
@@ -214,6 +222,7 @@ OC.L10N.register(
     "Ctrl" : "Ctrl",
     "Option" : "Option",
     "Formatting" : "フォーマット",
+    "Start writing or type '/' to add…" : "書き始めるか、'/' を入力して追加してください…",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
     "Choose" : "選択",
     "Choose {file}" : "{file}を選択",
@@ -223,6 +232,7 @@ OC.L10N.register(
     "Copied to the clipboard" : "クリップボードにコピーされました",
     "Could not copy to the clipboard" : "クリップボードにコピーできませんでした",
     "Front matter" : "Front matter",
+    "A table was pasted into a table. Nested tables are not supported." : "テーブルがテーブルに貼り付けられました。ネストされたテーブルはサポートされていません。",
     "Link to this section" : "このセクションへのリンク",
     "Close outline view" : "目次の表示を閉じる",
     "Outline" : "目次",
