@@ -14,11 +14,11 @@ OC.L10N.register(
     "{user} has mentioned you in the text document {node}" : "{user} pieminēja Tevi teksta dokumentā {node}",
     "File not found" : "Datne nav atrasta",
     "Text" : "Teksts",
-    "Translate" : "Tulkot",
     "Guest" : "Viesis",
     "you" : "Tu",
     "edit" : "rediģēt",
     "Open in new tab" : "Atvērt jaunā cilnē",
+    "Copy link" : "Ievietot saiti starpliktuvē",
     "Remove link" : "Noņemt saiti",
     "guest" : "viesis",
     "Offline" : "Bezsaistē",
@@ -33,18 +33,19 @@ OC.L10N.register(
     "Action" : "Darbība",
     "Undo" : "Atsaukt",
     "Redo" : "Atcelt atsaukšanu",
-    "Copy link to clipboard" : "Ievietot saiti starpliktuvē",
     "Open link" : "Atvērt saiti",
     "Save changes" : "Saglabāt izmaiņas",
     "Cancel" : "Atcelt",
     "URL" : "URL",
+    "Save" : "Saglabāt",
     "Update link" : "Atjaunināt saiti",
+    "Translate" : "Tulkot",
     "Select language" : "Atlasīt valodu",
     "to" : "kam",
     "Replace" : "Aizvietot",
+    "Edit" : "Labot",
     "Upload" : "Augšupielādēt",
     "Insert Table" : "Ievietot tabulu",
-    "Edit" : "Labot",
     "Source code" : "Izejas kods",
     "Done" : "Pabeigts",
     "Details" : "Informācija",
@@ -52,8 +53,6 @@ OC.L10N.register(
     "Command" : "Komanda",
     "Choose" : "Izvēlēties",
     "Add folder description" : "Pievienot mapes aprakstu",
-    "Use current version" : "Izmantot pašreizējo versiju",
-    "Info" : "Informācija",
-    "Warning" : "Brīdinājums"
+    "Copy link to clipboard" : "Ievietot saiti starpliktuvē"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
