@@ -183,17 +183,17 @@ OC.L10N.register(
     "Could not find image in attachments list." : "在附件清單中找不到影像。",
     "Delete this attachment" : "刪除此附件",
     "Delete this image" : "刪除此圖像",
-    "Add row before" : "在前面添加行",
-    "Add row after" : "在後面添加行",
-    "Delete this row" : "刪除此行",
-    "Left align column" : "左側對齊縱列",
-    "Center align column" : "置中對齊縱列",
-    "Right align column" : "右側對齊縱列",
-    "Add column before" : "在前面添加縱列",
-    "Add column after" : "在後面添加縱列",
-    "Delete this column" : "删除此縱列",
+    "Add row before" : "在前面新增一列",
+    "Add row after" : "在後面新增一列",
+    "Delete this row" : "刪除此列",
+    "Left align column" : "左側對齊直欄",
+    "Center align column" : "置中對齊直欄",
+    "Right align column" : "右側對齊直欄",
+    "Add column before" : "在前面添加直欄",
+    "Add column after" : "在後面添加直欄",
+    "Delete this column" : "刪除此直欄",
     "Delete this table" : "删除此表",
-    "Add row below" : "在下方新增列",
+    "Add row below" : "在下方新增一列",
     "Show folder description" : "顯示資料夾描述",
     "Hide outline" : "隱藏大綱",
     "Show outline" : "顯示大綱",
