@@ -10,11 +10,10 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "La dirección de política de privacidad proporcionada no es una URL válida",
     "The given slogan is too long" : "El lema dado es demasiado largo",
     "The given color is invalid" : "El color dado es inválido",
-    "Disable-user-theming should be true or false" : "Deshabilitar-temas-de-usuario debe ser verdadero o falso",
+    "Invalid setting key" : "Llave de ajuste inválida",
     "Saved" : "Guardado",
     "Invalid app given" : "Aplicación proporcionada inválida",
     "Invalid type for setting \"defaultApp\" given" : "El tipo de ajuste proporcionado para \"defaultApp\" es inválido",
-    "Invalid setting key" : "Llave de ajuste inválida",
     "The file was uploaded" : "El archivo fue cargado",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
@@ -51,61 +50,8 @@ OC.L10N.register(
     "Legal notice" : "Aviso legal",
     "Privacy policy" : "Política de privacidad",
     "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
-    "Name" : "Nombre",
-    "Web link" : "Enlace web",
-    "a safe home for all your data" : "un lugar seguro para todos tus datos",
-    "Slogan" : "Lema",
-    "Primary color" : "Color primario",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "El color primario es usado para destacar elementos como botones importantes. Podría ajustarse ligeramente dependiendo del esquema de color actual.",
-    "Legal notice link" : "Enlace al aviso legal",
-    "Privacy policy link" : "Liga a la política de privacidad",
-    "Header logo" : "Logo del encabezado",
-    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
-    "Favicon" : "Favicon",
-    "Upload new favicon" : "Cargar un nuevo favicon",
-    "User settings" : "Configuración de usuario",
-    "Disable user theming" : "Deshabilitar los temas de usuario",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede habilitarlo.",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
-    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "En vez de una imagen de fondo, también puede configurar un fondo de color plano. Si usa una imagen de fondo, cambiar este color influirá en el color de los íconos del menú de aplicaciones.",
-    "Background color" : "Color de fondo",
-    "Upload new logo" : "Cargar nuevo logotipo",
-    "Logo" : "Logotipo",
-    "Upload new background and login image" : "Cargar nueva imagen de fondo e inicio de sesión",
-    "Background and login image" : "Imagen de fondo e inicio de sesión",
-    "Advanced options" : "Opciones avanzadas",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale la extensión PHP ImageMagick con soporte para imágenes SVG para generar automáticamente favicons basados en el logo cargado y el color.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentra algún problema, no dude en reportarlo en {issuetracker}nuestro sistema de seguimiento de problemas{linkend}. Y si quiere participar, ¡únase a {designteam}nuestro equipo de diseño{linkend}!",
-    "Appearance and accessibility settings" : "Configuración de apariencia y accesibilidad",
-    "Misc accessibility options" : "Opciones de accesibilidad misceláneas",
-    "Enable blur background filter (may increase GPU load)" : "Habilitar el filtro de desenfoque de fondo (puede incrementar la carga de la GPU)",
-    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por su administrador",
-    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Establecer un color primario para destacar los elementos importantes. El color usado para elementos como botones primarios puede diferir ligeramente dado que se ajusta para cumplir con los requerimientos de accesibilidad.",
-    "Background and color" : "Fondo y color",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "El fondo puede establecerse a una imagen desde el conjunto predeterminado, una imagen subida personalizada, o un color plano.",
-    "Keyboard shortcuts" : "Atajos del teclado",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. Para permitir el enfoque correcto de su herramienta, puede desactivar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
-    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
-    "Current selected app: {app}, position {position} of {total}" : "Aplicación seleccionada actualmente: {app}, posición {position} de {total}",
-    "Move up" : "Mover arriba",
-    "Move down" : "Mover abajo",
-    "Select a background from your files" : "Seleccionar un fondo desde sus archivos",
-    "Select background" : "Seleccionar fondo",
-    "No background has been selected" : "No se ha seleccionado un fondo",
-    "Custom background" : "Fondo personalizado",
-    "Plain background" : "Fondo liso",
-    "Default background" : "Fondo predeterminado",
-    "Theme selection is enforced" : "La selección del tema es obligatoria",
-    "Could not set the app order" : "No se pudo establecer el orden de aplicaciones",
-    "Could not reset the app order" : "No se pudo restaurar el orden de aplicaciones",
-    "Navigation bar settings" : "Configuración de la barra de navegación",
-    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Puede configurar el orden de las aplicaciones en la barra de navegación. La primera será la aplicación predeterminada, que se muestra al iniciar sesión o al hacer clic en el logo.",
-    "The default app can not be changed because it was configured by the administrator." : "No se puede cambiar la aplicación predeterminada porque fue configurada por el administrador.",
-    "The app order was changed, to see it in action you have to reload the page." : "El orden de aplicaciones ha cambiado, para poder verlo, recargue la página.",
-    "Reset default app order" : "Restaurar el orden de aplicaciones predeterminado",
-    "Could not set primary color" : "No se pudo establecer el color primario",
-    "Reset primary color" : "Restablecer el color primario",
     "Could not set global default apps" : "No se pudieron establecer las aplicaciones predeterminadas globales",
+    "Navigation bar settings" : "Configuración de la barra de navegación",
     "Default app" : "Aplicación predeterminada",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "La aplicación predeterminada es la que se mostrará al iniciar sesión o al hacer clic en el logo del menú.",
     "Use custom default app" : "Utilizar la aplicación personalizada predeterminada",
@@ -113,10 +59,64 @@ OC.L10N.register(
     "Global default apps" : "Aplicaciones predeterminadas globales",
     "Default app priority" : "Prioridad de aplicaciones predeterminada",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Si una aplicación no está habilitada para un usuario, se utilizará la siguiente aplicación por orden de prioridad.",
-    "Select a custom color" : "Seleccionar un color personalizado",
-    "Reset to default" : "Restablecer al predeterminado",
-    "Upload" : "Cargar",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
+    "Name" : "Nombre",
+    "Web link" : "Enlace web",
+    "Slogan" : "Lema",
+    "a safe home for all your data" : "un lugar seguro para todos tus datos",
+    "Legal notice link" : "Enlace al aviso legal",
+    "Privacy policy link" : "Liga a la política de privacidad",
+    "Background and color" : "Fondo y color",
+    "Primary color" : "Color primario",
+    "Background color" : "Color de fondo",
     "Remove background image" : "Eliminar imagen de fondo",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo sea utilizable inclusive sin ratón, y con software de asistencia como lectores de pantalla. Buscamos cumplir con las {guidelines}Guías de Accesibilidad de Contenido Web{linkend} 2.1 sobre nivel AA, incluso sobre nivel AAA para el tema de alto contraste."
+    "Favicon" : "Favicon",
+    "Logo" : "Logotipo",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aunque puede seleccionar y personalizar su instancia, los usuarios pueden cambiar su fondo y colores. Si quiere forzar su personalización, puede habilitarlo.",
+    "Disable user theming" : "Deshabilitar los temas de usuario",
+    "Current selected app: {app}, position {position} of {total}" : "Aplicación seleccionada actualmente: {app}, posición {position} de {total}",
+    "Move up" : "Mover arriba",
+    "Move down" : "Mover abajo",
+    "Theme selection is enforced" : "La selección del tema es obligatoria",
+    "Could not set the app order" : "No se pudo establecer el orden de aplicaciones",
+    "Could not reset the app order" : "No se pudo restaurar el orden de aplicaciones",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Puede configurar el orden de las aplicaciones en la barra de navegación. La primera será la aplicación predeterminada, que se muestra al iniciar sesión o al hacer clic en el logo.",
+    "The default app can not be changed because it was configured by the administrator." : "No se puede cambiar la aplicación predeterminada porque fue configurada por el administrador.",
+    "The app order was changed, to see it in action you have to reload the page." : "El orden de aplicaciones ha cambiado, para poder verlo, recargue la página.",
+    "Reset default app order" : "Restaurar el orden de aplicaciones predeterminado",
+    "Select a background from your files" : "Seleccionar un fondo desde sus archivos",
+    "Select background" : "Seleccionar fondo",
+    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "El fondo puede establecerse a una imagen desde el conjunto predeterminado, una imagen subida personalizada, o un color plano.",
+    "Custom background" : "Fondo personalizado",
+    "Plain background" : "Fondo liso",
+    "Default background" : "Fondo predeterminado",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "En algunos casos, los atajos de teclado pueden interferir con las herramientas de accesibilidad. Para permitir el enfoque correcto de su herramienta, puede desactivar todos los atajos de teclado aquí. Esto también deshabilitará todos los atajos disponibles en las aplicaciones.",
+    "Disable all keyboard shortcuts" : "Deshabilitar todos los atajos de teclado",
+    "Could not set primary color" : "No se pudo establecer el color primario",
+    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Establecer un color primario para destacar los elementos importantes. El color usado para elementos como botones primarios puede diferir ligeramente dado que se ajusta para cumplir con los requerimientos de accesibilidad.",
+    "Reset primary color" : "Restablecer el color primario",
+    "Reset to default" : "Restablecer al predeterminado",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si encuentra algún problema, no dude en reportarlo en {issuetracker}nuestro sistema de seguimiento de problemas{linkend}. Y si quiere participar, ¡únase a {designteam}nuestro equipo de diseño{linkend}!",
+    "Appearance and accessibility settings" : "Configuración de apariencia y accesibilidad",
+    "Misc accessibility options" : "Opciones de accesibilidad misceláneas",
+    "Enable blur background filter (may increase GPU load)" : "Habilitar el filtro de desenfoque de fondo (puede incrementar la carga de la GPU)",
+    "Customization has been disabled by your administrator" : "La personalización ha sido deshabilitada por su administrador",
+    "Disable-user-theming should be true or false" : "Deshabilitar-temas-de-usuario debe ser verdadero o falso",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "El color primario es usado para destacar elementos como botones importantes. Podría ajustarse ligeramente dependiendo del esquema de color actual.",
+    "Header logo" : "Logo del encabezado",
+    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
+    "Upload new favicon" : "Cargar un nuevo favicon",
+    "User settings" : "Configuración de usuario",
+    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "En vez de una imagen de fondo, también puede configurar un fondo de color plano. Si usa una imagen de fondo, cambiar este color influirá en el color de los íconos del menú de aplicaciones.",
+    "Upload new logo" : "Cargar nuevo logotipo",
+    "Upload new background and login image" : "Cargar nueva imagen de fondo e inicio de sesión",
+    "Background and login image" : "Imagen de fondo e inicio de sesión",
+    "Advanced options" : "Opciones avanzadas",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale la extensión PHP ImageMagick con soporte para imágenes SVG para generar automáticamente favicons basados en el logo cargado y el color.",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "El acceso universal es muy importante para nosotros. Seguimos los estándares web y verificamos que todo sea utilizable inclusive sin ratón, y con software de asistencia como lectores de pantalla. Buscamos cumplir con las {guidelines}Guías de Accesibilidad de Contenido Web{linkend} 2.1 sobre nivel AA, incluso sobre nivel AAA para el tema de alto contraste.",
+    "No background has been selected" : "No se ha seleccionado un fondo",
+    "Select a custom color" : "Seleccionar un color personalizado",
+    "Upload" : "Cargar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
