@@ -75,7 +75,7 @@ OC.L10N.register(
     "Background color" : "Taustavärv",
     "When no background image is set the background color will be used." : "Kui taustapilt on seadistamata, on kasutusel taustavärv.",
     "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Muul juhul tuletatakse taustavärv vaikimisi taustapildist, kuid juhtnuppude jaoks saad seda veel peenhäälestada.",
-    "Use a plain background color instead of a background image." : "Taustapildi asemele kasuta ühtlast taustavärvi.",
+    "Use a plain background color instead of a background image." : "Taustapildi asemel kasuta ühtlast taustavärvi.",
     "Remove background image" : "Eemalda taustapilt",
     "Background image" : "Taustapilt",
     "Favicon" : "Saidi favikon",
@@ -109,6 +109,7 @@ OC.L10N.register(
     "Reset primary color" : "Lähtesta põhivärv",
     "Reset to default" : "Taasta vaikeseaded",
     "Non image file selected" : "Ühtegi pildifaili pole valitud",
+    "Failed to upload image" : "Pildi üleslaadimine ei õnnestunud",
     "Preview of the selected image" : "Valitud pildi eelvaade",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universaalne juurdepääs on meie jaoks väga oluline. Me järgime veebistandardeid ja kontrollime, et kõik oleks kasutatav ka ilma hiireta ja abitarkvara, näiteks ekraani lugejateta. Meie eesmärk on olla vastavuses {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 AA-tasemega, suure kontrastsusega kujunduse puhul isegi AAA-tasemega. ",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Kui leiad mingeid probleeme, siis teata neist {issuetracker}meie veahalduse süsteemis{linkend}. Ja kui soovid kaasa lüüa, siis tule liitu {designteam}meie disainimeeskonnaga{linkend}!",
@@ -118,7 +119,7 @@ OC.L10N.register(
     "Enable blur background filter (may increase GPU load)" : "Kasuta tausta hägustamise filtrit (suurendab graafikaprotsessori koormust)",
     "Customization has been disabled by your administrator" : "Kujunduse kohendamine pole peakasutaja poolt lubatud",
     "Disable-user-theming should be true or false" : "„Disable-user-theming“ väärtus saab olla kas „true“ või „false“",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Põhivärv on mõeldud lehe oluliste elementude rõhutamiseks. Vastavalt valitud üldkujundusele võib see värv ka natuke kohenduda.",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Põhivärv on mõeldud lehe oluliste elementide rõhutamiseks. Vastavalt valitud üldkujundusele võib see värv ka natuke kohenduda.",
     "Header logo" : "Päiselogo",
     "Upload new header logo" : "Laadi üles uus päiselogo",
     "Upload new favicon" : "Laadi üles uus saidi favikon",
