@@ -10,11 +10,12 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "Zadaná adresa zásady ochrany osobných údajov nie je platná adresa URL",
     "The given slogan is too long" : "Zadaný slogan je príliš dlhý",
     "The given color is invalid" : "Zadaná farba nie je platná",
-    "Disable-user-theming should be true or false" : "Disable-user-theming by malo byť true alebo false",
+    "%1$s should be true or false" : "%1$smalo by to byť pravda alebo nepravda",
+    "%1$s can only be set to %2$s through the API" : "%1$s môže byť nastavené na %2$s iba cez API",
+    "Invalid setting key" : "Neplatný kľúč nastavenia",
     "Saved" : "Uložené",
     "Invalid app given" : "Zadaná neplatná aplikácia",
     "Invalid type for setting \"defaultApp\" given" : "Zadaný neplatný typ nastavenia „defaultApp“.",
-    "Invalid setting key" : "Neplatný kľúč nastavenia",
     "The file was uploaded" : "Súbor bol nahraný",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Nahraný súbor prekročil limit nastavený v upload_max_filesize v súbore php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Ukladaný súbor prekračuje nastavenie MAX_FILE_SIZE z volieb HTML formulára.",
@@ -51,63 +52,8 @@ OC.L10N.register(
     "Legal notice" : "Právne upozornenie",
     "Privacy policy" : "Zásady ochrany osobných údajov",
     "Adjust the Nextcloud theme" : "Upraviť motív vzhľadu Nextcloudu",
-    "Name" : "Názov",
-    "Web link" : "Webový odkaz",
-    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
-    "Slogan" : "Slogan",
-    "Primary color" : "Primárna farba",
-    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Primárna farba sa používa na zvýraznenie prvkov, ako sú dôležité tlačidlá. Môže sa mierne upraviť v závislosti od aktuálnej farebnej schémy.",
-    "Legal notice link" : "Odkaz na právne upozornenie",
-    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
-    "Header logo" : "Logo v hlavičke",
-    "Upload new header logo" : "Nahrať nové logo do hlavičky",
-    "Favicon" : "Favicon",
-    "Upload new favicon" : "Nahrať novú ikonu webu",
-    "User settings" : "Nastavenia užívateľa",
-    "Disable user theming" : "Vypnúť úpravu vzhľadu používateľom",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Hoci si môžete vybrať a prispôsobiť svoju inštanciu, užívatelia môžu zmeniť svoje pozadie a farby. Ak chcete presadiť svoje prispôsobenie, môžete to tu zapnúť.",
-    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Vidieť ho budú všetci používatelia.",
-    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Namiesto obrázka na pozadí môžete nakonfigurovať aj obyčajnú farbu pozadia. Ak použijete obrázok na pozadí, zmena tejto farby ovplyvní farbu ikon ponuky aplikácie.",
-    "Background color" : "Farba pozadia",
-    "Upload new logo" : "Nahrať nové logo",
-    "Logo" : "Logo",
-    "Upload new background and login image" : "Nahrať nové pozadie a prihlasovací obrázok",
-    "Background and login image" : "Obrázok pozadia a prihlasovacej obrazovky",
-    "Advanced options" : "Pokročilé možnosti",
-    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainštalujte si rozšírenie ImageMagick PHP s podporou obrázkov SVG pre automatické generovanie favicon na základe nahraného loga a farby.",
-    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {linkstart}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
-    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaké problémy, neváhajte ich nahlásiť v {issuetracker}našom nástroji na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pridajte sa k {designteam}nášmu tímu dizajnérov{linkend}!",
-    "Unable to apply the setting." : "Nepodarilo sa použiť nastavenia.",
-    "Appearance and accessibility settings" : "Nastavenia vzhľadu a dostupnosti",
-    "Misc accessibility options" : "Rôzne možnosti dostupnosti",
-    "Enable blur background filter (may increase GPU load)" : "Povoliť filter rozmazania pozadia (môže zvýšiť zaťaženie GPU)",
-    "Customization has been disabled by your administrator" : "Prispôsobenie zakázal váš správca",
-    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Nastavte primárnu farbu na zvýraznenie dôležitých prvkov. Farba použitá pre prvky, ako sú primárne tlačidlá, sa môže pri úprave tak, aby spĺňala požiadavky na prístupnosť, trochu líšiť.",
-    "Background and color" : "Pozadie a farba",
-    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Pozadie môže byť nastavené na obrázok z predvolenej sady, vlastný nahraný obrázok alebo obyčajnú farbu.",
-    "Keyboard shortcuts" : "Klávesové skratky",
-    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V niektorých prípadoch môžu klávesové skratky zasahovať do nástrojov pre dostupnosť. Aby ste mohli správne používať svoje nástroje, môžete vypnúť všetky klávesové skratky. Tým sa tiež zakážu všetky dostupné skratky v aplikáciách.",
-    "Disable all keyboard shortcuts" : "Vypnúť všetky klávesové skratky",
-    "Current selected app: {app}, position {position} of {total}" : "Aktuálne vybratá aplikácia: {app}, pozícia {position} z {total}",
-    "Move up" : "Presunúť hore",
-    "Move down" : "Presunúť dole",
-    "Select a background from your files" : "Vybrať pozadie z vašich súborov",
-    "Select background" : "Vybrať pozadie",
-    "No background has been selected" : "Nebolo vybrané žiadne pozadie",
-    "Custom background" : "Vlastné pozadie",
-    "Plain background" : "Obyčajné pozadie",
-    "Default background" : "Predvolené pozadie",
-    "Theme selection is enforced" : "Vynucuje sa výber témy",
-    "Could not set the app order" : "Nepodarilo sa nastaviť poradie aplikácií",
-    "Could not reset the app order" : "Nepodarilo sa obnoviť poradie aplikácií",
-    "Navigation bar settings" : "Nastavenia panelu navigácie",
-    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Môžete nakonfigurovať poradie aplikácií používané pre navigačný panel. Prvá položka bude predvolená aplikácia, ktorá sa otvorí po prihlásení alebo po kliknutí na logo.",
-    "The default app can not be changed because it was configured by the administrator." : "Predvolenú aplikáciu nie je možné zmeniť, pretože ju nakonfiguroval správca.",
-    "The app order was changed, to see it in action you have to reload the page." : "Poradie aplikácie bolo zmenené. Ak ju chcete vidieť v akcii, musíte stránku znova načítať.",
-    "Reset default app order" : "Obnoviť predvolené poradie aplikácií",
-    "Could not set primary color" : "Nebolo možné nastaviť primárnu farbu",
-    "Reset primary color" : "Obnoviť primárnu farbu",
     "Could not set global default apps" : "Nepodarilo sa nastaviť globálne predvolené aplikácie",
+    "Navigation bar settings" : "Nastavenia panelu navigácie",
     "Default app" : "Predvolená aplikácia",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Predvolená aplikácia je aplikácia, ktorá sa napr. otvorí po prihlásení alebo po kliknutí na logo v menu.",
     "Use custom default app" : "Použiť vlastnú predvolenú aplikáciu",
@@ -115,11 +61,79 @@ OC.L10N.register(
     "Global default apps" : "Globálne predvolené aplikácie",
     "Default app priority" : "Predvolená priorita aplikácie",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Ak aplikácia nie je pre užívateľa povolená, použije sa nasledujúca aplikácia s nižšou prioritou.",
-    "Select a custom color" : "Vyberte vlastnú farbu",
-    "Reset to default" : "Nastaviť predvolené",
-    "Upload" : "Nahrať",
+    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Zmena vzhľadu umožňuje ľahko upraviť pocit z vašej inštalácie a podporovaných klientov. Vidieť ho budú všetci používatelia.",
+    "Name" : "Názov",
+    "Web link" : "Webový odkaz",
+    "Slogan" : "Slogan",
+    "a safe home for all your data" : "bezpečný domov pre všetky vaše dáta",
+    "Legal notice link" : "Odkaz na právne upozornenie",
+    "Privacy policy link" : "Odkaz na zásady ochrany osobných údajov",
+    "Background and color" : "Pozadie a farba",
+    "Primary color" : "Primárna farba",
+    "Set the default primary color, used to highlight important elements." : "Nastavte predvolenú hlavnú farbu, ktorá sa používa na zvýraznenie dôležitých prvkov.",
+    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Farba použitá pre prvky, ako sú hlavné tlačidlá, sa môže mierne líšiť, pretože sa upravuje na splnenie požiadaviek prístupnosti.",
+    "Background color" : "Farba pozadia",
+    "When no background image is set the background color will be used." : "Keď nie je nastavený žiadny obrázok na pozadí, bude použitá farba pozadia.",
+    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Inak je farba pozadia predvolene generovaná z obrázka pozadia, ale môže byť upravená na jemné doladenie farby navigačných ikon.",
+    "Use a plain background color instead of a background image." : "Použite jednoduchú farbu pozadia namiesto obrázku pozadia.",
     "Remove background image" : "Odstrániť obrázok pozadia",
+    "Background image" : "Obrázok pozadia",
+    "Favicon" : "Favicon",
+    "Logo" : "Logo",
+    "Navigation bar logo" : "Logo navigačného panela",
+    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Hoci si môžete vybrať a prispôsobiť svoju inštanciu, užívatelia môžu zmeniť svoje pozadie a farby. Ak chcete presadiť svoje prispôsobenie, môžete to tu zapnúť.",
+    "Disable user theming" : "Vypnúť úpravu vzhľadu používateľom",
+    "Current selected app: {app}, position {position} of {total}" : "Aktuálne vybratá aplikácia: {app}, pozícia {position} z {total}",
+    "Navigation bar app order" : "Poradie aplikácií v navigačnom paneli",
+    "Move up" : "Presunúť hore",
+    "Move down" : "Presunúť dole",
+    "Theme selection is enforced" : "Vynucuje sa výber témy",
+    "Could not set the app order" : "Nepodarilo sa nastaviť poradie aplikácií",
+    "Could not reset the app order" : "Nepodarilo sa obnoviť poradie aplikácií",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Môžete nakonfigurovať poradie aplikácií používané pre navigačný panel. Prvá položka bude predvolená aplikácia, ktorá sa otvorí po prihlásení alebo po kliknutí na logo.",
+    "The default app can not be changed because it was configured by the administrator." : "Predvolenú aplikáciu nie je možné zmeniť, pretože ju nakonfiguroval správca.",
+    "The app order was changed, to see it in action you have to reload the page." : "Poradie aplikácie bolo zmenené. Ak ju chcete vidieť v akcii, musíte stránku znova načítať.",
+    "Reset default app order" : "Obnoviť predvolené poradie aplikácií",
+    "Select a background from your files" : "Vybrať pozadie z vašich súborov",
+    "Select background" : "Vybrať pozadie",
+    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Pozadie môže byť nastavené na obrázok z predvolenej sady, vlastný nahraný obrázok alebo obyčajnú farbu.",
+    "Custom background" : "Vlastné pozadie",
+    "Plain background" : "Obyčajné pozadie",
+    "Default background" : "Predvolené pozadie",
+    "Default shipped background images" : "Predvolené dodávané obrázky pozadia",
+    "Keyboard shortcuts" : "Klávesové skratky",
+    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "V niektorých prípadoch môžu klávesové skratky zasahovať do nástrojov pre dostupnosť. Aby ste mohli správne používať svoje nástroje, môžete vypnúť všetky klávesové skratky. Tým sa tiež zakážu všetky dostupné skratky v aplikáciách.",
+    "Disable all keyboard shortcuts" : "Vypnúť všetky klávesové skratky",
+    "Could not set primary color" : "Nebolo možné nastaviť primárnu farbu",
+    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Nastavte primárnu farbu na zvýraznenie dôležitých prvkov. Farba použitá pre prvky, ako sú primárne tlačidlá, sa môže pri úprave tak, aby spĺňala požiadavky na prístupnosť, trochu líšiť.",
+    "Reset primary color" : "Obnoviť primárnu farbu",
+    "Reset to default" : "Nastaviť predvolené",
+    "Non image file selected" : "Nevybraný súbor s obrázkom",
+    "Failed to upload image" : "Chyba pri nahrávaní obrázku",
+    "Preview of the selected image" : "Náhľad vybraného obrázka",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {linkstart}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
+    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ak nájdete nejaké problémy, neváhajte ich nahlásiť v {issuetracker}našom nástroji na sledovanie problémov{linkend}. A ak sa chcete zapojiť, pridajte sa k {designteam}nášmu tímu dizajnérov{linkend}!",
+    "Unable to apply the setting." : "Nepodarilo sa použiť nastavenia.",
+    "Appearance and accessibility settings" : "Nastavenia vzhľadu a dostupnosti",
+    "Misc accessibility options" : "Rôzne možnosti dostupnosti",
+    "Enable blur background filter (may increase GPU load)" : "Povoliť filter rozmazania pozadia (môže zvýšiť zaťaženie GPU)",
+    "Customization has been disabled by your administrator" : "Prispôsobenie zakázal váš správca",
+    "Disable-user-theming should be true or false" : "Disable-user-theming by malo byť true alebo false",
+    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Primárna farba sa používa na zvýraznenie prvkov, ako sú dôležité tlačidlá. Môže sa mierne upraviť v závislosti od aktuálnej farebnej schémy.",
+    "Header logo" : "Logo v hlavičke",
+    "Upload new header logo" : "Nahrať nové logo do hlavičky",
+    "Upload new favicon" : "Nahrať novú ikonu webu",
+    "User settings" : "Nastavenia užívateľa",
+    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Namiesto obrázka na pozadí môžete nakonfigurovať aj obyčajnú farbu pozadia. Ak použijete obrázok na pozadí, zmena tejto farby ovplyvní farbu ikon ponuky aplikácie.",
+    "Upload new logo" : "Nahrať nové logo",
+    "Upload new background and login image" : "Nahrať nové pozadie a prihlasovací obrázok",
+    "Background and login image" : "Obrázok pozadia a prihlasovacej obrazovky",
+    "Advanced options" : "Pokročilé možnosti",
+    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Nainštalujte si rozšírenie ImageMagick PHP s podporou obrázkov SVG pre automatické generovanie favicon na základe nahraného loga a farby.",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Univerzálny prístup je pre nás veľmi dôležitý. Dodržiavame webové štandardy a kontrolujeme, aby bolo všetko použiteľné aj bez myši a pomocného softvéru, ako sú čítačky obrazovky. Naším cieľom je byť v súlade s {guidelines}pokynmi pre prístup k webovému obsahu {linkend} 2.1 na úrovni AA,  v režime vysokého kontrastu dokonca na úrovni AAA.",
-    ". Unable to apply the setting." : ". Nepodarilo sa použiť nastavenia."
+    ". Unable to apply the setting." : ". Nepodarilo sa použiť nastavenia.",
+    "No background has been selected" : "Nebolo vybrané žiadne pozadie",
+    "Select a custom color" : "Vyberte vlastnú farbu",
+    "Upload" : "Nahrať"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
