@@ -52,7 +52,7 @@ OC.L10N.register(
     "Legal notice" : "Правові застереження",
     "Privacy policy" : "Політика конфіденційності",
     "Adjust the Nextcloud theme" : "Налаштуйте тему Nextcloud",
-    "Could not set global default apps" : "Не вдалося встановити системний типовий застосунок",
+    "Could not set global default apps" : "Не вдалося встановити застосунок, який буде типово завантажуватися для всіх",
     "Navigation bar settings" : "Налаштування панелі навігації",
     "Default app" : "Типовий застосунок",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Типовий застосунок - це застосунок, який відкривається одразу після авторизації користувача або коли користувач клацає по логотипу сайту.",
@@ -71,7 +71,7 @@ OC.L10N.register(
     "Background and color" : "Тло та колір",
     "Primary color" : "Основний колір",
     "Set the default primary color, used to highlight important elements." : "Встановити основний колір, який використовується для виділення важливих елементів.",
-    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Колір, який використовується для таких елементів, як основні кнопки, може незначно відрізнятися, оскільки узгоджуватиметься з вимогами доступности. ",
+    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Колір, який використовується для таких елементів, як основні кнопки, може незначно відрізнятися, оскільки узгоджуватиметься з вимогами доступності. ",
     "Background color" : "Колір тла",
     "When no background image is set the background color will be used." : "Якщо не встановлено зображення тла, то використовуватиметься колір тла.",
     "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "В іншому випадку колір тла визначатиметься типово на основі зображення тла, але може підлаштовуватися під колір піктограм елементів навігації.",
@@ -109,11 +109,12 @@ OC.L10N.register(
     "Reset primary color" : "Скинути налаштування основного кольору",
     "Reset to default" : "Скинути до типового",
     "Non image file selected" : "Вибрано файл, який не є зображенням",
+    "Failed to upload image" : "Не вдалося завантажити зображення",
     "Preview of the selected image" : "Попередній вигляд вибраного зображення",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Для нас дуже важливо забезпечити доступ для всіх. Ми дотримуємось сучасних стандартів розробки у вебі, намагаємося забезпечити зручність користування без комп'ютерної миші, а також за допомогою допоміжного програмного забезпечення, наприклад, застосунки зчитування з екрана. Ми прагнемо відповідати {linkstart}Правилам доступу до вмісту у мережі {linkend} 2.1 на рівні AA, а з темою високої контрастності навіть на рівні AAA.",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Якщо ви виявите будь-які проблеми, не соромтеся повідомити про них на {issuetracker}нашій системі відстеження проблем{linkend}. І якщо ви хочете взяти участь, приєднуйтесь до {designteam}нашої команди дизайнерів{linkend}!",
     "Unable to apply the setting." : "Не вдалося застосувати налаштування.",
-    "Appearance and accessibility settings" : "Налаштування оформлення та доступности",
+    "Appearance and accessibility settings" : "Налаштування оформлення та доступності",
     "Misc accessibility options" : "Різні налаштування доступності",
     "Enable blur background filter (may increase GPU load)" : "Увімкнути фільтр розмиття тла (матиме додаткове навантаження на GPU)",
     "Customization has been disabled by your administrator" : "Налаштування персоналізації вимкнено адміністатором.",
