@@ -2,6 +2,7 @@ OC.L10N.register(
     "twofactor_totp",
     {
     "Enable TOTP" : "Enable TOTP",
-    "Verify" : "Verify"
+    "Verify" : "Verify",
+    "Submit" : "Submit"
 },
 "nplurals=1; plural=0;");
