@@ -9,7 +9,6 @@ declare(strict_types=1);
  */
 namespace OCA\UpdateNotification;
 
-use OC\Updater\ChangesCheck;
 use OC\Updater\VersionCheck;
 use OCP\AppFramework\Services\IInitialState;
 
@@ -17,7 +16,6 @@ class UpdateChecker {
 
 	public function __construct(
 		private VersionCheck $updater,
-		private ChangesCheck $changesCheck,
 		private IInitialState $initialState,
 	) {
 	}
@@ -41,13 +39,6 @@ class UpdateChecker {
 			if (strpos($data['url'], 'https://') === 0) {
 				$result['downloadLink'] = $data['url'];
 			}
-			if (strpos($data['changes'], 'https://') === 0) {
-				try {
-					$result['changes'] = $this->changesCheck->check($data['changes'], $data['version']);
-				} catch (\Exception $e) {
-					// no info, not a problem
-				}
-			}
 
 			return $result;
 		}
