@@ -27,21 +27,21 @@ OC.L10N.register(
     "%s accessed %s" : "%s hozzáfért a következőhöz: %s",
     "%s renamed %s" : "%s átnevezte a következőt: %s",
     "%s copied %s" : "%s átmásolta a következőt: %s",
-    "%s assigned %s to %s" : "%s hozzárendelte a következőt: %s, hozzá: %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s hozzárendelte a következőt: %2$s, hozzá: %3$s",
     "Operation #%s does not exist" : "A(z) #%s művelet nem létezik",
-    "Entity %s does not exist" : "A(z) %s entitás nem létezik",
     "Entity %s is invalid" : "A(z) %s entitás érvénytelen",
+    "Entity %s does not exist" : "A(z) %s entitás nem létezik",
     "No events are chosen." : "Nincs kiválasztva esemény.",
     "Entity %s has no event %s" : "A(z) %s entitásnak nincs eseménye %s",
-    "Operation %s does not exist" : "A(z) %s művelet nem létezik",
-    "Operation %s is invalid" : "A(z) #%s művelet érvénytelen",
-    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
     "The provided operation data is too long" : "A megadott műveleti adatok túl hosszúak",
+    "Operation %s is invalid" : "A(z) #%s művelet érvénytelen",
+    "Operation %s does not exist" : "A(z) %s művelet nem létezik",
+    "At least one check needs to be provided" : "Legalább egy ellenőrzést meg kell adni",
     "Invalid check provided" : "Érvénytelen ellenőrzést adott meg",
-    "Check %s does not exist" : "A(z) %s nem létezik, ellenőrizze",
-    "Check %s is invalid" : "A(z) %s érvénytelen, ellenőrizze",
-    "Check %s is not allowed with this entity" : "A(z) %s ellenőrzés nem engedélyezett ezzel az entitással",
     "The provided check value is too long" : "A megadott ellenőrzési érték túl hosszú",
+    "Check %s is invalid" : "A(z) %s érvénytelen, ellenőrizze",
+    "Check %s does not exist" : "A(z) %s nem létezik, ellenőrizze",
+    "Check %s is not allowed with this entity" : "A(z) %s ellenőrzés nem engedélyezett ezzel az entitással",
     "Check #%s does not exist" : "A(z) #%s nem létezik, ellenőrizze",
     "Check %s is invalid or does not exist" : "A(z) %s érvénytelen vagy nem létezik, ellenőrizze",
     "Flow" : "Folyamat",
@@ -56,7 +56,6 @@ OC.L10N.register(
     "PDF documents" : "PDF-dokumentumok",
     "Video" : "Videó",
     "Custom MIME type" : "Egyéni MIME-típus",
-    "Custom mimetype" : "Egyéni MIME-típus",
     "Select a file type" : "Válasszon fájltípust",
     "e.g. httpd/unix-directory" : "például httpd/unix-directory",
     "Please enter a valid time span" : "Érvényes időtartamot adjon meg",
