@@ -10,29 +10,29 @@ namespace OC\Core\AppInfo;
 
 use OCP\Capabilities\ICapability;
 use OCP\Config\IUserConfig;
+use OCP\IConfig;
 use OCP\IDateTimeZone;
-use OCP\IGroupManager;
 use OCP\IUserSession;
 use OCP\Server;
 
 class Capabilities implements ICapability {
 
 	public function __construct(
-		private IUserSession $session,
+		private IUserSession $userSession,
 		private IUserConfig $userConfig,
-		private IGroupManager $groupManager,
+		private IConfig $serverConfig,
 	) {
 	}
 
 	/**
 	 * Return the core capabilities
 	 *
-	 * @return array{core: array{'user'?: array{language: string, locale: string, timezone: string} } }
+	 * @return array{core: array{'user'?: array{language: string, locale: string, timezone: string}, 'can-create-app-token'?: bool } }
 	 */
 	public function getCapabilities(): array {
 		$capabilities = [];
 
-		$user = $this->session->getUser();
+		$user = $this->userSession->getUser();
 		if ($user !== null) {
 			$timezone = Server::get(IDateTimeZone::class)->getTimeZone();
 
@@ -41,6 +41,9 @@ class Capabilities implements ICapability {
 				'locale' => $this->userConfig->getValueString($user->getUID(), Application::APP_ID, ConfigLexicon::USER_LOCALE),
 				'timezone' => $timezone->getName(),
 			];
+
+			$capabilities['can-create-app-token'] = $this->userSession->getImpersonatingUserID() === null
+				&& $this->serverConfig->getSystemValueBool('auth_can_create_app_token', true);
 		}
 
 		return [
