@@ -13,14 +13,17 @@ use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\Attribute\FrontpageRoute;
 use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\JSONResponse;
+use OCP\Contacts\ContactsMenu\IEntry;
 use OCP\IRequest;
 use OCP\IUserSession;
+use OCP\Teams\ITeamManager;
 
 class ContactsMenuController extends Controller {
 	public function __construct(
 		IRequest $request,
 		private IUserSession $userSession,
 		private Manager $manager,
+		private ITeamManager $teamManager,
 	) {
 		parent::__construct('core', $request);
 	}
@@ -31,8 +34,18 @@ class ContactsMenuController extends Controller {
 	 */
 	#[NoAdminRequired]
 	#[FrontpageRoute(verb: 'POST', url: '/contactsmenu/contacts')]
-	public function index(?string $filter = null): array {
-		return $this->manager->getEntries($this->userSession->getUser(), $filter);
+	public function index(?string $filter = null, ?string $teamId = null): array {
+		$entries = $this->manager->getEntries($this->userSession->getUser(), $filter);
+		if ($teamId !== null) {
+			/** @var \OC\Teams\TeamManager */
+			$teamManager = $this->teamManager;
+			$memberIds = $teamManager->getMembersOfTeam($teamId, $this->userSession->getUser()->getUID());
+			$entries['contacts'] = array_filter(
+				$entries['contacts'],
+				fn (IEntry $entry) => in_array($entry->getProperty('UID'), $memberIds, true)
+			);
+		}
+		return $entries;
 	}
 
 	/**
@@ -49,4 +62,13 @@ class ContactsMenuController extends Controller {
 		}
 		return new JSONResponse([], Http::STATUS_NOT_FOUND);
 	}
+
+	/**
+	 * @return \JsonSerializable[]
+	 */
+	#[NoAdminRequired]
+	#[FrontpageRoute(verb: 'GET', url: '/contactsmenu/teams')]
+	public function getTeams(): array {
+		return $this->teamManager->getTeamsForUser($this->userSession->getUser()->getUID());
+	}
 }
