@@ -99,14 +99,6 @@ class AddMissingIndicesListener implements IEventListener {
 			true
 		);
 
-		$event->addMissingIndex(
-			'whats_new',
-			'version',
-			['version'],
-			[],
-			true
-		);
-
 		$event->addMissingIndex(
 			'cards',
 			'cards_abiduri',
@@ -210,5 +202,19 @@ class AddMissingIndicesListener implements IEventListener {
 			'unique_category_per_user',
 			['uid', 'type', 'category']
 		);
+
+		$event->addMissingIndex(
+			'share',
+			'share_with_file_target_index',
+			['share_with', 'file_target'],
+			['lengths' => [null, 128]]
+		);
+
+		$event->addMissingIndex(
+			'share_external',
+			'user_mountpoint_index',
+			['user', 'mountpoint'],
+			['lengths' => [null, 128]]
+		);
 	}
 }
