@@ -31,7 +31,7 @@ class Version13000Date20170718121200 extends SimpleMigrationStep {
 		if ($table->hasColumn('fileid')) {
 			$qb = $this->connection->getQueryBuilder();
 			$qb->delete('properties');
-			$qb->execute();
+			$qb->executeStatement();
 		}
 	}
 
@@ -454,6 +454,7 @@ class Version13000Date20170718121200 extends SimpleMigrationStep {
 			$table->addIndex(['file_source'], 'file_source_index');
 			$table->addIndex(['token'], 'token_index');
 			$table->addIndex(['share_with'], 'share_with_index');
+			$table->addIndex(['share_with', 'file_target'], 'share_with_file_target_index', [], ['lengths' => [null, 128]]);
 			$table->addIndex(['parent'], 'parent_index');
 			$table->addIndex(['uid_owner'], 'owner_index');
 			$table->addIndex(['uid_initiator'], 'initiator_index');
@@ -1008,6 +1009,7 @@ class Version13000Date20170718121200 extends SimpleMigrationStep {
 		$query = $this->connection->getQueryBuilder();
 		$query->select('*')
 			->from('dav_properties');
+		$result = $query->executeQuery();
 
 		$insert = $this->connection->getQueryBuilder();
 		$insert->insert('properties')
@@ -1016,14 +1018,13 @@ class Version13000Date20170718121200 extends SimpleMigrationStep {
 			->setValue('propertyvalue', $insert->createParameter('propertyvalue'))
 			->setValue('userid', $insert->createParameter('userid'));
 
-		$result = $query->execute();
-		while ($row = $result->fetch()) {
+		while ($row = $result->fetchAssociative()) {
 			preg_match('/(calendar)\/([A-z0-9-@_]+)\//', $row['propertypath'], $match);
 			$insert->setParameter('propertypath', (string)$row['propertypath'])
 				->setParameter('propertyname', (string)$row['propertyname'])
 				->setParameter('propertyvalue', (string)$row['propertyvalue'])
 				->setParameter('userid', ($match[2] ?? ''));
-			$insert->execute();
+			$insert->executeStatement();
 		}
 	}
 }
