@@ -76,20 +76,15 @@ OC.L10N.register(
     "Already up to date" : "Yá s'anovó",
     "Unknown" : "Desconocí­u",
     "PNG image" : "Imaxe PNG",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
-    "Update to {version}" : "Anovar a la versión {version}",
-    "An error occurred." : "Prodúxose un error.",
-    "Please reload the page." : "Volvi cargar la páxina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'anovamientu nun foi correutu. Pa consiguir más información, <a href=\"{url}\">comprueba l'artículu del foru</a> que cubre esti problema.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'anovamientu nun foi correutu. Informa d'esti problema na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidá de Nextcloud</a>.",
-    "Continue to {productName}" : "Siguir con «{productName}»",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundu.","L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundos."],
+    "Done" : "Fecho",
     "Applications menu" : "Menú d'aplicaciones",
     "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
     "_{count} notification_::_{count} notifications_" : ["{count} avisu","{count} avisos"],
     "No" : "Non",
     "Yes" : "Sí",
+    "App password" : "Contraseña de l'aplicación",
+    "Grant access" : "Conceder l'accesu",
     "Failed to add the public link to your Nextcloud" : "Nun se pue amestar l'enllaz públicu a esta instancia de Nextcloud",
     "Federated user" : "Usuariu federáu",
     "Create share" : "Crear l'elementu compartíu",
@@ -118,7 +113,6 @@ OC.L10N.register(
     "Log in to {productName}" : "Aniciar la sesión en: {productName}",
     "Wrong login or password." : "El nomatu o la contraseña nun son correutos.",
     "This account is disabled" : "Esta cuenta ta desactivada",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
     "Account name or email" : "Nome o direición de corréu de la cuenta",
     "Server side authentication failed!" : "¡L'autenticación de llau del sirvidor falló!",
     "Please contact your administrator." : "Ponte en contautu cola alministración.",
@@ -180,8 +174,23 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Login form is disabled." : "El formulariu p'aniciar la sesión ta desactiváu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulariu p'aniciar la sesión de Nextcloud ta desactiváu. Usa otra opción p'aniciar la sesión si ta disponible o ponte en contautu cola alministración.",
-    "More actions" : "Más aiciones",
+    "Connect to your account" : "Conectase cola to cuenta",
     "Security warning" : "Alvertencia de seguranza",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si nun tas tentando de configurar un preséu o aplicación nuevos, daquién tenta d'engañate pa que-y concedas l'accesu a los tos datos. Nesi casu nun sigas y ponte en contautu cola alministración.",
+    "Alternative log in using app password" : "Aniciu de la sesión alternativu cola contraseña de l'aplicación",
+    "Account connected" : "Cuenta conectada",
+    "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
+    "You can close this window." : "Pues zarrar esta ventana.",
+    "Account access" : "Accesu a la cuenta",
+    "More actions" : "Más aiciones",
+    "This share is password-protected" : "Esti secrete ta protexíu con una contraseña",
+    "The password is wrong or expired. Please try again or request a new one." : "La contraseña ye incorreuta o caducó. Volvi tentalo o solicita una nueva.",
+    "Submit" : "Unviar",
+    "Please type in your email address to request a temporary password" : "Escribi la to direición de corréu electrónicu pa solicitar una contraseña temporal",
+    "Password sent!" : "¡Unvióse la contraseña!",
+    "You are not authorized to request a password for this share" : "Nun tienes autorización pa solicitar una contraseña pa esta cuenta",
+    "Email address" : "Direición de corréu electrónicu",
+    "Forgot password" : "Contraseña de xuba",
     "Storage & database" : "Almacenamientu y base de datos",
     "Data folder" : "Carpeta de datos",
     "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
@@ -204,6 +213,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
     "Continue with this unsupported browser" : "SIguir con esti restolador incompatible",
     "Supported versions" : "Versiones compatibles",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'anovamientu ta en cursu. Ye posible qu'al colar d'esta páxina s'interrumpa'l procesu en dalgunos entornos.",
+    "App update required" : "Ríquese l'anovamientu de l'aplicación",
+    "These incompatible apps will be disabled:" : "Van desactivase esta aplicaciones incompatibles:",
+    "These apps will be updated:" : "Anovaránse estes aplicaciones:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrate de que se ficiere una copia de seguranza de la base de datos, la carpeta de configuración y la de datos enantes de siguir.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pa impidir que s'escose'l tiempu d'espera coles instalaciones grandes, pues executar el comandu siguiente dende'l direutoriu d'instalación:",
+    "Start update" : "Aniciar l'anovamientu",
+    "Continue to {productName}" : "Siguir con «{productName}»",
+    "Update to {version}" : "Anovar a la versión {version}",
+    "Hide details" : "Esconder los detalles",
+    "Show details" : "Amosar los detalles",
+    "Update needed" : "Anovamientu necesariu",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 cuentes.",
+    "Documentation" : "Documentación",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si sigo col anovamientu pela IU web tengo'l riesgu de que la solicitú escose'l tiempu d'espera y causar una perda de datos, más tengo una copia de seguranza y sé cómo restaurar la instancia en casu de fallu.",
+    "Upgrade via web on my own risk" : "Anovar pela web baxo'l mio riesgu",
     "Choose {file}" : "Escoyer «{file}»",
     "Choose" : "Escoyer",
     "Copy to {target}" : "Copiar a {target}",
@@ -223,20 +248,17 @@ OC.L10N.register(
     "(all selected)" : "(seleicionóse too)",
     "({count} selected)" : "({count} na seleición)",
     "Error loading file exists template" : "Hebo un error al cargar la plantía de ficheru esistente",
+    "Groups" : "Grupos",
+    "Group list is empty" : "La llista de grupos ta balera",
+    "Unable to retrieve the group list" : "Nun ye posible recuperar la llista de grupos",
     "seconds ago" : "hai segundos",
-    "Connection to server lost" : "Perdióse la conexón col sirividor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
     "Add to a project" : "Amestar al proyeutu",
-    "Show details" : "Amosar los detalles",
-    "Hide details" : "Esconder los detalles",
     "Rename project" : "Renomar el proyeutu",
     "Failed to rename the project" : "Nun se pue renomar el proyeutu",
     "Failed to create a project" : "Nun se pue crear el proyeutu",
     "Failed to add the item to the project" : "Nun se pue amestar l'elementu al proyeutu",
     "Connect items to a project to make them easier to find" : "Conecta elementos a un proyeutu pa que seyan más fáciles d'atopar",
     "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
-    "New in" : "Novedá en",
-    "View changelog" : "Ver el rexistru de cambeos",
     "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
     "Email length is at max (255)" : "La llongura de la direición de corréu electrónicu ye la máxima (255)",
     "Personal" : "Personal",
@@ -270,25 +292,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Saltar a la navegación de l'aplicación",
     "Go to %s" : "Dir a «%s»",
     "Get your own free account" : "Consigui la to cuenta gratuíta",
-    "Connect to your account" : "Conectase cola to cuenta",
-    "Please log in before granting %1$s access to your %2$s account." : "Anicia la sesión enantes de conceder l'accesu de %1$s na cuenta %2$s.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si nun tas tentando de configurar un preséu o aplicación nuevos, daquién tenta d'engañate pa que-y concedas l'accesu a los tos datos. Nesi casu nun sigas y ponte en contautu cola alministración.",
-    "App password" : "Contraseña de l'aplicación",
-    "Grant access" : "Conceder l'accesu",
-    "Alternative log in using app password" : "Aniciu de la sesión alternativu cola contraseña de l'aplicación",
-    "Account access" : "Accesu a la cuenta",
-    "Currently logged in as %1$s (%2$s)." : "Aniciesti la sesión como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Tas a piques de conceder a «%1$s» l'accesu a la cuenta %2$s.",
-    "Account connected" : "Cuenta conectada",
-    "Your client should now be connected!" : "¡La cuenta habría tar conectada!",
-    "You can close this window." : "Pues zarrar esta ventana.",
     "Previous" : "Anterior",
-    "This share is password-protected" : "Esti secrete ta protexíu con una contraseña",
-    "The password is wrong or expired. Please try again or request a new one." : "La contraseña ye incorreuta o caducó. Volvi tentalo o solicita una nueva.",
-    "Please type in your email address to request a temporary password" : "Escribi la to direición de corréu electrónicu pa solicitar una contraseña temporal",
-    "Email address" : "Direición de corréu electrónicu",
-    "Password sent!" : "¡Unvióse la contraseña!",
-    "You are not authorized to request a password for this share" : "Nun tienes autorización pa solicitar una contraseña pa esta cuenta",
     "Two-factor authentication" : "Autenticación en dos pasos",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Activóse la seguranza ameyorana pa la to cuenta. Escueyi una autenticación en dos pasos:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nun se pudo cargar, polo menos, unu de los métodos de l'autenticación en dos pasos. Ponte en contautu cola alministración.",
@@ -303,20 +307,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Acceder pente un dominiu que nun ye d'enfotu",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ponte en contautu cola alministración. Si yes alministrador, edita la opción «trusted_domain» en config/config.php como nel ficheru d'exemplu config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pues atopar más más información tocante a cómo configurar esta opción na %1$sdocumentación%2$s.",
-    "App update required" : "Ríquese l'anovamientu de l'aplicación",
-    "%1$s will be updated to version %2$s" : "%1$s va anovase a la versión %2$s",
-    "The following apps will be updated:" : "Van anovase les aplicaciones siguientes:",
-    "These incompatible apps will be disabled:" : "Van desactivase esta aplicaciones incompatibles:",
-    "The theme %s has been disabled." : "Desactivóse l'estilu «%s».",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asegúrate de que se ficiere una copia de seguranza de la base de datos, la carpeta de configuración y la de datos enantes de siguir.",
-    "Start update" : "Aniciar l'anovamientu",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pa impidir que s'escose'l tiempu d'espera coles instalaciones grandes, pues executar el comandu siguiente dende'l direutoriu d'instalación:",
-    "Detailed logs" : "Rexistros detallaos",
-    "Update needed" : "Anovamientu necesariu",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Usa l'anovador de la llinia de comandos porque tienes una instancia grande con más de 50 cuentes.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pa consiguir ayuda, mira la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sé que si sigo col anovamientu pela IU web tengo'l riesgu de que la solicitú escose'l tiempu d'espera y causar una perda de datos, más tengo una copia de seguranza y sé cómo restaurar la instancia en casu de fallu.",
-    "Upgrade via web on my own risk" : "Anovar pela web baxo'l mio riesgu",
     "Maintenance mode" : "Mou de caltenimientu",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s ta nel mou de caltenimientu y pue talo un tiempu",
     "This page will refresh itself when the instance is available again." : "Esta páxina va anovase sola cuando la instancia vuelva tar disponible.",
@@ -331,8 +321,14 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Equí tienes los resultaos de la busca<script>alert(1)</script></strong>",
     "new" : "novedá",
     "_download %n file_::_download %n files_" : ["baxar %n ficheru","baxar %n ficheros"],
+    "An error occurred." : "Prodúxose un error.",
+    "Please reload the page." : "Volvi cargar la páxina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'anovamientu nun foi correutu. Pa consiguir más información, <a href=\"{url}\">comprueba l'artículu del foru</a> que cubre esti problema.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'anovamientu nun foi correutu. Informa d'esti problema na <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidá de Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundu.","L'anovamientu foi correutu. Va redirixísete a {productName} en %n segundos."],
     "Searching …" : "Buscando…",
     "Logging in …" : "Aniciando la sesión…",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dende la to IP, detectemos múltiples intentos d'aniciar la sesión que son inválidos. Poro, el próximu aniciu de la sesión va tardar 30 segundos.",
     "Loading apps …" : "Cargando les aplicaciones…",
     "Installing apps …" : "Instalando les aplicaciones…",
     "Loading your contacts …" : "Cargando los contautos…",
@@ -341,6 +337,10 @@ OC.L10N.register(
     "Loading more results …" : "Cargando más resultaos…",
     "Search {types} …" : "Buscar «{types}»…",
     "Saving …" : "Guardando…",
+    "Connection to server lost" : "Perdióse la conexón col sirividor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Hebo un problema al cargar la páxina, va volver cargase en %n segundu","Hebo un problema al cargar la páxina, va volver cargase en %n segundos"],
+    "New in" : "Novedá en",
+    "View changelog" : "Ver el rexistru de cambeos",
     "Very weak password" : "La contraseña ye mui poco segura",
     "Weak password" : "La contraseña ye poco segura",
     "So-so password" : "La contraseña ye normal",
@@ -361,6 +361,14 @@ OC.L10N.register(
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Namás hai disponible %s.",
     "Database account" : "Cuenta de la base de datos",
-    "Installing …" : "Instalando…"
+    "Installing …" : "Instalando…",
+    "Please log in before granting %1$s access to your %2$s account." : "Anicia la sesión enantes de conceder l'accesu de %1$s na cuenta %2$s.",
+    "Currently logged in as %1$s (%2$s)." : "Aniciesti la sesión como %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Tas a piques de conceder a «%1$s» l'accesu a la cuenta %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s va anovase a la versión %2$s",
+    "The following apps will be updated:" : "Van anovase les aplicaciones siguientes:",
+    "The theme %s has been disabled." : "Desactivóse l'estilu «%s».",
+    "Detailed logs" : "Rexistros detallaos",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pa consiguir ayuda, mira la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>."
 },
 "nplurals=2; plural=(n != 1);");
