@@ -75,14 +75,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Следните приложения са изключени: %s",
     "Already up to date" : "Актуално",
     "Unknown" : "Неизвестен",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
-    "Update to {version}" : "Актуализирай до {version}",
-    "An error occurred." : "Възникна грешка.",
-    "Please reload the page." : "Моля, презаредете страницата.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Актуализацията беше неуспешна. За допълнителна информация <a href=\"{url}\">прегледайте темата</a> относно този проблем.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Актуализирането беше неуспешно. Моля отнесете този проблем към <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> Nextcloud общността</a>.",
-    "Continue to {productName}" : "Продължаване към {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Актуализацията беше успешна. Пренасочване към {productName} след %n секунди.","Актуализацията беше успешна. Пренасочване към {productName} след %n секунди."],
     "Done" : "Завършено",
     "Apps" : "Приложения",
     "More apps" : "Още приложения",
@@ -210,6 +202,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашият браузър не се поддържа. Моля, преминете към по-нова версия или към версия, която се поддържа.",
     "Continue with this unsupported browser" : "Продължете с този неподдържан браузър",
     "Supported versions" : "Поддържани версии",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Актуализирането е в процес, в някой среди - напускането на тази страница може да прекъсне процеса.",
+    "App update required" : "Изисква се актуализиране на приложението",
+    "These incompatible apps will be disabled:" : "Следните несъвместими добавки ще бъдат деактивирани:",
+    "These apps will be updated:" : "Следните добавки ще бъдат актуализирани:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Моля, уверете се, че сте направили копия на базата данни, папките с настройки и данните, преди да продължите.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
+    "Start update" : "Начало на обновяването",
+    "Continue to {productName}" : "Продължаване към {productName}",
+    "Update to {version}" : "Актуализирай до {version}",
+    "Hide details" : "Скриване на подробностите",
+    "Show details" : "Показване на подробности",
+    "Update needed" : "Нужно е актуализиране",
+    "Documentation" : "Документация",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам, че ако продължа да правя актуализацията чрез уеб потребителски интерфейсUI , има риск заявката временно да се прекъсне и може да доведе до загуба на данни, но имам резервно копие и знам как да възстановя своя екземпляр в случай на повреда.",
+    "Upgrade via web on my own risk" : "Актуализиране чрез интернет на собствен риск",
     "Choose {file}" : "Изберете {file}",
     "Choose" : "Избор",
     "Copy to {target}" : "Копиране в {target}",
@@ -234,19 +241,13 @@ OC.L10N.register(
     "Group list is empty" : "Списъкът с групи е празен",
     "Unable to retrieve the group list" : "Не може да се извлече списъкът с групи",
     "seconds ago" : "преди секунди",
-    "Connection to server lost" : "Няма връзка със сървъра",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
     "Add to a project" : "Добавяне към проект",
-    "Show details" : "Показване на подробности",
-    "Hide details" : "Скриване на подробностите",
     "Rename project" : "Преименуване на проект",
     "Failed to rename the project" : "Неуспешно преименуване на проект",
     "Failed to create a project" : "Неуспешно създаване на проект",
     "Failed to add the item to the project" : "Неуспешно добавяне на елемент към проекта",
     "Connect items to a project to make them easier to find" : "Свързване на елементи към проект, за да станат лесни за намиране",
     "Type to search for existing projects" : "Въведете, за търсене на съществуващи проекти",
-    "New in" : "Ново в",
-    "View changelog" : "Преглед на списъка с промени",
     "Close \"{dialogTitle}\" dialog" : "Затваряне на диалогов прозорец \"{dialogTitle}\"",
     "Personal" : "Лични",
     "Accounts" : "Профили",
@@ -294,19 +295,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Достъп през недоверен домейн",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Моля, свържете се с администратора. Ако сте администратор на текущата инстанция, конфигурирайте \"trusted_domains\" настройките в config/config.php. Примерна конфигурация е предоставена в config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Допълнителна информация как да конфигурирате това можете да намерите в %1$sдокументацията%2$s.",
-    "App update required" : "Изисква се актуализиране на приложението",
-    "%1$s will be updated to version %2$s" : "%1$s ще бъде актуализирана до версия %2$s",
-    "The following apps will be updated:" : "Следните приложения ще бъдат актуализирани:",
-    "These incompatible apps will be disabled:" : "Следните несъвместими добавки ще бъдат деактивирани:",
-    "The theme %s has been disabled." : "Темата %s е изключена.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Моля, уверете се, че сте направили копия на базата данни, папките с настройки и данните, преди да продължите.",
-    "Start update" : "Начало на обновяването",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
-    "Detailed logs" : "Подробни журнали",
-    "Update needed" : "Нужно е актуализиране",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помощ, прегледайте <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацията</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам, че ако продължа да правя актуализацията чрез уеб потребителски интерфейсUI , има риск заявката временно да се прекъсне и може да доведе до загуба на данни, но имам резервно копие и знам как да възстановя своя екземпляр в случай на повреда.",
-    "Upgrade via web on my own risk" : "Актуализиране чрез интернет на собствен риск",
     "Maintenance mode" : "Режим на поддръжка",
     "This %s instance is currently in maintenance mode, which may take a while." : "В момента се извършва профилактика на %s, може да продължи дълго.",
     "This page will refresh itself when the instance is available again." : "Страницата ще се зареди автоматично, когато е отново на линия.",
@@ -321,6 +309,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Това са вашите резултати от търсенето<script>сигнал (1)</script></strong>",
     "new" : "нов",
     "_download %n file_::_download %n files_" : ["изтегли %n файл","изтегли %n файла"],
+    "An error occurred." : "Възникна грешка.",
+    "Please reload the page." : "Моля, презаредете страницата.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Актуализацията беше неуспешна. За допълнителна информация <a href=\"{url}\">прегледайте темата</a> относно този проблем.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Актуализирането беше неуспешно. Моля отнесете този проблем към <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\"> Nextcloud общността</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Актуализацията беше успешна. Пренасочване към {productName} след %n секунди.","Актуализацията беше успешна. Пренасочване към {productName} след %n секунди."],
     "Direct link copied to clipboard" : "Директният адрес е копиран в клипборда",
     "Searching …" : "Търсене ...",
     "Logging in …" : "Вписване ...",
@@ -333,6 +326,10 @@ OC.L10N.register(
     "Loading more results …" : "Зарежда още резултати…",
     "Search {types} …" : "Търсене на  {types}  ...",
     "Saving …" : "Записване …",
+    "Connection to server lost" : "Няма връзка със сървъра",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при зареждането на страницата, презареждане след %n секунда","Проблем при зареждането на страницата, презареждане след %n секунди"],
+    "New in" : "Ново в",
+    "View changelog" : "Преглед на списъка с промени",
     "Very weak password" : "Много проста парола",
     "Weak password" : "Проста парола",
     "So-so password" : "Не особено добра парола",
@@ -358,6 +355,11 @@ OC.L10N.register(
     "Installing …" : "В процес на инсталиране…",
     "Please log in before granting %1$s access to your %2$s account." : "Необходимо е да се впишете, преди да дадете достъп на %1$s до вашия %2$s профил.",
     "Currently logged in as %1$s (%2$s)." : "В момента сте влезли като %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил."
+    "You are about to grant %1$s access to your %2$s account." : "Ще разрешите на %1$s да ползва вашия %2$s профил.",
+    "%1$s will be updated to version %2$s" : "%1$s ще бъде актуализирана до версия %2$s",
+    "The following apps will be updated:" : "Следните приложения ще бъдат актуализирани:",
+    "The theme %s has been disabled." : "Темата %s е изключена.",
+    "Detailed logs" : "Подробни журнали",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помощ, прегледайте <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацията</a>."
 },
 "nplurals=2; plural=(n != 1);");
