@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Eingabetext ist zu lang",
     "Requested task type does not exist" : "Angeforderter Aufgabentyp existiert nicht",
     "Necessary language model provider is not available" : "Erforderlicher Sprachmodellanbieter ist nicht verfügbar",
+    "Cannot generate more than 12 images" : "Es können nicht mehr als 12 Bilder erstellt werden",
+    "Cannot generate less than 1 image" : "Es kann nicht weniger als 1 Bild erstellt werden",
     "No text to image provider is available" : "Es ist kein Text-zu-Bild-Anbieter verfügbar",
     "Image not found" : "Bild nicht gefunden",
     "No translation provider available" : "Kein Übersetzungsanbieter verfügbar",
@@ -198,14 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska-Video",
     "Windows Media video" : "Windows Media-Video",
     "AVI video" : "AVI-Video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
-    "Update to {version}" : "Aktualisierung auf {version}",
-    "An error occurred." : "Es ist ein Fehler aufgetreten.",
-    "Please reload the page." : "Bitte die Seite neu laden.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für mehr Informationen <a href=\"{url}\">lies bitte diesen Forenbeitrag</a> zu diesem Thema.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud Community</a>.",
-    "Continue to {productName}" : "Fortfahren zu {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet.","Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet."],
     "Done" : "Erledigt",
     "Scan QR code to log in" : "QR-Code zum Anmelden scannen",
     "Use {productName} mobile client you want to connect to scan the code" : "Den mobilen {productName}-Client wählen, der zum Scannen des Codes verwendet werden soll",
@@ -314,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Lade deine Kontakte …",
     "Looking for {term} …" : "Suche nach {term} …",
     "Search contacts" : "Kontakte suchen",
-    "Reset search" : "Suche zurücksetzen",
+    "Filter by team" : "Nach Team filtern",
+    "All teams" : "Alle Teams",
+    "Search contacts in team {team}" : "Kontakte im Team {team} suchen",
     "Search contacts …" : "Kontakte suchen …",
+    "Reset search" : "Suche zurücksetzen",
     "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
     "No contacts found" : "Keine Kontakte gefunden",
+    "Contacts list" : "Kontaktliste",
     "Show all contacts" : "Alle Kontakte anzeigen",
     "Install the Contacts app" : "Kontakte-App installieren",
     "Search" : "Suche",
@@ -334,19 +332,32 @@ OC.L10N.register(
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
     "Connect to your account" : "Verbinde dich mit deinem Konto",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Bitte anmelden, bevor du \"{client}\" Zugriff auf dein {instanceName}-Konto gewährst.",
     "Security warning" : "Sicherheitswarnung",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Solltest du aktuell nicht versuchen, ein neues Gerät oder eine neue App einzurichten, dann kann es sein, dass jemand versucht, dich dazu zu bewegen, ihm Zugriff auf deine Daten zu gewähren. Fahre in diesem Fall nicht fort, sondern wende dich an deine Administration.",
+    "Log in using password" : "Mit Passwort anmelden",
     "Alternative log in using app password" : "Alternative Anmeldung mittels App-Passwort",
     "Account connected" : "Konto verbunden",
     "Your client should now be connected!" : "Dein Client sollte nun verbunden sein!",
     "You can close this window." : "Du kannst dieses Fenster schließen.",
     "Account access" : "Kontozugriff ",
+    "Currently logged in as {userDisplayName} ({userId})." : "Aktuell angemeldet als {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Du bist dabei, \"{client}\" Zugriff auf dein {instanceName}-Konto zu gewähren.",
     "More actions" : "Weitere Aktionen",
     "User menu" : "Benutzermenü",
     "Your guest name: {user}" : "Dein Gastname: {user}",
     "You are currently not identified." : "Du bist derzeit nicht identifiziert.",
     "Set public name" : "Öffentlichen Namen festlegen",
     "Change public name" : "Öffentlichen Namen ändern",
+    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
+    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte erneut versuchen oder ein neues Passwort anfordern.",
+    "Submit" : "Übermitteln",
+    "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
+    "Password sent!" : "Passwort wurde verschickt",
+    "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
+    "Email address" : "E-Mail-Adresse",
+    "Request password" : "Passwort anfordern",
+    "Forgot password" : "Passwort vergessen",
     "Password is too weak" : "Passwort ist zu schwach",
     "Password is weak" : "Passwort ist schwach",
     "Password is average" : "Passwort ist durchschnittlich",
@@ -389,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
     "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
     "Supported versions" : "Unterstützte Versionen",
+    "The update completed with warnings. Please check the details for more information." : "Das Update wurde mit Warnungen abgeschlossen. Bitte die Details für weitere Informationen überprüfen.",
+    "The update completed successfully." : "Update abgeschlossen.",
+    "Preparing update…" : "Bereite das Update vor …",
+    "You will be redirected to {productName} in {count} seconds." : "Du wirst in {count} Sekunden zu {productName} weitergeleitet.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
+    "App update required" : "App-Aktualisierung notwendig",
+    "{productName} will be updated to version {version}" : "{productName} wird auf Version {version} aktualisiert",
+    "The theme {oldTheme} has been disabled." : "Das Design {oldTheme} wurde deaktiviert.",
+    "These incompatible apps will be disabled:" : "Diese inkompatiblen Apps werden deaktiviert:",
+    "Incompatible apps" : "Inkompatible Apps",
+    "These apps will be updated:" : "Diese Apps werden aktualisiert:",
+    "Apps to update" : "Zu aktualisierende Apps",
+    "{app} from {oldVersion} to {version}" : "{app} von {oldVersion} auf {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bitte stelle vor dem Fortsetzen sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen kannst du stattdessen den folgenden Befehl in deinem Installationsverzeichnis ausführen:",
+    "Start update" : "Aktualisierung starten",
+    "Continue to {productName}" : "Fortfahren zu {productName}",
+    "Update to {version}" : "Aktualisierung auf {version}",
+    "Hide details" : "Details ausblenden",
+    "Show details" : "Details anzeigen",
+    "Update details" : "Updatedetails",
+    "Update needed" : "Aktualisierung erforderlich",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bitte verwende den Kommandozeilen-Updater, da du eine große Installation mit mehr als 50 Konten betreibst.",
+    "Documentation" : "Dokumentation",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mir ist bekannt, dass die Durchführung der Aktualisierung über die Web-Oberfläche das Risiko birgt, dass der Aktualisierungsprozess abgebrochen wird, was zu Datenverlust führen kann. Ich habe eine Sicherung und ich weiss, wie ich im Falle eines Fehlers beim Aktualisieren meine Installation wieder herstellen kann.",
+    "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
     "Search {types} …" : "Suche {types} …",
     "Choose {file}" : "{file} auswählen",
     "Choose" : "Auswählen",
@@ -414,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "Gruppenliste ist leer",
     "Unable to retrieve the group list" : "Gruppenliste konnte nicht abgerufen werden",
     "seconds ago" : "Gerade eben",
-    "Connection to server lost" : "Verbindung zum Server verloren",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
     "Add to a project" : "Zu einem Projekt hinzufügen",
-    "Show details" : "Details anzeigen",
-    "Hide details" : "Details ausblenden",
     "Rename project" : "Projekt umbenennen",
     "Failed to rename the project" : "Projekt konnte nicht umbenannt werden",
     "Failed to create a project" : "Projekt konnte nicht erstellt werden",
     "Failed to add the item to the project" : "Eintrag konnte nicht zum Projekt hinzu gefügt werden",
     "Connect items to a project to make them easier to find" : "Zum leichten Auffinden von Einträgen, diese zu einem Projekt hinzufügen",
     "Type to search for existing projects" : "Nach existierenden Projekten suchen",
-    "New in" : "Neu in",
-    "View changelog" : "Liste der Veränderungen ansehen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
     "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
     "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
@@ -464,12 +495,6 @@ OC.L10N.register(
     "Go to %s" : "%s aufrufen",
     "Get your own free account" : "Hole dir dein eigenes kostenloses Konto",
     "Previous" : "Vorige",
-    "This share is password-protected" : "Diese Freigabe ist passwortgeschützt",
-    "The password is wrong or expired. Please try again or request a new one." : "Das Passwort ist falsch oder abgelaufen. Bitte erneut versuchen oder ein neues Passwort anfordern.",
-    "Please type in your email address to request a temporary password" : "Bitte gib deine E-Mail-Adresse ein, um ein vorläufiges Passwort anzufordern",
-    "Email address" : "E-Mail-Adresse",
-    "Password sent!" : "Passwort wurde verschickt",
-    "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
     "Two-factor authentication" : "Zwei-Faktor-Authentifizierung",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte wähle einen zweiten Faktor für die Authentifizierung:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Mindestens eine deiner Zwei-Faktor-Authentifizierungsmethoden konnte nicht geladen werden. Kontaktiere deine Administration.",
@@ -484,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Zugriff über eine nicht vertrauenswürdige Domain",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du der Administration angehörst,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Weitere Informationen zur Konfiguration finden sich in der %1$sDokumentation%2$s.",
-    "App update required" : "App-Aktualisierung notwendig",
-    "%1$s will be updated to version %2$s" : "%1$s wird auf Version %2$s aktualisiert",
-    "The following apps will be updated:" : "Folgende Apps werden aktualisiert:",
-    "These incompatible apps will be disabled:" : "Diese inkompatiblen Apps werden deaktiviert:",
-    "The theme %s has been disabled." : "Das Design %s wurde deaktiviert.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bitte stelle vor dem Fortsetzen sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
-    "Start update" : "Aktualisierung starten",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen kannst du stattdessen den folgenden Befehl in deinem Installationsverzeichnis ausführen:",
-    "Detailed logs" : "Detaillierte Protokollmeldungen",
-    "Update needed" : "Aktualisierung erforderlich",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bitte verwende den Kommandozeilen-Updater, da du eine große Installation mit mehr als 50 Konten betreibst.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Dokumentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mir ist bekannt, dass die Durchführung der Aktualisierung über die Web-Oberfläche das Risiko birgt, dass der Aktualisierungsprozess abgebrochen wird, was zu Datenverlust führen kann. Ich habe eine Sicherung und ich weiss, wie ich im Falle eines Fehlers beim Aktualisieren meine Installation wieder herstellen kann.",
-    "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
     "Maintenance mode" : "Wartungsmodus",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
     "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
@@ -512,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
     "new" : "Neu",
     "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
+    "An error occurred." : "Es ist ein Fehler aufgetreten.",
+    "Please reload the page." : "Bitte die Seite neu laden.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für mehr Informationen <a href=\"{url}\">lies bitte diesen Forenbeitrag</a> zu diesem Thema.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud Community</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet.","Die Aktualisierung war erfolgreich. Du wirst in %n Sekunden zu {productName} weitergeleitet."],
     "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
     "Searching …" : "Suche …",
     "Logging in …" : "Melde an…",
@@ -524,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Lade weitere Ergebnisse …",
     "Search {types} …" : "Suche {types} …",
     "Saving …" : "Speichern …",
+    "Connection to server lost" : "Verbindung zum Server verloren",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
+    "New in" : "Neu in",
+    "View changelog" : "Liste der Veränderungen ansehen",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
@@ -550,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Installiere …",
     "Please log in before granting %1$s access to your %2$s account." : "Bitte melde dich an, bevor du %1$s Zugriff auf dein %2$s-Konto gewährst.",
     "Currently logged in as %1$s (%2$s)." : "Aktuell angemeldet als %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren."
+    "You are about to grant %1$s access to your %2$s account." : "Du bist dabei, %1$s Zugriff auf dein %2$s-Konto zu gewähren.",
+    "%1$s will be updated to version %2$s" : "%1$s wird auf Version %2$s aktualisiert",
+    "The following apps will be updated:" : "Folgende Apps werden aktualisiert:",
+    "The theme %s has been disabled." : "Das Design %s wurde deaktiviert.",
+    "Detailed logs" : "Detaillierte Protokollmeldungen",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Für weitere Hilfen, schaue bitte in die <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">Dokumentation</a>."
 },
 "nplurals=2; plural=(n != 1);");
