@@ -42,13 +42,17 @@ OC.L10N.register(
     "Not found" : "Not found",
     "Node is locked" : "Node is locked",
     "Bad request" : "Bad request",
+    "Input text is too long" : "Input text is too long",
     "Requested task type does not exist" : "Requested task type does not exist",
     "Necessary language model provider is not available" : "Necessary language model provider is not available",
+    "Cannot generate more than 12 images" : "Cannot generate more than 12 images",
+    "Cannot generate less than 1 image" : "Cannot generate less than 1 image",
     "No text to image provider is available" : "No text to image provider is available",
     "Image not found" : "Image not found",
     "No translation provider available" : "No translation provider available",
     "Could not detect language" : "Could not detect language",
     "Unable to translate" : "Unable to translate",
+    "No valid filters provided" : "No valid filters provided",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Repair step:",
     "Repair info:" : "Repair info:",
@@ -196,28 +200,18 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "unknown text" : "unknown text",
-    "Hello world!" : "Hello world!",
-    "sunny" : "sunny",
-    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
-    "Hello {name}" : "Hello {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
-    "new" : "new",
-    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
-    "Update to {version}" : "Update to {version}",
-    "An error occurred." : "An error occurred.",
-    "Please reload the page." : "Please reload the page.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
-    "Continue to {productName}" : "Continue to {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
+    "Done" : "Done",
+    "Scan QR code to log in" : "Scan QR code to log in",
+    "Use {productName} mobile client you want to connect to scan the code" : "Use {productName} mobile client you want to connect to scan the code",
+    "Code will expire {timeCountdown} or after use" : "Code will expire {timeCountdown} or after use",
     "Applications menu" : "Applications menu",
     "Apps" : "Apps",
     "More apps" : "More apps",
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "No",
     "Yes" : "Yes",
+    "App password" : "App password",
+    "Grant access" : "Grant access",
     "The remote URL must include the user." : "The remote URL must include the user.",
     "Invalid remote URL." : "Invalid remote URL.",
     "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
@@ -233,8 +227,9 @@ OC.L10N.register(
     "Search in current app" : "Search in current app",
     "Clear search" : "Clear search",
     "Search everywhere" : "Search everywhere",
-    "Searching …" : "Searching …",
+    "Searching …" : "Searching …",
     "Start typing to search" : "Start typing to search",
+    "Minimum search length is {minSearchLength} characters" : "Minimum search length is {minSearchLength} characters",
     "No matching results" : "No matching results",
     "Today" : "Today",
     "Last 7 days" : "Last 7 days",
@@ -253,12 +248,13 @@ OC.L10N.register(
     "Results" : "Results",
     "Load more results" : "Load more results",
     "Search in" : "Search in",
+    "Partial matches" : "Partial matches",
     "Log in" : "Log in",
-    "Logging in …" : "Logging in …",
+    "Logging in …" : "Logging in …",
     "Log in to {productName}" : "Log in to {productName}",
     "Wrong login or password." : "Wrong login or password.",
     "This account is disabled" : "This account is disabled",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Too many incorrect login attempts. Please try again in 30 seconds.",
     "Account name or email" : "Account name or email",
     "Account name" : "Account name",
     "Server side authentication failed!" : "Server side authentication failed!",
@@ -268,6 +264,7 @@ OC.L10N.register(
     "An internal error occurred." : "An internal error occurred.",
     "Please try again or contact your administrator." : "Please try again or contact your administrator.",
     "Password" : "Password",
+    "Remember me" : "Remember me",
     "Log in with a device" : "Log in with a device",
     "Login or email" : "Login or email",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
@@ -291,23 +288,34 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
     "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
-    "Loading apps …" : "Loading apps …",
+    "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
     "App download or installation failed" : "App download or installation failed",
     "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
     "Cannot install this app" : "Cannot install this app",
     "Skip" : "Skip",
-    "Installing apps …" : "Installing apps …",
+    "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
+    "Online" : "Online",
+    "Away" : "Away",
+    "Busy" : "Busy",
+    "Do not disturb" : "Do not disturb",
+    "Mute all notifications" : "Mute all notifications",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Appear offline",
     "Avatar of {displayName}" : "Avatar of {displayName}",
     "Settings menu" : "Settings menu",
-    "Loading your contacts …" : "Loading your contacts …",
-    "Looking for {term} …" : "Looking for {term} …",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
     "Search contacts" : "Search contacts",
+    "Filter by team" : "Filter by team",
+    "All teams" : "All teams",
+    "Search contacts in team {team}" : "Search contacts in team {team}",
+    "Search contacts …" : "Search contacts …",
     "Reset search" : "Reset search",
-    "Search contacts …" : "Search contacts …",
     "Could not load your contacts" : "Could not load your contacts",
     "No contacts found" : "No contacts found",
+    "Contacts list" : "Contacts list",
     "Show all contacts" : "Show all contacts",
     "Install the Contacts app" : "Install the Contacts app",
     "Search" : "Search",
@@ -317,18 +325,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
     "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
+    "Loading more results …" : "Loading more results …",
     "Forgot password?" : "Forgot password?",
     "Back to login form" : "Back to login form",
     "Back" : "Back",
     "Login form is disabled." : "Login form is disabled.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "The Nextcloud login form is disabled. Use another login option if available or contact your administration.",
+    "Connect to your account" : "Connect to your account",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Please log in before granting \"{client}\" access to your {instanceName} account.",
+    "Security warning" : "Security warning",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
+    "Log in using password" : "Log in using password",
+    "Alternative log in using app password" : "Alternative log in using app password",
+    "Account connected" : "Account connected",
+    "Your client should now be connected!" : "Your client should now be connected!",
+    "You can close this window." : "You can close this window.",
+    "Account access" : "Account access",
+    "Currently logged in as {userDisplayName} ({userId})." : "Currently logged in as {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "You are about to grant \"{client}\" access to your {instanceName} account.",
     "More actions" : "More actions",
     "User menu" : "User menu",
     "Your guest name: {user}" : "Your guest name: {user}",
     "You are currently not identified." : "You are currently not identified.",
     "Set public name" : "Set public name",
     "Change public name" : "Change public name",
+    "This share is password-protected" : "This share is password-protected",
+    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
+    "Submit" : "Submit",
+    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
+    "Password sent!" : "Password sent!",
+    "You are not authorized to request a password for this share" : "You are not authorised to request a password for this share",
+    "Email address" : "Email address",
+    "Request password" : "Request password",
+    "Forgot password" : "Forgot password",
     "Password is too weak" : "Password is too weak",
     "Password is weak" : "Password is weak",
     "Password is average" : "Password is average",
@@ -340,13 +369,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}",
     "Autoconfig file detected" : "Autoconfig file detected",
     "The setup form below is pre-filled with the values from the config file." : "The setup form below is pre-filled with the values from the config file.",
-    "Security warning" : "Security warning",
     "Create administration account" : "Create administration account",
     "Administration account name" : "Administration account name",
     "Administration account password" : "Administration account password",
     "Storage & database" : "Storage & database",
     "Data folder" : "Data folder",
     "Database configuration" : "Database configuration",
+    "Database type" : "Database type",
     "Only {firstAndOnlyDatabase} is available." : "Only {firstAndOnlyDatabase} is available.",
     "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
     "For more details check out the documentation." : "For more details check out the documentation.",
@@ -354,6 +383,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "You chose SQLite as database.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database connection" : "Database connection",
     "Database user" : "Database user",
     "Database password" : "Database password",
     "Database name" : "Database name",
@@ -361,7 +391,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
     "Database host" : "Database host",
     "localhost" : "localhost",
-    "Installing …" : "Installing …",
+    "Installing …" : "Installing …",
     "Install" : "Install",
     "Need help?" : "Need help?",
     "See the documentation" : "See the documentation",
@@ -370,7 +400,33 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "Search {types} …" : "Search {types} …",
+    "The update completed with warnings. Please check the details for more information." : "The update completed with warnings. Please check the details for more information.",
+    "The update completed successfully." : "The update completed successfully.",
+    "Preparing update…" : "Preparing update…",
+    "You will be redirected to {productName} in {count} seconds." : "You will be redirected to {productName} in {count} seconds.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
+    "App update required" : "App update required",
+    "{productName} will be updated to version {version}" : "{productName} will be updated to version {version}",
+    "The theme {oldTheme} has been disabled." : "The theme {oldTheme} has been disabled.",
+    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
+    "Incompatible apps" : "Incompatible apps",
+    "These apps will be updated:" : "These apps will be updated:",
+    "Apps to update" : "Apps to update",
+    "{app} from {oldVersion} to {version}" : "{app} from {oldVersion} to {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
+    "Start update" : "Start update",
+    "Continue to {productName}" : "Continue to {productName}",
+    "Update to {version}" : "Update to {version}",
+    "Hide details" : "Hide details",
+    "Show details" : "Show details",
+    "Update details" : "Update details",
+    "Update needed" : "Update needed",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Please use the command line updater because you have a big instance with more than 50 accounts.",
+    "Documentation" : "Documentation",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
+    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
+    "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
     "Copy to {target}" : "Copy to {target}",
@@ -390,23 +446,18 @@ OC.L10N.register(
     "(all selected)" : "(all selected)",
     "({count} selected)" : "({count} selected)",
     "Error loading file exists template" : "Error loading file exists template",
-    "Saving …" : "Saving …",
+    "Saving …" : "Saving …",
+    "Groups" : "Groups",
+    "Group list is empty" : "Group list is empty",
+    "Unable to retrieve the group list" : "Unable to retrieve the group list",
     "seconds ago" : "seconds ago",
-    "Connection to server lost" : "Connection to server lost",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
     "Add to a project" : "Add to a project",
-    "Show details" : "Show details",
-    "Hide details" : "Hide details",
     "Rename project" : "Rename project",
     "Failed to rename the project" : "Failed to rename the project",
     "Failed to create a project" : "Failed to create a project",
     "Failed to add the item to the project" : "Failed to add the item to the project",
     "Connect items to a project to make them easier to find" : "Connect items to a project to make them easier to find",
     "Type to search for existing projects" : "Type to search for existing projects",
-    "New in" : "New in",
-    "View changelog" : "View changelog",
-    "No action available" : "No action available",
-    "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
     "Email length is at max (255)" : "Email length is at max (255)",
     "Clipboard not available, please copy manually" : "Clipboard not available, please copy manually",
@@ -443,25 +494,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Skip to navigation of app",
     "Go to %s" : "Go to %s",
     "Get your own free account" : "Get your own free account",
-    "Connect to your account" : "Connect to your account",
-    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
-    "App password" : "App password",
-    "Grant access" : "Grant access",
-    "Alternative log in using app password" : "Alternative log in using app password",
-    "Account access" : "Account access",
-    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
-    "Account connected" : "Account connected",
-    "Your client should now be connected!" : "Your client should now be connected!",
-    "You can close this window." : "You can close this window.",
     "Previous" : "Previous",
-    "This share is password-protected" : "This share is password-protected",
-    "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
-    "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
-    "Email address" : "Email address",
-    "Password sent!" : "Password sent!",
-    "You are not authorized to request a password for this share" : "You are not authorised to request a password for this share",
     "Two-factor authentication" : "Two-factor authentication",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
@@ -476,50 +509,54 @@ OC.L10N.register(
     "Access through untrusted domain" : "Access through untrusted domain",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Further information how to configure this can be found in the %1$sdocumentation%2$s.",
-    "App update required" : "App update required",
-    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
-    "The following apps will be updated:" : "The following apps will be updated:",
-    "These incompatible apps will be disabled:" : "These incompatible apps will be disabled:",
-    "The theme %s has been disabled." : "The theme %s has been disabled.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Please make sure that the database, the config folder and the data folder have been backed up before proceeding.",
-    "Start update" : "Start update",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:",
-    "Detailed logs" : "Detailed logs",
-    "Update needed" : "Update needed",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Please use the command line updater because you have a big instance with more than 50 accounts.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
-    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
     "Maintenance mode" : "Maintenance mode",
     "This %s instance is currently in maintenance mode, which may take a while." : "This %s instance is currently in maintenance mode, which may take a while.",
     "This page will refresh itself when the instance is available again." : "This page will refresh itself when the instance is available again.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
-    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
-    "No crop data provided" : "No crop data provided",
-    "No valid crop data provided" : "No valid crop data provided",
-    "Crop is not square" : "Crop is not square",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
     "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
-    "You have not added any info yet" : "You have not added any info yet",
-    "{user} has not added any info yet" : "{user} has not added any info yet",
-    "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
-    "Edit Profile" : "Edit Profile",
-    "The headline and about sections will show up here" : "The headline and about sections will show up here",
+    "unknown text" : "unknown text",
+    "Hello world!" : "Hello world!",
+    "sunny" : "sunny",
+    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
+    "Hello {name}" : "Hello {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
+    "new" : "new",
+    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "An error occurred." : "An error occurred.",
+    "Please reload the page." : "Please reload the page.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
+    "Direct link copied to clipboard" : "Direct link copied to clipboard",
+    "Searching …" : "Searching …",
+    "Logging in …" : "Logging in …",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds.",
+    "Loading apps …" : "Loading apps …",
+    "Installing apps …" : "Installing apps …",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
+    "Search contacts …" : "Search contacts …",
+    "Loading more results …" : "Loading more results …",
+    "Search {types} …" : "Search {types} …",
+    "Saving …" : "Saving …",
+    "Connection to server lost" : "Connection to server lost",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
+    "New in" : "New in",
+    "View changelog" : "View changelog",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
+    "No action available" : "No action available",
+    "Error fetching contact actions" : "Error fetching contact actions",
     "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
     "Restricted" : "Restricted",
-    "Invisible" : "Invisible",
     "Delete" : "Delete",
     "Rename" : "Rename",
     "Collaborative tags" : "Collaborative tags",
     "No tags found" : "No tags found",
-    "Profile not found" : "Profile not found",
-    "The profile does not exist." : "The profile does not exist.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Create an admin account</strong>",
@@ -530,6 +567,14 @@ OC.L10N.register(
     "Configure the database" : "Configure the database",
     "Only %s is available." : "Only %s is available.",
     "Database account" : "Database account",
-    "Direct link copied to clipboard" : "Direct link copied to clipboard"
+    "Installing …" : "Installing …",
+    "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
+    "Currently logged in as %1$s (%2$s)." : "Currently logged in as %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "You are about to grant %1$s access to your %2$s account.",
+    "%1$s will be updated to version %2$s" : "%1$s will be updated to version %2$s",
+    "The following apps will be updated:" : "The following apps will be updated:",
+    "The theme %s has been disabled." : "The theme %s has been disabled.",
+    "Detailed logs" : "Detailed logs",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
 },
 "nplurals=2; plural=(n != 1);");
