@@ -195,14 +195,6 @@ OC.L10N.register(
     "Matroska video" : "ویدیوی Matroska.",
     "Windows Media video" : "ویدیوی Windows Media.",
     "AVI video" : "ویدیوی AVI.",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
-    "Update to {version}" : "بروزرسانی به  {version}",
-    "An error occurred." : "یک خطا رخ‌داده است.",
-    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
-    "Continue to {productName}" : "به {productName} ادامه دهید.",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید.","به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید."],
     "Done" : "Done",
     "Applications menu" : "منو برنامه‌ها.",
     "Apps" : "  برنامه ها",
@@ -370,6 +362,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "مرورگر شما پشتیبانی نمی‌شود. لطفاً به نسخه جدیدتر یا نسخه پشتیبانی‌شده ارتقا دهید.",
     "Continue with this unsupported browser" : "با این مرورگر پشتیبانی‌نشده ادامه دهید",
     "Supported versions" : "نسخه‌های پشتیبانی شده",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "به روز رسانی در حال انجام است، این صفحه ممکن است روند در برخی از محیط ها را قطع کند.",
+    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
+    "These incompatible apps will be disabled:" : "این برنامه‌های ناسازگار غیر فعال می‌شوند:",
+    "These apps will be updated:" : "این برنامه‌ها بروزرسانی شده‌اند:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "لطفاً قبل از ادامه کار از پایگاه داده، پوشه پیکربندی و پوشه داده‌ها نسخه پشتیبان تهیه کنید.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
+    "Start update" : "اغاز به روز رسانی",
+    "Continue to {productName}" : "به {productName} ادامه دهید.",
+    "Update to {version}" : "بروزرسانی به  {version}",
+    "Hide details" : "مخفی کردن جزئیات",
+    "Show details" : "نمایش جزئیات",
+    "Update needed" : "نیاز به روز رسانی دارد",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "لطفاً از به‌روزرسان خط فرمان استفاده کنید زیرا شما یک نمونه بزرگ با بیش از ۵۰ حساب دارید.",
+    "Documentation" : "مستندات",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "من می‌دانم که اگر به‌روزرسانی را از طریق رابط کاربری وب ادامه دهم، این خطر وجود دارد که درخواست به دلیل انقضای زمان متوقف شده و منجر به از دست رفتن داده‌ها شود، اما من پشتیبان دارم و می‌دانم چگونه در صورت بروز مشکل، نمونه خود را بازیابی کنم.",
+    "Upgrade via web on my own risk" : "ارتقا از طریق وب با مسئولیت خودم",
     "Choose {file}" : "انتخاب {file}",
     "Choose" : "انتخاب کردن",
     "Copy to {target}" : "رونوشت به {target}",
@@ -394,19 +402,13 @@ OC.L10N.register(
     "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
     "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
     "seconds ago" : "ثانیه‌ها پیش",
-    "Connection to server lost" : "اتصال به سرور از دست رفته است",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
     "Add to a project" : "افزودن به یک پروژه",
-    "Show details" : "نمایش جزئیات",
-    "Hide details" : "مخفی کردن جزئیات",
     "Rename project" : "تغییر نام پروژه",
     "Failed to rename the project" : "تغییر نام پروژه ناموفق بود",
     "Failed to create a project" : "ایجاد پروژه ناموفق بود",
     "Failed to add the item to the project" : "افزودن مورد به پروژه ناموفق بود",
     "Connect items to a project to make them easier to find" : "موارد را به یک پروژه متصل کنید تا یافتن آنها آسان‌تر شود",
     "Type to search for existing projects" : "برای جستجوی پروژه‌های موجود تایپ کنید",
-    "New in" : "جدید در",
-    "View changelog" : "مشاهده تغییرات",
     "Close \"{dialogTitle}\" dialog" : "بستن گفتگوی «{dialogTitle}»",
     "Email length is at max (255)" : "طول ایمیل حداکثر (۲۵۵) است",
     "Clipboard not available, please copy manually" : "کلیپ بورد در دسترس نیست، لطفا به صورت دستی کپی کنید",
@@ -457,19 +459,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "دسترسی از طریق دامنه نامعتبر",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "لطفاً با مدیر خود تماس بگیرید. اگر شما مدیر هستید، تنظیمات \"trusted_domains\" را در config/config.php مانند مثال در config.sample.php ویرایش کنید.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "اطلاعات بیشتر در مورد نحوه پیکربندی این مورد را می توانید در %1$sمستندات%2$s بیابید.",
-    "App update required" : "نیاز به بروزرسانی برنامه وجود دارد",
-    "%1$s will be updated to version %2$s" : "%1$s به نسخه %2$s بروزرسانی خواهد شد",
-    "The following apps will be updated:" : "برنامه‌های زیر بروزرسانی خواهند شد:",
-    "These incompatible apps will be disabled:" : "این برنامه‌های ناسازگار غیر فعال می‌شوند:",
-    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "لطفاً قبل از ادامه کار از پایگاه داده، پوشه پیکربندی و پوشه داده‌ها نسخه پشتیبان تهیه کنید.",
-    "Start update" : "اغاز به روز رسانی",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "برای جلوگیری از وقفه در نصب های طولانی تر، شما می توانید دستورات زیر را از مسیر نصبتان اجرا کنید:",
-    "Detailed logs" : "Detailed logs",
-    "Update needed" : "نیاز به روز رسانی دارد",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "لطفاً از به‌روزرسان خط فرمان استفاده کنید زیرا شما یک نمونه بزرگ با بیش از ۵۰ حساب دارید.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "من می‌دانم که اگر به‌روزرسانی را از طریق رابط کاربری وب ادامه دهم، این خطر وجود دارد که درخواست به دلیل انقضای زمان متوقف شده و منجر به از دست رفتن داده‌ها شود، اما من پشتیبان دارم و می‌دانم چگونه در صورت بروز مشکل، نمونه خود را بازیابی کنم.",
-    "Upgrade via web on my own risk" : "ارتقا از طریق وب با مسئولیت خودم",
     "Maintenance mode" : "حالت نگهداری",
     "This %s instance is currently in maintenance mode, which may take a while." : "این نمونه %s در حال حاضر در حالت نگهداری است که ممکن است مدتی طول بکشد.",
     "This page will refresh itself when the instance is available again." : "این صفحه پس از در دسترس قرار گرفتن مجدد نمونه، خود را بازخوانی خواهد کرد.",
@@ -484,6 +473,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>این نتایج جستجوی شماست <script>alert(1)</script> </strong>",
     "new" : "جدید",
     "_download %n file_::_download %n files_" : ["دانلود %n فایل","دانلود %n فایل"],
+    "An error occurred." : "یک خطا رخ‌داده است.",
+    "Please reload the page." : "لطفا صفحه را دوباره بارگیری کنید.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "به روزرسانی ناموفق بود. برای اطلاعات بیشتر <a href=\"{url}\">فروم ما را بررسی کنید</a>",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "به روزرسانی ناموفق بود. لطفا این مسئله را در <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">جامعه Nextcloud</a> گزارش دهید",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید.","به روزرسانی موفقیت آمیز بود. شما در %n ثانیه به {productName} هدایت می‌شوید."],
     "Direct link copied to clipboard" : "لینک مستقیم در کلیپ‌بورد کپی شد.",
     "Searching …" : "جستجوکردن …",
     "Logging in …" : "ورود به سیستم ...",
@@ -496,6 +490,10 @@ OC.L10N.register(
     "Loading more results …" : "در حال بارگذاری نتایج بیشتر ... .",
     "Search {types} …" : "جستجوی {types}...",
     "Saving …" : "ذخیره کردن …",
+    "Connection to server lost" : "اتصال به سرور از دست رفته است",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه","%nمشکل بارگذاری صفحه، بارگیری مجدد در  ثانیه"],
+    "New in" : "جدید در",
+    "View changelog" : "مشاهده تغییرات",
     "Very weak password" : "رمز عبور بسیار ضعیف",
     "Weak password" : "رمز عبور ضعیف",
     "So-so password" : "رمز عبور متوسط",
@@ -522,6 +520,10 @@ OC.L10N.register(
     "Installing …" : "درحال نصب...",
     "Please log in before granting %1$s access to your %2$s account." : "لطفاً قبل از اعطای دسترسی %1$s به حساب %2$s خود وارد شوید.",
     "Currently logged in as %1$s (%2$s)." : "در حال حاضر به عنوان %1$s (%2$s) وارد شده‌اید.",
-    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید."
+    "You are about to grant %1$s access to your %2$s account." : "شما در حال اعطای دسترسی %1$s به حساب %2$s خود هستید.",
+    "%1$s will be updated to version %2$s" : "%1$s به نسخه %2$s بروزرسانی خواهد شد",
+    "The following apps will be updated:" : "برنامه‌های زیر بروزرسانی خواهند شد:",
+    "The theme %s has been disabled." : "قالب %s غیر فعال شد.",
+    "Detailed logs" : "Detailed logs"
 },
 "nplurals=2; plural=(n > 1);");
