@@ -22,6 +22,7 @@ OC.L10N.register(
     "Invalid app password" : "Virheellinen sovellussalasana",
     "Could not complete login" : "Kirjautumista ei voitu suorittaa loppuun",
     "Your login token is invalid or has expired" : "Kirjautumispolettisi on virheellinen tai se on vanhentunut",
+    "Please use original client" : "Käytä alkuperäistä asiakasohjelmistoa",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Tämä Nextcloudin yhteisöjulkaisu ei ole tuettu ja push-ilmoituksia on rajoitettu.",
     "Login" : "Kirjaudu sisään",
     "Unsupported email length (>255)" : "Sähköpostin pituus ei ole tuettu (>255)",
@@ -119,6 +120,7 @@ OC.L10N.register(
     "XML document" : "XML-asiakirja",
     "YAML document" : "YAML-asiakirja",
     "Zip archive" : "Zip-arkisto",
+    "Zstandard archive" : "Zstandard-arkisto",
     "AAC audio" : "AAC-ääni",
     "FLAC audio" : "FLAC-ääni",
     "MPEG-4 audio" : "MPEG-4-ääni",
@@ -161,15 +163,9 @@ OC.L10N.register(
     "Matroska video" : "Matroska-video",
     "Windows Media video" : "Windows Media -video",
     "AVI video" : "AVI-video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
-    "Update to {version}" : "Päivitä versioon {version}",
-    "An error occurred." : "Tapahtui virhe.",
-    "Please reload the page." : "Päivitä sivu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
-    "Continue to {productName}" : "Jatka {productName}iin",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
     "Done" : "Valmis",
+    "Scan QR code to log in" : "Skannaa QR-koodi kirjautuaksesi sisään",
+    "Code will expire {timeCountdown} or after use" : "Koodi vanhenee {timeCountdown} tai kun se on käytetty",
     "Applications menu" : "Sovellusten valikko",
     "Apps" : "Sovellukset",
     "More apps" : "Lisää sovelluksia",
@@ -193,6 +189,7 @@ OC.L10N.register(
     "Search everywhere" : "Etsi kaikkialta",
     "Searching …" : "Haetaan …",
     "Start typing to search" : "Aloita kirjoittaminen hakeaksesi",
+    "Minimum search length is {minSearchLength} characters" : "Haun pituus tulee olla vähintään {minSearchLength} merkkiä",
     "No matching results" : "Ei tuloksia",
     "Today" : "Tänään",
     "Last 7 days" : "Edelliset 7 päivää",
@@ -215,6 +212,7 @@ OC.L10N.register(
     "Log in to {productName}" : "Kirjaudu palveluun {productName}",
     "Wrong login or password." : "Väärä käyttäjätunnus tai salasana.",
     "This account is disabled" : "Tämä tili on poistettu käytöstä",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Liian monta virheellistä sisäänkirjautumisyritystä. Yritä uudelleen 30 sekunnin kuluttua.",
     "Account name or email" : "Tilin nimi tai sähköpostiosoite",
     "Account name" : "Tilin nimi",
     "Server side authentication failed!" : "Palvelimen puoleinen tunnistautuminen epäonnistui!",
@@ -244,6 +242,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Aikatauluta työsi ja tapaamisesi synkronoidusti kaikkien laitteitesi välillä.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Pidä työkaverisi ja kaverisi samassa paikassa vuotamatta heidän yksityisiä tietojaan.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Yksinkertainen sähköpostisovellus, joka toimii yhdessä Tiedostojen, Kontaktien ja Kalenterin kanssa.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Keskustelu, videopuhelut, näytön jako, verkkotapaamiset ja web-konferenssit – selaimessasi ja puhelinsovelluksilla.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Asiakirjat, laskentataulukot ja esitykset yhteistyönä, taustavoimana Collabora Online.",
     "Distraction free note taking app." : "Häiriötön mustiinpanosovellus.",
     "Recommended apps" : "Suositellut sovellukset",
@@ -264,6 +263,7 @@ OC.L10N.register(
     "Appear offline" : "Näytä olevan poissa",
     "Settings menu" : "Asetusvalikko",
     "Search contacts" : "Etsi yhteystietoja",
+    "Filter by team" : "Suodata tiimin perusteella",
     "Reset search" : "Tyhjennä haku",
     "Could not load your contacts" : "Yhteystietojasi ei voitu ladata",
     "No contacts found" : "Yhteystietoja ei löytynyt",
@@ -285,6 +285,7 @@ OC.L10N.register(
     "Connect to your account" : "Yhdistä tiliisi",
     "Security warning" : "Turvallisuusvaroitus",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
+    "Log in using password" : "Kirjaudu sisään salasanalla",
     "Alternative log in using app password" : "Vaihtoehtoinen kirjautuminen käyttäen sovellussalasanaa",
     "Account connected" : "Tili yhdistetty",
     "Your client should now be connected!" : "Päätteesi pitäisi olla yhdistetty!",
@@ -343,6 +344,31 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
     "Continue with this unsupported browser" : "Jatka tällä tuen ulkopuolella olevalla selaimella",
     "Supported versions" : "Tuetut versiot",
+    "The update completed with warnings. Please check the details for more information." : "Päivitys valmistui varoitusten kera. Tarkista yksityiskohdat saadaksesi lisätietoja.",
+    "The update completed successfully." : "Päivitys valmistui onnistuneesti.",
+    "Preparing update…" : "Valmistellaan päivitystä…",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Päivitys on meneillään. Poistuminen tältä sivulta saattaa keskeyttää toimenpiteen joissain käyttöympäristöissä.",
+    "App update required" : "Sovelluksen päivittäminen vaaditaan",
+    "{productName} will be updated to version {version}" : "{productName} päivitetään versioon {version}",
+    "The theme {oldTheme} has been disabled." : "Teema {oldTheme} on poistettu käytöstä.",
+    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
+    "Incompatible apps" : "Yhteensopimattomia sovelluksia",
+    "These apps will be updated:" : "Nämä sovellukset päivitetään:",
+    "Apps to update" : "Päivitettävät sovellukset",
+    "{app} from {oldVersion} to {version}" : "{app} versiosta {oldVersion} versioon {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
+    "Start update" : "Käynnistä päivitys",
+    "Continue to {productName}" : "Jatka {productName}iin",
+    "Update to {version}" : "Päivitä versioon {version}",
+    "Hide details" : "Piilota tiedot",
+    "Show details" : "Näytä tiedot",
+    "Update details" : "Päivityksen tiedot",
+    "Update needed" : "Päivitys vaaditaan",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Käytä komentorivin päivitysohjelmaa, koska sinulla on suuri palvelininstanssi (yli 50 tiliä).",
+    "Documentation" : "Dokumentaatio",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
+    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
     "Search {types} …" : "Etsi {types} …",
     "Choose {file}" : "Valitse {file}",
     "Choose" : "Valitse",
@@ -368,19 +394,13 @@ OC.L10N.register(
     "Group list is empty" : "Ryhmälista on tyhjä",
     "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
     "seconds ago" : "sekunteja sitten",
-    "Connection to server lost" : "Yhteys palvelimelle katkesi",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
     "Add to a project" : "Lisää projektiin",
-    "Show details" : "Näytä tiedot",
-    "Hide details" : "Piilota tiedot",
     "Rename project" : "Nimeä projekti uudelleen",
     "Failed to rename the project" : "Projektin nimeäminen uudelleen epäonnistui",
     "Failed to create a project" : "Projektin luominen epäonnistui",
     "Failed to add the item to the project" : "Kohteen lisääminen projektiin epäonnistui",
     "Connect items to a project to make them easier to find" : "Yhdistä kohteita projektiin tehdäksesi niiden löytämisestä helpompaa",
     "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
-    "New in" : "Uutta versiossa",
-    "View changelog" : "Katso muutosloki",
     "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
     "Email length is at max (255)" : "Sähköpostin pituus on maksimissaan (255)",
     "Clipboard not available, please copy manually" : "Leikepöytä ei ole saatavilla, kopioi manuaalisesti",
@@ -430,20 +450,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Käyttö epäluotettavasta toimialueesta",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ota yhteys ylläpitoon, tai jos olet tämän palvelun ylläpitäjä, määritä \"trusted_domains\"-asetus config/config.php-tiedostossa. Esimerkkimääritys on tiedostossa config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Lisätietoa tämän määrittämisestä löydät %1$sdokumentaatiosta%2$s.",
-    "App update required" : "Sovelluksen päivittäminen vaaditaan",
-    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
-    "The following apps will be updated:" : "Seuraavat sovellukset päivitetään:",
-    "These incompatible apps will be disabled:" : "Nämä yhteensopimattomat sovellukset poistetaan käytöstä:",
-    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Varmista ennen jatkamista, että tietokanta, asetuskansio ja datakansio on varmuuskopioitu.",
-    "Start update" : "Käynnistä päivitys",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Välttääksesi aikakatkaisuja suurikokoisten asennusten kanssa, voit suorittaa vaihtoehtoisesti seuraavan komennon asennushakemistossa:",
-    "Detailed logs" : "Yksityiskohtainen loki",
-    "Update needed" : "Päivitys vaaditaan",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Käytä komentorivin päivitysohjelmaa, koska sinulla on suuri palvelininstanssi (yli 50 tiliä).",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tiedän että jos jatkan päivittämistä web-liittymän kautta, saatan menettää kaikki tiedostot, mikäli päivitys epäonnistuu. Onneksi olen tehnyt varmuuskopion ja osaan sen myös palauttaa tarvittaessa.",
-    "Upgrade via web on my own risk" : "Internetin kautta päivittäminen omalla vastuulla",
     "Maintenance mode" : "Huoltotila",
     "This %s instance is currently in maintenance mode, which may take a while." : "Tämä %s-instanssi on parhaillaan huoltotilassa, huollossa saattaa kestää hetki.",
     "This page will refresh itself when the instance is available again." : "Tämä sivu päivittyy itsestään, kun instanssi on jälleen käytettävissä.",
@@ -458,6 +464,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Nämä ovat hakutulokset<script>alert(1)</script></strong>",
     "new" : "uusi",
     "_download %n file_::_download %n files_" : ["lataa %n tiedosto","lataa %n tiedostoa"],
+    "An error occurred." : "Tapahtui virhe.",
+    "Please reload the page." : "Päivitä sivu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Päivitys epäonnistui. Katso lisätietoja tähän ongelmaan liittyen <a href=\"{url}\">keskustelupalstan viestistä</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Päivitys ei onnistunut. Raportoisitko tämän ongelman <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-yhteisölle</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua.","Päivitys onnistui. Ohjataan {productName}iin %n sekunnin kuluttua."],
     "Direct link copied to clipboard" : "Suora linkki kopioitu työpöydälle",
     "Searching …" : "Haetaan…",
     "Logging in …" : "Kirjaudutaan sisään...",
@@ -470,6 +481,10 @@ OC.L10N.register(
     "Loading more results …" : "Ladataan lisää tuloksia…",
     "Search {types} …" : "Etsi {types}…",
     "Saving …" : "Tallennetaan…",
+    "Connection to server lost" : "Yhteys palvelimelle katkesi",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua","Ongelma sivun lataamisessa, päivitetään %n sekunnin kuluttua"],
+    "New in" : "Uutta versiossa",
+    "View changelog" : "Katso muutosloki",
     "Very weak password" : "Erittäin heikko salasana",
     "Weak password" : "Heikko salasana",
     "So-so password" : "Kohtalainen salasana",
@@ -494,6 +509,11 @@ OC.L10N.register(
     "Only %s is available." : "Vain %s on käytettävissä.",
     "Database account" : "Tietokantatili",
     "Installing …" : "Asennetaan …",
-    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s)."
+    "Currently logged in as %1$s (%2$s)." : "Kirjautuneena käyttäjänä %1$s (%2$s).",
+    "%1$s will be updated to version %2$s" : "%1$s päivitetään versioon %2$s",
+    "The following apps will be updated:" : "Seuraavat sovellukset päivitetään:",
+    "The theme %s has been disabled." : "Teema %s on poistettu käytöstä.",
+    "Detailed logs" : "Yksityiskohtainen loki",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Jos tarvitset apua, katso <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ohjeista</a>."
 },
 "nplurals=2; plural=(n != 1);");
