@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Le texte saisi est trop long",
     "Requested task type does not exist" : "Le type de tâche demandé n’existe pas",
     "Necessary language model provider is not available" : "Le fournisseur de modèle de langage nécessaire n’est pas disponible",
+    "Cannot generate more than 12 images" : "Impossible de générer plus de 12 images",
+    "Cannot generate less than 1 image" : "Impossible de générer moins d'une image",
     "No text to image provider is available" : "Aucun fournisseur de texte vers image n’est disponible",
     "Image not found" : "Image non trouvée",
     "No translation provider available" : "Aucun fournisseur de traduction n’est disponible",
@@ -198,15 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Vidéo Matroska",
     "Windows Media video" : "Vidéo Windows Media",
     "AVI video" : "Vidéo AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
-    "Update to {version}" : "Mettre à jour vers {version}",
-    "An error occurred." : "Une erreur est survenue.",
-    "Please reload the page." : "Veuillez recharger la page.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d’informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mise à jour a échoué. Veuillez reporter le problème à la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">communauté Nextcloud</a>.",
-    "Continue to {productName}" : "Continuer vers {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes."],
     "Done" : "Terminé",
+    "Scan QR code to log in" : "Scannez le QR code pour vous connecter",
+    "Use {productName} mobile client you want to connect to scan the code" : "Utilisez le client mobile {productName} que vous voulez connecter pour scanner le code",
+    "Code will expire {timeCountdown} or after use" : "Le code expirera dans {timeCountdown} ou après utilisation",
     "Applications menu" : "Menu des applications",
     "Apps" : "Applications",
     "More apps" : "Plus d’applications",
@@ -310,10 +307,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Chargement de vos contacts...",
     "Looking for {term} …" : "Recherche de {term}...",
     "Search contacts" : "Rechercher des contacts",
-    "Reset search" : "Réinitialiser la recherche",
+    "Filter by team" : "Filtrer par équipe",
+    "All teams" : "Toutes les équipes",
+    "Search contacts in team {team}" : "Rechercher des contacts dans l'équipe {team}",
     "Search contacts …" : "Rechercher un contact...",
+    "Reset search" : "Réinitialiser la recherche",
     "Could not load your contacts" : "Impossible de charger vos contacts",
     "No contacts found" : "Aucun contact trouvé",
+    "Contacts list" : "Liste des contacts",
     "Show all contacts" : "Afficher tous les contacts",
     "Install the Contacts app" : "Installer l’appli Contacts",
     "Search" : "Rechercher",
@@ -330,19 +331,32 @@ OC.L10N.register(
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez un administrateur.",
     "Connect to your account" : "Connectez-vous à votre compte",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Veuillez vous connecter avant d'autoriser \"{client}\" à accéder à votre compte {instanceName}.",
     "Security warning" : "Avertissement de sécurité",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
+    "Log in using password" : "Se connecter avec un mot de passe",
     "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
     "Account connected" : "Compte connecté",
     "Your client should now be connected!" : "Votre client devrait maintenant être connecté !",
     "You can close this window." : "Vous pouvez fermer cette fenêtre.",
     "Account access" : "Accès au compte",
+    "Currently logged in as {userDisplayName} ({userId})." : "Connecté en tant que {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Vous êtes sur le point d'accorder à \"{client}\" l'accès à votre compte \"{instanceName}\".",
     "More actions" : "Plus d'actions",
     "User menu" : "Menu utilisateur",
     "Your guest name: {user}" : "Votre nom d'invité : {user}",
     "You are currently not identified." : "Vous n'êtes actuellement pas identifié.",
     "Set public name" : "Définir le nom public",
     "Change public name" : "Changer le nom public",
+    "This share is password-protected" : "Ce partage est protégé par mot de passe",
+    "The password is wrong or expired. Please try again or request a new one." : "Le mot de passe est incorrect ou expiré. Ré-essayez ou demandez-en un nouveau.",
+    "Submit" : "Envoyer",
+    "Please type in your email address to request a temporary password" : "Veuillez saisir votre adresse e-mail pour recevoir un mot de passe temporaire",
+    "Password sent!" : "Mot de passe envoyé !",
+    "You are not authorized to request a password for this share" : "Vous n'êtes pas autorisé à demander un mot de passe pour ce partage",
+    "Email address" : "Adresse e-mail",
+    "Request password" : "Demande de mot de passe",
+    "Forgot password" : "Mot de passe oublié",
     "Password is too weak" : "Mot de passe trop faible",
     "Password is weak" : "Mot de passe faible",
     "Password is average" : "Mot de passe moyen",
@@ -385,6 +399,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
     "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
     "Supported versions" : "Versions supportées",
+    "The update completed with warnings. Please check the details for more information." : "La mise à jour s'est terminée avec des avertissements. Veuillez vérifier les détails pour plus d'informations.",
+    "The update completed successfully." : "La mise à jour s'est terminée avec succès.",
+    "Preparing update…" : "Préparation de la mise à jour…",
+    "You will be redirected to {productName} in {count} seconds." : "Vous allez être redirigé vers {productName} dans {count} secondes.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
+    "App update required" : "Mise à jour de l’application nécessaire",
+    "{productName} will be updated to version {version}" : "{productName} sera mis à jour vers la version {version}",
+    "The theme {oldTheme} has been disabled." : "Le thème {oldTheme} a été désactivé.",
+    "These incompatible apps will be disabled:" : "Ces applications incompatibles ont été désactivées :",
+    "Incompatible apps" : "Applis incompatibles",
+    "These apps will be updated:" : "Les applications suivantes seront mises à jour :",
+    "Apps to update" : "Applis à mettre à jour",
+    "{app} from {oldVersion} to {version}" : "{app} de {oldVersion} vers {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu’une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
+    "Start update" : "Démarrer la mise à jour",
+    "Continue to {productName}" : "Continuer vers {productName}",
+    "Update to {version}" : "Mettre à jour vers {version}",
+    "Hide details" : "Masquer les détails",
+    "Show details" : "Afficher les détails",
+    "Update details" : "Détails de la mise à jour",
+    "Update needed" : "Mise à jour nécessaire",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 comptes.",
+    "Documentation" : "Documentation",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Je sais que si je continue à faire la mise à jour via le navigateur web, il existe le risque que la requête se heurte à un délai d'expiration et peut causer une perte de données, mais j'ai une copie de sauvegarde et je sais comment restaurer mon instance en cas d'échec.",
+    "Upgrade via web on my own risk" : "Mettre à jour via le navigateur web à mes propres risques",
     "Search {types} …" : "Rechercher {types}…",
     "Choose {file}" : "Choisir {file}",
     "Choose" : "Choisir",
@@ -410,19 +450,13 @@ OC.L10N.register(
     "Group list is empty" : "La liste des groupes est vide",
     "Unable to retrieve the group list" : "Impossible de récupérer la liste des groupes",
     "seconds ago" : "Il y a quelques secondes",
-    "Connection to server lost" : "La connexion au serveur a été perdue",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
     "Add to a project" : "Ajouter à un projet",
-    "Show details" : "Afficher les détails",
-    "Hide details" : "Masquer les détails",
     "Rename project" : "Renommer le projet",
     "Failed to rename the project" : "Impossible de renommer le projet",
     "Failed to create a project" : "Impossible de créer un projet",
     "Failed to add the item to the project" : "Impossible d'ajouter l'élément au projet",
     "Connect items to a project to make them easier to find" : "Reliez des éléments à un projet pour les retrouver plus facilement",
     "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
-    "New in" : "Nouveau dans",
-    "View changelog" : "Voir le journal des modifications",
     "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue « {dialogTitle} »",
     "Email length is at max (255)" : "La longueur de l'e-mail est au maximum (255)",
     "Clipboard not available, please copy manually" : "Le presse-papier n'est pas disponible, veuillez copier manuellement",
@@ -460,12 +494,6 @@ OC.L10N.register(
     "Go to %s" : "Aller à %s",
     "Get your own free account" : "Obtenez votre compte personnel gratuit",
     "Previous" : "Précédent",
-    "This share is password-protected" : "Ce partage est protégé par mot de passe",
-    "The password is wrong or expired. Please try again or request a new one." : "Le mot de passe est incorrect ou expiré. Ré-essayez ou demandez-en un nouveau.",
-    "Please type in your email address to request a temporary password" : "Veuillez saisir votre adresse e-mail pour recevoir un mot de passe temporaire",
-    "Email address" : "Adresse e-mail",
-    "Password sent!" : "Mot de passe envoyé !",
-    "You are not authorized to request a password for this share" : "Vous n'êtes pas autorisé à demander un mot de passe pour ce partage",
     "Two-factor authentication" : "Authentification à double facteur",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sécurité renforcée est activée pour votre compte. Choisissez un second facteur pour l'authentification :",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossible de charger au moins l'une de vos méthodes activées d'authentification à deux facteurs . Veuillez contacter votre administrateur.",
@@ -480,20 +508,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Accès à partir d'un domaine non approuvé",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Veuillez contacter votre administrateur. Si vous êtes un administrateur, modifiez la variable « trusted_domains » dans le fichier config/config.php comme l’exemple dans le fichier config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Vous trouverez d'autres informations sur la configuration dans la %1$sdocumentation %2$s.",
-    "App update required" : "Mise à jour de l’application nécessaire",
-    "%1$s will be updated to version %2$s" : "%1$s sera mis à jour vers la version %2$s",
-    "The following apps will be updated:" : "Les applications suivantes vont être mises à jour :",
-    "These incompatible apps will be disabled:" : "Ces applications incompatibles ont été désactivées :",
-    "The theme %s has been disabled." : "Le thème %s a été désactivé.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu’une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
-    "Start update" : "Démarrer la mise à jour",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
-    "Detailed logs" : "Logs détaillés",
-    "Update needed" : "Mise à jour nécessaire",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 comptes.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Je sais que si je continue à faire la mise à jour via le navigateur web, il existe le risque que la requête se heurte à un délai d'expiration et peut causer une perte de données, mais j'ai une copie de sauvegarde et je sais comment restaurer mon instance en cas d'échec.",
-    "Upgrade via web on my own risk" : "Mettre à jour via le navigateur web à mes propres risques",
     "Maintenance mode" : "Mode maintenance",
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
     "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
@@ -508,6 +522,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
     "new" : "nouveau ",
     "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
+    "An error occurred." : "Une erreur est survenue.",
+    "Please reload the page." : "Veuillez recharger la page.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d’informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mise à jour a échoué. Veuillez reporter le problème à la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">communauté Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes."],
     "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers",
     "Searching …" : "Recherche…",
     "Logging in …" : "Connexion…",
@@ -520,6 +539,10 @@ OC.L10N.register(
     "Loading more results …" : "Chargement de plus de résultats …",
     "Search {types} …" : "Rechercher {types}…",
     "Saving …" : "Enregistrement...",
+    "Connection to server lost" : "La connexion au serveur a été perdue",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
+    "New in" : "Nouveau dans",
+    "View changelog" : "Voir le journal des modifications",
     "Very weak password" : "Mot de passe très faible",
     "Weak password" : "Mot de passe faible",
     "So-so password" : "Mot de passe tout juste acceptable",
@@ -546,6 +569,11 @@ OC.L10N.register(
     "Installing …" : "Installation...",
     "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s »."
+    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s ».",
+    "%1$s will be updated to version %2$s" : "%1$s sera mis à jour vers la version %2$s",
+    "The following apps will be updated:" : "Les applications suivantes vont être mises à jour :",
+    "The theme %s has been disabled." : "Le thème %s a été désactivé.",
+    "Detailed logs" : "Logs détaillés",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
