@@ -198,15 +198,10 @@ OC.L10N.register(
     "Matroska video" : "Matroska-videó",
     "Windows Media video" : "Windows Media-videó",
     "AVI video" : "AVI-videó",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása egyes környezetekben megszakíthatja a folyamatot.",
-    "Update to {version}" : "Frissítés erre: {version}",
-    "An error occurred." : "Hiba történt.",
-    "Please reload the page." : "Frissítse az oldalt.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a problémáról szóló fórumbejegyzésünket</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
-    "Continue to {productName}" : "Tovább erre: {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}.","A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}."],
     "Done" : "Kész",
+    "Scan QR code to log in" : "Olvassa le a QR-kódot a bejelentkezéshez",
+    "Use {productName} mobile client you want to connect to scan the code" : "Használja a hozzákapcsolandó {productName} mobilklienst a kód leolvasásához",
+    "Code will expire {timeCountdown} or after use" : "A kód {timeCountdown} vagy a használat után lejár",
     "Applications menu" : "Alkalmazások menü",
     "Apps" : "Alkalmazások",
     "More apps" : "További alkalmazások",
@@ -251,11 +246,13 @@ OC.L10N.register(
     "Results" : "Eredmények",
     "Load more results" : "További találatok betöltése",
     "Search in" : "Keresés ebben:",
+    "Partial matches" : "Részleges egyezések",
     "Log in" : "Bejelentkezés",
     "Logging in …" : "Bejelentkezés…",
     "Log in to {productName}" : "Bejelentkezés ebbe: {productName}",
     "Wrong login or password." : "Hibás bejelentkezés vagy jelszó.",
     "This account is disabled" : "Ez a fiók le van tiltva",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Túl sok helytelen bejelentkezési kísérlet. Próbálja újra 30 másodperc múlva.",
     "Account name or email" : "Fióknév vagy e-mail-cím",
     "Account name" : "Fiók neve",
     "Server side authentication failed!" : "A kiszolgálóoldali hitelesítés sikertelen.",
@@ -265,7 +262,7 @@ OC.L10N.register(
     "An internal error occurred." : "Belső hiba történt.",
     "Please try again or contact your administrator." : "Próbálja meg újra, vagy vegye fel a kapcsolatot a rendszergazdával.",
     "Password" : "Jelszó",
-    "Remember me" : "Emlékeztetés később",
+    "Remember me" : "Bejelentkezés megjegyzése",
     "Log in with a device" : "Bejelentkezés eszközzel",
     "Login or email" : "Bejelentkezés vagy e-mail",
     "Your account is not setup for passwordless login." : "A fiókja nincs beállítva jelszómentes bejelentkezésre.",
@@ -309,10 +306,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Névjegyek betöltése…",
     "Looking for {term} …" : "{term} keresése…",
     "Search contacts" : "Névjegyek keresése",
-    "Reset search" : "Keresés visszaállítása",
+    "Filter by team" : "Szűrés csapat szerint",
+    "All teams" : "Összes csapat",
+    "Search contacts in team {team}" : "Névjegyek keresése a(z) {team} csapatban",
     "Search contacts …" : "Névjegyek keresése…",
+    "Reset search" : "Keresés visszaállítása",
     "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
     "No contacts found" : "Nem találhatók névjegyek",
+    "Contacts list" : "Névjegylista",
     "Show all contacts" : "Összes névjegy megjelenítése",
     "Install the Contacts app" : "A Névjegyek alkalmazás telepítése",
     "Search" : "Keresés",
@@ -329,13 +330,17 @@ OC.L10N.register(
     "Login form is disabled." : "A bejelentkezési űrlap letiltva.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "A Nextcloud bejelentkezési űrlap le van tiltva. Használjon más bejelentkezési lehetőséget, ha van ilyen, vagy lépjen kapcsolatba az adminisztrációval.",
     "Connect to your account" : "Kapcsolódás a fiókjához",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Jelentkezzen be mielőtt hozzáférést biztosít a(z) „{client}” számára ehhez a fiókjához: {instanceName}.",
     "Security warning" : "Biztonsági figyelmeztetés",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ha nem új eszközt vagy alkalmazást próbál beállítani, akkor valaki megpróbálja becsapni, hogy hozzáférést biztosítson számára az adatokhoz. Ebben az esetben ne folytassa, hanem lépjen kapcsolatba a rendszergazdával.",
+    "Log in using password" : "Bejelentkezés jelszó használatával ",
     "Alternative log in using app password" : "Alternatív bejelentkezés alkalmazásjelszó segítségével",
     "Account connected" : "Fiók csatlakoztatva",
     "Your client should now be connected!" : "A kliens most már kapcsolódik.",
     "You can close this window." : "Bezárhatja ezt az ablakot.",
     "Account access" : "Fiókhozzáférés",
+    "Currently logged in as {userDisplayName} ({userId})." : "Jelenleg bejelentkezve: {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Hozzáférést készül biztosítani a(z) „{client}” számára ehhez a fiókjához: {instanceName}.",
     "More actions" : "További műveletek",
     "User menu" : "Felhasználói menü",
     "Your guest name: {user}" : "A vendég neve: {user}",
@@ -393,6 +398,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "A böngészője nem támogatott. Frissítsen újabb verzióra, vagy váltson egy támogatott böngészőre.",
     "Continue with this unsupported browser" : "Folytatás ezzel a nem támogatott böngészővel",
     "Supported versions" : "Támogatott verziók",
+    "The update completed with warnings. Please check the details for more information." : "A frissítés figyelmeztetésekkel fejeződött be. További információkért ellenőrizze a részleteket.",
+    "The update completed successfully." : "A frissítés sikeresen befejeződött",
+    "Preparing update…" : "Frissítés előkészítése…",
+    "You will be redirected to {productName} in {count} seconds." : "{count} másodpercen belül át lesz irányítva ide: {productName}.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A frissítés folyamatban van, az oldal elhagyása egyes környezetekben megszakíthatja a folyamatot.",
+    "App update required" : "Alkalmazásfrissítés szükséges",
+    "{productName} will be updated to version {version}" : "A(z) {productName} frissítve lesz erre a verzióra: {version}",
+    "The theme {oldTheme} has been disabled." : "A(z) {oldTheme} téma le lett tiltva.",
+    "These incompatible apps will be disabled:" : "A következő nem kompatibilis alkalmazások le lesznek tiltva:",
+    "Incompatible apps" : "Nem kompatibilis alkalmazások",
+    "These apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
+    "Apps to update" : "Frissítendő alkalmazások",
+    "{app} from {oldVersion} to {version}" : "{app} erről: {oldVersion}, erre: {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatmappa tartalmát, mielőtt folytatja.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "A nagy méretű telepítések által okozott időtúllépések elkerülése érdekében, inkább futtassa a következő parancsot a telepítési alkönyvtárban:",
+    "Start update" : "A frissítés megkezdése",
+    "Continue to {productName}" : "Tovább erre: {productName}",
+    "Update to {version}" : "Frissítés erre: {version}",
+    "Hide details" : "Részletek elrejtése",
+    "Show details" : "Részletek megjelenítése",
+    "Update details" : "Frissítés részletei",
+    "Update needed" : "Frissítés szükséges",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Használja a parancssori frissítőt, mert 50 fiókosnál nagyobb példánya van.",
+    "Documentation" : "Dokumentáció",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tudomásul veszem, hogy a webes frissítési felület használata közben fellépő időtúllépés adatvesztéssel járhat. Van biztonsági mentésem, hiba esetén tudom, hogyan állítsam vissza az adatokat.",
+    "Upgrade via web on my own risk" : "Frissítés weben keresztül, saját felelősségre",
     "Search {types} …" : "{types} keresése…",
     "Choose {file}" : "{file} kiválasztása",
     "Choose" : "Válasszon",
@@ -418,19 +449,13 @@ OC.L10N.register(
     "Group list is empty" : "A csoportlista üres",
     "Unable to retrieve the group list" : "A csoportlista betöltése sikertelen",
     "seconds ago" : "pár másodperce",
-    "Connection to server lost" : "A kapcsolat megszakadt a kiszolgálóval",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probléma az oldal betöltésekor, újratöltés %n másodperc múlva","Probléma az oldal betöltésekor, újratöltés %n másodperc múlva"],
     "Add to a project" : "Hozzáadás egy projekthez",
-    "Show details" : "Részletek megjelenítése",
-    "Hide details" : "Részletek elrejtése",
     "Rename project" : "Projekt átnevezése",
     "Failed to rename the project" : "A projekt átnevezése sikertelen",
     "Failed to create a project" : "A projekt létrehozása sikertelen",
     "Failed to add the item to the project" : "Az elem hozzáadása a projekthez sikertelen",
     "Connect items to a project to make them easier to find" : "Kössön hozzá elemeket a projekthez, hogy könnyebben megtalálhatóak legyenek",
     "Type to search for existing projects" : "Gépeljen a meglévő projektet kereséséhez",
-    "New in" : "Újdonságok a következőben:",
-    "View changelog" : "Változásnapló megtekintése",
     "Close \"{dialogTitle}\" dialog" : "A(z) „{dialogTitle}” párbeszédablak bezárása",
     "Email length is at max (255)" : "Az e-mail-cím hossza elérte a maximumot (255)",
     "Clipboard not available, please copy manually" : "A vágólap nem érhető el, másolja kézileg",
@@ -482,20 +507,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Nem megbízható tartományon keresztüli hozzáférés",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lépjen kapcsolatba a rendszergazdával. Ha Ön az, akkor szerkessze a „trusted_domains” beállítást a config/config.php-ban, a config.sample.php-hoz hasonlóan.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ennek a beállításához további információkat talál a %1$sdokumentációban%2$s.",
-    "App update required" : "Alkalmazásfrissítés szükséges",
-    "%1$s will be updated to version %2$s" : "A(z) %1$s frissítve lesz erre a verzióra: %2$s",
-    "The following apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
-    "These incompatible apps will be disabled:" : "A következő nem kompatibilis alkalmazások le lesznek tiltva:",
-    "The theme %s has been disabled." : "A(z) %s téma letiltásra került.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Gondoskodjon róla, hogy elmentse az adatbázist, a konfigurációs mappa és az adatmappa tartalmát, mielőtt folytatja.",
-    "Start update" : "A frissítés megkezdése",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "A nagy méretű telepítések által okozott időtúllépések elkerülése érdekében, inkább futtassa a következő parancsot a telepítési alkönyvtárban:",
-    "Detailed logs" : "Részletes naplók",
-    "Update needed" : "Frissítés szükséges",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Használja a parancssori frissítőt, mert 50 fiókosnál nagyobb példánya van.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Segítségért tekintse meg a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentációt</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tudomásul veszem, hogy a webes frissítési felület használata közben fellépő időtúllépés adatvesztéssel járhat. Van biztonsági mentésem, hiba esetén tudom, hogyan állítsam vissza az adatokat.",
-    "Upgrade via web on my own risk" : "Frissítés weben keresztül, saját felelősségre",
     "Maintenance mode" : "Karbantartási üzemmód",
     "This %s instance is currently in maintenance mode, which may take a while." : "Ez a %s példány éppen karbantartási üzemmódban van, amely eltarthat egy darabig.",
     "This page will refresh itself when the instance is available again." : "Ez az oldal frissíteni fogja magát, amint a példány ismét elérhető lesz.",
@@ -510,6 +521,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ezek a találatok<script>alert(1)</script></strong>",
     "new" : "új",
     "_download %n file_::_download %n files_" : ["%n fájl letöltése","%n fájl letöltése"],
+    "An error occurred." : "Hiba történt.",
+    "Please reload the page." : "Frissítse az oldalt.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A frissítés sikertelen. Bővebb információért <a href=\"{url}\">keresse fel a problémáról szóló fórumbejegyzésünket</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A frissítés sikertelen. Jelezze a problémát a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud közösségnek</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}.","A frissítés sikeres volt. %n másodperc múlva át lesz irányítva a következőhöz: {productName}."],
     "Direct link copied to clipboard" : "Közvetlen hivatkozás a vágólapra másolva",
     "Searching …" : "Keresés…",
     "Logging in …" : "Bejelentkezés…",
@@ -522,6 +538,10 @@ OC.L10N.register(
     "Loading more results …" : "További találatok betöltése…",
     "Search {types} …" : "{types} keresése…",
     "Saving …" : "Mentés…",
+    "Connection to server lost" : "A kapcsolat megszakadt a kiszolgálóval",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probléma az oldal betöltésekor, újratöltés %n másodperc múlva","Probléma az oldal betöltésekor, újratöltés %n másodperc múlva"],
+    "New in" : "Újdonságok a következőben:",
+    "View changelog" : "Változásnapló megtekintése",
     "Very weak password" : "Nagyon gyenge jelszó",
     "Weak password" : "Gyenge jelszó",
     "So-so password" : "Nem túl jó jelszó",
@@ -548,6 +568,11 @@ OC.L10N.register(
     "Installing …" : "Telepítés…",
     "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
     "Currently logged in as %1$s (%2$s)." : "Jelenleg bejelentkezve: %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Hozzáférést készül biztosítani %1$s számára ehhez a fiókjához: %2$s.",
+    "%1$s will be updated to version %2$s" : "A(z) %1$s frissítve lesz erre a verzióra: %2$s",
+    "The following apps will be updated:" : "A következő alkalmazások lesznek frissítve:",
+    "The theme %s has been disabled." : "A(z) %s téma letiltásra került.",
+    "Detailed logs" : "Részletes naplók",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Segítségért tekintse meg a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentációt</a>."
 },
 "nplurals=2; plural=(n != 1);");
