@@ -198,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Video Matroska",
     "Windows Media video" : "Video Windows Media",
     "AVI video" : "Video AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
-    "Update to {version}" : "Perbarui ke {version}",
-    "An error occurred." : "Terjadi kesalahan.",
-    "Please reload the page." : "Silakan muat ulang halaman.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Pembaruan gagal. Untuk informasi berikutnya <a href=\"{url}\">cek posting di forum</a> yang mencakup masalah kami.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
-    "Continue to {productName}" : "Lanjutkan ke {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Pembaruan berhasil. Mengarahkan Anda ke {productName} dalam hitungan detik."],
     "Done" : "Selesai",
     "Scan QR code to log in" : "Pindai kode QR untuk masuk",
     "Use {productName} mobile client you want to connect to scan the code" : "Gunakan klien seluler {productName} yang ingin Anda hubungkan untuk memindai kode",
@@ -213,6 +205,7 @@ OC.L10N.register(
     "Applications menu" : "Menu aplikasi",
     "Apps" : "Aplikasi",
     "More apps" : "Aplikasi lainnya",
+    "_{count} notification_::_{count} notifications_" : ["{count} notifikasi"],
     "No" : "Tidak",
     "Yes" : "Ya",
     "App password" : "Kata sandi aplikasi",
@@ -313,8 +306,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Memuat kontak Anda …",
     "Looking for {term} …" : "Mencari {term} …",
     "Search contacts" : "Cari kontak",
-    "Reset search" : "Ulang pencarian",
     "Search contacts …" : "Cari kontak …",
+    "Reset search" : "Ulang pencarian",
     "Could not load your contacts" : "Tidak dapat memuat kontak Anda",
     "No contacts found" : "Kontak tidak ditemukan",
     "Show all contacts" : "Tampilkan semua kontak",
@@ -333,13 +326,17 @@ OC.L10N.register(
     "Login form is disabled." : "Formulir login dinonaktifkan.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formulir login Nextcloud dinonaktifkan. Gunakan opsi login lain jika tersedia atau hubungi administrasi Anda.",
     "Connect to your account" : "Hubungkan ke akun Anda",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Silakan masuk sebelum memberikan \"{client}\" akses ke akun {instanceName} Anda.",
     "Security warning" : "Peringatan keamanan",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jika Anda tidak mencoba menyiapkan perangkat atau aplikasi baru, seseorang mencoba menipu Anda agar memberi mereka akses ke data Anda. Dalam hal ini jangan lanjutkan dan hubungi administrator sistem Anda.",
+    "Log in using password" : "Masuk menggunakan kata sandi",
     "Alternative log in using app password" : "Login alternatif menggunakan kata sandi aplikasi",
     "Account connected" : "Akun terhubung",
     "Your client should now be connected!" : "Klien sudah terhubung!",
     "You can close this window." : "Anda dapat menutup jendela ini.",
     "Account access" : "Akses akun",
+    "Currently logged in as {userDisplayName} ({userId})." : "Saat ini masuk sebagai {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Anda akan memberikan \"{client}\" akses ke akun {instanceName} Anda.",
     "More actions" : "Tindakan lainnya",
     "User menu" : "Menu pengguna",
     "Your guest name: {user}" : "Nama tamu Anda: {user}",
@@ -397,6 +394,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browser Anda tidak didukung. Silakan tingkatkan ke versi yang lebih baru atau yang didukung.",
     "Continue with this unsupported browser" : "Lanjutkan dengan browser yang tidak didukung ini",
     "Supported versions" : "Versi yang didukung",
+    "The update completed with warnings. Please check the details for more information." : "Pembaruan selesai dengan peringatan. Silakan periksa detail untuk informasi lebih lanjut.",
+    "The update completed successfully." : "Pembaruan berhasil diselesaikan.",
+    "Preparing update…" : "Menyiapkan pembaruan…",
+    "You will be redirected to {productName} in {count} seconds." : "Anda akan dialihkan ke {productName} dalam {count} detik.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
+    "App update required" : "Diperlukan perbarui aplikasi",
+    "{productName} will be updated to version {version}" : "{productName} akan diperbarui ke versi {version}",
+    "The theme {oldTheme} has been disabled." : "Tema {oldTheme} telah dinonaktifkan.",
+    "These incompatible apps will be disabled:" : "Aplikasi yang tidak kompatibel berikut akan dinonaktifkan:",
+    "Incompatible apps" : "Aplikasi tidak kompatibel",
+    "These apps will be updated:" : "Aplikasi berikut akan diperbarui:",
+    "Apps to update" : "Aplikasi yang akan diperbarui",
+    "{app} from {oldVersion} to {version}" : "{app} dari {oldVersion} ke {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pastikan bahwa basis data, folder konfig, dan folder data telah dicadangkan sebelum melanjutkan.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
+    "Start update" : "Jalankan pembaruan",
+    "Continue to {productName}" : "Lanjutkan ke {productName}",
+    "Update to {version}" : "Perbarui ke {version}",
+    "Hide details" : "Sembunyikan detail",
+    "Show details" : "Tampilkan detail",
+    "Update details" : "Detail pembaruan",
+    "Update needed" : "Pembaruan dibutuhkan",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Silakan gunakan pembaru baris perintah karena Anda memiliki instance besar dengan lebih dari 50 akun.",
+    "Documentation" : "Dokumentasi",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Saya paham jika melakukan proses pemutakhiran via antarmuka web, berisiko komunikasi terhenti dan kemungkinan kehilangan data. Saya punya cadangan dan paham bagaimana cara pemulihan, jika terjadi kegagalan.",
+    "Upgrade via web on my own risk" : "Pemutakhiran via web adalah risiko saya",
     "Search {types} …" : "Cari {types} …",
     "Choose {file}" : "Pilih {file}",
     "Choose" : "Pilih",
@@ -422,19 +445,13 @@ OC.L10N.register(
     "Group list is empty" : "Daftar grup kosong",
     "Unable to retrieve the group list" : "Tidak dapat mengambil daftar grup",
     "seconds ago" : "beberapa detik yang lalu",
-    "Connection to server lost" : "Koneksi ke server gagal",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
     "Add to a project" : "Tambah ke proyek",
-    "Show details" : "Tampilkan detail",
-    "Hide details" : "Sembunyikan detail",
     "Rename project" : "Ubah nama proyek",
     "Failed to rename the project" : "Gagal mengubah nama proyek",
     "Failed to create a project" : "Gagal membuat proyek",
     "Failed to add the item to the project" : "Gagal menambahkan item ke proyek",
     "Connect items to a project to make them easier to find" : "Hubungkan item ke proyek agar mudah ditemukan",
     "Type to search for existing projects" : "Ketik untuk mencari proyek eksis",
-    "New in" : "Terbaru",
-    "View changelog" : "Lihat log pembaruan",
     "Close \"{dialogTitle}\" dialog" : "Tutup dialog \"{dialogTitle}\"",
     "Email length is at max (255)" : "Panjang email sudah maksimal (255)",
     "Clipboard not available, please copy manually" : "Papan klip tidak tersedia, silakan salin secara manual",
@@ -486,20 +503,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Akses melalui domain tidak terpercaya",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Silakan hubungi administrator Anda. Apabila Anda adalah administrator dari instalasi ini, setel parameter \"trusted_domains\" pada config/config.php seperti contoh yang tersedia pada config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Info lebih lanjut mengenai pengaturan ini, dapat ditemukan pada %1$sdokumentasi%2$s.",
-    "App update required" : "Diperlukan perbarui aplikasi",
-    "%1$s will be updated to version %2$s" : "%1$s akan diperbarui ke versi %2$s",
-    "The following apps will be updated:" : "Aplikasi berikut akan diperbarui:",
-    "These incompatible apps will be disabled:" : "Aplikasi yang tidak kompatibel berikut akan dinonaktifkan:",
-    "The theme %s has been disabled." : "Tema %s telah dinonaktfkan.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pastikan bahwa basis data, folder konfig, dan folder data telah dicadangkan sebelum melanjutkan.",
-    "Start update" : "Jalankan pembaruan",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
-    "Detailed logs" : "Log detail",
-    "Update needed" : "Pembaruan dibutuhkan",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Silakan gunakan pembaru baris perintah karena Anda memiliki instance besar dengan lebih dari 50 akun.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Lihat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasi</a> untuk panduan.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Saya paham jika melakukan proses pemutakhiran via antarmuka web, berisiko komunikasi terhenti dan kemungkinan kehilangan data. Saya punya cadangan dan paham bagaimana cara pemulihan, jika terjadi kegagalan.",
-    "Upgrade via web on my own risk" : "Pemutakhiran via web adalah risiko saya",
     "Maintenance mode" : "Mode pemeliharaan",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
     "This page will refresh itself when the instance is available again." : "Laman ini akan dimuat otomatis saat instalasi kembali tersedia.",
@@ -514,18 +517,27 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ini adalah hasil pencarian Anda<script>alert(1)</script></strong>",
     "new" : "baru",
     "_download %n file_::_download %n files_" : ["unduh %n berkas"],
+    "An error occurred." : "Terjadi kesalahan.",
+    "Please reload the page." : "Silakan muat ulang halaman.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Pembaruan gagal. Untuk informasi berikutnya <a href=\"{url}\">cek posting di forum</a> yang mencakup masalah kami.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Pembaruan berhasil. Mengarahkan Anda ke {productName} dalam hitungan detik."],
     "Direct link copied to clipboard" : "Tautan langsung disalin ke papan klip",
     "Searching …" : "Mencari …",
-    "Logging in …" : "Log masuk...",
+    "Logging in …" : "Log masuk …",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Terdeteksi multipel percobaan log masuk tidak valid dari IP Anda. Pencekalan log masuk berikutnya dilakukan hingga 30 detik.",
-    "Loading apps …" : "Memuat aplikasi ...",
-    "Installing apps …" : "menginstal aplikasi ...",
-    "Loading your contacts …" : "Memuat kontak Anda ...",
+    "Loading apps …" : "Memuat aplikasi …",
+    "Installing apps …" : "Menginstal aplikasi …",
+    "Loading your contacts …" : "Memuat kontak Anda …",
     "Looking for {term} …" : "Mencari {term}",
-    "Search contacts …" : "Cari kontak ...",
+    "Search contacts …" : "Cari kontak …",
     "Loading more results …" : "Memuat hasil lainnya…",
     "Search {types} …" : "Cari {types} …",
-    "Saving …" : "Menyimpan ...",
+    "Saving …" : "Menyimpan …",
+    "Connection to server lost" : "Koneksi ke server gagal",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
+    "New in" : "Terbaru",
+    "View changelog" : "Lihat log pembaruan",
     "Very weak password" : "Kata sandi sangat lemah",
     "Weak password" : "Kata sandi lemah",
     "So-so password" : "Kata sandi lumayan",
@@ -547,11 +559,16 @@ OC.L10N.register(
     "Show password" : "Tampilkan kata sandi",
     "Toggle password visibility" : "Alihkan visibilitas kata sandi",
     "Configure the database" : "Konfigurasikan basis data",
-    "Only %s is available." : "Hanya %s yang tersedia",
+    "Only %s is available." : "Hanya %s yang tersedia.",
     "Database account" : "Akun database",
     "Installing …" : "Memasang …",
     "Please log in before granting %1$s access to your %2$s account." : "Silakan log masuk sebelum mengizinkan %1$s mengakses akun %2$s Anda.",
     "Currently logged in as %1$s (%2$s)." : "Saat ini masuk sebagai %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Anda akan memberikan izin %1$s akses ke akun %2$s Anda."
+    "You are about to grant %1$s access to your %2$s account." : "Anda akan memberikan izin %1$s akses ke akun %2$s Anda.",
+    "%1$s will be updated to version %2$s" : "%1$s akan diperbarui ke versi %2$s",
+    "The following apps will be updated:" : "Aplikasi berikut akan diperbarui:",
+    "The theme %s has been disabled." : "Tema %s telah dinonaktfkan.",
+    "Detailed logs" : "Log detail",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Lihat <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasi</a> untuk panduan."
 },
 "nplurals=1; plural=0;");
