@@ -154,7 +154,7 @@ OC.L10N.register(
     "Ogg audio" : "Audio Ogg",
     "RIFF/WAVe standard Audio" : "Standard audio RIFF/WAVe",
     "WebM audio" : "Audio WebM",
-    "MP3 ShoutCast playlist" : "Playlist MP3 ShoutCast",
+    "MP3 ShoutCast playlist" : "Scaletta MP3 ShoutCast",
     "Windows BMP image" : "Immagine BMP di Windows",
     "Better Portable Graphics image" : "Migliore immagine grafica portatile",
     "EMF image" : "Immagine EMF",
@@ -198,15 +198,10 @@ OC.L10N.register(
     "Matroska video" : "Video Matroska",
     "Windows Media video" : "Video di Windows Media",
     "AVI video" : "Video AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
-    "Update to {version}" : "Aggiorna a {version}",
-    "An error occurred." : "Si è verificato un errore.",
-    "Please reload the page." : "Ricarica la pagina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunità di Nextcloud </a>.",
-    "Continue to {productName}" : "Continua in {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} in %n secondo.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi."],
     "Done" : "Completato",
+    "Scan QR code to log in" : "Esegui la scansione del codice QR per accedere",
+    "Use {productName} mobile client you want to connect to scan the code" : "Utilizza il client mobile di {productName} che vuoi collegare per eseguire la scansione del codice",
+    "Code will expire {timeCountdown} or after use" : "Il codice scadrà {timeCountdown} o dopo l'utilizzo",
     "Applications menu" : "Menu applicazioni",
     "Apps" : "Applicazioni",
     "More apps" : "Altre applicazioni",
@@ -221,7 +216,7 @@ OC.L10N.register(
     "Federated user" : "Utente federato",
     "user@your-nextcloud.org" : "utente@il-tuo-nextcloud.org",
     "Create share" : "Crea condivisione",
-    "Direct link copied" : "Link diretto copiato",
+    "Direct link copied" : "Collegamento diretto copiato",
     "Please copy the link manually:" : "Copia il collegamento manualmente:",
     "Custom date range" : "Intervallo di date personalizzato",
     "Pick start date" : "Scegli la data di inizio",
@@ -234,7 +229,7 @@ OC.L10N.register(
     "Start typing to search" : "Inizia a digitare per cercare",
     "Minimum search length is {minSearchLength} characters" : "La lunghezza minima della ricerca è {minSearchLength} caratteri",
     "No matching results" : "Nessun risultato corrispondente",
-    "Today" : "Ogg",
+    "Today" : "Oggi",
     "Last 7 days" : "Ultimi 7 giorni",
     "Last 30 days" : "Ultimi 30 giorni",
     "This year" : "Quest'anno",
@@ -287,7 +282,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Pianificare lavoro e riunioni, sincronizzati con tutti i tuoi dispositivi.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Tieni i tuoi colleghi e i tuoi amici in un posto proteggendo le loro Informazioni personali.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Applicazione di posta elettronica semplice e ben integrata con File, Contatti e Calendario.",
-    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione dello schermo, riunioni online e web conference, direttamente dal tuo browser e dalle app mobili.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videochiamate, condivisione dello schermo, riunioni online e conferenze web, direttamente dal tuo browser e dalle applicazioni mobili.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documenti collaborativi, fogli di calcolo e presentazioni, integrati in Collabora Online.",
     "Distraction free note taking app." : "Applicazione per note, senza distrazioni.",
     "Recommended apps" : "Applicazioni consigliate",
@@ -311,8 +306,8 @@ OC.L10N.register(
     "Loading your contacts …" : "Caricamento dei tuoi contatti …",
     "Looking for {term} …" : "Ricerca di {term} …",
     "Search contacts" : "Cerca nei contatti",
-    "Reset search" : "Ripristina ricerca",
     "Search contacts …" : "Cerca contatti …",
+    "Reset search" : "Ripristina ricerca",
     "Could not load your contacts" : "Impossibile caricare i tuoi contatti",
     "No contacts found" : "Nessun contatto trovato",
     "Show all contacts" : "Mostra tutti i contatti",
@@ -331,13 +326,17 @@ OC.L10N.register(
     "Login form is disabled." : "Il modulo di accesso è disabilitato.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
     "Connect to your account" : "Connetti il tuo account",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Accedi prima di accordare a \"{client}\" l'accesso al tuo account {instanceName}.",
     "Security warning" : "Avviso di sicurezza",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se non stai tentando di configurare un nuovo dispositivo o applicazione, qualcuno sta provando a ingannarti per ottenere l'accesso ai tuoi dati. In questo caso non procedere e contatta l'amministratore di sistema.",
+    "Log in using password" : "Accedi utilizzando la password",
     "Alternative log in using app password" : "Accesso alternativo utilizzando la password dell'applicazione",
     "Account connected" : "Account connesso",
     "Your client should now be connected!" : "Il client ora dovrebbe essere connesso!",
     "You can close this window." : "Puoi chiudere questa finestra.",
     "Account access" : "Accesso account",
+    "Currently logged in as {userDisplayName} ({userId})." : "Attualmente connesso come {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Stai per accordare a \"{client}\" l'accesso al tuo account {instanceName}.",
     "More actions" : "Altre azioni",
     "User menu" : "Menu utente",
     "Your guest name: {user}" : "Il tuo nome ospite: {user}",
@@ -395,6 +394,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Il tuo browser non è supportato. Effettua l'aggiornamento a una versione più recente o supportata.",
     "Continue with this unsupported browser" : "Prosegui con questo browser non supportato",
     "Supported versions" : "Versioni supportate",
+    "The update completed with warnings. Please check the details for more information." : "L'aggiornamento è stato completato con avvisi. Per maggiori informazioni, consulta i dettagli.",
+    "The update completed successfully." : "L'aggiornamento è stato completato correttamente.",
+    "Preparing update…" : "Preparazione dell'aggiornamento...",
+    "You will be redirected to {productName} in {count} seconds." : "Sarai rediretto a {productName} tra {count} secondi.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "L'aggiornamento è in corso, l'abbandono di questa pagina potrebbe interrompere il processo in alcuni ambienti.",
+    "App update required" : "Aggiornamento dell'applicazione richiesto",
+    "{productName} will be updated to version {version}" : "{productName} sarà aggiornato alla versione {version}",
+    "The theme {oldTheme} has been disabled." : "Il tema {oldTheme} è stato disabilitato.",
+    "These incompatible apps will be disabled:" : "Queste applicazioni incompatibili saranno disabilitate:",
+    "Incompatible apps" : "Applicazioni incompatibili",
+    "These apps will be updated:" : "Queste applicazioni saranno aggiornate:",
+    "Apps to update" : "Applicazioni da aggiornare",
+    "{app} from {oldVersion} to {version}" : "{app} da {oldVersion} a {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assicurati di aver creato una copia di sicurezza del database, della cartella config e della cartella data prima di procedere. ",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
+    "Start update" : "Avvia l'aggiornamento",
+    "Continue to {productName}" : "Continua in {productName}",
+    "Update to {version}" : "Aggiorna a {version}",
+    "Hide details" : "Nascondi dettagli",
+    "Show details" : "Mostra dettagli",
+    "Update details" : "Dettagli dell'aggiornamento",
+    "Update needed" : "Aggiornamento necessario",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Utilizza lo strumento di aggiornamento tramite riga di comando in quanto disponi di un'istanza di grandi dimensioni con più di 50 utenti.",
+    "Documentation" : "Documentazione",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sono consapevole che, procedendo con l'aggiornamento tramite interfaccia web, esista il rischio che la richiesta possa scadere e causare perdite di dati, ma ho una copia di sicurezza e so come ripristinare la mia istanza in caso di problemi.",
+    "Upgrade via web on my own risk" : "Aggiorna tramite web a mio rischio",
     "Search {types} …" : "Cerca {types} …",
     "Choose {file}" : "Scegli {file}",
     "Choose" : "Scegli",
@@ -420,19 +445,13 @@ OC.L10N.register(
     "Group list is empty" : "L'elenco dei gruppi è vuoto",
     "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
     "seconds ago" : "secondi fa",
-    "Connection to server lost" : "Connessione al server interrotta",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
     "Add to a project" : "Aggiungi a un progetto",
-    "Show details" : "Mostra dettagli",
-    "Hide details" : "Nascondi dettagli",
     "Rename project" : "Rinomina progetto",
     "Failed to rename the project" : "Rinomina progetto non riuscita",
     "Failed to create a project" : "Creazione progetto non riuscita",
     "Failed to add the item to the project" : "Aggiunta dell'elemento al progetto non riuscita",
     "Connect items to a project to make them easier to find" : "Collega elementi a un progetto per poterli trovare più facilmente",
     "Type to search for existing projects" : "Digita per cercare progetti esistenti",
-    "New in" : "Nuovo in",
-    "View changelog" : "Visualizza le novità",
     "Close \"{dialogTitle}\" dialog" : "Chiudi la finestra \"{dialogTitle}\"",
     "Email length is at max (255)" : "La lunghezza dell'email è al massimo (255)",
     "Clipboard not available, please copy manually" : "Appunti non disponibili, copiare manualmente",
@@ -450,7 +469,7 @@ OC.L10N.register(
     "Error" : "Errore",
     "Internal Server Error" : "Errore interno del server",
     "The server was unable to complete your request." : "Il server non è stato in grado di completare la tua richiesta.",
-    "If this happens again, please send the technical details below to the server administrator." : "Se ciò si verifca nuovamente, invia i seguenti dettagli tecnici all'amministratore del server.",
+    "If this happens again, please send the technical details below to the server administrator." : "Se ciò si verifica nuovamente, invia i seguenti dettagli tecnici all'amministratore del server.",
     "More details can be found in the server log." : "Ulteriori dettagli sono disponibili nel log del server.",
     "For more details see the documentation ↗." : "Per ulteriori dettagli, leggi la documentazione ↗.",
     "Technical details" : "Dettagli tecnici",
@@ -484,20 +503,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Accedi tramite un dominio non attendibile",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contatta il tuo amministratore. Se sei un amministratore, modifica l'impostazione \"trusted_domains\" in config/config.php come l'esempio disponibile in config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ulteriori informazioni sulla configurazione sono disponibili nella %1$s documentazione %2$s.",
-    "App update required" : "Aggiornamento dell'applicazione richiesto",
-    "%1$s will be updated to version %2$s" : "%1$s sarà aggiornato alla versione %2$s",
-    "The following apps will be updated:" : "Le seguenti applicazioni saranno aggiornate:",
-    "These incompatible apps will be disabled:" : "Queste applicazioni incompatibili saranno disabilitate:",
-    "The theme %s has been disabled." : "Il tema %s è stato disabilitato.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Assicurati di aver creato una copia di sicurezza del database, della cartella config e della cartella data prima di procedere. ",
-    "Start update" : "Avvia l'aggiornamento",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitare timeout con installazioni di grandi dimensioni, puoi eseguire il comando che segue dalla cartella di installazione:",
-    "Detailed logs" : "Log dettagliati",
-    "Update needed" : "Aggiornamento necessario",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Utilizza lo strumento di aggiornamento tramite riga di comando in quanto disponi di un'istanza di grandi dimensioni con più di 50 utenti.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentazione</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sono consapevole che, procedendo con l'aggiornamento tramite interfaccia web, esista il rischio che la richiesta possa scadere e causare perdite di dati, ma ho una copia di sicurezza e so come ripristinare la mia istanza in caso di problemi.",
-    "Upgrade via web on my own risk" : "Aggiorna tramite web a mio rischio",
     "Maintenance mode" : "Modalità Manutenzione",
     "This %s instance is currently in maintenance mode, which may take a while." : "Questa istanza di %s è attualmente in manutenzione, potrebbe richiedere del tempo.",
     "This page will refresh itself when the instance is available again." : "Questa pagina si aggiornerà quando l'istanza sarà nuovamente disponibile.",
@@ -512,6 +517,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Questi sono i tuoi risultati di ricerca<script>alert(1)</script></strong>",
     "new" : "nuovo",
     "_download %n file_::_download %n files_" : ["scarica %n file","scarica %n file","scarica %n file"],
+    "An error occurred." : "Si è verificato un errore.",
+    "Please reload the page." : "Ricarica la pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "L'aggiornamento non è riuscito. Per ulteriori informazioni <a href=\"{url}\">controlla l'articolo del nostro forum</a> che riguarda questo problema.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "L'aggiornamento non è riuscito. Segnala il problema alla <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunità di Nextcloud </a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} in %n secondo.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi.","L'aggiornamento è stato effettuato correttamente. Reindirizzamento a {productName} %n secondi."],
     "Direct link copied to clipboard" : "Collegamento diretto copiato negli appunti",
     "Searching …" : "Ricerca in corso…",
     "Logging in …" : "Accesso in corso...",
@@ -524,6 +534,10 @@ OC.L10N.register(
     "Loading more results …" : "Caricamento di più risultati...",
     "Search {types} …" : "Cerca {types}...",
     "Saving …" : "Salvataggio…",
+    "Connection to server lost" : "Connessione al server interrotta",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema durante il caricamento della pagina, aggiornamento tra %n secondo","Problema durante il caricamento della pagina, aggiornamento tra %n secondi","Problema durante il caricamento della pagina, aggiornamento tra %n secondi"],
+    "New in" : "Nuovo in",
+    "View changelog" : "Visualizza le novità",
     "Very weak password" : "Password molto debole",
     "Weak password" : "Password debole",
     "So-so password" : "Password così-così",
@@ -550,6 +564,11 @@ OC.L10N.register(
     "Installing …" : "Installazione …",
     "Please log in before granting %1$s access to your %2$s account." : "Accedi prima di accordare a %1$s l'accesso al tuo account %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Attualmente connesso come %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Stai per accordare a %1$s l'accesso al tuo account %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s sarà aggiornato alla versione %2$s",
+    "The following apps will be updated:" : "Le seguenti applicazioni saranno aggiornate:",
+    "The theme %s has been disabled." : "Il tema %s è stato disabilitato.",
+    "Detailed logs" : "Registri dettagliati",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per la guida, vedi la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentazione</a>."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
