@@ -128,14 +128,6 @@ OC.L10N.register(
     "Matroska video" : "Mastroka-video",
     "Windows Media video" : "Windows Media-video",
     "AVI video" : "AVI-video",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen på enkelte systemer.",
-    "Update to {version}" : "Oppdater til {version}",
-    "An error occurred." : "En feil oppsto.",
-    "Please reload the page." : "Last inn siden på nytt.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Oppdateringen var mislykket. For mer informasjon <a href=\"{url}\">se vår forum-artikkel</a> som beskriver dette problemet.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
-    "Continue to {productName}" : "Fortsett til {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
     "Done" : "Ferdig",
     "Applications menu" : "Applikasjonsmeny",
     "Apps" : "Apper",
@@ -305,6 +297,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
     "Continue with this unsupported browser" : "Fortsett med denne nettleseren som ikke støttes",
     "Supported versions" : "Støttede versjoner",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "En oppdatering foregår, lukking av denne siden kan forstyrre prosessen på enkelte systemer.",
+    "App update required" : "Oppdatering av app kreves",
+    "These incompatible apps will be disabled:" : "Disse ikke-kompatible appene vil bli deaktivert:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
+    "Start update" : "Start oppdatering",
+    "Continue to {productName}" : "Fortsett til {productName}",
+    "Update to {version}" : "Oppdater til {version}",
+    "Hide details" : "Skjul detaljer",
+    "Show details" : "Vis detaljer",
+    "Update needed" : "Oppdatering er nødvendig",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bruk kommandolinjeoppdatereren siden du har en stor forekomst med mer enn 50 kontoer.",
+    "Documentation" : "Dokumentasjo",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg vet at hvis jeg fortsetter oppdateringen via web-grensesnittet er det en mulighet for tap av data som følge av tidsavbrudd, men jeg har en sikkerhetskopi og vet hvordan jeg skal gjenopprette min installasjon hvis den feiler.",
+    "Upgrade via web on my own risk" : "Oppgrader via web på min egen risikio",
     "Choose {file}" : "Velg {file}",
     "Choose" : "Velg",
     "Copy to {target}" : "Kopier til {target}",
@@ -329,19 +336,13 @@ OC.L10N.register(
     "Group list is empty" : "Gruppeliste er tom",
     "Unable to retrieve the group list" : "Kunne ikke hente gruppelisten",
     "seconds ago" : "for få sekunder siden",
-    "Connection to server lost" : "Mistet tilkobling til server",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
     "Add to a project" : "Legg til i et prosjekt",
-    "Show details" : "Vis detaljer",
-    "Hide details" : "Skjul detaljer",
     "Rename project" : "Endre navn på prosjekt",
     "Failed to rename the project" : "Klarte ikke å endre navnet på prosjektet",
     "Failed to create a project" : "Klarte ikke å opprettet prosjektet",
     "Failed to add the item to the project" : "Klarte ikke å koble objektet til prosjektet",
     "Connect items to a project to make them easier to find" : "Koble objekter til et prosjekt gjør dem enklere å finne",
     "Type to search for existing projects" : "Skriv for å søke etter eksisterende prosjekter",
-    "New in" : "Ny i",
-    "View changelog" : "Se endringslogg",
     "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
     "Email length is at max (255)" : "E-postlengden er på maks (255)",
     "Clipboard not available, please copy manually" : "Utklippstavlen ikke tilgjengelig, kopier manuelt",
@@ -393,20 +394,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Nå gjennom ubetrodd domene",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontakt din administrator. Hvis du er en administrator, sett opp innstillingen \"trusted_domains\" i config/config.php som eksemplet i config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ytterligere informasojn om oppsett finnes i %1$sdokumentasjon%2$s.",
-    "App update required" : "Oppdatering av app kreves",
-    "%1$s will be updated to version %2$s" : "%1$soppdateres til versjon %2$s",
-    "The following apps will be updated:" : "Følgende apper vil bli oppdatert:",
-    "These incompatible apps will be disabled:" : "Disse ikke-kompatible appene vil bli deaktivert:",
-    "The theme %s has been disabled." : "Temaet %s har blitt deaktivert.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Forsikre deg om at databasen, config-mappen og datamappen er blitt sikkerhetskopiert før du fortsetter.",
-    "Start update" : "Start oppdatering",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
-    "Detailed logs" : "Detaljerte logger",
-    "Update needed" : "Oppdatering er nødvendig",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bruk kommandolinjeoppdatereren siden du har en stor forekomst med mer enn 50 kontoer.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjelp, les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasjonen</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg vet at hvis jeg fortsetter oppdateringen via web-grensesnittet er det en mulighet for tap av data som følge av tidsavbrudd, men jeg har en sikkerhetskopi og vet hvordan jeg skal gjenopprette min installasjon hvis den feiler.",
-    "Upgrade via web on my own risk" : "Oppgrader via web på min egen risikio",
     "Maintenance mode" : "Modus for vedlikehold",
     "This %s instance is currently in maintenance mode, which may take a while." : "Denne %s-instansen er for øyeblikket i vedlikeholdsmodus, noe som kan vare en stund.",
     "This page will refresh itself when the instance is available again." : "Siden vil oppdatere seg selv når instans er tilgjengelig igjen.",
@@ -421,6 +408,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dette er dine søketreff<script>alert(1)</script></strong>",
     "new" : "ny",
     "_download %n file_::_download %n files_" : ["last ned %n fil","last ned %n filer"],
+    "An error occurred." : "En feil oppsto.",
+    "Please reload the page." : "Last inn siden på nytt.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Oppdateringen var mislykket. For mer informasjon <a href=\"{url}\">se vår forum-artikkel</a> som beskriver dette problemet.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
     "Direct link copied to clipboard" : "Direkte lenke kopiert til utklippstavlen",
     "Searching …" : "Søker ...",
     "Logging in …" : "Logger inn…",
@@ -433,6 +425,10 @@ OC.L10N.register(
     "Loading more results …" : "Laster flere resultater ...",
     "Search {types} …" : "Søk {types} ...",
     "Saving …" : "Lagrer...",
+    "Connection to server lost" : "Mistet tilkobling til server",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem ved lasting av side, laster på nytt om %n sekund","Problem ved lasting av side, laster på nytt om %n sekunder"],
+    "New in" : "Ny i",
+    "View changelog" : "Se endringslogg",
     "Very weak password" : "Veldig svakt passord",
     "Weak password" : "Svakt passord",
     "So-so password" : "Bob-bob-passord",
@@ -459,6 +455,11 @@ OC.L10N.register(
     "Installing …" : "Installerer ...",
     "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
     "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto."
+    "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto.",
+    "%1$s will be updated to version %2$s" : "%1$soppdateres til versjon %2$s",
+    "The following apps will be updated:" : "Følgende apper vil bli oppdatert:",
+    "The theme %s has been disabled." : "Temaet %s har blitt deaktivert.",
+    "Detailed logs" : "Detaljerte logger",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjelp, les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasjonen</a>."
 },
 "nplurals=2; plural=(n != 1);");
