@@ -56,13 +56,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Las aplicacions seguentas son estadas desactivadas : %s",
     "Already up to date" : "Ja a jorn",
     "Unknown" : "Desconegut",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
-    "Update to {version}" : "Metre a jorn a {version}",
-    "An error occurred." : "Una error s’es producha.",
-    "Please reload the page." : "Volgatz recargar la pagina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mesa a jorn a pas reüssit. Mai mai d’informacions <a href=\"{url}\">visitatz nòstra publicacion al forum</a> que tracta d’aqueste problèma.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mesa a jorn a pas reüssit. Mercés de senhalar aqueste problèma a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunautat Nexcloud</a>.",
-    "Continue to {productName}" : "Contunhar cap a {productName}",
     "Apps" : "Aplicacions",
     "More apps" : "Mai d’aplicacions",
     "_{count} notification_::_{count} notifications_" : ["{count} notificacion","{count} notificacions"],
@@ -159,6 +152,21 @@ OC.L10N.register(
     "{name} version {version} and above" : "{name} version {version} e ulterior",
     "This browser is not supported" : "Aqueste navigador es pas pres en carga",
     "Supported versions" : "Versions presas en carga",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mesa a jorn es en cors, quitar aquesta pagina poiriá interrompre lo processús dins d’unes environaments.",
+    "App update required" : "Mesa a jorn d’aplicacion requerida",
+    "These incompatible apps will be disabled:" : "Aquestas aplicacions incompatiblas seràn desactivadas :",
+    "These apps will be updated:" : "Aquestas aplicacions son estadas actualizadas :",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos que la basa de donadas, lo dossièr config e lo dossièr de donadas « data » foguèron salvagardats abans de contunhar.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar qu’expire lo temps d’espèra amb de bravas installacions, podètz a la plaça executar la comanda seguentas a partir del repertòri d’installacion :",
+    "Start update" : "Començar la mesa a jorn",
+    "Continue to {productName}" : "Contunhar cap a {productName}",
+    "Update to {version}" : "Metre a jorn a {version}",
+    "Hide details" : "Amagar detalhs",
+    "Show details" : "Mostrar detalhs",
+    "Update needed" : "Mesa a jorn requerida",
+    "Documentation" : "Documentacion",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sabi que se contunhi la mesa a jorn via l’interfàcia web i a un risc, que la requèsta s’execute e despasse lo delai e poiriá causar una pèrda de donadas, mas ai una salvagarda de seguretat e sabi cossí restaurar mon instància en cas de fracàs.",
+    "Upgrade via web on my own risk" : "Accèpti lo risc de metre a nivèl",
     "Choose" : "Causir",
     "Copy" : "Copiar",
     "Move" : "Move",
@@ -177,18 +185,12 @@ OC.L10N.register(
     "Group list is empty" : "La lista de grop es voida",
     "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
     "seconds ago" : "fa qualques segondas",
-    "Connection to server lost" : "Connexion al servidor perduda",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
     "Add to a project" : "Ajustar a un projècte",
-    "Show details" : "Mostrar detalhs",
-    "Hide details" : "Amagar detalhs",
     "Rename project" : "Renomenar lo projècte",
     "Failed to rename the project" : "Renomenatge impossible del projècte",
     "Failed to create a project" : "Creacion d’un projècte fracassada",
     "Failed to add the item to the project" : "Apondon fracassat d’un element al projècte",
     "Connect items to a project to make them easier to find" : "Connectatz d’elements a un projècte per lo rendre mai simples de trobar",
-    "New in" : "Nòu dins",
-    "View changelog" : "Veire jornal de modificacions",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
     "Admin" : "Admin",
@@ -231,19 +233,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Accès via un domeni pas fisable",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Contactatz vòstre administrator. Se ne sètz un, modificatz lo paramètre « trusted_domains » dins config/config.php coma l’exemple dins config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Per mai d’informacions per configurar aquò consultatz la %1$sdocumentacion%2$s.",
-    "App update required" : "Mesa a jorn d’aplicacion requerida",
-    "%1$s will be updated to version %2$s" : "%1$s serà passat a la version %2$s",
-    "The following apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
-    "These incompatible apps will be disabled:" : "Aquestas aplicacions incompatiblas seràn desactivadas :",
-    "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asseguratz-vos que la basa de donadas, lo dossièr config e lo dossièr de donadas « data » foguèron salvagardats abans de contunhar.",
-    "Start update" : "Començar la mesa a jorn",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Per evitar qu’expire lo temps d’espèra amb de bravas installacions, podètz a la plaça executar la comanda seguentas a partir del repertòri d’installacion :",
-    "Detailed logs" : "Jornals detalhats",
-    "Update needed" : "Mesa a jorn requerida",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per d’ajuda, vejatz la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentacion</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sabi que se contunhi la mesa a jorn via l’interfàcia web i a un risc, que la requèsta s’execute e despasse lo delai e poiriá causar una pèrda de donadas, mas ai una salvagarda de seguretat e sabi cossí restaurar mon instància en cas de fracàs.",
-    "Upgrade via web on my own risk" : "Accèpti lo risc de metre a nivèl",
     "Maintenance mode" : "Mòde manteniment",
     "This %s instance is currently in maintenance mode, which may take a while." : "L’instància %s es actualament en mòde manteniment, pòt trigar.",
     "This page will refresh itself when the instance is available again." : "Aquesta pagina s’actualizarà soleta quand l’instància serà disponibla de nòu.",
@@ -257,6 +246,10 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Vaquí vòstres resultats de recèrca<script>alert(1)</script></strong>",
     "new" : "nòu",
     "_download %n file_::_download %n files_" : ["telecargar %n fichièr","telecargar %n fichièrs"],
+    "An error occurred." : "Una error s’es producha.",
+    "Please reload the page." : "Volgatz recargar la pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mesa a jorn a pas reüssit. Mai mai d’informacions <a href=\"{url}\">visitatz nòstra publicacion al forum</a> que tracta d’aqueste problèma.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mesa a jorn a pas reüssit. Mercés de senhalar aqueste problèma a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunautat Nexcloud</a>.",
     "Searching …" : "Recèrca…",
     "Logging in …" : "Identificacion…",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Avèm detectat mantun ensag invalid de connexion a partir de vòstra IP. Per consequent vòstra connexion venenta serà en pausa per 30 segondas.",
@@ -268,6 +261,10 @@ OC.L10N.register(
     "Loading more results …" : "Cargament de mai de resultats…",
     "Search {types} …" : "Recèrca {types}…",
     "Saving …" : "Enregistrament…",
+    "Connection to server lost" : "Connexion al servidor perduda",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problèma de cargar de la pagina, actualizacion d’aquí %n seconda","Problèma de cargar de la pagina, actualizacion d’aquí %n secondas"],
+    "New in" : "Nòu dins",
+    "View changelog" : "Veire jornal de modificacions",
     "Very weak password" : "Senhal plan feble",
     "Weak password" : "Senhal feble",
     "So-so password" : "Senhal mejan",
@@ -290,6 +287,11 @@ OC.L10N.register(
     "Installing …" : "Installacion...",
     "Please log in before granting %1$s access to your %2$s account." : "Autentificatz-vos abans de donnar l’accès a %1$s a vòstre compte %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Actualament connectat coma %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s."
+    "You are about to grant %1$s access to your %2$s account." : "Sètz a mand de donar accès a vòstra compte %2$s a %1$s.",
+    "%1$s will be updated to version %2$s" : "%1$s serà passat a la version %2$s",
+    "The following apps will be updated:" : "Las aplicacions seguentas seràn mesas a jorn :",
+    "The theme %s has been disabled." : "Lo tèma %s es estat desactivat.",
+    "Detailed logs" : "Jornals detalhats",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Per d’ajuda, vejatz la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentacion</a>."
 },
 "nplurals=2; plural=(n > 1);");
