@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Texto de entrada é muito longo",
     "Requested task type does not exist" : "O tipo de tarefa solicitado não existe",
     "Necessary language model provider is not available" : "O provedor de modelo de linguagem necessário não está disponível",
+    "Cannot generate more than 12 images" : "Não é possível gerar mais de 12 imagens",
+    "Cannot generate less than 1 image" : "Não é possível gerar menos de 1 imagem",
     "No text to image provider is available" : "Nenhum provedor de texto para imagem está disponível",
     "Image not found" : "Imagem não encontrada",
     "No translation provider available" : "Nenhum provedor de tradução disponível",
@@ -198,14 +200,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
-    "Update to {version}" : "Atualizar para {version}",
-    "An error occurred." : "Ocorreu um erro.",
-    "Please reload the page." : "Por favor recarregue a página",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi realizada com sucesso. Para mais informações <a href=\"{url}\">verifique nosso post no fórum</a> que abrange esta questão.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
-    "Continue to {productName}" : "Continuar para {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n de segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
     "Done" : "Concluído",
     "Scan QR code to log in" : "Digitalize o código QR para fazer login",
     "Use {productName} mobile client you want to connect to scan the code" : "Use o cliente móvel {productName} que você deseja conectar para escanear o código",
@@ -314,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Carregando seus contatos …",
     "Looking for {term} …" : "Pesquisando {term} …",
     "Search contacts" : "Pesquisar contatos",
-    "Reset search" : "Redefinir pesquisa",
+    "Filter by team" : "Filtrar por equipe",
+    "All teams" : "Todas as equipes",
+    "Search contacts in team {team}" : "Pesquisar contatos na equipe {team}",
     "Search contacts …" : "Pesquisar contatos …",
+    "Reset search" : "Redefinir pesquisa",
     "Could not load your contacts" : "Não foi possível carregar seus contatos",
     "No contacts found" : "Nenhum contato encontrado",
+    "Contacts list" : "Lista de contatos",
     "Show all contacts" : "Mostrar todos os contatos",
     "Install the Contacts app" : "Instalar o aplicativo Contatos",
     "Search" : "Pesquisar",
@@ -334,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
     "Connect to your account" : "Conectar à sua conta",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Faça login antes de conceder acesso a \"{client}\" à sua conta {instanceName}.",
     "Security warning" : "Alerta de segurança",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se você não está tentando configurar um novo dispositivo ou aplicativo, alguém está tentando induzi-lo a conceder acesso a seus dados. Nesse caso, não prossiga e entre em contato com o administrador do sistema.",
+    "Log in using password" : "Faça login com senha",
     "Alternative log in using app password" : "Login alternativo usando senha do aplicativo",
     "Account connected" : "Conta conectada",
     "Your client should now be connected!" : "Seu cliente deve estar conectado agora!",
     "You can close this window." : "Você pode fechar esta janela.",
     "Account access" : "Acesso à conta",
+    "Currently logged in as {userDisplayName} ({userId})." : "Atualmente conectado como {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Você está prestes a conceder a \"{client}\" acesso à sua conta {instanceName}.",
     "More actions" : "Mais ações",
     "User menu" : "Menu do usuário",
     "Your guest name: {user}" : "Seu nome de convidado: {user}",
@@ -398,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é compatível. Por favor, atualize para uma versão mais recente ou compatível.",
     "Continue with this unsupported browser" : "Continuar com este navegador não compatível",
     "Supported versions" : "Versões compatíveis",
+    "The update completed with warnings. Please check the details for more information." : "A atualização foi concluída com avisos. Verifique os detalhes para obter mais informações.",
+    "The update completed successfully." : "A atualização foi concluída com sucesso.",
+    "Preparing update…" : "Preparando a atualização…",
+    "You will be redirected to {productName} in {count} seconds." : "Você será redirecionado para {productName} em {count} segundos.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em andamento. Em alguns ambientes, se sair desta página o processo poderá ser interrompido.",
+    "App update required" : "Atualização de aplicativo é necessária",
+    "{productName} will be updated to version {version}" : "{productName} será atualizado para a versão {version}",
+    "The theme {oldTheme} has been disabled." : "O tema {oldTheme} foi desativado.",
+    "These incompatible apps will be disabled:" : "Estes aplicativos incompatíveis serão desabilitados:",
+    "Incompatible apps" : "Aplicativos incompatíveis",
+    "These apps will be updated:" : "Estes aplicativos serão atualizados:",
+    "Apps to update" : "Aplicativos para atualizar",
+    "{app} from {oldVersion} to {version}" : "{app} de {oldVersion} para {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que o banco de dados, a pasta config e a pasta de dados foram copiados antes de prosseguir.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar atingir o tempo limite em instalações maiores, você pode em vez disso executar o seguinte comando a partir do diretório de instalação:",
+    "Start update" : "Iniciar atualização",
+    "Continue to {productName}" : "Continuar para {productName}",
+    "Update to {version}" : "Atualizar para {version}",
+    "Hide details" : "Ocultar detalhes",
+    "Show details" : "Mostrar detalhes",
+    "Update details" : "Detalhes da atualização",
+    "Update needed" : "Atualização necessária",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Por favor, use o atualizador de linha de comando porque você tem uma grande instância com mais de 50 contas.",
+    "Documentation" : "Documentação",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar atualizando pela interfaceweb, há o risco de atingir o tempo limite e ocorrer perda de dados mas eu tenho um cópia de backup e sei como restaurar meu sistema se isso ocorrer.",
+    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco",
     "Search {types} …" : "Pesquisar{types} …",
     "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
@@ -423,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "A lista de grupos está vazia",
     "Unable to retrieve the group list" : "Não é possível recuperar a lista de grupos",
     "seconds ago" : "segundos atrás",
-    "Connection to server lost" : "Conexão perdida com o servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n de segundos","Problema no carregamento da página, recarregando em %n segundos"],
     "Add to a project" : "Adicionar a um projeto",
-    "Show details" : "Mostrar detalhes",
-    "Hide details" : "Ocultar detalhes",
     "Rename project" : "Renomear projeto",
     "Failed to rename the project" : "Erro ao renomear projeto",
     "Failed to create a project" : "Erro ao criar um projeto",
     "Failed to add the item to the project" : "Erro ao adicionar o item ao projeto",
     "Connect items to a project to make them easier to find" : "Conecte itens a um projeto para torná-los mais fáceis de encontrar",
     "Type to search for existing projects" : "Digite para pesquisar projetos existentes",
-    "New in" : "Novo em",
-    "View changelog" : "Ver alterações",
     "Close \"{dialogTitle}\" dialog" : "Fechar a caixa de diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O comprimento do e-mail é no máximo (255)",
     "Clipboard not available, please copy manually" : "A área de transferência não está disponível, por favor, copie manualmente",
@@ -487,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Acessar através de um domínio inseguro",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte seu administrador. Se você for o administrador, edite a configuração \"trusted_domains\" em config/config.php como o exemplo em config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informações de como configurar isso podem ser encontradas na %1$sdocumentação%2$s.",
-    "App update required" : "Atualização de aplicativo é necessária",
-    "%1$s will be updated to version %2$s" : "%1$s será atualizado para a versão %2$s",
-    "The following apps will be updated:" : "Os seguintes aplicativos serão atualizados:",
-    "These incompatible apps will be disabled:" : "Estes aplicativos incompatíveis serão desabilitados:",
-    "The theme %s has been disabled." : "O tema %s foi desativado.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que o banco de dados, a pasta config e a pasta de dados foram copiados antes de prosseguir.",
-    "Start update" : "Iniciar atualização",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar atingir o tempo limite em instalações maiores, você pode em vez disso executar o seguinte comando a partir do diretório de instalação:",
-    "Detailed logs" : "Logs detalhados",
-    "Update needed" : "Atualização necessária",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Por favor, use o atualizador de linha de comando porque você tem uma grande instância com mais de 50 contas.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Precisando de ajuda, leia a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar atualizando pela interfaceweb, há o risco de atingir o tempo limite e ocorrer perda de dados mas eu tenho um cópia de backup e sei como restaurar meu sistema se isso ocorrer.",
-    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco",
     "Maintenance mode" : "Modo de manutenção",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está em modo de manutenção, o que pode demorar um pouco.",
     "This page will refresh itself when the instance is available again." : "Esta página será atualizada quando o Nextcloud estiver disponível novamente.",
@@ -515,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estes são os resultados de sua pesquisa<script>alert(1)</script></strong>",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["baixar %n arquivo","baixar %n de arquivos","baixar %n arquivos"],
+    "An error occurred." : "Ocorreu um erro.",
+    "Please reload the page." : "Por favor recarregue a página",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização não foi realizada com sucesso. Para mais informações <a href=\"{url}\">verifique nosso post no fórum</a> que abrange esta questão.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi realizada com sucesso. Por favor, informe este problema para  a <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi bem-sucedida. Redirecionando você à {productName} em %n segundo.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n de segundos.","A atualização foi bem-sucedida. Redirecionando você para {productName} em %n segundos."],
     "Direct link copied to clipboard" : "Link direto copiado para a área de transferência",
     "Searching …" : "Pesquisando …",
     "Logging in …" : "Entrando …",
@@ -527,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Carregando mais resultados…",
     "Search {types} …" : "Pesquisar {types}…",
     "Saving …" : "Salvando...",
+    "Connection to server lost" : "Conexão perdida com o servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema no carregamento da página, recarregando em %n segundo","Problema no carregamento da página, recarregando em %n de segundos","Problema no carregamento da página, recarregando em %n segundos"],
+    "New in" : "Novo em",
+    "View changelog" : "Ver alterações",
     "Very weak password" : "Senha muito fraca",
     "Weak password" : "Senha fraca",
     "So-so password" : "Senha mais ou menos",
@@ -553,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Instalando …",
     "Please log in before granting %1$s access to your %2$s account." : "Logue-se antes de conceder acesso %1$s à sua conta %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Atualmente logado como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Você irá conceder acesso %1$s à sua conta %2$s.",
+    "%1$s will be updated to version %2$s" : "%1$s será atualizado para a versão %2$s",
+    "The following apps will be updated:" : "Os seguintes aplicativos serão atualizados:",
+    "The theme %s has been disabled." : "O tema %s foi desativado.",
+    "Detailed logs" : "Logs detalhados",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Precisando de ajuda, leia a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
