@@ -198,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo Windows Media",
     "AVI video" : "Vídeo AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em progresso. Se sair desta página poderá interromper o processo em alguns ambientes.",
-    "Update to {version}" : "Atualizar para {version}",
-    "An error occurred." : "Ocorreu um erro.",
-    "Please reload the page." : "Por favor, recarregue a página.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, reporte este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
-    "Continue to {productName}" : "Continuar para {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi concluída. A redirecionar para {productName} dentro de %n segundo.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos."],
     "Done" : "Concluído",
     "Applications menu" : "Menu de Aplicações",
     "Apps" : "Aplicações",
@@ -309,8 +301,8 @@ OC.L10N.register(
     "Loading your contacts …" : "A carregar os seus contactos...",
     "Looking for {term} …" : "A procurar por {term} …",
     "Search contacts" : "Pesquisar contactos",
-    "Reset search" : "Redefinir pesquisa",
     "Search contacts …" : "Procurar contactos...",
+    "Reset search" : "Redefinir pesquisa",
     "Could not load your contacts" : "Não foi possível carregar os seus contactos",
     "No contacts found" : "Não foram encontrados contactos",
     "Show all contacts" : "Mostrar todos os contactos",
@@ -392,6 +384,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador não é suportado. Por favor, atualize para uma versão mais recente ou para um suportado.",
     "Continue with this unsupported browser" : "Continuar com este navegador não suportado",
     "Supported versions" : "Versões suportadas",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "A atualização está em progresso. Se sair desta página poderá interromper o processo em alguns ambientes.",
+    "App update required" : "É necessário atualizar a aplicação",
+    "These incompatible apps will be disabled:" : "Estas aplicações incompatíveis irão ser desativadas:",
+    "These apps will be updated:" : "Estas aplicações irão ser atualizadas.",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
+    "Start update" : "Iniciar atualização",
+    "Continue to {productName}" : "Continuar para {productName}",
+    "Update to {version}" : "Atualizar para {version}",
+    "Hide details" : "Ocultar detalhes",
+    "Show details" : "Mostrar detalhes",
+    "Update needed" : "É necessário atualizar",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Use o atualizador de linha de comandos porque tem uma instância grande com mais de 50 contas.",
+    "Documentation" : "Documentação",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a atualização via interface web arrisco a que o pedido expire e pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
+    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
     "Search {types} …" : "Pesquisar {types}...",
     "Choose {file}" : "Escolher {file}",
     "Choose" : "Escolher",
@@ -417,19 +425,13 @@ OC.L10N.register(
     "Group list is empty" : "Lista de grupo vazia",
     "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
     "seconds ago" : "segundos atrás",
-    "Connection to server lost" : "Ligação perdida ao servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar em %n segundo","Problema ao carregar a página. A recarregar em  %n segundos","Problema ao carregar a página. A recarregar em %n segundos"],
     "Add to a project" : "Adicionar a um projeto",
-    "Show details" : "Mostrar detalhes",
-    "Hide details" : "Ocultar detalhes",
     "Rename project" : "Renomear projeto",
     "Failed to rename the project" : "Erro ao renomear o projeto",
     "Failed to create a project" : "Erro ao criar o projeto",
     "Failed to add the item to the project" : "Falha ao adicionar item ao projeto",
     "Connect items to a project to make them easier to find" : "Ligar itens a um projeto para poderem ser mais facilmente encontrados",
     "Type to search for existing projects" : "Digite para procurar por projetos existentes",
-    "New in" : "Novo em",
-    "View changelog" : "Ver registo de alterações",
     "Close \"{dialogTitle}\" dialog" : "Fechar diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "O tamanho do email atingiu o máximo (255)",
     "Clipboard not available, please copy manually" : "Área de transferência indisponível, copie manualmente",
@@ -481,20 +483,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Aceder através de um domínio não confiável",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Por favor contacte o seu administrador. Se é um administrador, edite a definição \"trusted_domains\" no config/config.php como no exemplo em config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mais informação acerca de como configurar pode ser encontrada na %1$sdocumentação%2$s. ",
-    "App update required" : "É necessário atualizar a aplicação",
-    "%1$s will be updated to version %2$s" : "%1$s irá ser atualizada para a versão %2$s",
-    "The following apps will be updated:" : "As seguintes aplicações serão atualizadas:",
-    "These incompatible apps will be disabled:" : "Estas aplicações incompatíveis irão ser desativadas:",
-    "The theme %s has been disabled." : "O tema %s foi desativado.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Por favor, certifique-se de que foi efetuada uma cópia de segurança da base de dados, pasta de configuração e de dados antes de prosseguir.",
-    "Start update" : "Iniciar atualização",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
-    "Detailed logs" : "Registos detalhados",
-    "Update needed" : "É necessário atualizar",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Use o atualizador de linha de comandos porque tem uma instância grande com mais de 50 contas.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a atualização via interface web arrisco a que o pedido expire e pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
-    "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
     "Maintenance mode" : "Modo de manutenção",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instância %s está atualmente no modo de manutenção, o que poderá demorar algum tempo.",
     "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
@@ -509,6 +497,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Resultados da pesquisa<script>alert(1)</script></strong>",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["transferir %n ficheiro","transferir %n ficheiros","transferir %n ficheiros"],
+    "An error occurred." : "Ocorreu um erro.",
+    "Please reload the page." : "Por favor, recarregue a página.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "A atualização falhou. Para mais informação <a href=\"{url}\">consulte o nosso artigo do fórum</a> sobre como resolver este problema.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "A atualização não foi bem sucedida. Por favor, reporte este problema à <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunidade de Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["A atualização foi concluída. A redirecionar para {productName} dentro de %n segundo.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos.","A atualização foi concluída. A redirecionar para {productName} dentro de %n segundos."],
     "Direct link copied to clipboard" : "Ligação direta copiada para a área de transferência",
     "Searching …" : "A procurar…",
     "Logging in …" : "A iniciar a sessão...",
@@ -521,6 +514,10 @@ OC.L10N.register(
     "Loading more results …" : "A carregar mais resultados...",
     "Search {types} …" : "Pesquisar {types}...",
     "Saving …" : "A guardar...",
+    "Connection to server lost" : "Ligação perdida ao servidor",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema a carregar a página. A recarregar em %n segundo","Problema ao carregar a página. A recarregar em  %n segundos","Problema ao carregar a página. A recarregar em %n segundos"],
+    "New in" : "Novo em",
+    "View changelog" : "Ver registo de alterações",
     "Very weak password" : "Palavra-passe muito fraca",
     "Weak password" : "Palavra-passe fraca",
     "So-so password" : "Palavra-passe aceitável",
@@ -547,6 +544,11 @@ OC.L10N.register(
     "Installing …" : "A instalar...",
     "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Atualmente com sessão iniciada como %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir que %1$s aceda à sua conta %2$s. "
+    "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir que %1$s aceda à sua conta %2$s. ",
+    "%1$s will be updated to version %2$s" : "%1$s irá ser atualizada para a versão %2$s",
+    "The following apps will be updated:" : "As seguintes aplicações serão atualizadas:",
+    "The theme %s has been disabled." : "O tema %s foi desativado.",
+    "Detailed logs" : "Registos detalhados",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
