@@ -75,14 +75,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Următoarele aplicații au fost dezactivate: %s",
     "Already up to date" : "Deja actualizat",
     "Unknown" : "Necunoscut",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în desfășurare, părăsirea acestei pagini ar putea întrerupe procesul în anumite medii.",
-    "Update to {version}" : "Actualizare la {version}",
-    "An error occurred." : "A apărut o eroare.",
-    "Please reload the page." : "Te rugăm să reîncarci pagina.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Actualizarea nu a reușit. Pentru mai multe informații <a href=\"{url}\">verificați postările din forum</a> pe această temă.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Actualizarea nu a reușit. Te rugăm să raportezi această problemă <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunității Nextcloud</a>.",
-    "Continue to {productName}" : "Continuă la {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Actualizare efectuată. Redirectare la {productName} în %n secundă.","Actualizare efectuată. Redirectare la {productName} în %n seconde.","Actualizare efectuată. Redirectare la {productName} în %n secunde."],
     "Done" : "Realizat",
     "Applications menu" : "Meniul aplicațiilor",
     "Apps" : "Aplicații",
@@ -210,6 +202,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
     "Continue with this unsupported browser" : "Continuă cu browserul incompatibil",
     "Supported versions" : "Versiuni compatibile",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Actualizarea este în desfășurare, părăsirea acestei pagini ar putea întrerupe procesul în anumite medii.",
+    "App update required" : "E necesară o actualizare a aplicației",
+    "These incompatible apps will be disabled:" : "Aceste aplicații incompatibile vor fi dezactivate:",
+    "These apps will be updated:" : "Aceste aplicații vor fi actualizate:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asigură-te că ai creat un backup pentru baza de date, folderul config și folderul de date înainte de a continua.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pentru a evita timeout-uri la instalări de mari dimensiuni, poți rula în schimb următoarea comandă în folderul de instalare:",
+    "Start update" : "Începe actualizarea",
+    "Continue to {productName}" : "Continuă la {productName}",
+    "Update to {version}" : "Actualizare la {version}",
+    "Hide details" : "Ascunde detaliile",
+    "Show details" : "Arată detaliile",
+    "Update needed" : "E necesară actualizarea",
+    "Documentation" : "Documentație",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Înțeleg că dacă continui să folosesc actualizarea din interfața web, există riscul ca cererea să expire și să cauzeze pierderi de date, dar am un backup și știu cum sa restaurez sesiunea în caz de eșec.",
+    "Upgrade via web on my own risk" : "Actualizare prin interfața web pe riscul meu",
     "Choose {file}" : "Selectați {file}",
     "Choose" : "Alege",
     "Copy to {target}" : "Copiază la {target}",
@@ -233,19 +240,13 @@ OC.L10N.register(
     "Group list is empty" : "Lista de grupuri este goală",
     "Unable to retrieve the group list" : "Nu s-a putut obține lista de grupuri",
     "seconds ago" : "secunde în urmă",
-    "Connection to server lost" : "S-a pierdut conexiunea la server",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
     "Add to a project" : "Adaugă la un proiect",
-    "Show details" : "Arată detaliile",
-    "Hide details" : "Ascunde detaliile",
     "Rename project" : "Redenumește proiectul",
     "Failed to rename the project" : "Redenumirea proiectului a eșuat",
     "Failed to create a project" : "Creearea proiectului a eșuat",
     "Failed to add the item to the project" : "Eroare la adăugarea elementului la proiect",
     "Connect items to a project to make them easier to find" : "Conectați elemente la un proiect pentru a le face mai accesibile",
     "Type to search for existing projects" : "Tastați pentru căutarea proiectelor",
-    "New in" : "Nou în",
-    "View changelog" : "Vezi changelog",
     "Close \"{dialogTitle}\" dialog" : "Închide dialogul \"{dialogTitle}\"",
     "Personal" : "Personal",
     "Accounts" : "Conturi",
@@ -293,19 +294,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Acces printr-un domeniu nesigur",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vă rugăm contactați administratorul. Dacă sunteți administrator, editați setarea \"trusted_domains\" în config/config.php la fel ca în exemplul din config.sample.php",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Mai multe informații despre cum se configurează aceasta se găsește în %1$sdocumentație%2$s.",
-    "App update required" : "E necesară o actualizare a aplicației",
-    "%1$s will be updated to version %2$s" : "%1$sva fi actualizat la versiunea %2$s",
-    "The following apps will be updated:" : "Următoarele aplicații vor fi actualizate:",
-    "These incompatible apps will be disabled:" : "Aceste aplicații incompatibile vor fi dezactivate:",
-    "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Asigură-te că ai creat un backup pentru baza de date, folderul config și folderul de date înainte de a continua.",
-    "Start update" : "Începe actualizarea",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Pentru a evita timeout-uri la instalări de mari dimensiuni, poți rula în schimb următoarea comandă în folderul de instalare:",
-    "Detailed logs" : "Loguri detaliate",
-    "Update needed" : "E necesară actualizarea",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pentru ajutor, vedeți  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentația</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Înțeleg că dacă continui să folosesc actualizarea din interfața web, există riscul ca cererea să expire și să cauzeze pierderi de date, dar am un backup și știu cum sa restaurez sesiunea în caz de eșec.",
-    "Upgrade via web on my own risk" : "Actualizare prin interfața web pe riscul meu",
     "Maintenance mode" : "Mod mentenanță",
     "This %s instance is currently in maintenance mode, which may take a while." : "Instanța %s este acum în modul de mentenanță, ceea ce ar putea dura o vreme.",
     "This page will refresh itself when the instance is available again." : "Această pagină se va actualiza automat când instanța va fi disponibilă din nou.",
@@ -320,6 +308,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Acestea sunt rezultatele căutării tale<script>alert(1)</script></strong>",
     "new" : "nou",
     "_download %n file_::_download %n files_" : ["descarcă %n fișier","descarcă %n fișiere","descarcă %n fișiere"],
+    "An error occurred." : "A apărut o eroare.",
+    "Please reload the page." : "Te rugăm să reîncarci pagina.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Actualizarea nu a reușit. Pentru mai multe informații <a href=\"{url}\">verificați postările din forum</a> pe această temă.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Actualizarea nu a reușit. Te rugăm să raportezi această problemă <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">comunității Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Actualizare efectuată. Redirectare la {productName} în %n secundă.","Actualizare efectuată. Redirectare la {productName} în %n seconde.","Actualizare efectuată. Redirectare la {productName} în %n secunde."],
     "Searching …" : "Căutare ...",
     "Logging in …" : "Se autentifică...",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Au fost detectate mai multe încercări de logare eșuate de la adresa dumneavoastră IP. De aceea, următoarea încercare va fi încetinită până la 30 de secunde.",
@@ -331,6 +324,10 @@ OC.L10N.register(
     "Loading more results …" : "Se încarcă mai multe rezultate ...",
     "Search {types} …" : "Căutare {types} …",
     "Saving …" : "Se salvează",
+    "Connection to server lost" : "S-a pierdut conexiunea la server",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleme la încărcarea paginii, se reîncarcă într-o secundă","Probleme la încărcarea paginii, se reîncarcă în câteva secunde","Probleme la încărcarea paginii, se reîncarcă în %n secunde"],
+    "New in" : "Nou în",
+    "View changelog" : "Vezi changelog",
     "Very weak password" : "Parolă foarte slabă",
     "Weak password" : "Parolă slabă",
     "So-so password" : "Parolă medie",
@@ -354,6 +351,11 @@ OC.L10N.register(
     "Installing …" : "Se instalează ...",
     "Please log in before granting %1$s access to your %2$s account." : "Trebuie să vă logați înainte de a permite accesul %1$s la contul dumneavoastră %2$s.",
     "Currently logged in as %1$s (%2$s)." : "Autentificat ca %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău."
+    "You are about to grant %1$s access to your %2$s account." : "Ești pe cale să permiți %1$s accesul la %2$s contul tău.",
+    "%1$s will be updated to version %2$s" : "%1$sva fi actualizat la versiunea %2$s",
+    "The following apps will be updated:" : "Următoarele aplicații vor fi actualizate:",
+    "The theme %s has been disabled." : "Tema %s a fost dezactivată.",
+    "Detailed logs" : "Loguri detaliate",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pentru ajutor, vedeți  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentația</a>."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
