@@ -42,13 +42,17 @@ OC.L10N.register(
     "Not found" : "Nenájdené",
     "Node is locked" : "Uzol je uzamknutý",
     "Bad request" : "Neplatná požiadavka",
+    "Input text is too long" : "Vstupný text je príliš dlhý.",
     "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
     "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
+    "Cannot generate more than 12 images" : "Nie je možné vygenerovať viac ako 12 obrázkov",
+    "Cannot generate less than 1 image" : "Nie je možné vygenerovať menej ako 1 obrázok",
     "No text to image provider is available" : "Nie je dostupný žiadny poskytovateľ služby \"text na obrázok\"",
     "Image not found" : "Obrázok nenájdený",
     "No translation provider available" : "Nie je dostupný žiadny poskytovateľ prekladu",
     "Could not detect language" : "Nepodarilo sa zistiť jazyk",
     "Unable to translate" : "Nie je možné preložiť",
+    "No valid filters provided" : "Žiadne platné filtre poskytnuté",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Krok opravy:",
     "Repair info:" : "Informácie o oprave:",
@@ -77,8 +81,10 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (nekompatibilná)",
     "The following apps have been disabled: %s" : "Nasledujúce aplikácie boli vypnuté: %s",
     "Already up to date" : "Už aktuálne",
+    "Windows Command Script" : "Skript príkazov Windows",
     "Electronic book document" : "Dokument elektronickej knihy",
     "TrueType Font Collection" : "Kolekcia fontov TrueType",
+    "Web Open Font Format" : "Web Open Font Format",
     "GPX geographic data" : "GPX geografické dáta",
     "Gzip archive" : "Gzip archív",
     "Adobe Illustrator document" : "Dokument Adobe Illustrator",
@@ -152,34 +158,67 @@ OC.L10N.register(
     "WebM audio" : "WebM audio",
     "MP3 ShoutCast playlist" : "MP3 ShoutCast playlist",
     "Windows BMP image" : "Obrázok Windows BMP",
-    "unknown text" : "neznámy text",
-    "Hello world!" : "Ahoj svet!",
-    "sunny" : "slnečno",
-    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
-    "Hello {name}" : "Vitaj {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
-    "new" : "nový",
-    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
-    "Update to {version}" : "Aktualizuj na {version}",
-    "An error occurred." : "Vyskytla sa chyba.",
-    "Please reload the page." : "Obnovte prosím stránku.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
-    "Continue to {productName}" : "Pokračovať na {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
+    "Better Portable Graphics image" : "Lepší prenosný grafický obrázok",
+    "EMF image" : "EMF obrázok",
+    "GIF image" : "GIF obrázok",
+    "HEIC image" : "HEIC obrázok",
+    "HEIF image" : "HEIF obrázok",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 obrázok",
+    "JPEG image" : "JPEG obrázok",
+    "PNG image" : "PNG obrázok",
+    "SVG image" : "SVG obrázok",
+    "Truevision Targa image" : "Truevision Targa obrázok",
+    "TIFF image" : "TIFF obrázok",
+    "WebP image" : "WebP obrázok",
+    "Digital raw image" : "Digital raw obrázok",
+    "Windows Icon" : "Windows ikona",
+    "Email message" : "E-mailová správa",
+    "VCS/ICS calendar" : "VCS/ICS kalendár",
+    "CSS stylesheet" : "CSS štýlový list",
+    "CSV document" : "CSV dokument",
+    "HTML document" : "HTML dokument",
+    "Markdown document" : "Markdown dokument",
+    "Org-mode file" : "Org-mode súbor",
+    "Plain text document" : "Dokument v čistom texte",
+    "Rich Text document" : "Dokument vo formátovanom texte",
+    "Electronic business card" : "Elektronická vizitka",
+    "C++ source code" : "C++ zdrojový kód",
+    "LDIF address book" : "Adresár LDIF",
+    "NFO document" : "NFO dokument",
+    "PHP source" : "PHP zdroj",
+    "Python script" : "Python skript",
+    "ReStructuredText document" : "ReStructuredText dokument",
+    "3GPP multimedia file" : "3GPP multimediálny súbor",
+    "MPEG video" : "MPEG video",
+    "DV video" : "DV video",
+    "MPEG-2 transport stream" : "MPEG-2 transportný tok",
+    "MPEG-4 video" : "MPEG-4 video",
+    "Ogg video" : "Ogg video",
+    "QuickTime video" : "QuickTime video",
+    "WebM video" : "WebM video",
+    "Flash video" : "Flash video",
+    "Matroska video" : "Matroska video",
+    "Windows Media video" : "Windows Media video",
+    "AVI video" : "AVI video",
+    "Done" : "Hotovo",
+    "Scan QR code to log in" : "Naskenujte QR kód na prihlásenie",
+    "Use {productName} mobile client you want to connect to scan the code" : "Použite {productName} mobilného klienta, ktorý chcete pripojiť, na naskenovanie kódu.",
+    "Code will expire {timeCountdown} or after use" : "Kód vyprší {timeCountdown} alebo po použití",
     "Applications menu" : "Ponuka aplikácií",
     "Apps" : "Aplikácie",
     "More apps" : "Viac aplikácií",
     "_{count} notification_::_{count} notifications_" : ["{count} upozornenie","{count} upozornenia","{count} upozornení","{count} upozornenia"],
     "No" : "Nie",
     "Yes" : "Áno",
+    "App password" : "Heslo aplikácie",
+    "Grant access" : "Povoliť prístup",
     "The remote URL must include the user." : "Vzdialená adresa URL musí zahŕňať užívateľa.",
     "Invalid remote URL." : "Neplatná vzdialená adresa URL.",
     "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud zlyhalo",
     "Federated user" : "Združený užívateľ",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "Vytvoriť zdieľanie",
+    "Direct link copied" : "Priamy odkaz skopírovaný",
     "Please copy the link manually:" : "Prosím skopírujte odkaz manuálne:",
     "Custom date range" : "Vlastné rozpätie dátumov",
     "Pick start date" : "Vyberte dátum začiatku",
@@ -188,14 +227,16 @@ OC.L10N.register(
     "Search in current app" : "Hľadať v aktuálnej aplikácii",
     "Clear search" : "Vymazať hľadanie",
     "Search everywhere" : "Hľadať všade",
-    "Searching …" : "Hľadá sa…",
+    "Searching …" : "Vyhľadáva sa …",
     "Start typing to search" : "Začnite písať pre vyhľadanie",
+    "Minimum search length is {minSearchLength} characters" : "Minimálna dĺžka vyhľadávania je {minSearchLength} znakov",
     "No matching results" : "Žiadne zhodujúce výsledky",
     "Today" : "Dnes",
     "Last 7 days" : "Posledných 7 dní",
     "Last 30 days" : "Posledných 30 dní",
     "This year" : "Tento rok",
     "Last year" : "Minulý rok",
+    "Between {startDate} and {endDate}" : "Medzi {startDate} a {endDate}",
     "Unified search" : "Jednotné vyhľadávanie",
     "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
     "Places" : "Miesta",
@@ -203,15 +244,17 @@ OC.L10N.register(
     "Search people" : "Hľadať ľudí",
     "People" : "Ľudia",
     "Filter in current view" : "Filter v aktuálnom zobrazení",
+    "Search connected services" : "Vyhľadávať pripojené služby",
     "Results" : "Výsledky",
     "Load more results" : "Načítať viac výsledkov",
     "Search in" : "Hľadať v",
+    "Partial matches" : "Čiastočné zhody",
     "Log in" : "Prihlásiť sa",
-    "Logging in …" : "Prihlasujem ...",
+    "Logging in …" : "Prebieha prihlasovanie …",
     "Log in to {productName}" : "Prihlásiť sa do {productName}u",
     "Wrong login or password." : "Nesprávne meno alebo heslo.",
     "This account is disabled" : "Tento účet je deaktivovaný",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Príliš veľa neúspešných pokusov o prihlásenie. Skúste to znova o 30 sekúnd.",
     "Account name or email" : "Názov účtu alebo e-mail",
     "Account name" : "Názov účtu",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
@@ -221,6 +264,7 @@ OC.L10N.register(
     "An internal error occurred." : "Došlo k vnútornej chybe.",
     "Please try again or contact your administrator." : "Skúste to znovu, alebo sa obráťte na vášho administrátora.",
     "Password" : "Heslo",
+    "Remember me" : "Zapamätať si ma",
     "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
     "Login or email" : "Prihlasovacie meno alebo email",
     "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
@@ -244,23 +288,34 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
     "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
     "Recommended apps" : "Odporúčané apky",
-    "Loading apps …" : "Načítavanie apiek...",
+    "Loading apps …" : "Načítavanie aplikácií ...",
     "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
     "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
     "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
     "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
     "Skip" : "Preskočiť",
-    "Installing apps …" : "Inštalácia apiek...",
+    "Installing apps …" : "Inštalácia aplikácií …",
     "Install recommended apps" : "Nainštalovať odporúčané apky",
+    "Online" : "Pripojený",
+    "Away" : "Preč",
+    "Busy" : "Zaneprázdnený",
+    "Do not disturb" : "Nerušiť",
+    "Mute all notifications" : "Stlmiť všetky upozornenia",
+    "Invisible" : "Neviditeľný",
+    "Appear offline" : "Zdá sa byť offline",
     "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
     "Settings menu" : "Menu nastavení",
-    "Loading your contacts …" : "Načítavam vaše kontakty...",
-    "Looking for {term} …" : "Hľadá sa výraz {term}...",
+    "Loading your contacts …" : "Načítavanie vašich kontaktov...",
+    "Looking for {term} …" : "Hľadá sa {term}...",
     "Search contacts" : "Prehľadať kontakty",
+    "Filter by team" : "Filtrovať podľa tímu",
+    "All teams" : "Všetky tímy",
+    "Search contacts in team {team}" : "Vyhľadať kontakty v tíme {team}",
+    "Search contacts …" : "Prehľadať kontakty ...",
     "Reset search" : "Vynuluj vyhľadávanie",
-    "Search contacts …" : "Prehľadať kontakty...",
     "Could not load your contacts" : "Nie je možné načítať Vaše kontakty",
     "No contacts found" : "Kontakty nenájdené",
+    "Contacts list" : "Zoznam kontaktov",
     "Show all contacts" : "Zobraziť všetky kontakty",
     "Install the Contacts app" : "Inštalovať aplikáciu Kontakty",
     "Search" : "Hľadať",
@@ -270,13 +325,39 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
     "Search for {name} only" : "Hľadať iba {name}",
-    "Loading more results …" : "Načítava sa viac výsledkov …",
+    "Loading more results …" : "Načítava sa viac výsledkov …",
     "Forgot password?" : "Zabudli ste heslo?",
     "Back to login form" : "Späť na prihlásenie",
     "Back" : "Späť",
     "Login form is disabled." : "Prihlasovací formulár je vypnutý.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prihlasovanie do Nextcloud je zakázané. Použite inú možnosť prihlásenia, ak je k dispozícii, alebo kontaktujte svojho administrátora.",
+    "Connect to your account" : "Pripojte sa k svojmu účtu",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Pred prístupom {instanceName} k vášmu účtu \"{client}\" sa prosím prihláste.",
+    "Security warning" : "Bezpečnostné varovanie",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
+    "Log in using password" : "Prihlásenie pomocou hesla",
+    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
+    "Account connected" : "Účet pripojený",
+    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
+    "You can close this window." : "Toto okno už môžete zatvoriť.",
+    "Account access" : "Prístup k účtu",
+    "Currently logged in as {userDisplayName} ({userId})." : "Momentálne ste prihlásený ako {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Chystáte sa povoliť prístup \"{client}\" k vášmu účtu {instanceName}.",
     "More actions" : "Viac akcií",
+    "User menu" : "Používateľské menu",
+    "Your guest name: {user}" : "Vaše meno hosťa: {user}",
+    "You are currently not identified." : "Momentálne nie ste identifikovaní.",
+    "Set public name" : "Nastaviť verejné meno",
+    "Change public name" : "Zmeniť verejné meno",
+    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
+    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
+    "Submit" : "Odoslať",
+    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
+    "Password sent!" : "Heslo odoslané!",
+    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
+    "Email address" : "E-mailová adresa",
+    "Request password" : "Vyžiadať heslo",
+    "Forgot password" : "Zabudnuté heslo",
     "Password is too weak" : "Heslo je príliš jednoduché",
     "Password is weak" : "Heslo je jednoduché",
     "Password is average" : "Heslo je priemerné",
@@ -288,13 +369,13 @@ OC.L10N.register(
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pre informácie o tom, ako správne nakonfigurovať server, prosím navštívte {linkStart} dokumentáciu {linkEnd}",
     "Autoconfig file detected" : "Detekovaný súbor automatickej konfigurácie",
     "The setup form below is pre-filled with the values from the config file." : "Inštalačný formulár nižšie je vopred vyplnený hodnotami z konfiguračného súboru.",
-    "Security warning" : "Bezpečnostné varovanie",
     "Create administration account" : "Vytvoriť účet administrátora",
     "Administration account name" : "Názov účtu administrátora",
     "Administration account password" : "Heslo účtu administrátora",
     "Storage & database" : "Úložisko & databáza",
     "Data folder" : "Priečinok dát",
     "Database configuration" : "Konfigurácia Databáze",
+    "Database type" : "Typ databázy",
     "Only {firstAndOnlyDatabase} is available." : "Je dostupná iba {firstAndOnlyDatabase}",
     "Install and activate additional PHP modules to choose other database types." : "Pri výbere iného typu databázy bude potrebné nainštalovať a aktivovať ďalšie PHP moduly.",
     "For more details check out the documentation." : "Viac informácií nájdete v dokumentácii.",
@@ -302,6 +383,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Ako databázu ste vybrali SQLite.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by sa malo používať len pre naozaj maličké alebo vývojové inštancie. Pre produkčné použitie výrazne odporúčame použiť robustnejšiu databázu.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ak používate klientské aplikácie pre synchronizáciu súborov, tak výrazne odporúčame nepoužívať SQLite.",
+    "Database connection" : "Pripojenie k databáze",
     "Database user" : "Používateľ databázy",
     "Database password" : "Heslo databázy",
     "Database name" : "Meno databázy",
@@ -309,7 +391,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadajte číslo portu spolu s názvom hostiteľa (napr. localhost:5432).",
     "Database host" : "Server databázy",
     "localhost" : "localhost",
-    "Installing …" : "Inštalujem ...",
+    "Installing …" : "Inštalujem ...",
     "Install" : "Inštalovať",
     "Need help?" : "Potrebujete pomoc?",
     "See the documentation" : "Pozri dokumentáciu",
@@ -318,7 +400,33 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
     "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
     "Supported versions" : "Podporované verzie",
-    "Search {types} …" : "Vyhľadať {types}",
+    "The update completed with warnings. Please check the details for more information." : "Aktualizácia bola dokončená s varovaniami. Skontrolujte podrobnosti pre viac informácií.",
+    "The update completed successfully." : "Aktualizácia bola úspešne dokončená.",
+    "Preparing update…" : "Pripravuje sa aktualizácia ...",
+    "You will be redirected to {productName} in {count} seconds." : "Budete presmerovaní na {productName} za {count} sekúnd.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Aktualizácie prebieha. V niektorých prostrediach môže opustenie tejto stránky spôsobiť prerušenie aktualizácie.",
+    "App update required" : "Je nutná aktualizácia aplikácie",
+    "{productName} will be updated to version {version}" : "{productName} bude zaktualizovaný na verziu {version}.",
+    "The theme {oldTheme} has been disabled." : "Téma {oldTheme} bola zakázaná.",
+    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
+    "Incompatible apps" : "Nekompatibilné aplikácie",
+    "These apps will be updated:" : "Tieto aplikácie budú aktualizované:",
+    "Apps to update" : "Aplikácie na aktualizáciu",
+    "{app} from {oldVersion} to {version}" : "{app} z {oldVersion} na {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
+    "Start update" : "Spustiť aktualizáciu",
+    "Continue to {productName}" : "Pokračovať na {productName}",
+    "Update to {version}" : "Aktualizuj na {version}",
+    "Hide details" : "Skryť podrobnosti",
+    "Show details" : "Zobraziť podrobnosti",
+    "Update details" : "Detaily aktualizácie",
+    "Update needed" : "Aktualizácia je potrebná",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 účtami.",
+    "Documentation" : "Dokumentácia",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Viem, že ak budem pokračovať v aktualizácii prostredníctvom webového rozhrania, existuje riziko, že žiadosť prekročí časový limit a môže spôsobiť stratu dát, ale mám zálohu a viem, ako obnoviť svoju inštanciu v prípade zlyhania.",
+    "Upgrade via web on my own risk" : "Aktualizovať cez web na vlastné riziko",
+    "Search {types} …" : "Vyhľadať {types} ...",
     "Choose {file}" : "Vyberte {file}",
     "Choose" : "Vybrať",
     "Copy to {target}" : "Kopírovať do {target}",
@@ -338,23 +446,18 @@ OC.L10N.register(
     "(all selected)" : "(všetko vybrané)",
     "({count} selected)" : "({count} vybraných)",
     "Error loading file exists template" : "Chyba pri nahrávaní šablóny existencie súboru",
-    "Saving …" : "Ukladá sa...",
+    "Saving …" : "Ukladanie …",
+    "Groups" : "Skupiny",
+    "Group list is empty" : "Zoznam skupín je prázdny",
+    "Unable to retrieve the group list" : "Nie je možné načítať zoznam skupín",
     "seconds ago" : "pred sekundami",
-    "Connection to server lost" : "Stratené spojenie so serverom",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
     "Add to a project" : "Pridať do projektu",
-    "Show details" : "Zobraziť podrobnosti",
-    "Hide details" : "Skryť podrobnosti",
     "Rename project" : "Premenovať projekt",
     "Failed to rename the project" : "Nepodarilo sa premenovať projekt",
     "Failed to create a project" : "Nepodarilo sa vytvoriť projekt",
     "Failed to add the item to the project" : "Nepodarilo sa pridať položku do projektu",
     "Connect items to a project to make them easier to find" : "Priradiť položky do projektu, aby sa ľahšie hľadali",
     "Type to search for existing projects" : "Hľadajte v existujúcich projektoch",
-    "New in" : "Nové v",
-    "View changelog" : "Zobraziť súhrn zmien",
-    "No action available" : "NIe sú dostupné žiadne akcie",
-    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zatvoriť okno \"{dialogTitle}\"",
     "Email length is at max (255)" : "E-mailová správa má maximálnu veľkosť (255)",
     "Clipboard not available, please copy manually" : "Schránka nie je k dispozícii, prosím skopírujte ručne",
@@ -363,6 +466,7 @@ OC.L10N.register(
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
     "Access forbidden" : "Prístup odmietnutý",
+    "You are not allowed to access this page." : "Nie je vám povolený prístup na túto stránku.",
     "Back to %s" : "Späť na %s",
     "Page not found" : "Stránka nenájdená",
     "The page could not be found on the server or you may not be allowed to view it." : "Túto stránku sa nepodarilo na serveri nájsť alebo nemáte oprávnenie na jej zobrazenie.",
@@ -390,25 +494,7 @@ OC.L10N.register(
     "Skip to navigation of app" : "Preskočiť do navigácie apky",
     "Go to %s" : "Prejsť na %s",
     "Get your own free account" : "Získajte zdarma svoj vlastný účet",
-    "Connect to your account" : "Pripojte sa k svojmu účtu",
-    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
-    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ak sa nesnažíte nastaviť nové zariadenie alebo aplikáciu, niekto sa vás pokúša oklamať, aby ste im poskytli prístup k vašim údajom. V takom prípade nepokračujte a obráťte sa na správcu systému.",
-    "App password" : "Heslo aplikácie",
-    "Grant access" : "Povoliť prístup",
-    "Alternative log in using app password" : "Alternatívne prihlásenie pomocou hesla aplikácie",
-    "Account access" : "Prístup k účtu",
-    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
-    "Account connected" : "Účet pripojený",
-    "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
-    "You can close this window." : "Toto okno už môžete zatvoriť.",
     "Previous" : "Predchádzajúce",
-    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
-    "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
-    "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
-    "Email address" : "E-mailová adresa",
-    "Password sent!" : "Heslo odoslané!",
-    "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
     "Two-factor authentication" : "Dvojfázové overovanie",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načítať minimálne jeden z vašich povolených spôsobov na dvojfázové overovanie. Kontaktujte prosím správcu systému.",
@@ -423,50 +509,54 @@ OC.L10N.register(
     "Access through untrusted domain" : "Prístup cez nedôveryhodnú doménu",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Kontaktujte svojho správcu. Ak ste administrátorom vy, upravte nastavenie \"trusted_domains\" v config/config.php ako napríklad v config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Viac informácií o konfigurácii je možné nájsť v %1$s dokumentácii %2$s.",
-    "App update required" : "Je nutná aktualizácia aplikácie",
-    "%1$s will be updated to version %2$s" : "%1$s bude zaktualizovaný na verziu %2$s.",
-    "The following apps will be updated:" : "Aktualizujú sa nasledujúce aplikácie:",
-    "These incompatible apps will be disabled:" : "Tieto nekompatibilné aplikácie budú vypnuté:",
-    "The theme %s has been disabled." : "Téma %s bola zakázaná.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred vykonaním ďalšieho kroku sa presvedčte, že databáza, konfiguračný a dátový priečinok sú zazálohované.",
-    "Start update" : "Spustiť aktualizáciu",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Aby nedošlo k vypršaniu časového limitu vo väčších inštaláciách, môžete namiesto toho použiť nasledujúci príkaz z inštalačného priečinka:",
-    "Detailed logs" : "Podrobné záznamy",
-    "Update needed" : "Aktualizácia je potrebná",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 účtami.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pre pomoc si pozrite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentáciu</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Viem, že ak budem pokračovať v aktualizácii prostredníctvom webového rozhrania, existuje riziko, že žiadosť prekročí časový limit a môže spôsobiť stratu dát, ale mám zálohu a viem, ako obnoviť svoju inštanciu v prípade zlyhania.",
-    "Upgrade via web on my own risk" : "Aktualizovať cez web na vlastné riziko",
     "Maintenance mode" : "Mód údržby",
     "This %s instance is currently in maintenance mode, which may take a while." : "Táto %s inštancia je v súčasnej dobe v režime údržby. Počkajte prosím.",
     "This page will refresh itself when the instance is available again." : "Táto stránka sa obnoví sama hneď ako bude inštancia znovu dostupná.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
-    "No temporary profile picture available, try again" : "Dočasný profilový obrázok nie je k dispozícii, skúste to znovu",
-    "No crop data provided" : "Dáta pre orezanie neboli zadané",
-    "No valid crop data provided" : "Neplatné dáta pre orezanie neboli zadané",
-    "Crop is not square" : "Orezanie nie je štvorcové",
     "Error occurred while checking server setup" : "Počas kontroly nastavenia serveru sa stala chyba",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Viac podrobností nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
-    "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
-    "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
-    "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
-    "Edit Profile" : "Upraviť rofil",
-    "The headline and about sections will show up here" : "Tu sa zobrazí titul a sekcia Informácie",
+    "unknown text" : "neznámy text",
+    "Hello world!" : "Ahoj svet!",
+    "sunny" : "slnečno",
+    "Hello {name}, the weather is {weather}" : "Dobrý deň {name}, počasie je {weather}",
+    "Hello {name}" : "Vitaj {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Toto sú výsledky vášho vyhľadávania <script>alert(1)</script></strong>",
+    "new" : "nový",
+    "_download %n file_::_download %n files_" : ["stiahnuť %n súbor","stiahnuť %n súbory","stiahnuť %n súborov","stiahnuť %n súborov"],
+    "An error occurred." : "Vyskytla sa chyba.",
+    "Please reload the page." : "Obnovte prosím stránku.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Aktualizácia neprebehla úspešne. Pre viac informácií <a href=\"{url}\">navštívte príspevok na našom fóre</a>, ktorý pokrýva tento problém.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Aktualizácia bola neúspešná. Oznámte prosím tento problém <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunite Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
+    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky",
+    "Searching …" : "Hľadá sa…",
+    "Logging in …" : "Prihlasujem ...",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
+    "Loading apps …" : "Načítavanie apiek...",
+    "Installing apps …" : "Inštalácia apiek...",
+    "Loading your contacts …" : "Načítavam vaše kontakty...",
+    "Looking for {term} …" : "Hľadá sa výraz {term}...",
+    "Search contacts …" : "Prehľadať kontakty...",
+    "Loading more results …" : "Načítava sa viac výsledkov …",
+    "Search {types} …" : "Vyhľadať {types}",
+    "Saving …" : "Ukladá sa...",
+    "Connection to server lost" : "Stratené spojenie so serverom",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Nepodarilo sa načítať stránku, opätovný pokus o %n sekundu","Nepodarilo sa načítať stránku, opätovný pokus o %n sekundy","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd","Nepodarilo sa načítať stránku, opätovný pokus o %n sekúnd"],
+    "New in" : "Nové v",
+    "View changelog" : "Zobraziť súhrn zmien",
     "Very weak password" : "Veľmi slabé heslo",
     "Weak password" : "Slabé heslo",
     "So-so password" : "Priemerné heslo",
     "Good password" : "Dobré heslo",
     "Strong password" : "Silné heslo",
+    "No action available" : "NIe sú dostupné žiadne akcie",
+    "Error fetching contact actions" : "Chyba počas získavania akcií kontaktu",
     "Non-existing tag #{tag}" : "Neexistujúci štítok #{tag}",
     "Restricted" : "Obmedzené",
-    "Invisible" : "Neviditeľný",
     "Delete" : "Zmazať",
     "Rename" : "Premenovať",
     "Collaborative tags" : "Štítky pre spoluprácu",
     "No tags found" : "Štítky sa nenašli",
-    "Profile not found" : "Profil nenájdený",
-    "The profile does not exist." : "Profil neexistuje.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pre podrobnosti ako správne nakonfigurovať server si pozrite prosím <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentáciu</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Vytvoriť účet administrátora</strong>",
@@ -477,6 +567,14 @@ OC.L10N.register(
     "Configure the database" : "Nastaviť databázu",
     "Only %s is available." : "Je dostupný len %s.",
     "Database account" : "Databázový účet",
-    "Direct link copied to clipboard" : "Priamy odkaz bol skopírovný do schránky"
+    "Installing …" : "Inštalujem ...",
+    "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
+    "Currently logged in as %1$s (%2$s)." : "Momentálne ste prihlásený ako %1$s (%2$s).",
+    "You are about to grant %1$s access to your %2$s account." : "Chystáte sa udeliť %1$s prístup k svojmu %2$s účtu.",
+    "%1$s will be updated to version %2$s" : "%1$s bude zaktualizovaný na verziu %2$s.",
+    "The following apps will be updated:" : "Aktualizujú sa nasledujúce aplikácie:",
+    "The theme %s has been disabled." : "Téma %s bola zakázaná.",
+    "Detailed logs" : "Podrobné záznamy",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pre pomoc si pozrite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentáciu</a>."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
