@@ -191,14 +191,6 @@ OC.L10N.register(
     "Matroska video" : "Video Matroska",
     "Windows Media video" : "Video Windows Media",
     "AVI video" : "Video AVI",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
-    "Update to {version}" : "Posodobitev na različico {version}",
-    "An error occurred." : "Prišlo je do napake.",
-    "Please reload the page." : "Stran je treba osvežiti.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
-    "Continue to {productName}" : "Nadaljuj v {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
     "Done" : "Končano",
     "Applications menu" : "Meni programov",
     "Apps" : "Programi",
@@ -373,6 +365,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Uporabljen brskalnik ni podprt. Posodobite program na novejšo različico, ali pa uporabite drug program.",
     "Continue with this unsupported browser" : "Nadaljuj delo z nepodprtim brskalnikom",
     "Supported versions" : "Podprte različice",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "V teku je posodobitev. Odhod s te strani lahko v določenih okoljih prekine opravilo.",
+    "App update required" : "Zahtevana je posodobitev programa",
+    "These incompatible apps will be disabled:" : "Zaradi neskladnosti bodo onemogočeni:",
+    "These apps will be updated:" : "Posodobljeni bodo programi:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
+    "Start update" : "Začni posodobitev",
+    "Continue to {productName}" : "Nadaljuj v {productName}",
+    "Update to {version}" : "Posodobitev na različico {version}",
+    "Hide details" : "Skrij podrobnosti",
+    "Show details" : "Pokaži podrobnosti",
+    "Update needed" : "Zahtevana je posodobitev",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Uporabite posodabljalnik ukazne vrstice, ker je v sistemu več kot 50 računov.",
+    "Documentation" : "Dokumentacija",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Zavedam se, da obstaja pri posodabljanju prek spletnega uporabniškega vmesnika nevarnost, da zahteva časovno poteče in s tem povzroči izgubo podatkov. Imam ustvarjeno varnostno kopijo in znam podatke iz kopij v primeru napak obnoviti.",
+    "Upgrade via web on my own risk" : "Posodobi prek spleta kljub večjemu tveganju",
     "Choose {file}" : "Izberite datoteko {file}",
     "Choose" : "Izbor",
     "Copy to {target}" : "Kopiraj na {target}",
@@ -397,19 +405,13 @@ OC.L10N.register(
     "Group list is empty" : "Seznam skupin je prazen",
     "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
     "seconds ago" : "pred nekaj sekundami",
-    "Connection to server lost" : "Povezava s strežnikom je izgubljena",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
     "Add to a project" : "Dodaj k projektu",
-    "Show details" : "Pokaži podrobnosti",
-    "Hide details" : "Skrij podrobnosti",
     "Rename project" : "Preimenuj projekt",
     "Failed to rename the project" : "Preimenovanje projekta je spodletelo.",
     "Failed to create a project" : "Ustvarjanje projekta je spodletelo",
     "Failed to add the item to the project" : "Dodajanje predmeta k projektu je spodletelo.",
     "Connect items to a project to make them easier to find" : "Povežite predmete s projektom, da jih bo lažje najti.",
     "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
-    "New in" : "Novo v",
-    "View changelog" : "Poglej dnevnik sprememb",
     "Close \"{dialogTitle}\" dialog" : "Zapri pogovorno okno »{dialogTitle}«",
     "Email length is at max (255)" : "Dolžina sporočila je dosegla omejitev (255)",
     "Clipboard not available, please copy manually" : "Odložišče ni na voljo, kopirajte ročno",
@@ -460,20 +462,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Dostop z uporabo domene, ki ni zaupanja vredna",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Stopite v stik s skrbnikom sistema. Če ste skrbnik, prilagodite nastavitev »trusted_domains« v datoteki config/config.php, kot je zavedeno v predlogi config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Podrobnosti o možnostih nastavitev je mogoče najti v %1$sdokumentaciji%2$s.",
-    "App update required" : "Zahtevana je posodobitev programa",
-    "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
-    "The following apps will be updated:" : "Navedeni programi bodo posodobljeni:",
-    "These incompatible apps will be disabled:" : "Zaradi neskladnosti bodo onemogočeni:",
-    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pred nadaljevanjem se prepričajte, da je ustvarjena varnostna kopija podatkovne zbirke, nastavitvenih datotek in podatkovne mape.",
-    "Start update" : "Začni posodobitev",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Za razreševanje časovnih zahtev večjih namestitev lahko uporabite ukaz iz namestitvene mape:",
-    "Detailed logs" : "Podrobni dnevniški zapisi",
-    "Update needed" : "Zahtevana je posodobitev",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Uporabite posodabljalnik ukazne vrstice, ker je v sistemu več kot 50 računov.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Za pomoč si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacijo</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Zavedam se, da obstaja pri posodabljanju prek spletnega uporabniškega vmesnika nevarnost, da zahteva časovno poteče in s tem povzroči izgubo podatkov. Imam ustvarjeno varnostno kopijo in znam podatke iz kopij v primeru napak obnoviti.",
-    "Upgrade via web on my own risk" : "Posodobi prek spleta kljub večjemu tveganju",
     "Maintenance mode" : "Vzdrževalni način",
     "This %s instance is currently in maintenance mode, which may take a while." : "Strežnik %s je trenutno v vzdrževalnem načinu, kar onemogoča prijavo.",
     "This page will refresh itself when the instance is available again." : "Stran bo samodejno osvežena, ko bo okolje spet pripravljeno za delo.",
@@ -488,6 +476,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>To so zadetki iskanja<script>alert(1)</script></strong>.",
     "new" : "novo",
     "_download %n file_::_download %n files_" : ["prejmi %n datoteko","prejmi %n datoteki","prejmi %n datoteke","prejmi %n datotek"],
+    "An error occurred." : "Prišlo je do napake.",
+    "Please reload the page." : "Stran je treba osvežiti.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Posodobitev je spodletela. Več podrobnosti o napaki je <a href=\"{url}\">objavljenih na forumu</a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Posodobitev je spodletela. Pošljite poročilo o napaki <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">skupnosti Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundo.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekundi.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekunde.","Posodobitev je bila uspešna. Stran bo preusmerjena na {productName} čez %n sekund."],
     "Direct link copied to clipboard" : "Povezava je kopirana v odložišče.",
     "Searching …" : "Poteka iskanje ...",
     "Logging in …" : "Poteka prijavljanje ...",
@@ -500,6 +493,10 @@ OC.L10N.register(
     "Loading more results …" : "Poteka nalaganje več zadetkov ...",
     "Search {types} …" : "Poišči {types} …",
     "Saving …" : "Poteka shranjevanje ...",
+    "Connection to server lost" : "Povezava s strežnikom je izgubljena",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundo.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekundi.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekunde.","Napaka nalaganja strani! Ponoven poskus bo izveden čez %n sekund."],
+    "New in" : "Novo v",
+    "View changelog" : "Poglej dnevnik sprememb",
     "Very weak password" : "Zelo šibko geslo",
     "Weak password" : "Šibko geslo",
     "So-so password" : "Slabo geslo",
@@ -526,6 +523,11 @@ OC.L10N.register(
     "Installing …" : "Poteka nameščanje ...",
     "Please log in before granting %1$s access to your %2$s account." : "Pred %1$s odobritvijo dostopa %2$s do računa se je treba prijaviti.",
     "Currently logged in as %1$s (%2$s)." : "Dejavna je prijava %1$s (%2$s)",
-    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s."
+    "You are about to grant %1$s access to your %2$s account." : "Računu %1$s boste omogočili dostop do vašega računa %2$s.",
+    "%1$s will be updated to version %2$s" : "Okolje %1$s bo posodobljeno na različico %2$s",
+    "The following apps will be updated:" : "Navedeni programi bodo posodobljeni:",
+    "The theme %s has been disabled." : "Tema %s je onemogočena za uporabo.",
+    "Detailed logs" : "Podrobni dnevniški zapisi",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Za pomoč si oglejte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentacijo</a>."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
