@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "Giriş yazısı çok uzun",
     "Requested task type does not exist" : "İstenilen görev türü bulunamadı",
     "Necessary language model provider is not available" : "Gerekli dil modeli sağlayıcısı kullanılamıyor",
+    "Cannot generate more than 12 images" : "En fazla 12 görsel oluşturulabilir",
+    "Cannot generate less than 1 image" : "En az 1 görsel oluşturulabilir",
     "No text to image provider is available" : "Kullanılabilecek bir yazıdan görsel oluşturma hizmeti sağlayıcısı yok",
     "Image not found" : "Görsel bulunamadı",
     "No translation provider available" : "Kullanılabilecek bir çeviri hizmeti sağlayıcı yok",
@@ -198,16 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Matroska görüntü dosyası",
     "Windows Media video" : "Windows Media görüntü dosyası",
     "AVI video" : "AVI görüntü dosyası",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Güncelleniyor. Bu sayfadan ayrılırsanız bazı işlemler yarım kalabilir.",
-    "Update to {version}" : "{version} sürümüne güncelleniyor",
-    "An error occurred." : "Bir sorun çıktı.",
-    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uygulama güncellenemedi. Ayrıntılı bilgi almak için bu sorun ile ilgili <a href=\"{url}\">forum iletimize</a> bakabilirsiniz.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uygulama güncellenemedi. Lütfen bu sorunu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud topluluğuna</a> bildirin.",
-    "Continue to {productName}" : "{productName} ile ilerle",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
     "Done" : "Tamam",
     "Scan QR code to log in" : "Oturum açmak için kare kodu tarayın",
+    "Use {productName} mobile client you want to connect to scan the code" : "{productName} mobil istemcisi ile bağlanmak istediğiniz kodu tarayın",
+    "Code will expire {timeCountdown} or after use" : "Kod {timeCountdown} ya da kullanıldıktan sonra geçersiz olacak",
     "Applications menu" : "Uygulamalar menüsü",
     "Apps" : "Uygulamalar",
     "More apps" : "Diğer uygulamalar",
@@ -312,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "Kişileriniz yükleniyor…",
     "Looking for {term} …" : "{term} ifadesi aranıyor…",
     "Search contacts" : "Kişi arama",
-    "Reset search" : "Aramayı sıfırla",
+    "Filter by team" : "Takıma göre süz",
+    "All teams" : "Tüm takımlar",
+    "Search contacts in team {team}" : "{team} takımındaki kişileri ara",
     "Search contacts …" : "Kişi arama…",
+    "Reset search" : "Aramayı sıfırla",
     "Could not load your contacts" : "Kişileriniz yüklenemedi",
     "No contacts found" : "Herhangi bir kişi bulunamadı",
+    "Contacts list" : "Kişi listesi",
     "Show all contacts" : "Tüm kişileri görüntüle",
     "Install the Contacts app" : "Kişiler uygulamasını kur",
     "Search" : "Arama",
@@ -332,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "Oturum açma formu kullanımdan kaldırılmış.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu kullanımdan kaldırılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
     "Connect to your account" : "Hesabınızı bağlayın",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Lütfen \"{client}\" erişim iznini {instanceName} hesabınıza vermeden önce oturum açın.",
     "Security warning" : "Güvenlik uyarısı",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Yeni bir aygıt ya da uygulama kurmaya çalışmıyorsanız, başka biri verilerinize erişmek için sizi kandırmaya çalışıyor. Durum buysa daha ileri gitmeyin ve sistem yöneticiniz ile görüşün.",
+    "Log in using password" : "Parola ile oturum aç",
     "Alternative log in using app password" : "Uygulama parolası ile alternatif oturum açma",
     "Account connected" : "Hesap bağlandı",
     "Your client should now be connected!" : "İstemciniz şimdi bağlantı kurmuş olmalı!",
     "You can close this window." : "Bu pencereyi kapatabilirsiniz.",
     "Account access" : "Hesap erişimi",
+    "Currently logged in as {userDisplayName} ({userId})." : "{userDisplayName} ({userId}) olarak oturum açıldı.",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "\"{client}\" erişim iznini {instanceName} hesabınıza vermek üzeresiniz.",
     "More actions" : "Diğer işlemler",
     "User menu" : "Kullanıcı menüsü",
     "Your guest name: {user}" : "Konuk adınız: {user}",
@@ -353,7 +357,7 @@ OC.L10N.register(
     "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
     "Email address" : "E-posta adresi",
     "Request password" : "Parola iste",
-    "Forgot password" : "Parolamı Unuttum",
+    "Forgot password" : "Parolamı unuttum",
     "Password is too weak" : "Parola çok kolay",
     "Password is weak" : "Parola kolay",
     "Password is average" : "Parola orta zorlukta",
@@ -396,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
     "Continue with this unsupported browser" : "Bu desteklenmeyen tarayıcı ile ilerle",
     "Supported versions" : "Desteklenen sürümler",
+    "The update completed with warnings. Please check the details for more information." : "Güncelleme bazı uyarılar ile tamamlandı. Ayrıntılı bilgi almak için ayrıntılara bakın.",
+    "The update completed successfully." : "Güncelleme tamamlandı.",
+    "Preparing update…" : "Güncelleme hazırlanıyor…",
+    "You will be redirected to {productName} in {count} seconds." : "{count} saniye sonra {productName} üzerine yönlendirileceksiniz.",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Güncelleniyor. Bu sayfadan ayrılırsanız bazı işlemler yarım kalabilir.",
+    "App update required" : "Uygulamanın güncellenmesi gerekli",
+    "{productName} will be updated to version {version}" : "{productName}, {version} sürümüne güncellenecek",
+    "The theme {oldTheme} has been disabled." : "{oldTheme} teması kullanımdan kaldırıldı.",
+    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar kullanımdan kaldırılacak:",
+    "Incompatible apps" : "Uyumsuz uygulamalar",
+    "These apps will be updated:" : "Şu uygulamalar güncellenecek:",
+    "Apps to update" : "Güncellenecek uygulamalar",
+    "{app} from {oldVersion} to {version}" : "{app}, {oldVersion} sürümünden {version} sürümüne",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "İlerlemeden önce lütfen veri tabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum klasörünüzden şu komutu da çalıştırabilirsiniz:",
+    "Start update" : "Güncellemeyi başlat",
+    "Continue to {productName}" : "{productName} ile ilerle",
+    "Update to {version}" : "{version} sürümüne güncelleniyor",
+    "Hide details" : "Ayrıntılar gizlensin",
+    "Show details" : "Ayrıntılar görüntülensin",
+    "Update details" : "Güncelleme ayrıntıları",
+    "Update needed" : "Güncelleme gerekiyor",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50 üzerinde hesap bulunan bir kopya kullandığınız için lütfen komut satırı güncelleyiciyi kullanın.",
+    "Documentation" : "Belgeler",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Güncellemeyi site arayüzü üzerinden yapmanın zaman aşımına neden olarak veri kaybına neden olabileceğini biliyorum. Ancak bir yedeğim var ve sorun çıkması durumunda nasıl geri yükleyebileceğimi biliyorum.",
+    "Upgrade via web on my own risk" : "Riski alıyorum site arayüzünden güncelle",
     "Search {types} …" : "{types} arama…",
     "Choose {file}" : "{file} seçin",
     "Choose" : "Seçin",
@@ -421,19 +451,13 @@ OC.L10N.register(
     "Group list is empty" : "Grup listesi boş",
     "Unable to retrieve the group list" : "Grup listesi alınamadı",
     "seconds ago" : "saniye önce",
-    "Connection to server lost" : "Sunucu bağlantısı kesildi",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
     "Add to a project" : "Bir projeye ekle",
-    "Show details" : "Ayrıntılar görüntülensin",
-    "Hide details" : "Ayrıntılar gizlensin",
     "Rename project" : "Projeyi yeniden adlandır",
     "Failed to rename the project" : "Proje yeniden adlandırılamadı",
     "Failed to create a project" : "Bir proje eklenemedi",
     "Failed to add the item to the project" : "Öge projeye eklenemedi",
     "Connect items to a project to make them easier to find" : "Ögeleri bir projeye bağlayarak bulunmasını kolaylaştırın",
     "Type to search for existing projects" : "Var olan projeleri aramak için yazın",
-    "New in" : "Şuraya ekle",
-    "View changelog" : "Değişiklik günlüğünü görüntüle",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" penceresini kapat",
     "Email length is at max (255)" : "E-posta uzunluğu en fazla (255)",
     "Clipboard not available, please copy manually" : "Pano kullanılamıyor. Lütfen el ile kopyalayın",
@@ -485,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Güvenilmeyen etki alanı üzerinden erişim",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lütfen BT yöneticiniz ile görüşün. Yöneticisi siz iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını config/config.sample.php dosyasındaki gibi düzenleyin.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Bu ayar ile ilgili ayrıntılı bilgi almak için %1$sbelgelere%2$s bakabilirsiniz.",
-    "App update required" : "Uygulamanın güncellenmesi gerekli",
-    "%1$s will be updated to version %2$s" : "%1$s, %2$s sürümüne güncellenecek",
-    "The following apps will be updated:" : "Şu uygulamalar güncellenecek:",
-    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar kullanımdan kaldırılacak:",
-    "The theme %s has been disabled." : "%s teması kullanımdan kaldırıldı.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "İlerlemeden önce lütfen veri tabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
-    "Start update" : "Güncellemeyi başlat",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum klasörünüzden şu komutu da çalıştırabilirsiniz:",
-    "Detailed logs" : "Ayrıntılı günlükler",
-    "Update needed" : "Güncelleme gerekiyor",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50 üzerinde hesap bulunan bir kopya kullandığınız için lütfen komut satırı güncelleyiciyi kullanın.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Yardım almak için, <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">belgelere</a> bakın.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Güncellemeyi site arayüzü üzerinden yapmanın zaman aşımına neden olarak veri kaybına neden olabileceğini biliyorum. Ancak bir yedeğim var ve sorun çıkması durumunda nasıl geri yükleyebileceğimi biliyorum.",
-    "Upgrade via web on my own risk" : "Riski alıyorum site arayüzünden güncelle",
     "Maintenance mode" : "Bakım kipi",
     "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s kopyası şu anda bakım kipinde, bu işlem biraz zaman alabilir.",
     "This page will refresh itself when the instance is available again." : "Sistem yeniden kullanılabilir olduğunda bu sayfa kendiliğinden yenilenecek",
@@ -513,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Arama sonuçlarınız<script>alert(1)</script></strong>",
     "new" : "yeni",
     "_download %n file_::_download %n files_" : ["%n dosya indiriliyor","%n dosya indiriliyor"],
+    "An error occurred." : "Bir sorun çıktı.",
+    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uygulama güncellenemedi. Ayrıntılı bilgi almak için bu sorun ile ilgili <a href=\"{url}\">forum iletimize</a> bakabilirsiniz.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uygulama güncellenemedi. Lütfen bu sorunu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud topluluğuna</a> bildirin.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
     "Direct link copied to clipboard" : "Doğrudan bağlantı panoya kopyalandı",
     "Searching …" : "Aranıyor…",
     "Logging in …" : "Oturum açılıyor …",
@@ -525,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "Diğer sonuçlar yükleniyor…",
     "Search {types} …" : "{types} arama…",
     "Saving …" : "Kaydediliyor …",
+    "Connection to server lost" : "Sunucu bağlantısı kesildi",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
+    "New in" : "Şuraya ekle",
+    "View changelog" : "Değişiklik günlüğünü görüntüle",
     "Very weak password" : "Parola çok zayıf",
     "Weak password" : "Parola zayıf",
     "So-so password" : "Parola idare eder",
@@ -551,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "Kuruluyor…",
     "Please log in before granting %1$s access to your %2$s account." : "Lütfen %1$s için %2$s hesabınıza erişim izni vermeden önce oturum açın.",
     "Currently logged in as %1$s (%2$s)." : "%1$s (%2$s) olarak oturum açıldı.",
-    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz."
+    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz.",
+    "%1$s will be updated to version %2$s" : "%1$s, %2$s sürümüne güncellenecek",
+    "The following apps will be updated:" : "Şu uygulamalar güncellenecek:",
+    "The theme %s has been disabled." : "%s teması kullanımdan kaldırıldı.",
+    "Detailed logs" : "Ayrıntılı günlükler",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Yardım almak için, <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">belgelere</a> bakın."
 },
 "nplurals=2; plural=(n > 1);");
