@@ -198,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska سىن",
     "Windows Media video" : "Windows Media سىن",
     "AVI video" : "AVI سىن",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "يېڭىلاش ئېلىپ بېرىلىۋاتىدۇ ، بۇ بەتتىن ئايرىلىش بەزى مۇھىتتىكى جەرياننى قالايمىقانلاشتۇرۇشى مۇمكىن.",
-    "Update to {version}" : "{version} يېڭىلاش",
-    "An error occurred." : "خاتالىق كۆرۈلدى.",
-    "Please reload the page." : "بۇ بەتنى قايتا يۈكلەڭ.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن <a href = \"{url}\"> بۇ مەسىلىنى ئۆز ئىچىگە ئالغان مۇنبەر يازمىمىزنى تەكشۈرۈڭ </a>.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. بۇ مەسىلىنى <a href = \"https://github.com/nextcloud/server/issues\" target = \"_ blank\"> Nextcloud مەھەللىسىگە دوكلات قىلىڭ.",
-    "Continue to {productName}" : "داۋاملاشتۇرۇش {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["يېڭىلاش مۇۋەپپەقىيەتلىك بولدى. %n سېكۇنت ئىچىدە سىزنى {productName} غا يۆتكەيدۇ.","يېڭىلاش مۇۋەپپەقىيەتلىك بولدى. %n سېكۇنت ئىچىدە سىزنى {productName} غا يۆتكەيدۇ."],
     "Done" : "پۈتتى",
     "Applications menu" : "قوللىنىشچان تىزىملىك",
     "Apps" : "ئەپلەر",
@@ -311,8 +303,8 @@ OC.L10N.register(
     "Loading your contacts …" : "ئالاقىداشلىرىڭىزنى يۈكلەۋاتىدۇ ...",
     "Looking for {term} …" : "{term} نى ئىزدەۋاتىدۇ  ...",
     "Search contacts" : "ئالاقىداشلارنى ئىزدە",
-    "Reset search" : "ئىزدەشنى ئەسلىگە كەلتۈرۈڭ",
     "Search contacts …" : "ئالاقىداشلارنى ئىزدەش ...",
+    "Reset search" : "ئىزدەشنى ئەسلىگە كەلتۈرۈڭ",
     "Could not load your contacts" : "ئالاقىداشلىرىڭىزنى يۈكلىيەلمىدى",
     "No contacts found" : "ئالاقىداش تېپىلمىدى",
     "Show all contacts" : "بارلىق ئالاقىنى كۆرسەت",
@@ -394,6 +386,21 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "توركۆرگۈڭىزنى قوللىمايدۇ. يېڭى نەشرىگە ياكى قوللايدىغان نەشرىگە يېڭىلاڭ.",
     "Continue with this unsupported browser" : "بۇ قوللىمايدىغان توركۆرگۈ بىلەن داۋاملاشتۇرۇڭ",
     "Supported versions" : "قوللايدىغان نەشرى",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "يېڭىلاش ئېلىپ بېرىلىۋاتىدۇ ، بۇ بەتتىن ئايرىلىش بەزى مۇھىتتىكى جەرياننى قالايمىقانلاشتۇرۇشى مۇمكىن.",
+    "App update required" : "ئەپ يېڭىلاش تەلەپ قىلىنىدۇ",
+    "These incompatible apps will be disabled:" : "ماس كەلمەيدىغان بۇ دېتاللار چەكلىنىدۇ:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "داۋاملاشتۇرۇشتىن بۇرۇن ساندان ، سەپلىمە ھۆججەت قىسقۇچ ۋە سانلىق مەلۇمات قىسقۇچنىڭ زاپاسلانغانلىقىنى جەزملەشتۈرۈڭ.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "چوڭراق قاچىلاش ۋاقتىدىن ساقلىنىش ئۈچۈن ، قاچىلاش مۇندەرىجىسىدىن تۆۋەندىكى بۇيرۇقنى ئىجرا قىلالايسىز:",
+    "Start update" : "يېڭىلاشنى باشلاڭ",
+    "Continue to {productName}" : "داۋاملاشتۇرۇش {productName}",
+    "Update to {version}" : "{version} يېڭىلاش",
+    "Hide details" : "تەپسىلاتلارنى يوشۇرۇش",
+    "Show details" : "تەپسىلاتلارنى كۆرسەت",
+    "Update needed" : "يېڭىلاش لازىم",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ ، چۈنكى سىزنىڭ 50 دىن ئارتۇق ھېساباتىڭىز بار.",
+    "Documentation" : "پۈتۈك",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "مەن تور UI ئارقىلىق يېڭىلاشنى داۋاملاشتۇرسام ، خەتەرنىڭ بارلىقىنى ، تەلەپنىڭ ۋاقىت چەكلىمىسىگە ئۇچراپ ، سانلىق مەلۇماتلارنىڭ يوقاپ كېتىشىنى كەلتۈرۈپ چىقىرىدىغانلىقىنى بىلىمەن ، ئەمما مېنىڭ زاپاسلاش ئىقتىدارىم بار ، مەغلۇپ بولغان ئەھۋال ئاستىدا مىسالىمنى قانداق ئەسلىگە كەلتۈرۈشنى بىلىمەن.",
+    "Upgrade via web on my own risk" : "ئۆزۈمنىڭ خەتىرىگە ئاساسەن تور ئارقىلىق يېڭىلاش",
     "Search {types} …" : "ئىزدەش {types}  ...",
     "Choose {file}" : "{file} نى تاللاڭ",
     "Choose" : "تاللاڭ",
@@ -419,19 +426,13 @@ OC.L10N.register(
     "Group list is empty" : "گۇرۇپپا تىزىملىكى قۇرۇق",
     "Unable to retrieve the group list" : "گۇرۇپپا تىزىملىكىنى ئەسلىگە كەلتۈرگىلى بولمىدى",
     "seconds ago" : "سېكۇنت بۇرۇن",
-    "Connection to server lost" : "مۇلازىمېتىرغا ئۇلىنىش يوقاپ كەتتى",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["بەتنى يۈكلەشتە مەسىلە بار، %n سىكۇنتتا قايتا يۈكلىنىدۇ","بەتنى يۈكلەشتە مەسىلە بار، %n سىكۇنتتا قايتا يۈكلىنىدۇ"],
     "Add to a project" : "بىر تۈرگە قوشۇڭ",
-    "Show details" : "تەپسىلاتلارنى كۆرسەت",
-    "Hide details" : "تەپسىلاتلارنى يوشۇرۇش",
     "Rename project" : "تۈرنىڭ نامىنى ئۆزگەرتىش",
     "Failed to rename the project" : "بۇ تۈرنىڭ نامىنى ئۆزگەرتەلمىدى",
     "Failed to create a project" : "بىر تۈر قۇرالمىدى",
     "Failed to add the item to the project" : "بۇ تۈرگە تۈر قوشالمىدى",
     "Connect items to a project to make them easier to find" : "نەرسىلەرنى تېپىشقا قۇلايلىق بولسۇن ئۈچۈن تۈرلەرگە ئۇلاڭ",
     "Type to search for existing projects" : "مەۋجۇت تۈرلەرنى ئىزدەش ئۈچۈن كىرگۈزۈڭ",
-    "New in" : "يېڭى",
-    "View changelog" : "Changelog نى كۆرۈڭ",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" سۆزلىشىش رامكىسىنى تاقاڭ",
     "Email length is at max (255)" : "ئېلېكترونلۇق خەتنىڭ ئۇزۇنلۇقى ئەڭ يۇقىرى بولغاندا (255)",
     "Clipboard not available, please copy manually" : "كۆچۈرۈش تاختىسى يوق، قولدا كۆچۈرۈڭ",
@@ -483,20 +484,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "ئىشەنچسىز دائىرە ئارقىلىق زىيارەت قىلىڭ",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ. ئەگەر سىز باشقۇرغۇچى بولسىڭىز ، config.sample.php دىكى مىسالغا ئوخشاش config / config.php دىكى «ئىشەنچلىك_ دائىرە» تەڭشىكىنى تەھرىرلەڭ.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "بۇنى قانداق تەڭشەش توغرىسىدىكى تېخىمۇ كۆپ ئۇچۇرلارنى %1$s نىڭ قوللانمىسى %2$s دىن تاپقىلى بولىدۇ.",
-    "App update required" : "ئەپ يېڭىلاش تەلەپ قىلىنىدۇ",
-    "%1$s will be updated to version %2$s" : "%1$s بولسا %2$s نەشرىگە يېڭىلىنىدۇ",
-    "The following apps will be updated:" : "تۆۋەندىكى ئەپلەر يېڭىلىنىدۇ:",
-    "These incompatible apps will be disabled:" : "ماس كەلمەيدىغان بۇ دېتاللار چەكلىنىدۇ:",
-    "The theme %s has been disabled." : "باشتېما %s چەكلەنگەن.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "داۋاملاشتۇرۇشتىن بۇرۇن ساندان ، سەپلىمە ھۆججەت قىسقۇچ ۋە سانلىق مەلۇمات قىسقۇچنىڭ زاپاسلانغانلىقىنى جەزملەشتۈرۈڭ.",
-    "Start update" : "يېڭىلاشنى باشلاڭ",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "چوڭراق قاچىلاش ۋاقتىدىن ساقلىنىش ئۈچۈن ، قاچىلاش مۇندەرىجىسىدىن تۆۋەندىكى بۇيرۇقنى ئىجرا قىلالايسىز:",
-    "Detailed logs" : "تەپسىلىي خاتىرىلەر",
-    "Update needed" : "يېڭىلاش لازىم",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "بۇيرۇق قۇرىنى يېڭىلاشنى ئىشلىتىڭ ، چۈنكى سىزنىڭ 50 دىن ئارتۇق ھېساباتىڭىز بار.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "ياردەم ئۈچۈن <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\"> ھۆججەت </a> نى كۆرۈڭ.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "مەن تور UI ئارقىلىق يېڭىلاشنى داۋاملاشتۇرسام ، خەتەرنىڭ بارلىقىنى ، تەلەپنىڭ ۋاقىت چەكلىمىسىگە ئۇچراپ ، سانلىق مەلۇماتلارنىڭ يوقاپ كېتىشىنى كەلتۈرۈپ چىقىرىدىغانلىقىنى بىلىمەن ، ئەمما مېنىڭ زاپاسلاش ئىقتىدارىم بار ، مەغلۇپ بولغان ئەھۋال ئاستىدا مىسالىمنى قانداق ئەسلىگە كەلتۈرۈشنى بىلىمەن.",
-    "Upgrade via web on my own risk" : "ئۆزۈمنىڭ خەتىرىگە ئاساسەن تور ئارقىلىق يېڭىلاش",
     "Maintenance mode" : "ئاسراش ھالىتى",
     "This %s instance is currently in maintenance mode, which may take a while." : "بۇ %s مىسال ھازىر ئاسراش ھالىتىدە بولۇپ ، بۇنىڭغا بىر ئاز ۋاقىت كېتىشى مۇمكىن.",
     "This page will refresh itself when the instance is available again." : "مىسال قايتا بولغاندا بۇ بەت ئۆزىنى يېڭىلايدۇ.",
@@ -511,6 +498,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong> بۇلار سىزنىڭ ئىزدەش نەتىجىلىرىڭىز <script> ئاگاھلاندۇرۇش (1) </script> </strong>",
     "new" : "يېڭى",
     "_download %n file_::_download %n files_" : ["%n ھۆججەتلەرنى چۈشۈرۈش","%n ھۆججەتلەرنى چۈشۈرۈش"],
+    "An error occurred." : "خاتالىق كۆرۈلدى.",
+    "Please reload the page." : "بۇ بەتنى قايتا يۈكلەڭ.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. تېخىمۇ كۆپ ئۇچۇرغا ئېرىشىش ئۈچۈن <a href = \"{url}\"> بۇ مەسىلىنى ئۆز ئىچىگە ئالغان مۇنبەر يازمىمىزنى تەكشۈرۈڭ </a>.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "يېڭىلاش مۇۋەپپەقىيەتلىك بولمىدى. بۇ مەسىلىنى <a href = \"https://github.com/nextcloud/server/issues\" target = \"_ blank\"> Nextcloud مەھەللىسىگە دوكلات قىلىڭ.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["يېڭىلاش مۇۋەپپەقىيەتلىك بولدى. %n سېكۇنت ئىچىدە سىزنى {productName} غا يۆتكەيدۇ.","يېڭىلاش مۇۋەپپەقىيەتلىك بولدى. %n سېكۇنت ئىچىدە سىزنى {productName} غا يۆتكەيدۇ."],
     "Direct link copied to clipboard" : "چاپلاش تاختىسىغا كۆچۈرۈلگەن بىۋاسىتە ئۇلىنىش",
     "Searching …" : "ئىزدەش…",
     "Logging in …" : "تىزىمغا كىرىش…",
@@ -523,6 +515,10 @@ OC.L10N.register(
     "Loading more results …" : "تېخىمۇ كۆپ نەتىجىلەرنى يۈكلەۋاتىدۇ…",
     "Search {types} …" : "ئىزدەش {types}…",
     "Saving …" : "ساقلاۋاتىدۇ…",
+    "Connection to server lost" : "مۇلازىمېتىرغا ئۇلىنىش يوقاپ كەتتى",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["بەتنى يۈكلەشتە مەسىلە بار، %n سىكۇنتتا قايتا يۈكلىنىدۇ","بەتنى يۈكلەشتە مەسىلە بار، %n سىكۇنتتا قايتا يۈكلىنىدۇ"],
+    "New in" : "يېڭى",
+    "View changelog" : "Changelog نى كۆرۈڭ",
     "Very weak password" : "پارول بەك ئاجىز",
     "Weak password" : "پارول ئاجىز",
     "So-so password" : "شۇڭا مەخپىي نومۇر",
@@ -549,6 +545,11 @@ OC.L10N.register(
     "Installing …" : "قاچىلاۋاتىدۇ…",
     "Please log in before granting %1$s access to your %2$s account." : "%2$s ھېساباتىڭىزغا %1$s ئىجازەت بېرىشتىن بۇرۇن كىرىڭ.",
     "Currently logged in as %1$s (%2$s)." : "ھازىر %1$s s (%2$s) سۈپىتىدە تىزىمغا كىردى.",
-    "You are about to grant %1$s access to your %2$s account." : "سىز %2$s ھېساباتىڭىزغا%1$s ئىجازەت بەرمەكچى بولۇۋاتىسىز."
+    "You are about to grant %1$s access to your %2$s account." : "سىز %2$s ھېساباتىڭىزغا%1$s ئىجازەت بەرمەكچى بولۇۋاتىسىز.",
+    "%1$s will be updated to version %2$s" : "%1$s بولسا %2$s نەشرىگە يېڭىلىنىدۇ",
+    "The following apps will be updated:" : "تۆۋەندىكى ئەپلەر يېڭىلىنىدۇ:",
+    "The theme %s has been disabled." : "باشتېما %s چەكلەنگەن.",
+    "Detailed logs" : "تەپسىلىي خاتىرىلەر",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "ياردەم ئۈچۈن <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\"> ھۆججەت </a> نى كۆرۈڭ."
 },
 "nplurals=2; plural=(n != 1);");
