@@ -23,6 +23,7 @@ OC.L10N.register(
     "Could not complete login" : "Không thể hoàn thành đăng nhập",
     "State token missing" : "Thiếu mã thông báo trạng thái",
     "Your login token is invalid or has expired" : "Mã thông báo đăng nhập của bạn không hợp lệ hoặc quá hạn",
+    "Please use original client" : "Vui lòng sử dụng ứng dụng gốc",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Bản phát hành cộng đồng này của Nextcloud không được hỗ trợ và thông báo đẩy bị hạn chế.",
     "Login" : "Đăng nhập",
     "Unsupported email length (>255)" : "Độ dài Email không hợp lệ (>255 ký tự)",
@@ -40,6 +41,7 @@ OC.L10N.register(
     "Internal error" : "Lỗi nội bộ",
     "Not found" : "Không tìm thấy",
     "Bad request" : "Lỗi yêu cầu",
+    "Input text is too long" : "Văn bản nhập quá dài",
     "Requested task type does not exist" : "Loại nhiệm vụ đã yêu cầu không tồn tại",
     "Necessary language model provider is not available" : "Không có nhà cung cấp mô hình ngôn ngữ cần thiết",
     "No text to image provider is available" : "Không có nhà cung cấp AI tạo sinh nào khả dụng",
@@ -76,14 +78,10 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
     "Already up to date" : "Đã được cập nhật bản mới nhất",
     "Unknown" : "Không xác định",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
-    "Update to {version}" : "Cập nhật lên {version}",
-    "An error occurred." : "Đã xảy ra lỗi.",
-    "Please reload the page." : "Vui lòng tải lại trang.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
-    "Continue to {productName}" : "Tiếp tục đến {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Cập nhật đã thành công. Chuyển hướng bạn đến {productName} trong %n seconds."],
+    "PDF document" : "Tài liệu PDF",
+    "Excel spreadsheet" : "Bảng tính Excel",
+    "Ogg audio" : "Âm thanh Ogg",
+    "C++ source code" : "Mã nguồn C++",
     "Done" : "Hoàn tất",
     "Applications menu" : "Menu ứng dụng",
     "Apps" : "Ứng dụng",
@@ -122,13 +120,16 @@ OC.L10N.register(
     "Log in to {productName}" : "Đăng nhập vào {productName}",
     "Wrong login or password." : "Tên người dùng hoặc mật khẩu sai.",
     "This account is disabled" : "Tài khoản này không còn khả dụng",
+    "Too many incorrect login attempts. Please try again in 30 seconds." : "Quá nhiều lần đăng nhập thất bại. Vui lòng thử lại sau 30 giây.",
     "Account name or email" : "Tên tài khoản hoặc email",
     "Account name" : "Tên tài khoản",
     "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
     "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
+    "Session error" : "Lỗi phiên làm việc",
     "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
     "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
     "Password" : "Mật khẩu",
+    "Remember me" : "Ghi nhớ",
     "Log in with a device" : "Đăng nhập bằng thiết bị",
     "Login or email" : "Tên đăng nhập hoặc Email",
     "Your account is not setup for passwordless login." : "Tài khoản của bạn chưa được thiết lập để đăng nhập không cần mật khẩu.",
@@ -151,11 +152,13 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Tài liệu, bảng tính và bản trình bày cộng tác, được xây dựng trên Collabora Online.",
     "Distraction free note taking app." : "Ứng dụng ghi chú không gây xao lãng.",
     "Recommended apps" : "Ứng dụng được đề xuất",
+    "Loading apps …" : "Đang tải ứng dụng…",
     "Could not fetch list of apps from the App Store." : "Không thể tìm nạp danh sách ứng dụng từ App Store.",
     "App download or installation failed" : "Tải xuống hoặc cài đặt ứng dụng không thành công",
     "Cannot install this app because it is not compatible" : "Không thể cài đặt ứng dụng này vì nó không tương thích",
     "Cannot install this app" : "Không thể cài đặt ứng dụng này",
     "Skip" : "Bỏ qua",
+    "Installing apps …" : "Đang cài đặt ứng dụng …",
     "Install recommended apps" : "Cài đặt các ứng dụng được đề xuất",
     "Online" : "Trực tuyến",
     "Away" : "Tạm vắng",
@@ -165,8 +168,14 @@ OC.L10N.register(
     "Invisible" : "Vô hình",
     "Appear offline" : "Đang offline",
     "Avatar of {displayName}" : "Ảnh đại diện của {displayName}",
-    "Settings menu" : "Trình đơn thiết lập",
+    "Settings menu" : "Menu cài đặt",
+    "Loading your contacts …" : "Đang tải liên hệ của bạn …",
+    "Looking for {term} …" : "Tìm thấy {term} …",
     "Search contacts" : "Tìm kiếm liên hệ",
+    "Filter by team" : "Lọc theo nhóm",
+    "All teams" : "Tất cả nhóm",
+    "Search contacts in team {team}" : "Tìm kiếm liên hệ trong nhóm {team}",
+    "Search contacts …" : "Tìm kiếm liên hệ …",
     "Reset search" : "Đặt lại tìm kiếm",
     "Could not load your contacts" : "Không thể tải liên hệ của bạn",
     "No contacts found" : "Không tìm thấy liên hệ nào",
@@ -185,14 +194,19 @@ OC.L10N.register(
     "Login form is disabled." : "Trang đăng nhập bị vô hiệu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Phương thức đăng nhập này đã bị tắt. Sử dụng hình thức đăng nhập khả dụng khác hoặc liên hệ quản trị viên.",
     "Connect to your account" : "Kết nối tài khoản của bạn",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "Vui lòng đăng nhập để cấp quyền cho \"{client}\" truy cập {instanceName} của bạn.",
     "Security warning" : "Cảnh báo bảo mật",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Nếu bạn không cố gắng thiết lập một thiết bị hoặc ứng dụng mới, ai đó đang cố lừa bạn cấp cho họ quyền truy cập vào dữ liệu của bạn. Trong trường hợp này, không tiếp tục và thay vào đó hãy liên hệ với quản trị viên hệ thống của bạn.",
+    "Log in using password" : "Đăng nhập bằng mật khẩu",
     "Alternative log in using app password" : "Đăng nhập thay thế bằng mật khẩu dành cho ứng dụng",
     "Account connected" : "Tài khoản đã được kết nối",
     "Your client should now be connected!" : "Máy khách của bạn bây giờ sẽ được kết nối!",
     "You can close this window." : "Bạn có thể đóng lại cửa sổ này",
     "Account access" : "Truy cập tài khoản",
+    "Currently logged in as {userDisplayName} ({userId})." : "Tài khoản: {userDisplayName} ({userId}).",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "Hành động này sẽ cho phép \"{client}\" truy cập tải khoản {instanceName} của bạn.",
     "More actions" : "Nhiều hành động hơn",
+    "Your guest name: {user}" : "Tên khách của bạn:  {user}",
     "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
     "The password is wrong or expired. Please try again or request a new one." : "Mật khẩu không đúng hoặc đã hết hạn.\nVui lòng thử lại hoặc yêu cầu mật khẩu mới.",
     "Submit" : "Gửi",
@@ -224,6 +238,22 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
     "Continue with this unsupported browser" : "Tiếp tục với trình duyệt không được hỗ trợ này",
     "Supported versions" : "Các phiên bản được hỗ trợ",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
+    "App update required" : "Ứng dụng yêu cầu cập nhật",
+    "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
+    "These apps will be updated:" : "Những ứng dụng sẽ được cập nhật:",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Để tránh thời gian quá hạn với các cài đặt lớn hơn, bạn có thể thực hiện chạy lệnh sau từ thư mục cài đặt:",
+    "Start update" : "Bắt đầu cập nhật",
+    "Continue to {productName}" : "Tiếp tục đến {productName}",
+    "Update to {version}" : "Cập nhật lên {version}",
+    "Hide details" : "Ẩn chi tiết",
+    "Show details" : "Hiển thị chi tiết",
+    "Update needed" : "Cần phải cập nhật",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Vui lòng cập nhật bằng lệnh bởi vì bản cài đặt này có hơn 50 tài khoản đang hoạt động.",
+    "Documentation" : "Tài liệu",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tôi biết rằng nếu tôi tiếp tục thực hiện cập nhập qua giao diện Web có rủi ro, mà yêu cầu đó chạy trong một khoảng thời gian bị quá hạn và có thể gây mất dữ liệu, nếu tôi có một bản sao và tôi biết cách khôi phục bản cài đặt đã sao lưu trong trường hợp bị lỗi khi cập nhật.",
+    "Upgrade via web on my own risk" : "Nâng cấp qua web",
     "Choose {file}" : "Chọn {file}",
     "Choose" : "Chọn",
     "Copy to {target}" : "Sao chép vào {target}",
@@ -247,19 +277,13 @@ OC.L10N.register(
     "Group list is empty" : "Danh sách nhóm trống",
     "Unable to retrieve the group list" : "Không thể truy xuất danh sách nhóm",
     "seconds ago" : "vài giây trước",
-    "Connection to server lost" : "Kết nối tới máy chủ bị mất",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
     "Add to a project" : "Thêm vào dự án",
-    "Show details" : "Hiển thị chi tiết",
-    "Hide details" : "Ẩn chi tiết",
     "Rename project" : "Đổi tên dự án",
     "Failed to rename the project" : "Không thể đổi tên dự án",
     "Failed to create a project" : "Không thể tạo dự án",
     "Failed to add the item to the project" : "Không thể thêm mục vào dự án",
     "Connect items to a project to make them easier to find" : "Kết nối các mục với dự án để dễ tìm thấy chúng hơn",
     "Type to search for existing projects" : "Nhập để tìm kiếm các dự án hiện có",
-    "New in" : "Mới trong",
-    "View changelog" : "Xem nhật ký thay đổi",
     "Close \"{dialogTitle}\" dialog" : "Đóng hộp thoại \"{dialogTitle}\"",
     "Email length is at max (255)" : "Độ dài Email đã đạt giới hạn (255 ký tự)",
     "Personal" : "Cá nhân",
@@ -309,20 +333,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Thông tin thêm về cách cấu hình có thể được tìm thấy trong tài liệu %1$s %2$s.",
-    "App update required" : "Ứng dụng yêu cầu cập nhật",
-    "%1$s will be updated to version %2$s" : "%1$s sẽ được cập nhật lên phiên bản %2$s",
-    "The following apps will be updated:" : "Các ứng dụng sau sẽ được cập nhật:",
-    "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
-    "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
-    "Start update" : "Bắt đầu cập nhật",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Để tránh thời gian quá hạn với các cài đặt lớn hơn, bạn có thể thực hiện chạy lệnh sau từ thư mục cài đặt:",
-    "Detailed logs" : "Nhật ký chi tiết",
-    "Update needed" : "Cần phải cập nhật",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Vui lòng cập nhật bằng lệnh bởi vì bản cài đặt này có hơn 50 tài khoản đang hoạt động.",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Trợ giúp, xem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tôi biết rằng nếu tôi tiếp tục thực hiện cập nhập qua giao diện Web có rủi ro, mà yêu cầu đó chạy trong một khoảng thời gian bị quá hạn và có thể gây mất dữ liệu, nếu tôi có một bản sao và tôi biết cách khôi phục bản cài đặt đã sao lưu trong trường hợp bị lỗi khi cập nhật.",
-    "Upgrade via web on my own risk" : "Nâng cấp qua web",
     "Maintenance mode" : "Chế độ bảo trì",
     "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
     "This page will refresh itself when the instance is available again." : "Trang này sẽ tự làm mới khi phiên bản khả dụng trở lại.",
@@ -337,6 +347,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
     "new" : "mới",
     "_download %n file_::_download %n files_" : ["tải về%ntệp"],
+    "An error occurred." : "Đã xảy ra lỗi.",
+    "Please reload the page." : "Vui lòng tải lại trang.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Cập nhật đã thành công. Chuyển hướng bạn đến {productName} trong %n seconds."],
     "Direct link copied to clipboard" : "URL đã được sao chép vào bộ nhớ tạm",
     "Searching …" : "Đang tìm kiếm ...",
     "Logging in …" : "Đang đăng nhập",
@@ -349,6 +364,10 @@ OC.L10N.register(
     "Loading more results …" : "Tải thêm kết quả ...",
     "Search {types} …" : "Tìm kiếm {types} ...",
     "Saving …" : "Đang lưu ...",
+    "Connection to server lost" : "Kết nối tới máy chủ bị mất",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
+    "New in" : "Mới trong",
+    "View changelog" : "Xem nhật ký thay đổi",
     "Very weak password" : "Mật khẩu rất yếu",
     "Weak password" : "Mật khẩu yếu",
     "So-so password" : "Mật khẩu tạm được",
@@ -372,6 +391,11 @@ OC.L10N.register(
     "Installing …" : "Đang cài đặt",
     "Please log in before granting %1$s access to your %2$s account." : "Vui lòng đăng nhập trước khi cấp quyền cho %1$s truy cập vào tài khoản %2$s của bạn.",
     "Currently logged in as %1$s (%2$s)." : "Hiện đang đăng nhập với tư cách %1$s (%2$s).",
-    "You are about to grant %1$s access to your %2$s account." : "Bạn sắp cấp quyền truy cập cho %1$s vào tài khoản %2$s của mình."
+    "You are about to grant %1$s access to your %2$s account." : "Bạn sắp cấp quyền truy cập cho %1$s vào tài khoản %2$s của mình.",
+    "%1$s will be updated to version %2$s" : "%1$s sẽ được cập nhật lên phiên bản %2$s",
+    "The following apps will be updated:" : "Các ứng dụng sau sẽ được cập nhật:",
+    "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
+    "Detailed logs" : "Nhật ký chi tiết",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Trợ giúp, xem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>."
 },
 "nplurals=1; plural=0;");
