@@ -2,8 +2,8 @@ OC.L10N.register(
     "core",
     {
     "Please select a file." : "请选择一个文件。",
-    "File is too big" : "文件太大",
-    "The selected file is not an image." : "所选文件不是一张图片。",
+    "File is too big" : "文件太大了",
+    "The selected file is not an image." : "所选的文件不是图片格式。",
     "The selected file cannot be read." : "无法读取所选文件。",
     "The file was uploaded" : "文件已上传 ",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超过了 php.ini 中的 upload_max_filesize 指令",
@@ -45,6 +45,8 @@ OC.L10N.register(
     "Input text is too long" : "输入文本太长",
     "Requested task type does not exist" : "请求的任务类型不存在",
     "Necessary language model provider is not available" : "无必要的语言模型提供程序",
+    "Cannot generate more than 12 images" : "无法产生超过12张图片",
+    "Cannot generate less than 1 image" : "至少需要生成一张图片",
     "No text to image provider is available" : "没有可用的文字转图片提供者",
     "Image not found" : "未找到图片",
     "No translation provider available" : "没有可用的翻译提供程序",
@@ -198,16 +200,10 @@ OC.L10N.register(
     "Matroska video" : "Matroska 视频",
     "Windows Media video" : "Windows 媒体视频",
     "AVI video" : "AVI 视频",
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
-    "Update to {version}" : "升级到 {version}",
-    "An error occurred." : "发生错误。",
-    "Please reload the page." : "请重新加载页面。",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失败。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud社区</a>。",
-    "Continue to {productName}" : "继续到 {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后你将重定向到 {productName}。"],
     "Done" : "完成",
     "Scan QR code to log in" : "扫描二维码登录",
+    "Use {productName} mobile client you want to connect to scan the code" : "使用要连接的 {productName} 移动客户端扫描二维码",
+    "Code will expire {timeCountdown} or after use" : "二维码将在 {timeCountdown} 或使用后过期",
     "Applications menu" : "应用程序菜单",
     "Apps" : "应用",
     "More apps" : "更多的应用程序",
@@ -312,10 +308,14 @@ OC.L10N.register(
     "Loading your contacts …" : "正在加载您的联系人 …",
     "Looking for {term} …" : "正在寻找 {term} …",
     "Search contacts" : "搜索联系人",
-    "Reset search" : "重置搜索",
+    "Filter by team" : "按团队筛选",
+    "All teams" : "所有团队",
+    "Search contacts in team {team}" : "搜索团队 {team} 中的联系人",
     "Search contacts …" : "搜索联系人 …",
+    "Reset search" : "重置搜索",
     "Could not load your contacts" : "无法加载您的联系人",
     "No contacts found" : "无法找到联系人",
+    "Contacts list" : "联系人列表",
     "Show all contacts" : "显示所有联系人",
     "Install the Contacts app" : "安装联系人应用",
     "Search" : "搜索",
@@ -332,13 +332,17 @@ OC.L10N.register(
     "Login form is disabled." : "登录表单已禁用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
     "Connect to your account" : "连接到您的账号",
+    "Please log in before granting \"{client}\" access to your {instanceName} account." : "请先登录，然后再授予“{client}”访问您的 {instanceName} 账号的权限。",
     "Security warning" : "安全警告",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
+    "Log in using password" : "使用密码登录",
     "Alternative log in using app password" : "使用应用密码进行登录",
     "Account connected" : "账号已连接",
     "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
     "You can close this window." : "您可以关闭此窗口。",
     "Account access" : "账号访问",
+    "Currently logged in as {userDisplayName} ({userId})." : "当前登录身份 {userDisplayName}（{userId}）。.",
+    "You are about to grant \"{client}\" access to your {instanceName} account." : "您即将授予“{client}访问您的 {instanceName} 账号的权限。",
     "More actions" : "更多操作 ",
     "User menu" : "用户菜单",
     "Your guest name: {user}" : "您的访客名称：{user}",
@@ -396,6 +400,32 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
     "Continue with this unsupported browser" : "继续使用该过时的浏览器",
     "Supported versions" : "支持的版本",
+    "The update completed with warnings. Please check the details for more information." : "更新已完成，但出现警告。如需更多信息，请查看详情。",
+    "The update completed successfully." : "更新已成功完成。",
+    "Preparing update…" : "正在准备更新…",
+    "You will be redirected to {productName} in {count} seconds." : "您将在 {count} 秒后重定向到 {productName}。",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
+    "App update required" : "必须的应用更新",
+    "{productName} will be updated to version {version}" : "{productName} 将更新到版本 {version}",
+    "The theme {oldTheme} has been disabled." : "主题 {oldTheme} 已被禁用。",
+    "These incompatible apps will be disabled:" : "下述不兼容的应用将被禁用：",
+    "Incompatible apps" : "不兼容的应用",
+    "These apps will be updated:" : "这些应用将会更新：",
+    "Apps to update" : "要更新的应用",
+    "{app} from {oldVersion} to {version}" : "{app} 从 {oldVersion} 到 {version}",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为避免较大安装时的超时，您可以在安装目录下执行下述的命令：",
+    "Start update" : "开始更新",
+    "Continue to {productName}" : "继续到 {productName}",
+    "Update to {version}" : "升级到 {version}",
+    "Hide details" : "隐藏详细信息",
+    "Show details" : "显示详情",
+    "Update details" : "更新详情",
+    "Update needed" : "需要更新",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因为你拥有超过50个账号的应用实例，请使用命令行进行更新。",
+    "Documentation" : "文档",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道继续通过 Web UI 进行更新的风险，请求超时运行，并可能导致数据丢失，但我有一个备份，并知道如何恢复。",
+    "Upgrade via web on my own risk" : "通过网络升级的风险",
     "Search {types} …" : "搜索 {types} …",
     "Choose {file}" : "选择 {file}",
     "Choose" : "选择",
@@ -417,23 +447,17 @@ OC.L10N.register(
     "({count} selected)" : "（选择了 {count} 个）",
     "Error loading file exists template" : "加载文件存在性模板失败",
     "Saving …" : "正在保存 …",
-    "Groups" : "用户组",
+    "Groups" : "群组",
     "Group list is empty" : "群组列表为空",
-    "Unable to retrieve the group list" : "无法获取分组列表",
+    "Unable to retrieve the group list" : "无法检索群组列表",
     "seconds ago" : "几秒前",
-    "Connection to server lost" : "与服务器的连接断开",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
     "Add to a project" : "添加到项目",
-    "Show details" : "显示详情",
-    "Hide details" : "隐藏详细信息",
     "Rename project" : "重命名项目",
     "Failed to rename the project" : "无法重命名项目",
     "Failed to create a project" : "无法创建项目",
     "Failed to add the item to the project" : "无法将条目添加到项目中",
     "Connect items to a project to make them easier to find" : "将条目关联到项目以使它们更容易查找",
     "Type to search for existing projects" : "输入以搜索已有项目",
-    "New in" : "新品",
-    "View changelog" : "查看更新记录",
     "Close \"{dialogTitle}\" dialog" : "关闭“{dialogTitle}”对话",
     "Email length is at max (255)" : "邮箱长度达到最大（255）",
     "Clipboard not available, please copy manually" : "剪贴板不可用，请手动复制",
@@ -485,20 +509,6 @@ OC.L10N.register(
     "Access through untrusted domain" : "通过不被信任的域名访问",
     "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的“trusted_domains”设置。",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "配置此项的详细内容请查阅 %1$s文档%2$s。",
-    "App update required" : "必须的应用更新",
-    "%1$s will be updated to version %2$s" : "%1$s 将被升级至版本 %2$s",
-    "The following apps will be updated:" : "以下应用将被更新：",
-    "These incompatible apps will be disabled:" : "下述不兼容的应用将被禁用：",
-    "The theme %s has been disabled." : "%s 主题已被禁用。",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
-    "Start update" : "开始更新",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为避免较大安装时的超时，您可以在安装目录下执行下述的命令：",
-    "Detailed logs" : "详细日志",
-    "Update needed" : "需要更新",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因为你拥有超过50个账号的应用实例，请使用命令行进行更新。",
-    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">文档</a>。",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道继续通过 Web UI 进行更新的风险，请求超时运行，并可能导致数据丢失，但我有一个备份，并知道如何恢复。",
-    "Upgrade via web on my own risk" : "通过网络升级的风险",
     "Maintenance mode" : "维护模式",
     "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
     "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
@@ -513,6 +523,11 @@ OC.L10N.register(
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
     "new" : "新建",
     "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
+    "An error occurred." : "发生错误。",
+    "Please reload the page." : "请重新加载页面。",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失败。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud社区</a>。",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后你将重定向到 {productName}。"],
     "Direct link copied to clipboard" : "直链已复制至粘贴板",
     "Searching …" : "正在搜索 ...",
     "Logging in …" : "正在登录……",
@@ -525,6 +540,10 @@ OC.L10N.register(
     "Loading more results …" : "加载更多结果...",
     "Search {types} …" : "搜索 {types} …",
     "Saving …" : "正在保存…",
+    "Connection to server lost" : "与服务器的连接断开",
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
+    "New in" : "新品",
+    "View changelog" : "查看更新记录",
     "Very weak password" : "非常弱的密码",
     "Weak password" : "弱密码",
     "So-so password" : "一般强度的密码",
@@ -551,6 +570,11 @@ OC.L10N.register(
     "Installing …" : "正在安装...",
     "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
     "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
-    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。"
+    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。",
+    "%1$s will be updated to version %2$s" : "%1$s 将被升级至版本 %2$s",
+    "The following apps will be updated:" : "以下应用将被更新：",
+    "The theme %s has been disabled." : "%s 主题已被禁用。",
+    "Detailed logs" : "详细日志",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">文档</a>。"
 },
 "nplurals=1; plural=0;");
