@@ -11,7 +11,7 @@ OC.L10N.register(
     "The page could not be found on the server." : "Die Seite konnte auf dem Server nicht gefunden werden.",
     "%s email verification" : "%s E-Mail-Überprüfung",
     "Email verification" : "E-Mail-Überprüfung",
-    "Click the following button to confirm your email." : "Die folgende Schaltfläche anklicken, um die E-Mail-Adresse zu bestätigen.",
+    "Click the following button to confirm your email." : "Auf die folgende Schaltfläche klicken, um die E-Mail-Adresse zu bestätigen.",
     "Click the following link to confirm your email." : "Auf den nachfolgenden Link klicken, um die E-Mail-Adresse zu bestätigen",
     "Confirm your email" : "Bestätige deine E-Mail-Adresse",
     "Other activities" : "Andere Aktivitäten",
@@ -37,10 +37,10 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Die folgenden Plattformen werden unterstützt: %s",
     "Server version %s or higher is required." : "Server Version %s oder höher wird benötigt.",
     "Server version %s or lower is required." : "Server Version %s oder niedriger wird benötigt.",
-    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrator, ein Unteradministrator sein oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Das angemeldete Konto muss ein Administrationskonto sein, ein Unteradministrationskontor sein, oder ein Sonderrecht haben, um auf diese Einstellung zuzugreifen",
     "Your current IP address doesn't allow you to perform admin actions" : "Unter deiner aktuellen IP-Adresse sind keine Administrationsaktionen erlaubt",
-    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrator sein",
-    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrator sein",
+    "Logged in account must be an admin or sub admin" : "Das angemeldete Konto muss ein (Unter-)Administrationskonto sein",
+    "Logged in account must be an admin" : "Das angemeldete Konto muss ein Administrationskonto sein",
     "Wiping of device %s has started" : "Löschen von Gerät %s wurde gestartet",
     "Wiping of device »%s« has started" : "Löschen von Gerät »%s« wurde gestartet",
     "»%s« started remote wipe" : "»%s« hat das Löschen aus der Ferne gestartet",
@@ -160,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Es konnte keine Verbindung zur Oracle-Datenbank hergestellt werden",
     "Oracle Login and/or password not valid" : "Oracle-Anmeldename und/oder -Passwort ungültig",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-Anmeldename und/oder Passwort ungültig",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "macOS is not supported and %s will not work properly on this platform." : "MacOS wird nicht unterstützt und %s wird auf dieser Plattform nicht richtig funktionieren.",
     "For the best results, please consider using a GNU/Linux server instead." : "Zur Gewährleistung eines optimalen Betriebs sollte stattdessen ein GNU/Linux-Server verwendet werden.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Es scheint, dass diese %s-Instanz unter einer 32-Bit-PHP-Umgebung läuft und open_basedir in der Datei php.ini konfiguriert worden ist. Von einem solchen Betrieb wird dringend abgeraten, weil es dabei zu Problemen mit Dateien kommt, deren Größe 4 GB übersteigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bitte die open_basedir-Einstellung in der php.ini entfernen oder zu 64-Bit-PHP wechseln.",
@@ -225,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Die Kategorie \"%s\" konnte nicht gefunden werden",
     "Input text" : "Texteingabe",
     "The input text" : "Der Eingabetext",
+    "Cannot generate more than 12 images" : "Es können nicht mehr als 12 Bilder erstellt werden",
+    "Cannot generate less than 1 image" : "Es kann nicht weniger als 1 Bild erstellt werden",
     "Sunday" : "Sonntag",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
@@ -274,7 +276,7 @@ OC.L10N.register(
     "The Login is already being used" : "Dieser Anmeldename wird bereits verwendet",
     "Could not create account" : "Konto konnte nicht erstellt werden",
     "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Nur die folgenden Zeichen sind in einem Anmeldenamen erlaubt: \"a-z\", \"A-Z\", \"0-9\", Leerzeichen und \"_.@-'\"",
-    "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden.",
+    "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden",
     "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
     "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
     "Username is too long" : "Benutzername ist zu lang",
@@ -295,7 +297,7 @@ OC.L10N.register(
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
     "Your data directory is not writable." : "Das Datenverzeichnis ist schreibgeschützt.",
     "Setting locale to %s failed." : "Das Setzen der Spracheeinstellung auf %s ist fehlgeschlagen.",
-    "Please install one of these locales on your system and restart your web server." : "Bitte eine dieser Sprachen auf dem System installieren und den Webserver neu starten.",
+    "Please install one of these locales on your system and restart your web server." : "Bitte eine dieser Sprachen (locales) auf dem System installieren und den Webserver neu starten.",
     "PHP module %s not installed." : "PHP-Modul %s nicht installiert.",
     "Please ask your server administrator to install the module." : "Bitte für die Installation des Moduls die Serveradministration kontaktieren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung \"%s\" ist nicht auf \"%s\" gesetzt.",
@@ -303,7 +305,7 @@ OC.L10N.register(
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
-    "Please ask your server administrator to restart the web server." : "Bitte die Serveradministration konatktieren und um Neustart des Webservers bitten.",
+    "Please ask your server administrator to restart the web server." : "Bitte die Serveradministration kontaktieren und um Neustart des Webservers bitten.",
     "The required %s config variable is not configured in the config.php file." : "Die erforderliche %s Konfigurationsvariable ist in der config.php nicht konfiguriert.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Die Serveradministration bitten, die Nextcloud-Konfiguration zu überprüfen.",
     "Your data directory is readable by other people." : "Dein Datenverzeichnis kann von anderen Benutzern gelesen werden",
@@ -379,6 +381,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Der Text aus dem ein Emoji erstellt werden soll",
     "Generated emoji" : "Erstelltes Emoji",
     "The generated emoji based on the input text" : "Das aus dem eingegebenen Text erstelltes Emoji",
+    "Optical character recognition" : "Texterkennung",
+    "Extract text from files like images or PDFs" : "Text aus Dateien wie Bildern oder PDFs extrahieren",
+    "Input files" : "Eingabedateien",
+    "The files to extract text from" : "Die Dateien, aus denen Text extrahiert werden soll",
+    "Output texts" : "Ausgabetexte",
+    "The texts that were extracted from the files" : "Die Texte, die aus den Dateien extrahiert wurden",
     "Generate image" : "Bild erstellen",
     "Generate an image from a text prompt" : "Bild aus einer Texteingabe erstellen",
     "Prompt" : "Prompt",
@@ -401,7 +409,7 @@ OC.L10N.register(
     "Change the tone of a piece of text." : "Den Ton eines Textes ändern.",
     "Write a text that you want the assistant to rewrite in another tone." : "Schreibe einen Text, den der Assistent in einen anderen Ton umschreiben soll.",
     "Desired tone" : "Gewünschter Ton",
-    "In which tone should your text be rewritten?" : "In welchem Ton soll Dein Text umgeschrieben werden?",
+    "In which tone should your text be rewritten?" : "In welchen Ton soll Dein Text umgeschrieben werden?",
     "The rewritten text in the desired tone, written by the assistant:" : "Der umgeschriebene Text im gewünschten Ton, erstellt vom Assistenten:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Mit dem Assistenten chatten",
@@ -469,12 +477,11 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
     "Organisation" : "Organisation",
-    "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
-    "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X wird nicht unterstützt und %s wird unter dieser Plattform nicht richtig funktionieren. Verwendung auf eigene Gefahr!",
+    "Login is too long" : "Die Anmeldung dauert zu lange",
     "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen.",
-    "Login is too long" : "Die Anmeldung dauert zu lange"
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen."
 },
 "nplurals=2; plural=(n != 1);");
