@@ -38,7 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Nõutav on serveri versioon %s või suurem.",
     "Server version %s or lower is required." : "Serveri versioon %s või madalam on nõutav.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Sisselogitud kasutajakonto peab olema peakasutajate või selle alamgrupi liige või omama eraldi õigust selle seadustuse muutmiseks",
-    "Your current IP address doesn't allow you to perform admin actions" : "Sinu praeguselt e-posti aadressilt ei saa teha haldustoiminguid",
+    "Your current IP address doesn't allow you to perform admin actions" : "Sinu praeguselt IP-posti aadressilt ei saa teha haldustoiminguid",
     "Logged in account must be an admin or sub admin" : "Sisselogitud kasutajakonto peab olema peakasutajate või selle alamgrupi liige",
     "Logged in account must be an admin" : "Sisselogitud kasutajakonto peab olema peakasutajate grupi liige",
     "Wiping of device %s has started" : "Andmete kustutamine seadmes „%s“ algas",
@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Ei suuda luua ühendust Oracle baasiga",
     "Oracle Login and/or password not valid" : "Oracle andmebaasi kasutajatunnus ja/või salasõna pole õiged",
     "PostgreSQL Login and/or password not valid" : "PostgreSQLi andmebaasi kasutajatunnus ja/või salasõna pole õiged",
+    "macOS is not supported and %s will not work properly on this platform." : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil.",
     "For the best results, please consider using a GNU/Linux server instead." : "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Tundub, et %s server töötab 32-bitises PHP käituskeskkonnas ja „open_basedir“ on php.ini failis seadistatud. Kui failide suurus on üle 4 GB, siis võib tekkida probleeme ning antud lahenduse kasutamist me ei soovita.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Palun eemalda oma serveri seadistustest php.ini failist „open_basedir“ seadistus või võta kasutusele 64-bitisel platvormil põhinev PHP versioon.",
@@ -220,6 +221,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Ei leia kategooriat „%s“",
     "Input text" : "Sisendtekst",
     "The input text" : "Sisendtekst",
+    "Cannot generate more than 12 images" : "Ei saa luua üle 12 pildi",
+    "Cannot generate less than 1 image" : "Ei saa luua alla 1 pildi",
     "Sunday" : "Pühapäev",
     "Monday" : "Esmaspäev",
     "Tuesday" : "Teisipäev",
@@ -373,6 +376,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Lähtetekst, millest lood emoji",
     "Generated emoji" : "Loodud emoji",
     "The generated emoji based on the input text" : "Sisestatud teksti alusel loodud emoji",
+    "Optical character recognition" : "Optiline märgituvastus",
+    "Extract text from files like images or PDFs" : "Tuvasta tekst erinevatest failidest, sh pildid ja PDF-failid",
+    "Input files" : "Sisendfailid",
+    "The files to extract text from" : "Failid, millest tahad tuvastada teksti",
+    "Output texts" : "Väljundtekstid",
+    "The texts that were extracted from the files" : "Tekstid, mis on etteantud failidest tuvastatud",
     "Generate image" : "Pildiloome",
     "Generate an image from a text prompt" : "Loo tekstisisendist pilt",
     "Prompt" : "Sisendvorm",
@@ -446,6 +455,7 @@ OC.L10N.register(
     "The desired language to translate the origin text in" : "Keel, millesse lähteteksti tõlgime",
     "Result" : "Tulemus",
     "The translated text" : "Tõlgitud tekst",
+    "Generate headline" : "Alapealkirja loomine",
     "Organisation" : "Organisatsioon",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
     "Login is too long" : "Kasutajanimi on liiga pikk",
