@@ -160,7 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
     "Oracle Login and/or password not valid" : "Oracle saio edota pasahitza baliogabea",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL saio edota pasahitza baliogabea",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X ez da onartzen eta %s ez da ondo funtzionatuko plataforma honetan. Erabili zure ardurapean!",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS ez da onartzen eta %s ez da behar bezala funtzionatuko plataforma honetan.",
     "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
@@ -379,6 +379,12 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Emoji bat sortzeko testua",
     "Generated emoji" : "Sortutako emojia",
     "The generated emoji based on the input text" : "Sarrerako testuan oinarrituta sortutako emojia",
+    "Optical character recognition" : "Karaktereen errekonozimendu optikoa",
+    "Extract text from files like images or PDFs" : "Erauzi testua irudiak edo PDFak bezalako fitxategietatik",
+    "Input files" : "Sarrerako fitxategiak",
+    "The files to extract text from" : "Zein fitxategietatik erauzi behar da testua",
+    "Output texts" : "Irteerako testuak",
+    "The texts that were extracted from the files" : "Fitxategietatik erauzitako testuak",
     "Generate image" : "Sortu irudia",
     "Generate an image from a text prompt" : "Sortu irudi bat testu-gonbita batetik",
     "Prompt" : "Galdera",
@@ -469,12 +475,11 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Testua laburtzen du bere luzera murrizten informazio baliotsua galdu gabe.",
     "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
     "Organisation" : "Erakundea",
-    "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
-    "Cannot download file" : "Ezin da fitxategia deskargatu",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X ez da onartzen eta %s ez da ondo funtzionatuko plataforma honetan. Erabili zure ardurapean!",
+    "Login is too long" : "Saio hasiera luzeegia d",
     "Cannot write into \"apps\" directory." : "Ezin da idatzi \"apps\" fitxategian.",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian aplikazioen biltegia (App Store) desgaituz.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezarrita dago, espero zen <code>0</code> balioaren ordez.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian.",
-    "Login is too long" : "Saio hasiera luzeegia d"
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian."
 },
 "nplurals=2; plural=(n != 1);");
