@@ -1,7 +1,7 @@
 OC.L10N.register(
     "lib",
     {
-    "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
+    "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire \"config\" !",
     "This can usually be fixed by giving the web server write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true.",
     "See %s" : "Voir %s",
@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "La destination n'existe pas",
     "Destination is not creatable" : "La destination ne peut pas être créée",
     "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
+    "%1$s (renamed)" : "%1$s (renommé)",
+    "renamed file" : "fichier renommé",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" est un nom de fichier ou de dossier interdit.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" est un préfixe interdit pour les noms de fichiers ou de dossiers.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" n'est pas autorisé dans un nom de fichier ou de dossier.",
@@ -127,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Paramètres",
     "Log out" : "Se déconnecter",
     "Accounts" : "Comptes",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Voir %s sur Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "E-mail %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "À propos",
     "Display name" : "Nom d'affichage",
     "Headline" : "Titre",
-    "Organisation" : "Organisme",
+    "Organization" : "Organisation",
     "Role" : "Fonction",
     "Pronouns" : "Pronoms",
     "Unknown account" : "Compte inconnu",
@@ -156,7 +160,6 @@ OC.L10N.register(
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
     "Oracle Login and/or password not valid" : "Identifiant et/ou mot de passe Oracle invalide",
     "PostgreSQL Login and/or password not valid" : "Identifiant et/ou mot de passe PostgreSQL invalide",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plateforme. Vous l'utilisez à vos risques et périls ! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32 bits et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez retirer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
@@ -201,6 +204,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Le chemin est déjà partagé avec ce groupe",
     "Link sharing is not allowed" : "Le partage de liens n'est pas autorisé",
     "Public upload is not allowed" : "Le téléversement public n'est pas autorisé",
+    "You cannot share a folder that contains other shares" : "Vous ne pouvez pas partager un dossier qui contient déjà d'autres partages.",
     "Sharing is disabled" : "Le partage est désactivé",
     "Sharing is disabled for you" : "Le partage est désactivé pour vous",
     "Cannot share with the share owner" : "Impossible de partager avec le propriétaire de l'action",
@@ -220,6 +224,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie « %s »",
     "Input text" : "Texte d'entrée",
     "The input text" : "Le texte d'entrée",
+    "Cannot generate more than 12 images" : "Impossible de générer plus de 12 images",
+    "Cannot generate less than 1 image" : "Impossible de générer moins d'une image",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
     "Tuesday" : "Mardi",
@@ -272,6 +278,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Un identifiant valide doit être saisi",
     "Login contains whitespace at the beginning or at the end" : "L'identifiant contient des espaces au début ou à la fin",
     "Login must not consist of dots only" : "L'identifiant ne doit pas être composé uniquement de points",
+    "Username is too long" : "Le nom d'utilisateur est trop long",
     "Login is invalid because files already exist for this user" : "L’identifiant n'est pas valide car des fichiers existent déjà pour cet utilisateur",
     "Account disabled" : "Compte désactivé",
     "Login canceled by app" : "L'authentification a été annulée par l'application",
@@ -284,8 +291,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Impossible d’écrire dans le répertoire « config ».",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire « config ». Voir %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true. Voir %s",
-    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire « apps ».",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
     "Cannot create \"data\" directory." : "Impossible de créer le dossier \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
@@ -296,8 +301,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP « %s » n'est pas « %s ».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
@@ -322,27 +325,49 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Pour autoriser cette vérification, pour devez vous assurer que votre serveur web peut se connecter à lui-même. Il doit donc être capable de résoudre et de se connecter à au moins un de ses `trusted_domains` ou à l'URL `overwrite.cli.url`. Cet échec peut être le résultat d'une erreur de DNS côté serveur ou d'une règle de pare-feu sortante.",
-    "Transcribe audio" : "Transcrire l'audio",
+    "Analyze images" : "Analyser des images",
+    "Ask a question about the given images." : "Poser une question sur les images fournies.",
+    "Images" : "Images",
+    "Images to ask a question about" : "Images pour lesquelles poser la question",
+    "Question" : "Question",
+    "What to ask about the images." : "Que demander au sujet des images.",
+    "Generated response" : "Réponse générée",
+    "The answer to the question" : "La réponse à la question",
+    "Audio chat" : "Discussion audio",
+    "Voice chat with the assistant" : "Discussion vocale avec l'assistant",
+    "System prompt" : "Invite du système",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Définir les règles et les hypothèses que l'assistant doit suivre pendant la conversation.",
+    "Chat voice message" : "Message vocal",
+    "Describe a task that you want the assistant to do or ask a question." : "Décrivez une tâche que vous souhaitez confier à l'assistant ou posez une question.",
+    "Chat history" : "Historique de la discussion",
+    "The history of chat messages before the current message, starting with a message by the user." : "L'historique des messages précédant le message actuel, en commençant par un message de l'utilisateur.",
+    "Input transcript" : "Transcription de l'entrée",
+    "Transcription of the audio input" : "Transcription de l'entrée audio",
+    "Response voice message" : "Message vocal de réponse",
+    "The generated voice response as part of the conversation" : "La réponse vocale générée dans le cadre de la conversation",
+    "Output transcript" : "Transcription de la sortie",
+    "Transcription of the audio output" : "Transcription de la sortie audio",
+    "Transcribe audio" : "Transcrire de l'audio",
     "Transcribe the things said in an audio" : "Transcrire les propos exprimés dans un fichier audio",
     "Audio input" : "Entrée audio",
     "The audio to transcribe" : "Audio à retranscrire",
     "Transcription" : "Transcription",
     "The transcribed text" : "Le texte transcrit",
-    "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "Discuter avec un agent conversationnel",
-    "Chat message" : "Message de discussion",
-    "A chat message to send to the agent." : "Un message instantané à envoyer à l'agent.",
+    "Chat by voice with an agent" : "Discuter vocalement avec un agent",
+    "Describe a task that you want the agent to do or ask a question." : "Décrivez une tâche que vous souhaitez confier à l'agent ou posez-lui une question.",
     "Confirmation" : "Confirmation",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Confirmation des actions demandées précédemment : 0 pour refuser et 1 pour confirmer.",
     "Conversation token" : "Jeton de conversation",
     "A token representing the conversation." : "Un jeton représentant la conversation.",
-    "Generated response" : "Réponse générée",
-    "The response from the chat model." : "La réponse du modèle de messagerie instantanée",
     "The new conversation token" : "Le nouveau jeton de conversation",
     "Send this along with the next interaction." : "Envoyer ceci lors de la prochaine interaction.",
     "Requested actions by the agent" : "Actions demandées par l'agent",
     "Actions that the agent would like to carry out in JSON format." : "Actions que l'agent souhaiterait effectuer au format JSON.",
-    "Context write" : "Écrire contextuellement",
+    "Chat with an agent" : "Discuter avec un agent conversationnel",
+    "Chat message" : "Message de discussion",
+    "A chat message to send to the agent." : "Un message instantané à envoyer à l'agent.",
+    "The response from the chat model." : "La réponse du modèle de messagerie instantanée",
+    "Context write" : "Écrire selon un contexte",
     "Writes text in a given style based on the provided source material." : "Écrit un texte dans un style donné, basé sur des données initiales préalablement fournies.",
     "Writing style" : "Style rédactionnel",
     "Demonstrate a writing style that you would like to immitate" : "Montrez un style d'écriture que vous aimeriez imiter",
@@ -350,12 +375,13 @@ OC.L10N.register(
     "The content that would like to be rewritten in the new writing style" : "Contenu qui doit être réécrit dans le nouveau style de rédaction",
     "Generated text" : "Texte généré",
     "The generated text with content from the source material in the given style" : "Le texte généré reprend le contenu du document source dans le style donné",
-    "Emoji generator" : "Générateur d'emoji",
+    "Emoji generator" : "Générateur d'émoji",
     "Takes text and generates a representative emoji for it." : "Prend un texte et génère un émoji représentatif.",
     "The text to generate an emoji for" : "Texte pour lequel générer un émoji",
     "Generated emoji" : "Émoji généré",
     "The generated emoji based on the input text" : "Émoji généré en fonction du texte saisi",
-    "Generate image" : "Générer l'image",
+    "Optical character recognition" : "Reconnaissance optique de caractères",
+    "Generate image" : "Générer une image",
     "Generate an image from a text prompt" : "Générer une image à partir d'un texte",
     "Prompt" : "Prompt",
     "Describe the image you want to generate" : "Décrivez l'image que vous souhaitez générer",
@@ -363,6 +389,11 @@ OC.L10N.register(
     "How many images to generate" : "Nombre d'images à générer",
     "Output images" : "Images de sortie",
     "The generated images" : "Les images générées",
+    "Generate speech" : "Générer une synthèse vocale",
+    "Generate speech from a transcript" : "Générer synthèse vocale à partir d'une transcription",
+    "Write transcript that you want the assistant to generate speech from" : "Écrire la transcription à partir de laquelle vous voulez générer la synthèse vocale",
+    "Output speech" : "Synthèse vocale",
+    "The generated speech" : "La synthèse vocale générée",
     "Free text to text prompt" : "Texte libre à texte libre",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Exécute une commande arbitraire à l'aide d'un modèle linguistique qui génère une réponse",
     "Describe a task that you want the assistant to do or ask a question" : "Décrivez une tâche que vous voulez que l'assistant effectue ou posez une question",
@@ -376,9 +407,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Le texte réécrit dans le ton souhaité par l'assistant : ",
     "Chat" : "Discussion instantanée ",
     "Chat with the assistant" : "Discuter avec l'assistant",
-    "System prompt" : "Invite du système",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Définir les règles et les hypothèses que l'assistant doit suivre pendant la conversation.",
-    "Chat history" : "Historique de la discussion",
     "The history of chat messages before the current message, starting with a message by the user" : "Historique des messages de discussion avant le message actuel, commençant par un message de l'utilisateur",
     "Response message" : "Message de réponse",
     "The generated response as part of the conversation" : "Réponse générée comme partie de la conversation",
@@ -422,7 +450,7 @@ OC.L10N.register(
     "The original text to summarize" : "Le texte original à résumer",
     "Summary" : "Résumé",
     "The generated summary" : "Le résumé généré",
-    "Extract topics" : "Extraire des thèmes",
+    "Extract topics" : "Extraire des sujets",
     "Extracts topics from a text and outputs them separated by commas" : "Extrait les sujets d'un texte et les affiche en les séparant par des virgules.",
     "The original text to extract topics from" : "Texte original à partir duquel les thèmes sont extraits",
     "Topics" : "Sujets",
@@ -442,21 +470,12 @@ OC.L10N.register(
     "Generate headline" : "Générer un titre",
     "Summarizes text by reducing its length without losing key information." : "Résume un texte en réduisant sa longueur sans perdre d’informations essentielles.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrait les thèmes d'un texte et les restitue séparés par des virgules.",
-    "Education Edition" : "Édition pour l'éducation ",
-    "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
-    "File name contains at least one invalid character" : "Le nom de fichier contient au moins un caractère invalide",
-    "File name is too long" : "Nom de fichier trop long",
-    "Users" : "Utilisateurs",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter :",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s a partagé « %2$s » avec vous et souhaite ajouter",
-    "»%s« added a note to a file shared with you" : "« %s » a ajouté une note à un fichier partagé avec vous",
-    "Open »%s«" : "Ouvrir « %s »",
-    "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
-    "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
-    "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
-    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Cannot download file" : "Impossible de télécharger le fichier",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assurez-vous que le répertoire de données contient un fichier \".ocdata\" à sa racine.",
-    "Path contains files shared with you" : "Le chemin contient des fichiers partagés avec vous"
+    "Organisation" : "Organisme",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plateforme. Vous l'utilisez à vos risques et périls ! ",
+    "Login is too long" : "La connexion est trop longue",
+    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire « apps ».",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
