@@ -82,6 +82,7 @@ OC.L10N.register(
     "Empty file" : "Tom fil",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med ID: %s finnes ikke. Skru den på i app-innstillingene eller kontakt en administrator.",
     "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
+    "%1$s (renamed)" : "%1$s (har fått nytt navn)",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" er et forbudt fil- eller mappenavn.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" er et forbudt prefiks for fil- eller mappenavn.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" er ikke tillatt i et fil- eller mappenavn.",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Settings" : "Innstillinger",
     "Log out" : "Logg ut",
     "Accounts" : "Kontoer",
+    "Bluesky" : "Bluesky",
     "Email" : "E-post",
     "Mail %s" : "E-post til %s",
     "Fediverse" : "Fediverse",
@@ -124,7 +126,7 @@ OC.L10N.register(
     "About" : "Om",
     "Display name" : "Visningsnavn",
     "Headline" : "Overskrift",
-    "Organisation" : "Organisasion",
+    "Organization" : "Organisering",
     "Role" : "Rolle",
     "Pronouns" : "Pronomen",
     "Unknown account" : "Ukjent konto",
@@ -242,8 +244,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan ikke skrive i \"config\"-katalogen.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til config-katalogen. Se %s.",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Men hvis du foretrekker å holde config.php filen skrivebeskyttet, angir du alternativet \"config_is_read_only\" til sant i den. Se %s.",
-    "Cannot write into \"apps\" directory." : "Kan ikke skrive i \"apps\"-katalogen.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan vanligvis løses ved å gi webserveren skrivetilgang til apps-katalogen eller deaktivere App Store i konfigurasjonsfilen.",
     "Cannot create \"data\" directory." : "Kan ikke opprette \"data\"-katalogen.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dette kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotkatalogen. Se %s.",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Tillatelser kan vanligvis ordnes ved å gi webserveren skrivetilgang til rotkatalogen. Se %s.",
@@ -254,8 +254,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Be server-administratoren om å installere modulen.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ved å endre denne innstillingen i php.ini gjør at Nextcloud vil kjøre igjen.",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er satt til <code>%s</code> istedenfor den forventede verdien <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For å fikse dette problemet sett <code>mbstring.func_overload</code> til <code>0</code> i php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut til at at PHP er satt opp til å fjerne innebygde doc-blokker. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av hurtiglager/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
@@ -280,14 +278,19 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
     "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "For å la denne kontrollen kjøre, må du sørge for at webserveren din kan koble til seg selv. Derfor må den kunne løse og koble til minst en dens 'trusted_domains' eller 'overwrite.cli.url'. Denne feilen kan være et resultat av ikke-DNS-samsvar på serversiden eller en regel for utgående brannmur.",
+    "Images" : "Bilder",
+    "Question" : "Spørsmål",
+    "System prompt" : "Systemledetekst",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser som assistenten skal følge under samtalen.",
+    "Chat history" : "Chathistorikk",
     "Transcribe audio" : "Transkriber lyd",
     "Transcribe the things said in an audio" : "Transkriber tingene som blir sagt i en lyd",
     "Audio input" : "Lydinndata",
     "The audio to transcribe" : "Lyden å transkribere",
     "Transcription" : "Transkripsjon",
     "The transcribed text" : "Den transkriberte teksten",
-    "Chat message" : "Chatmelding",
     "Confirmation" : "Bekreftelse",
+    "Chat message" : "Chatmelding",
     "Context write" : "Kontekstskriving",
     "Writes text in a given style based on the provided source material." : "Skriver tekst i en gitt stil basert på det angitte kildematerialet.",
     "Writing style" : "Skrivestil",
@@ -301,6 +304,7 @@ OC.L10N.register(
     "The text to generate an emoji for" : "Teksten for å generere en emoji for",
     "Generated emoji" : "Generert emoji",
     "The generated emoji based on the input text" : "Den genererte emojien basert på inndatateksten",
+    "Optical character recognition" : "Optisk tegngjenkjenning",
     "Generate image" : "Generer bilde",
     "Generate an image from a text prompt" : "Generere et bilde fra en tekstledetekst",
     "Prompt" : "Spør",
@@ -316,9 +320,6 @@ OC.L10N.register(
     "The generated text from the assistant" : "Den genererte teksten fra assistenten",
     "Chat" : "Chat",
     "Chat with the assistant" : "Chat med assistenten",
-    "System prompt" : "Systemledetekst",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definer regler og antagelser som assistenten skal følge under samtalen.",
-    "Chat history" : "Chathistorikk",
     "The history of chat messages before the current message, starting with a message by the user" : "Loggen over chatmeldinger før gjeldende melding, som starter med en melding fra brukeren",
     "Response message" : "Svarmelding",
     "The generated response as part of the conversation" : "Den genererte responsen som en del av samtalen",
@@ -368,20 +369,10 @@ OC.L10N.register(
     "Generate headline" : "Generer overskrift",
     "Summarizes text by reducing its length without losing key information." : "Oppsummerer tekst ved å redusere lengden uten å miste nøkkelinformasjon.",
     "Extracts topics from a text and outputs them separated by commas." : "Trekker ut emner fra en tekst og sender dem ut atskilt med komma.",
-    "Education Edition" : "Utdanningsversjon",
-    "File name is a reserved word" : "Filnavnet er et reservert ord",
-    "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
-    "File name is too long" : "Filnavnet er for langt",
-    "Users" : "Brukere",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med deg og vil legge til:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med deg og vil legge til",
-    "»%s« added a note to a file shared with you" : "»%s« la til en melding til en fil delt med deg",
-    "Open »%s«" : "Åpne »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med deg",
-    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med deg.",
-    "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
-    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
-    "Cannot download file" : "Kan ikke laste ned fil",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Forsikre deg om at det finnes ei fil kalt \".ocdata\" på rota av datamappa."
+    "Organisation" : "Organisasion",
+    "Cannot write into \"apps\" directory." : "Kan ikke skrive i \"apps\"-katalogen.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dette kan vanligvis løses ved å gi webserveren skrivetilgang til apps-katalogen eller deaktivere App Store i konfigurasjonsfilen.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er satt til <code>%s</code> istedenfor den forventede verdien <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "For å fikse dette problemet sett <code>mbstring.func_overload</code> til <code>0</code> i php.ini."
 },
 "nplurals=2; plural=(n != 1);");
