@@ -160,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
     "Oracle Login and/or password not valid" : "Login e/ou senha do Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
+    "macOS is not supported and %s will not work properly on this platform." : "O macOS não é compatível e %s não funcionará corretamente nesta plataforma.",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
@@ -224,6 +225,8 @@ OC.L10N.register(
     "Could not find category \"%s\"" : "Impossível localizar a categoria \"%s\"",
     "Input text" : "Texto de entrada",
     "The input text" : "O texto de entrada",
+    "Cannot generate more than 12 images" : "Não é possível gerar mais de 12 imagens",
+    "Cannot generate less than 1 image" : "Não é possível gerar menos de 1 imagem",
     "Sunday" : "Domingo",
     "Monday" : "Segunda-feira",
     "Tuesday" : "Terça-feira",
@@ -379,6 +382,11 @@ OC.L10N.register(
     "Generated emoji" : "Emoji gerado",
     "The generated emoji based on the input text" : "O emoji gerado com base no texto de entrada",
     "Optical character recognition" : "Reconhecimento ótico de caracteres",
+    "Extract text from files like images or PDFs" : "Extraia texto de arquivos como imagens ou PDFs",
+    "Input files" : "Arquivos de entrada",
+    "The files to extract text from" : "Os arquivos dos quais extrair texto",
+    "Output texts" : "Textos de saída",
+    "The texts that were extracted from the files" : "Os textos que foram extraídos dos arquivos",
     "Generate image" : "Gerar imagem",
     "Generate an image from a text prompt" : "Gere uma imagem a partir de um prompt de texto",
     "Prompt" : "Prompt",
