@@ -97,7 +97,11 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Ao partilhar a interface %s deve implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Não foi encontrada a partilha da interface %s",
     "Sharing backend for %s not found" : "Não foi encontrada a partilha da interface para %s",
+    "%1$s shared %2$s with you" : "%1$s partilhou %2$s consigo",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s partilhado »%2$s« consigo e quer adicionar:",
+    "%s added a note to a file shared with you" : "»%s« adicionou uma nota a um ficheiro partilhado consigo",
     "Unknown share type" : "Tipo de partilha desconhecido",
     "You are not allowed to share %s" : "Não está autorizado a partilhar %s",
     "Cannot increase permissions of %s" : "Não é possível aumentar as permissões de %s",
