@@ -130,6 +130,7 @@ OC.L10N.register(
     "Log out" : "Odhlásiť sa",
     "Accounts" : "Účty",
     "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Zobraziť %s na Bluesky",
     "Email" : "E-mail",
     "Mail %s" : "Pošta pre %s",
     "Fediverse" : "Fediverse",
@@ -145,6 +146,7 @@ OC.L10N.register(
     "About" : "O aplikácii",
     "Display name" : "Zobrazované meno",
     "Headline" : "Titul",
+    "Organization" : "Organizácia",
     "Role" : "Rola",
     "Pronouns" : "Zámená",
     "Unknown account" : "Neznámy účet",
@@ -158,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Nie je možné pripojiť sa k Oracle",
     "Oracle Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre Oracle databázu je neplatné",
     "PostgreSQL Login and/or password not valid" : "Prihlasovacie meno a/alebo heslo pre PostgreSQL databázu je neplatné",
+    "macOS is not supported and %s will not work properly on this platform." : "macOS nie je podporovaný a %s nebude správne fungovať na tejto platforme.",
     "For the best results, please consider using a GNU/Linux server instead." : "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá sa, že táto inštancia %s beží v 32-bitovom prostredí PHP a v php.ini bola nastavená voľba open_basedir. To bude zdrojom problémov so súbormi väčšími ako 4GB a dôrazne sa neodporúča.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Prosím, odstráňte nastavenie open_basedir vo vašom php.ini alebo prejdite na 64-bit PHP.",
@@ -202,6 +205,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Cesta je už zdieľaná s touto skupinou",
     "Link sharing is not allowed" : "Zdieľanie odkazu nie je povolené",
     "Public upload is not allowed" : "Verejné nahrávanie nie je povolené",
+    "You cannot share a folder that contains other shares" : "Nemôžete zdieľať priečinok, ktorý obsahuje iné zdieľania",
     "Sharing is disabled" : "Zdieľanie je zakázané",
     "Sharing is disabled for you" : "Zdieľanie je pre vás zakázané",
     "Cannot share with the share owner" : "Nie je možné zdieľať s vlastníkom",
@@ -275,6 +279,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Musíte zadať platné prihlasovacie meno.",
     "Login contains whitespace at the beginning or at the end" : "Prihlasovacie meno obsahuje medzeru na začiatku alebo na konci.",
     "Login must not consist of dots only" : "Prihlasovacie meno sa nesmie skladať len z bodiek",
+    "Username is too long" : "Užívateľské meno je príliš dlhé",
     "Login is invalid because files already exist for this user" : "Prihlasovacie meno je neplatné, pretože pre tohto užívateľa už existujú súbory.",
     "Account disabled" : "Účet bol zakázaný",
     "Login canceled by app" : "Prihlásenie bolo zrušené aplikáciou",
@@ -326,13 +331,17 @@ OC.L10N.register(
     "Images" : "Obrázky",
     "Images to ask a question about" : "Obrázky na položenie otázky",
     "Question" : "Otázka",
+    "What to ask about the images." : "Čo sa pýtať o obrázkoch.",
     "Generated response" : "Vygenerovaná odpoveď",
     "The answer to the question" : "Odpoveď na otázku",
+    "Audio chat" : "Audio chat",
     "Voice chat with the assistant" : "Hlasový chat s asistentom",
     "System prompt" : "Systémová výzva",
     "Define rules and assumptions that the assistant should follow during the conversation." : "Definovať pravidlá a predpoklady, ktoré by mal asistent počas rozhovoru dodržiavať.",
     "Chat voice message" : "Hlasová správa v chate",
+    "Describe a task that you want the assistant to do or ask a question." : "Popíšte úlohu, ktorú chcete, aby asistent vykonal, alebo sa spýtajte otázku.",
     "Chat history" : "História chatu",
+    "The history of chat messages before the current message, starting with a message by the user." : "História chatových správ pred touto správou, začínajúc správou používateľa.",
     "Input transcript" : "Vstupný prepis",
     "Transcription of the audio input" : "Prepis audio vstupu",
     "Response voice message" : "Odpovedať hlasovou správou",
@@ -345,6 +354,8 @@ OC.L10N.register(
     "The audio to transcribe" : "Zvuk pre prepísanie",
     "Transcription" : "Prepis",
     "The transcribed text" : "Prepísaný text",
+    "Chat by voice with an agent" : "Chatovať hlasom s agentom",
+    "Describe a task that you want the agent to do or ask a question." : "Popíšte úlohu, ktorú chcete, aby agent vykonal, alebo sa opýtajte otázku.",
     "Confirmation" : "Potvrdenie",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Či potvrdiť predtým požadované akcie: 0 pre odmietnutie a 1 pre potvrdenie.",
     "Conversation token" : "Token konverzácie",
@@ -371,6 +382,11 @@ OC.L10N.register(
     "Generated emoji" : "Vygenerované emotikony",
     "The generated emoji based on the input text" : "Vygenerovaný emotikon založený na vstupnom texte",
     "Optical character recognition" : "Optické rozpoznávanie znakov",
+    "Extract text from files like images or PDFs" : "Extrahujte text z dokumentov, ako sú obrázky alebo PDF súbory",
+    "Input files" : "Vstupné súbory",
+    "The files to extract text from" : "Súbory na extrahovanie textu z",
+    "Output texts" : "Výstupné texty",
+    "The texts that were extracted from the files" : "Texty, ktoré boli extrahované z dokumentov",
     "Generate image" : "Vygenerovať obrázok",
     "Generate an image from a text prompt" : "Vygenerovať obrázok na základe textového zadania",
     "Prompt" : "Zadanie",
@@ -462,6 +478,7 @@ OC.L10N.register(
     "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
     "Organisation" : "Organizácia",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použitie na vlastné riziko!",
+    "Login is too long" : "Prihlasovacie meno je príliš dlhé",
     "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastavený na <code>%s</code>, namiesto predpokladanej hodnoty <code>0</code>.",
