@@ -23,9 +23,11 @@ use OCP\Config\ValueType;
 use OCP\DB\Exception as DBException;
 use OCP\DB\IResult;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Security\ICrypto;
+use OCP\User\Events\UserConfigChangedEvent;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -75,6 +77,7 @@ class UserConfig implements IUserConfig {
 		private readonly PresetManager $presetManager,
 		protected LoggerInterface $logger,
 		protected ICrypto $crypto,
+		protected IEventDispatcher $dispatcher,
 	) {
 	}
 
@@ -1123,12 +1126,14 @@ class UserConfig implements IUserConfig {
 			}
 		}
 
+		$oldValue = null;
 		if ($this->hasKey($userId, $app, $key, $lazy)) {
 			/**
 			 * no update if key is already known with set lazy status and value is
 			 * not different, unless sensitivity is switched from false to true.
 			 */
-			if ($origValue === $this->getTypedValue($userId, $app, $key, $value, $lazy, $type)
+			$oldValue = $this->getTypedValue($userId, $app, $key, $value, $lazy, $type);
+			if ($origValue === $oldValue
 				&& (!$sensitive || $this->isSensitive($userId, $app, $key, $lazy))) {
 				return false;
 			}
@@ -1210,6 +1215,8 @@ class UserConfig implements IUserConfig {
 			$update->executeStatement();
 		}
 
+		$this->dispatcher->dispatchTyped(new UserConfigChangedEvent($userId, $app, $key, $value, $oldValue));
+
 		if ($refreshCache) {
 			$this->clearCache($userId);
 			return true;
