@@ -11,14 +11,15 @@ use Doctrine\DBAL\Exception;
 use OC\Files\Storage\Wrapper\Encryption;
 use OC\Files\Storage\Wrapper\Jail;
 use OC\Hooks\BasicEmitter;
-use OC\SystemConfig;
 use OCP\Files\Cache\IScanner;
 use OCP\Files\ForbiddenException;
 use OCP\Files\NotFoundException;
 use OCP\Files\Storage\ILockingStorage;
 use OCP\Files\Storage\IReliableEtagStorage;
+use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Lock\ILockingProvider;
+use OCP\Server;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -69,12 +70,11 @@ class Scanner extends BasicEmitter implements IScanner {
 		$this->storage = $storage;
 		$this->storageId = $this->storage->getId();
 		$this->cache = $storage->getCache();
-		/** @var SystemConfig $config */
-		$config = \OC::$server->get(SystemConfig::class);
-		$this->cacheActive = !$config->getValue('filesystem_cache_readonly', false);
-		$this->useTransactions = !$config->getValue('filescanner_no_transactions', false);
-		$this->lockingProvider = \OC::$server->get(ILockingProvider::class);
-		$this->connection = \OC::$server->get(IDBConnection::class);
+		$config = Server::get(IConfig::class);
+		$this->cacheActive = !$config->getSystemValueBool('filesystem_cache_readonly', false);
+		$this->useTransactions = !$config->getSystemValueBool('filescanner_no_transactions', false);
+		$this->lockingProvider = Server::get(ILockingProvider::class);
+		$this->connection = Server::get(IDBConnection::class);
 	}
 
 	/**
@@ -210,7 +210,7 @@ class Scanner extends BasicEmitter implements IScanner {
 					 * @var \OC\Files\Cache\CacheEntry $cacheData
 					 */
 					$newData = $this->array_diff_assoc_multi($data, $cacheData->getData());
-					
+
 					// make it known to the caller that etag has been changed and needs propagation
 					if (isset($newData['etag'])) {
 						$data['etag_changed'] = true;
@@ -318,7 +318,6 @@ class Scanner extends BasicEmitter implements IScanner {
 
 		try {
 			$data = $this->scanFile($path, $reuse, -1, lock: $lock);
-
 			if ($data !== null && $data['mimetype'] === 'httpd/unix-directory') {
 				$size = $this->scanChildren($path, $recursive, $reuse, $data['fileid'], $lock, $data['size']);
 				$data['size'] = $size;
@@ -351,23 +350,23 @@ class Scanner extends BasicEmitter implements IScanner {
 	 *
 	 */
 	protected function array_diff_assoc_multi(array $array1, array $array2) {
-		
+
 		$result = [];
 
 		foreach ($array1 as $key => $value) {
-		
+
 			// if $array2 doesn't have the same key, that's a result
 			if (!array_key_exists($key, $array2)) {
 				$result[$key] = $value;
 				continue;
 			}
-		
+
 			// if $array2's value for the same key is different, that's a result
 			if ($array2[$key] !== $value && !is_array($value)) {
 				$result[$key] = $value;
 				continue;
 			}
-		
+
 			if (is_array($value)) {
 				$nestedDiff = $this->array_diff_assoc_multi($value, $array2[$key]);
 				if (!empty($nestedDiff)) {
@@ -452,7 +451,7 @@ class Scanner extends BasicEmitter implements IScanner {
 	 * @param bool|IScanner::SCAN_RECURSIVE_INCOMPLETE $recursive
 	 */
 	private function handleChildren(string $path, $recursive, int $reuse, int $folderId, bool $lock, int|float &$size, bool &$etagChanged): array {
-		// we put this in it's own function so it cleans up the memory before we start recursing
+		// we put this in its own function so it cleans up the memory before we start recursing
 		$existingChildren = $this->getExistingChildren($folderId);
 		$newChildren = iterator_to_array($this->storage->getDirectoryContent($path));
 
