@@ -7,9 +7,8 @@
  */
 namespace OC\Files;
 
-use OC\Files\Mount\MountPoint;
+use OC\Files\Storage\StorageFactory;
 use OC\User\NoUserException;
-use OCP\Cache\CappedMemoryCache;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\Events\Node\FilesystemTornDownEvent;
 use OCP\Files\Mount\IMountManager;
@@ -27,8 +26,6 @@ class Filesystem {
 
 	private static ?View $defaultInstance = null;
 
-	private static ?CappedMemoryCache $normalizedPathCache = null;
-
 	private static ?FilenameValidator $validator = null;
 
 	/**
@@ -177,7 +174,9 @@ class Filesystem {
 		}
 
 		$mounts = self::getMountManager()->getAll();
-		if (!self::getLoader()->addStorageWrapper($wrapperName, $wrapper, $priority, $mounts)) {
+		/** @var StorageFactory $loader */
+		$loader = self::getLoader();
+		if (!$loader->addStorageWrapper($wrapperName, $wrapper, $priority, $mounts)) {
 			// do not re-wrap if storage with this name already existed
 			return;
 		}
@@ -386,30 +385,6 @@ class Filesystem {
 		self::$mounts->addMount($mount);
 	}
 
-	/**
-	 * return the path to a local version of the file
-	 * we need this because we can't know if a file is stored local or not from
-	 * outside the filestorage and for some purposes a local file is needed
-	 */
-	public static function getLocalFile(string $path): string|false {
-		return self::$defaultInstance->getLocalFile($path);
-	}
-
-	/**
-	 * return path to file which reflects one visible in browser
-	 *
-	 * @param string $path
-	 * @return string
-	 */
-	public static function getLocalPath($path) {
-		$datadir = \OC_User::getHome(\OC_User::getUser()) . '/files';
-		$newpath = $path;
-		if (strncmp($newpath, $datadir, strlen($datadir)) == 0) {
-			$newpath = substr($path, strlen($datadir));
-		}
-		return $newpath;
-	}
-
 	/**
 	 * check if the requested path is valid
 	 *
@@ -628,16 +603,6 @@ class Filesystem {
 			return '/';
 		}
 
-		if (is_null(self::$normalizedPathCache)) {
-			self::$normalizedPathCache = new CappedMemoryCache(2048);
-		}
-
-		$cacheKey = json_encode([$path, $stripTrailingSlash, $isAbsolutePath, $keepUnicode]);
-
-		if ($cacheKey && isset(self::$normalizedPathCache[$cacheKey])) {
-			return self::$normalizedPathCache[$cacheKey];
-		}
-
 		//normalize unicode if possible
 		if (!$keepUnicode) {
 			$path = \OC_Util::normalizeUnicode($path);
@@ -663,8 +628,6 @@ class Filesystem {
 			$path = rtrim($path, '/');
 		}
 
-		self::$normalizedPathCache[$cacheKey] = $path;
-
 		return $path;
 	}
 
