@@ -8,6 +8,7 @@ declare(strict_types=1);
 
 namespace OC\Files;
 
+use OC\Files\Cache\FileAccess;
 use OC\Files\Config\MountProviderCollection;
 use OC\Files\Mount\HomeMountPoint;
 use OC\Files\Mount\MountPoint;
@@ -21,22 +22,26 @@ use OC\Files\Storage\Wrapper\Quota;
 use OC\Lockdown\Filesystem\NullStorage;
 use OC\Share\Share;
 use OC\Share20\ShareDisableChecker;
-use OC_App;
 use OC_Hook;
-use OC_Util;
 use OCA\Files_External\Config\ExternalMountPoint;
 use OCA\Files_Sharing\External\Mount;
 use OCA\Files_Sharing\ISharedMountPoint;
 use OCA\Files_Sharing\SharedMount;
+use OCP\App\IAppManager;
 use OCP\Constants;
 use OCP\Diagnostics\IEventLogger;
 use OCP\EventDispatcher\IEventDispatcher;
+use OCP\Files\Config\IAuthoritativeMountProvider;
 use OCP\Files\Config\ICachedMountInfo;
 use OCP\Files\Config\IHomeMountProvider;
 use OCP\Files\Config\IMountProvider;
+use OCP\Files\Config\IPartialMountProvider;
+use OCP\Files\Config\IRootMountProvider;
 use OCP\Files\Config\IUserMountCache;
+use OCP\Files\Config\MountProviderArgs;
 use OCP\Files\Events\BeforeFileSystemSetupEvent;
 use OCP\Files\Events\InvalidateMountCacheEvent;
+use OCP\Files\Events\Node\BeforeNodeRenamedEvent;
 use OCP\Files\Events\Node\FilesystemTornDownEvent;
 use OCP\Files\Mount\IMountManager;
 use OCP\Files\Mount\IMountPoint;
@@ -53,6 +58,10 @@ use OCP\IUserSession;
 use OCP\Lockdown\ILockdownManager;
 use OCP\Share\Events\ShareCreatedEvent;
 use Psr\Log\LoggerInterface;
+use function array_key_exists;
+use function count;
+use function dirname;
+use function in_array;
 
 class SetupManager {
 	private bool $rootSetup = false;
@@ -60,13 +69,26 @@ class SetupManager {
 	private array $setupUsers = [];
 	// List of users for which all mounts are setup
 	private array $setupUsersComplete = [];
-	/** @var array<string, string[]> */
+	/**
+	 * An array of provider classes that have been set up, indexed by UserUID.
+	 *
+	 * @var array<string, class-string<IMountProvider>[]>
+	 */
 	private array $setupUserMountProviders = [];
+	/**
+	 * An array of paths that have already been set up
+	 *
+	 * @var array<string, int>
+	 */
+	private array $setupMountProviderPaths = [];
 	private ICache $cache;
 	private bool $listeningForProviders;
 	private array $fullSetupRequired = [];
 	private bool $setupBuiltinWrappersDone = false;
-	private bool $forceFullSetup = false;
+	private bool $forceFullSetup;
+	private bool $optimizeAuthoritativeProviders;
+	private const SETUP_WITH_CHILDREN = 1;
+	private const SETUP_WITHOUT_CHILDREN = 0;
 
 	public function __construct(
 		private IEventLogger $eventLogger,
@@ -81,10 +103,13 @@ class SetupManager {
 		private LoggerInterface $logger,
 		private IConfig $config,
 		private ShareDisableChecker $shareDisableChecker,
+		private IAppManager $appManager,
+		private FileAccess $fileAccess,
 	) {
 		$this->cache = $cacheFactory->createDistributed('setupmanager::');
 		$this->listeningForProviders = false;
 		$this->forceFullSetup = $this->config->getSystemValueBool('debug.force-full-fs-setup');
+		$this->optimizeAuthoritativeProviders = $this->config->getSystemValueBool('debug.optimize-authoritative-providers', true);
 
 		$this->setupListeners();
 	}
@@ -97,6 +122,27 @@ class SetupManager {
 		return in_array($user->getUID(), $this->setupUsersComplete, true);
 	}
 
+	/**
+	 * Checks if a path has been cached either directly or through a full setup
+	 * of one of its parents.
+	 */
+	private function isPathSetup(string $path): bool {
+		// if the exact path was already setup with or without children
+		if (array_key_exists($path, $this->setupMountProviderPaths)) {
+			return true;
+		}
+
+		// or if any of the ancestors was fully setup
+		while (($path = dirname($path)) !== '/') {
+			$setupPath = $this->setupMountProviderPaths[$path . '/'] ?? null;
+			if ($setupPath === self::SETUP_WITH_CHILDREN) {
+				return true;
+			}
+		}
+
+		return false;
+	}
+
 	private function setupBuiltinWrappers() {
 		if ($this->setupBuiltinWrappersDone) {
 			return;
@@ -104,7 +150,7 @@ class SetupManager {
 		$this->setupBuiltinWrappersDone = true;
 
 		// load all filesystem apps before, so no setup-hook gets lost
-		OC_App::loadApps(['filesystem']);
+		$this->appManager->loadApps(['filesystem']);
 		$prevLogging = Filesystem::logWarningWhenAddingStorageWrapper(false);
 
 		Filesystem::addStorageWrapper('mount_options', function ($mountPoint, IStorage $storage, IMountPoint $mount) {
@@ -156,7 +202,7 @@ class SetupManager {
 			if ($mount instanceof HomeMountPoint) {
 				$user = $mount->getUser();
 				return new Quota(['storage' => $storage, 'quotaCallback' => function () use ($user) {
-					return OC_Util::getUserQuota($user);
+					return $user->getQuotaBytes();
 				}, 'root' => 'files', 'include_external_storage' => $quotaIncludeExternal]);
 			}
 
@@ -171,9 +217,9 @@ class SetupManager {
 				return new PermissionsMask([
 					'storage' => $storage,
 					'mask' => Constants::PERMISSION_ALL & ~(
-						Constants::PERMISSION_UPDATE |
-						Constants::PERMISSION_CREATE |
-						Constants::PERMISSION_DELETE
+						Constants::PERMISSION_UPDATE
+						| Constants::PERMISSION_CREATE
+						| Constants::PERMISSION_DELETE
 					),
 				]);
 			}
@@ -183,6 +229,33 @@ class SetupManager {
 		Filesystem::logWarningWhenAddingStorageWrapper($prevLogging);
 	}
 
+	/**
+	 * Update the cached mounts for all non-authoritative mount providers for a user.
+	 */
+	private function updateNonAuthoritativeProviders(IUser $user): void {
+		// prevent recursion loop from when getting mounts from providers ends up setting up the filesystem
+		static $updatingProviders = false;
+		if ($updatingProviders) {
+			return;
+		}
+		$updatingProviders = true;
+
+		$providers = $this->mountProviderCollection->getProviders();
+		$nonAuthoritativeProviders = array_filter(
+			$providers,
+			fn (IMountProvider $provider) => !(
+				$provider instanceof IAuthoritativeMountProvider
+				|| $provider instanceof IRootMountProvider
+				|| $provider instanceof IHomeMountProvider
+			)
+		);
+		$providerNames = array_map(fn (IMountProvider $provider) => get_class($provider), $nonAuthoritativeProviders);
+		$mount = $this->mountProviderCollection->getUserMountsForProviderClasses($user, $providerNames);
+		$this->userMountCache->registerMounts($user, $mount, $providerNames);
+
+		$updatingProviders = false;
+	}
+
 	/**
 	 * Setup the full filesystem for the specified user
 	 */
@@ -194,17 +267,16 @@ class SetupManager {
 
 		$this->eventLogger->start('fs:setup:user:full', 'Setup full filesystem for user');
 
-		if (!isset($this->setupUserMountProviders[$user->getUID()])) {
-			$this->setupUserMountProviders[$user->getUID()] = [];
-		}
+		$this->dropPartialMountsForUser($user);
 
+		$this->setupUserMountProviders[$user->getUID()] ??= [];
 		$previouslySetupProviders = $this->setupUserMountProviders[$user->getUID()];
 
 		$this->setupForUserWith($user, function () use ($user) {
 			$this->mountProviderCollection->addMountForUser($user, $this->mountManager, function (
-				IMountProvider $provider,
+				string $providerClass,
 			) use ($user) {
-				return !in_array(get_class($provider), $this->setupUserMountProviders[$user->getUID()]);
+				return !in_array($providerClass, $this->setupUserMountProviders[$user->getUID()]);
 			});
 		});
 		$this->afterUserFullySetup($user, $previouslySetupProviders);
@@ -212,7 +284,7 @@ class SetupManager {
 	}
 
 	/**
-	 * part of the user setup that is run only once per user
+	 * Part of the user setup that is run only once per user.
 	 */
 	private function oneTimeUserSetup(IUser $user) {
 		if ($this->isSetupStarted($user)) {
@@ -280,29 +352,42 @@ class SetupManager {
 		$mounts = array_filter($mounts, function (IMountPoint $mount) use ($userRoot) {
 			return str_starts_with($mount->getMountPoint(), $userRoot);
 		});
-		$allProviders = array_map(function (IMountProvider $provider) {
+		$allProviders = array_map(function (IMountProvider|IHomeMountProvider|IRootMountProvider $provider) {
 			return get_class($provider);
-		}, $this->mountProviderCollection->getProviders());
+		}, array_merge(
+			$this->mountProviderCollection->getProviders(),
+			$this->mountProviderCollection->getHomeProviders(),
+			$this->mountProviderCollection->getRootProviders(),
+		));
 		$newProviders = array_diff($allProviders, $previouslySetupProviders);
 		$mounts = array_filter($mounts, function (IMountPoint $mount) use ($previouslySetupProviders) {
 			return !in_array($mount->getMountProvider(), $previouslySetupProviders);
 		});
-		$this->userMountCache->registerMounts($user, $mounts, $newProviders);
+		$this->registerMounts($user, $mounts, $newProviders);
 
+		$this->markUserMountsCached($user);
+		$this->eventLogger->end('fs:setup:user:full:post');
+	}
+
+	private function markUserMountsCached(IUser $user): void {
 		$cacheDuration = $this->config->getSystemValueInt('fs_mount_cache_duration', 5 * 60);
 		if ($cacheDuration > 0) {
 			$this->cache->set($user->getUID(), true, $cacheDuration);
 			$this->fullSetupRequired[$user->getUID()] = false;
 		}
-		$this->eventLogger->end('fs:setup:user:full:post');
 	}
 
 	/**
+	 * Executes the one-time user setup and, if the user can access the
+	 * filesystem, executes $mountCallback.
+	 *
 	 * @param IUser $user
 	 * @param IMountPoint $mounts
 	 * @return void
 	 * @throws \OCP\HintException
 	 * @throws \OC\ServerNotAvailableException
+	 * @see self::oneTimeUserSetup()
+	 *
 	 */
 	private function setupForUserWith(IUser $user, callable $mountCallback): void {
 		$this->oneTimeUserSetup($user);
@@ -349,8 +434,10 @@ class SetupManager {
 	 * @param string $path
 	 * @return IUser|null
 	 */
-	private function getUserForPath(string $path) {
-		if (str_starts_with($path, '/__groupfolders')) {
+	private function getUserForPath(string $path, bool $includeChildren = false): ?IUser {
+		if (($path === '' || $path === '/') && !$includeChildren) {
+			return null;
+		} elseif (str_starts_with($path, '/__groupfolders')) {
 			return null;
 		} elseif (substr_count($path, '/') < 2) {
 			if ($user = $this->userSession->getUser()) {
@@ -368,10 +455,11 @@ class SetupManager {
 	}
 
 	/**
-	 * Set up the filesystem for the specified path
+	 * Set up the filesystem for the specified path, optionally including all
+	 * children mounts.
 	 */
 	public function setupForPath(string $path, bool $includeChildren = false): void {
-		$user = $this->getUserForPath($path);
+		$user = $this->getUserForPath($path, $includeChildren);
 		if (!$user) {
 			$this->setupRoot();
 			return;
@@ -382,8 +470,13 @@ class SetupManager {
 		}
 
 		if ($this->fullSetupRequired($user)) {
-			$this->setupForUser($user);
-			return;
+			if ($this->optimizeAuthoritativeProviders) {
+				$this->updateNonAuthoritativeProviders($user);
+				$this->markUserMountsCached($user);
+			} else {
+				$this->setupForUser($user);
+				return;
+			}
 		}
 
 		// for the user's home folder, and includes children we need everything always
@@ -410,51 +503,140 @@ class SetupManager {
 		$this->eventLogger->start('fs:setup:user:path', "Setup $path filesystem for user");
 		$this->eventLogger->start('fs:setup:user:path:find', "Find mountpoint for $path");
 
-		$mounts = [];
-		if (!in_array($cachedMount->getMountProvider(), $setupProviders)) {
-			$currentProviders[] = $cachedMount->getMountProvider();
-			if ($cachedMount->getMountProvider()) {
-				$setupProviders[] = $cachedMount->getMountProvider();
-				$mounts = $this->mountProviderCollection->getUserMountsForProviderClasses($user, [$cachedMount->getMountProvider()]);
-			} else {
+		$fullProviderMounts = [];
+		$authoritativeMounts = [];
+
+		$mountProvider = $cachedMount->getMountProvider();
+		$mountPoint = $cachedMount->getMountPoint();
+		$isMountProviderSetup = in_array($mountProvider, $setupProviders);
+		$isPathSetupAsAuthoritative = $this->isPathSetup($mountPoint);
+		if (!$isMountProviderSetup && !$isPathSetupAsAuthoritative) {
+			if ($mountProvider === '') {
 				$this->logger->debug('mount at ' . $cachedMount->getMountPoint() . ' has no provider set, performing full setup');
 				$this->eventLogger->end('fs:setup:user:path:find');
 				$this->setupForUser($user);
 				$this->eventLogger->end('fs:setup:user:path');
 				return;
 			}
+
+			if (is_a($mountProvider, IPartialMountProvider::class, true)) {
+				$rootId = $cachedMount->getRootId();
+				$rootMetadata = $this->fileAccess->getByFileId($rootId);
+				if (!$rootMetadata) {
+					$this->setupForUser($user);
+					return;
+				}
+				$providerArgs = new MountProviderArgs($cachedMount, $rootMetadata);
+				// mark the path as cached (without children for now...)
+				$this->setupMountProviderPaths[$mountPoint] = self::SETUP_WITHOUT_CHILDREN;
+				$authoritativeMounts[] = array_values(
+					$this->mountProviderCollection->getUserMountsFromProviderByPath(
+						$mountProvider,
+						$path,
+						false,
+						[$providerArgs]
+					)
+				);
+			} else {
+				$currentProviders[] = $mountProvider;
+				$setupProviders[] = $mountProvider;
+				$fullProviderMounts[] = $this->mountProviderCollection->getUserMountsForProviderClasses($user, [$mountProvider]);
+			}
 		}
 
 		if ($includeChildren) {
 			$subCachedMounts = $this->userMountCache->getMountsInPath($user, $path);
 			$this->eventLogger->end('fs:setup:user:path:find');
 
-			$needsFullSetup = array_reduce($subCachedMounts, function (bool $needsFullSetup, ICachedMountInfo $cachedMountInfo) {
-				return $needsFullSetup || $cachedMountInfo->getMountProvider() === '';
-			}, false);
+			$needsFullSetup = array_any(
+				$subCachedMounts,
+				fn (ICachedMountInfo $info) => $info->getMountProvider() === ''
+			);
 
 			if ($needsFullSetup) {
 				$this->logger->debug('mount has no provider set, performing full setup');
 				$this->setupForUser($user);
 				$this->eventLogger->end('fs:setup:user:path');
 				return;
-			} else {
-				foreach ($subCachedMounts as $cachedMount) {
-					if (!in_array($cachedMount->getMountProvider(), $setupProviders)) {
-						$currentProviders[] = $cachedMount->getMountProvider();
-						$setupProviders[] = $cachedMount->getMountProvider();
-						$mounts = array_merge($mounts, $this->mountProviderCollection->getUserMountsForProviderClasses($user, [$cachedMount->getMountProvider()]));
+			}
+
+			/** @var array<class-string<IMountProvider>, ICachedMountInfo[]> $authoritativeCachedMounts */
+			$authoritativeCachedMounts = [];
+			foreach ($subCachedMounts as $cachedMount) {
+				/** @var class-string<IMountProvider> $mountProvider */
+				$mountProvider = $cachedMount->getMountProvider();
+
+				// skip setup for already set up providers
+				if (in_array($mountProvider, $setupProviders)) {
+					continue;
+				}
+
+				if (is_a($mountProvider, IPartialMountProvider::class, true)) {
+					// skip setup if path was set up as authoritative before
+					if ($this->isPathSetup($cachedMount->getMountPoint())) {
+						continue;
 					}
+					// collect cached mount points for authoritative providers
+					$authoritativeCachedMounts[$mountProvider] ??= [];
+					$authoritativeCachedMounts[$mountProvider][] = $cachedMount;
+					continue;
+				}
+
+				$currentProviders[] = $mountProvider;
+				$setupProviders[] = $mountProvider;
+				$fullProviderMounts[] = $this->mountProviderCollection->getUserMountsForProviderClasses(
+					$user,
+					[$mountProvider]
+				);
+			}
+
+			if (!empty($authoritativeCachedMounts)) {
+				$rootIds = array_map(
+					fn (ICachedMountInfo $mount) => $mount->getRootId(),
+					array_merge(...array_values($authoritativeCachedMounts)),
+				);
+
+				$rootsMetadata = [];
+				foreach (array_chunk($rootIds, 1000) as $chunk) {
+					foreach ($this->fileAccess->getByFileIds($chunk) as $id => $fileMetadata) {
+						$rootsMetadata[$id] = $fileMetadata;
+					}
+				}
+				$this->setupMountProviderPaths[$mountPoint] = self::SETUP_WITH_CHILDREN;
+				foreach ($authoritativeCachedMounts as $providerClass => $cachedMounts) {
+					$providerArgs = array_values(array_filter(array_map(
+						static function (ICachedMountInfo $info) use ($rootsMetadata) {
+							$rootMetadata = $rootsMetadata[$info->getRootId()] ?? null;
+
+							return $rootMetadata
+								? new MountProviderArgs($info, $rootMetadata)
+								: null;
+						},
+						$cachedMounts
+					)));
+					$authoritativeMounts[] = $this->mountProviderCollection->getUserMountsFromProviderByPath(
+						$providerClass,
+						$path,
+						true,
+						$providerArgs,
+					);
 				}
 			}
 		} else {
 			$this->eventLogger->end('fs:setup:user:path:find');
 		}
 
-		if (count($mounts)) {
-			$this->userMountCache->registerMounts($user, $mounts, $currentProviders);
-			$this->setupForUserWith($user, function () use ($mounts) {
-				array_walk($mounts, [$this->mountManager, 'addMount']);
+		$fullProviderMounts = array_merge(...$fullProviderMounts);
+		$authoritativeMounts = array_merge(...$authoritativeMounts);
+
+		if (count($fullProviderMounts) || count($authoritativeMounts)) {
+			if (count($fullProviderMounts)) {
+				$this->registerMounts($user, $fullProviderMounts, $currentProviders);
+			}
+
+			$this->setupForUserWith($user, function () use ($fullProviderMounts, $authoritativeMounts) {
+				$allMounts = [...$fullProviderMounts, ...$authoritativeMounts];
+				array_walk($allMounts, $this->mountManager->addMount(...));
 			});
 		} elseif (!$this->isSetupStarted($user)) {
 			$this->oneTimeUserSetup($user);
@@ -491,7 +673,18 @@ class SetupManager {
 			return;
 		}
 
-		if ($this->fullSetupRequired($user)) {
+		$providersAreAuthoritative = true;
+		foreach ($providers as $provider) {
+			if (!(
+				is_a($provider, IAuthoritativeMountProvider::class, true)
+				|| is_a($provider, IRootMountProvider::class, true)
+				|| is_a($provider, IHomeMountProvider::class, true)
+			)) {
+				$providersAreAuthoritative = false;
+			}
+		}
+
+		if (!$providersAreAuthoritative && $this->fullSetupRequired($user)) {
 			$this->setupForUser($user);
 			return;
 		}
@@ -519,11 +712,12 @@ class SetupManager {
 			$this->eventLogger->end('fs:setup:user:providers');
 			return;
 		} else {
+			$this->dropPartialMountsForUser($user, $providers);
 			$this->setupUserMountProviders[$user->getUID()] = array_merge($setupProviders, $providers);
 			$mounts = $this->mountProviderCollection->getUserMountsForProviderClasses($user, $providers);
 		}
 
-		$this->userMountCache->registerMounts($user, $mounts, $providers);
+		$this->registerMounts($user, $mounts, $providers);
 		$this->setupForUserWith($user, function () use ($mounts) {
 			array_walk($mounts, [$this->mountManager, 'addMount']);
 		});
@@ -534,9 +728,11 @@ class SetupManager {
 		$this->setupUsers = [];
 		$this->setupUsersComplete = [];
 		$this->setupUserMountProviders = [];
+		$this->setupMountProviderPaths = [];
 		$this->fullSetupRequired = [];
 		$this->rootSetup = false;
 		$this->mountManager->clear();
+		$this->userMountCache->clear();
 		$this->eventDispatcher->dispatchTyped(new FilesystemTornDownEvent());
 	}
 
@@ -573,6 +769,16 @@ class SetupManager {
 		$this->eventDispatcher->addListener(ShareCreatedEvent::class, function (ShareCreatedEvent $event) {
 			$this->cache->remove($event->getShare()->getSharedWith());
 		});
+		$this->eventDispatcher->addListener(BeforeNodeRenamedEvent::class, function (BeforeNodeRenamedEvent $event) {
+			// update cache information that is cached by mount point
+			$from = rtrim($event->getSource()->getPath(), '/') . '/';
+			$to = rtrim($event->getTarget()->getPath(), '/') . '/';
+			$existingMount = $this->setupMountProviderPaths[$from] ?? null;
+			if ($existingMount !== null) {
+				$this->setupMountProviderPaths[$to] = $this->setupMountProviderPaths[$from];
+				unset($this->setupMountProviderPaths[$from]);
+			}
+		});
 		$this->eventDispatcher->addListener(InvalidateMountCacheEvent::class, function (InvalidateMountCacheEvent $event,
 		) {
 			if ($user = $event->getUser()) {
@@ -595,4 +801,46 @@ class SetupManager {
 			});
 		}
 	}
+
+	private function registerMounts(IUser $user, array $mounts, ?array $mountProviderClasses = null): void {
+		if ($this->lockdownManager->canAccessFilesystem()) {
+			$this->userMountCache->registerMounts($user, $mounts, $mountProviderClasses);
+		}
+	}
+
+	/**
+	 * Drops partially set-up mounts for the given user
+	 *
+	 * @param class-string<IMountProvider>[] $providers
+	 */
+	public function dropPartialMountsForUser(IUser $user, array $providers = []): void {
+		// mounts are cached by mount-point
+		$mounts = $this->mountManager->getAll();
+		$partialMounts = array_filter($this->setupMountProviderPaths,
+			static function (string $mountPoint) use (
+				$providers,
+				$user,
+				$mounts
+			) {
+				$isUserMount = str_starts_with($mountPoint, '/' . $user->getUID() . '/files');
+
+				if (!$isUserMount) {
+					return false;
+				}
+
+				$mountProvider = ($mounts[$mountPoint] ?? null)?->getMountProvider();
+
+				return empty($providers)
+					|| \in_array($mountProvider, $providers, true);
+			},
+			ARRAY_FILTER_USE_KEY);
+
+		if (!empty($partialMounts)) {
+			// remove partially set up mounts
+			foreach ($partialMounts as $mountPoint => $_mount) {
+				$this->mountManager->removeMount($mountPoint);
+				unset($this->setupMountProviderPaths[$mountPoint]);
+			}
+		}
+	}
 }
