@@ -11,16 +11,15 @@ namespace OC\Files\Template;
 use OC\AppFramework\Bootstrap\Coordinator;
 use OC\Files\Cache\Scanner;
 use OC\Files\Filesystem;
+use OCA\Files\ResponseDefinitions;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\Files\File;
 use OCP\Files\Folder;
 use OCP\Files\GenericFileException;
 use OCP\Files\IFilenameValidator;
 use OCP\Files\IRootFolder;
-use OCP\Files\Node;
 use OCP\Files\NotFoundException;
 use OCP\Files\Template\BeforeGetTemplatesEvent;
-use OCP\Files\Template\Field;
 use OCP\Files\Template\FileCreatedFromTemplateEvent;
 use OCP\Files\Template\ICustomTemplateProvider;
 use OCP\Files\Template\ITemplateManager;
@@ -28,65 +27,54 @@ use OCP\Files\Template\RegisterTemplateCreatorEvent;
 use OCP\Files\Template\Template;
 use OCP\Files\Template\TemplateFileCreator;
 use OCP\IConfig;
+use OCP\IL10N;
 use OCP\IPreview;
-use OCP\IServerContainer;
 use OCP\IUserManager;
 use OCP\IUserSession;
 use OCP\L10N\IFactory;
+use Override;
+use Psr\Container\ContainerInterface;
 use Psr\Log\LoggerInterface;
 
+/**
+ * @psalm-import-type FilesTemplateFile from ResponseDefinitions
+ */
 class TemplateManager implements ITemplateManager {
-	private $registeredTypes = [];
-	private $types = [];
-
-	/** @var array|null */
-	private $providers = null;
-
-	private $serverContainer;
-	private $eventDispatcher;
-	private $rootFolder;
-	private $userManager;
-	private $previewManager;
-	private $config;
-	private $l10n;
-	private $logger;
-	private $userId;
-	private $l10nFactory;
-	/** @var Coordinator */
-	private $bootstrapCoordinator;
+	/** @var list<callable(): TemplateFileCreator> */
+	private array $registeredTypes = [];
+	/** @var list<TemplateFileCreator> */
+	private array $types = [];
+	/** @var array<class-string<ICustomTemplateProvider>, ICustomTemplateProvider>|null */
+	private ?array $providers = null;
+	private IL10n $l10n;
+	private ?string $userId;
 
 	public function __construct(
-		IServerContainer $serverContainer,
-		IEventDispatcher $eventDispatcher,
-		Coordinator $coordinator,
-		IRootFolder $rootFolder,
+		private readonly ContainerInterface $serverContainer,
+		private readonly IEventDispatcher $eventDispatcher,
+		private readonly Coordinator $bootstrapCoordinator,
+		private readonly IRootFolder $rootFolder,
 		IUserSession $userSession,
-		IUserManager $userManager,
-		IPreview $previewManager,
-		IConfig $config,
-		IFactory $l10nFactory,
-		LoggerInterface $logger,
-		private IFilenameValidator $filenameValidator,
+		private readonly IUserManager $userManager,
+		private readonly IPreview $previewManager,
+		private readonly IConfig $config,
+		private readonly IFactory $l10nFactory,
+		private readonly LoggerInterface $logger,
+		private readonly IFilenameValidator $filenameValidator,
 	) {
-		$this->serverContainer = $serverContainer;
-		$this->eventDispatcher = $eventDispatcher;
-		$this->bootstrapCoordinator = $coordinator;
-		$this->rootFolder = $rootFolder;
-		$this->userManager = $userManager;
-		$this->previewManager = $previewManager;
-		$this->config = $config;
-		$this->l10nFactory = $l10nFactory;
 		$this->l10n = $l10nFactory->get('lib');
-		$this->logger = $logger;
-		$user = $userSession->getUser();
-		$this->userId = $user ? $user->getUID() : null;
+		$this->userId = $userSession->getUser()?->getUID();
 	}
 
+	#[Override]
 	public function registerTemplateFileCreator(callable $callback): void {
 		$this->registeredTypes[] = $callback;
 	}
 
-	public function getRegisteredProviders(): array {
+	/**
+	 * @return array<class-string<ICustomTemplateProvider>, ICustomTemplateProvider>
+	 */
+	private function getRegisteredProviders(): array {
 		if ($this->providers !== null) {
 			return $this->providers;
 		}
@@ -101,7 +89,10 @@ class TemplateManager implements ITemplateManager {
 		return $this->providers;
 	}
 
-	public function getTypes(): array {
+	/**
+	 * @return list<TemplateFileCreator>
+	 */
+	private function getTypes(): array {
 		if (!empty($this->types)) {
 			return $this->types;
 		}
@@ -112,6 +103,7 @@ class TemplateManager implements ITemplateManager {
 		return $this->types;
 	}
 
+	#[Override]
 	public function listCreators(): array {
 		$types = $this->getTypes();
 		usort($types, function (TemplateFileCreator $a, TemplateFileCreator $b) {
@@ -120,6 +112,7 @@ class TemplateManager implements ITemplateManager {
 		return $types;
 	}
 
+	#[Override]
 	public function listTemplates(): array {
 		return array_values(array_map(function (TemplateFileCreator $entry) {
 			return array_merge($entry->jsonSerialize(), [
@@ -128,6 +121,7 @@ class TemplateManager implements ITemplateManager {
 		}, $this->listCreators()));
 	}
 
+	#[Override]
 	public function listTemplateFields(int $fileId): array {
 		foreach ($this->listCreators() as $creator) {
 			$fields = $this->getTemplateFields($creator, $fileId);
@@ -141,13 +135,7 @@ class TemplateManager implements ITemplateManager {
 		return [];
 	}
 
-	/**
-	 * @param string $filePath
-	 * @param string $templateId
-	 * @param array $templateFields
-	 * @return array
-	 * @throws GenericFileException
-	 */
+	#[Override]
 	public function createFromTemplate(string $filePath, string $templateId = '', string $templateType = 'user', array $templateFields = []): array {
 		$userFolder = $this->rootFolder->getUserFolder($this->userId);
 		try {
@@ -159,6 +147,7 @@ class TemplateManager implements ITemplateManager {
 			if (!$userFolder->nodeExists(dirname($filePath))) {
 				throw new GenericFileException($this->l10n->t('Invalid path'));
 			}
+			/** @var Folder $folder */
 			$folder = $userFolder->get(dirname($filePath));
 			$template = null;
 			if ($templateType === 'user' && $templateId !== '') {
@@ -178,7 +167,9 @@ class TemplateManager implements ITemplateManager {
 			$targetFile = $folder->newFile($filename, ($template instanceof File ? $template->fopen('rb') : null));
 
 			$this->eventDispatcher->dispatchTyped(new FileCreatedFromTemplateEvent($template, $targetFile, $templateFields));
-			return $this->formatFile($userFolder->get($filePath));
+			/** @var File $file */
+			$file = $userFolder->get($filePath);
+			return $this->formatFile($file);
 		} catch (\Exception $e) {
 			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			throw new GenericFileException($this->l10n->t('Failed to create file from template'));
@@ -186,7 +177,6 @@ class TemplateManager implements ITemplateManager {
 	}
 
 	/**
-	 * @return Folder
 	 * @throws \OCP\Files\NotFoundException
 	 * @throws \OCP\Files\NotPermittedException
 	 * @throws \OC\User\NoUserException
@@ -246,6 +236,9 @@ class TemplateManager implements ITemplateManager {
 
 		foreach ($type->getMimetypes() as $mimetype) {
 			foreach ($userTemplateFolder->searchByMime($mimetype) as $templateFile) {
+				if (!($templateFile instanceof File)) {
+					continue;
+				}
 				$template = new Template(
 					'user',
 					$this->rootFolder->getUserFolder($this->userId)->getRelativePath($templateFile->getPath()),
@@ -268,9 +261,7 @@ class TemplateManager implements ITemplateManager {
 
 		$matchedTemplates = array_filter(
 			array_merge($providerTemplates, $userTemplates),
-			function (Template $template) use ($fileId) {
-				return $template->jsonSerialize()['fileid'] === $fileId;
-			});
+			fn (Template $template): bool => $template->jsonSerialize()['fileid'] === $fileId);
 
 		if (empty($matchedTemplates)) {
 			return [];
@@ -278,22 +269,19 @@ class TemplateManager implements ITemplateManager {
 
 		$this->eventDispatcher->dispatchTyped(new BeforeGetTemplatesEvent($matchedTemplates, true));
 
-		return array_values(array_map(function (Template $template) {
-			return $template->jsonSerialize()['fields'] ?? [];
-		}, $matchedTemplates));
+		return array_values(array_map(static fn (Template $template): array => $template->jsonSerialize()['fields'] ?? [], $matchedTemplates));
 	}
 
 	/**
-	 * @param Node|File $file
-	 * @return array
+	 * @return FilesTemplateFile
 	 * @throws NotFoundException
 	 * @throws \OCP\Files\InvalidPathException
 	 */
-	private function formatFile(Node $file): array {
+	private function formatFile(File $file): array {
 		return [
 			'basename' => $file->getName(),
 			'etag' => $file->getEtag(),
-			'fileid' => $file->getId(),
+			'fileid' => $file->getId() ?? -1,
 			'filename' => $this->rootFolder->getUserFolder($this->userId)->getRelativePath($file->getPath()),
 			'lastmod' => $file->getMTime(),
 			'mime' => $file->getMimetype(),
@@ -313,14 +301,17 @@ class TemplateManager implements ITemplateManager {
 		return false;
 	}
 
+	#[Override]
 	public function setTemplatePath(string $path): void {
 		$this->config->setUserValue($this->userId, 'core', 'templateDirectory', $path);
 	}
 
+	#[Override]
 	public function getTemplatePath(): string {
 		return $this->config->getUserValue($this->userId, 'core', 'templateDirectory', '');
 	}
 
+	#[Override]
 	public function initializeTemplateDirectory(?string $path = null, ?string $userId = null, $copyTemplates = true): string {
 		if ($userId !== null) {
 			$this->userId = $userId;
@@ -365,12 +356,7 @@ class TemplateManager implements ITemplateManager {
 				}
 			}
 
-			try {
-				$folder = $userFolder->get($userTemplatePath);
-			} catch (NotFoundException $e) {
-				$folder = $userFolder->get(dirname($userTemplatePath));
-				$folder = $folder->newFolder(basename($userTemplatePath));
-			}
+			$folder = $userFolder->getOrCreateFolder($userTemplatePath);
 
 			$folderIsEmpty = count($folder->getDirectoryListing()) === 0;
 
@@ -408,7 +394,7 @@ class TemplateManager implements ITemplateManager {
 		return $this->getTemplatePath();
 	}
 
-	private function getLocalizedTemplatePath(string $skeletonTemplatePath, string $userLang) {
+	private function getLocalizedTemplatePath(string $skeletonTemplatePath, string $userLang): string {
 		$localizedSkeletonTemplatePath = str_replace('{lang}', $userLang, $skeletonTemplatePath);
 
 		if (!file_exists($localizedSkeletonTemplatePath)) {
