@@ -23,7 +23,7 @@ class AuthorizedGroup extends Entity implements \JsonSerializable {
 
 	public function jsonSerialize(): array {
 		return [
-			'id' => $this->id,
+			'id' => $this->getId(),
 			'group_id' => $this->groupId,
 			'class' => $this->class
 		];
