@@ -32,7 +32,9 @@ use OCP\Mail\IMailer;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IAttributes;
 use OCP\Share\IManager;
+use OCP\Share\IPartialShareProvider;
 use OCP\Share\IShare;
+use OCP\Share\IShareProviderGetUsers;
 use OCP\Share\IShareProviderSupportsAccept;
 use OCP\Share\IShareProviderSupportsAllSharesInFolder;
 use OCP\Share\IShareProviderWithNotification;
@@ -44,7 +46,12 @@ use function str_starts_with;
  *
  * @package OC\Share20
  */
-class DefaultShareProvider implements IShareProviderWithNotification, IShareProviderSupportsAccept, IShareProviderSupportsAllSharesInFolder {
+class DefaultShareProvider implements
+	IShareProviderWithNotification,
+	IShareProviderSupportsAccept,
+	IShareProviderSupportsAllSharesInFolder,
+	IShareProviderGetUsers,
+	IPartialShareProvider {
 	public function __construct(
 		private IDBConnection $dbConn,
 		private IUserManager $userManager,
@@ -823,13 +830,46 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 		return true;
 	}
 
-	/**
-	 * @inheritdoc
-	 */
 	public function getSharedWith($userId, $shareType, $node, $limit, $offset) {
+		return $this->_getSharedWith($userId, $shareType, $limit, $offset, $node);
+	}
+
+	public function getSharedWithByPath(
+		string $userId,
+		int $shareType,
+		string $path,
+		bool $forChildren,
+		int $limit,
+		int $offset,
+	): iterable {
+		return $this->_getSharedWith($userId, $shareType, $limit, $offset, null, $path, $forChildren);
+	}
+
+	/**
+	 * @return IShare[]
+	 */
+	private function _getSharedWith(
+		string $userId,
+		int $shareType,
+		int $limit,
+		int $offset,
+		?Node $node = null,
+		?string $path = null,
+		?bool $forChildren = false,
+	): iterable {
 		/** @var Share[] $shares */
 		$shares = [];
 
+		$nonChildPath = '/';
+		if ($path !== null) {
+			$path = str_replace('/' . $userId . '/files', '', $path);
+			$path = rtrim($path, '/');
+
+			if ($path !== '') {
+				$nonChildPath = $path;
+			}
+		}
+
 		if ($shareType === IShare::TYPE_USER) {
 			//Get shares directly with this user
 			$qb = $this->dbConn->getQueryBuilder();
@@ -861,6 +901,19 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 				$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
 			}
 
+			if ($path !== null) {
+				if ($forChildren) {
+					$qb->andWhere(
+						$qb->expr()->like(
+							'file_target',
+							$qb->createNamedParameter($this->dbConn->escapeLikeParameter($path) . '/_%', IQueryBuilder::PARAM_STR),
+						),
+					);
+				} else {
+					$qb->andWhere($qb->expr()->eq('file_target', $qb->createNamedParameter($nonChildPath, IQueryBuilder::PARAM_STR)));
+				}
+			}
+
 			$cursor = $qb->executeQuery();
 
 			while ($data = $cursor->fetch()) {
@@ -912,14 +965,46 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 					$qb->andWhere($qb->expr()->eq('file_source', $qb->createNamedParameter($node->getId())));
 				}
 
+				if ($path !== null) {
+					$onClause = $qb->expr()->andX(
+						$qb->expr()->eq('sc.parent', 's.id'),
+						$qb->expr()->eq('sc.share_type', $qb->createNamedParameter(IShare::TYPE_USERGROUP)),
+						$qb->expr()->eq('sc.share_with', $qb->createNamedParameter($userId)),
+					);
+					$qb->leftJoin('s', 'share', 'sc', $onClause);
+
+					if ($forChildren) {
+						$childPathTemplate = $this->dbConn->escapeLikeParameter($path) . '/_%';
+						$qb->andWhere(
+							$qb->expr()->orX(
+								$qb->expr()->like('sc.file_target', $qb->createNamedParameter($childPathTemplate)),
+								$qb->expr()->andX(
+									$qb->expr()->isNull('sc.file_target'),
+									$qb->expr()->like('s.file_target', $qb->createNamedParameter($childPathTemplate))
+								),
+							),
+						);
+					} else {
+						$qb->andWhere(
+							$qb->expr()->orX(
+								$qb->expr()->eq('sc.file_target', $qb->createNamedParameter($nonChildPath, IQueryBuilder::PARAM_STR)),
+								$qb->expr()->andX(
+									$qb->expr()->isNull('sc.file_target'),
+									$qb->expr()->eq('s.file_target', $qb->createNamedParameter($nonChildPath, IQueryBuilder::PARAM_STR)),
+								),
+							)
+						);
+					}
+				}
+
 				$groups = array_filter($groups);
 
-				$qb->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_GROUP)))
-					->andWhere($qb->expr()->in('share_with', $qb->createNamedParameter(
+				$qb->andWhere($qb->expr()->eq('s.share_type', $qb->createNamedParameter(IShare::TYPE_GROUP)))
+					->andWhere($qb->expr()->in('s.share_with', $qb->createNamedParameter(
 						$groups,
 						IQueryBuilder::PARAM_STR_ARRAY
 					)))
-					->andWhere($qb->expr()->in('item_type', $qb->createNamedParameter(['file', 'folder'], IQueryBuilder::PARAM_STR_ARRAY)));
+					->andWhere($qb->expr()->in('s.item_type', $qb->createNamedParameter(['file', 'folder'], IQueryBuilder::PARAM_STR_ARRAY)));
 
 				$cursor = $qb->executeQuery();
 				while ($data = $cursor->fetch()) {
@@ -939,7 +1024,7 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 			/*
 			 * Resolve all group shares to user specific shares
 			 */
-			$shares = $this->resolveGroupShares($shares2, $userId);
+			$shares = $this->resolveGroupShares($shares2, $userId, $path, $forChildren);
 		} else {
 			throw new BackendError('Invalid backend');
 		}
@@ -989,7 +1074,7 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 	 */
 	private function createShare($data) {
 		$share = new Share($this->rootFolder, $this->userManager);
-		$share->setId((int)$data['id'])
+		$share->setId($data['id'])
 			->setShareType((int)$data['share_type'])
 			->setPermissions((int)$data['permissions'])
 			->setTarget($data['file_target'])
@@ -1055,7 +1140,7 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 	 * @param $userId
 	 * @return Share[] The updates shares if no update is found for a share return the original
 	 */
-	private function resolveGroupShares($shareMap, $userId) {
+	private function resolveGroupShares($shareMap, $userId, ?string $path = null, ?bool $forChildren = false) {
 		$qb = $this->dbConn->getQueryBuilder();
 		$query = $qb->select('*')
 			->from('share')
@@ -1069,6 +1154,14 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 		if (count($shareMap) === 1) {
 			$share = reset($shareMap);
 			$query->andWhere($qb->expr()->eq('parent', $qb->createNamedParameter($share->getId())));
+		} elseif ($path !== null) {
+			if ($forChildren) {
+				$query->andWhere($qb->expr()->like('file_target',
+					$qb->createNamedParameter($this->dbConn->escapeLikeParameter($path) . '/_%')));
+			} else {
+				$nonChildPath = $path !== '' ? $path : '/';
+				$query->andWhere($qb->expr()->eq('file_target', $qb->createNamedParameter($nonChildPath)));
+			}
 		}
 
 		$stmt = $query->executeQuery();
@@ -1678,4 +1771,15 @@ class DefaultShareProvider implements IShareProviderWithNotification, IShareProv
 		}
 		return \json_encode($compressedAttributes);
 	}
+
+	public function getUsersForShare(IShare $share): iterable {
+		if ($share->getShareType() === IShare::TYPE_USER) {
+			return [new LazyUser($share->getSharedWith(), $this->userManager)];
+		} elseif ($share->getShareType() === IShare::TYPE_GROUP) {
+			$group = $this->groupManager->get($share->getSharedWith());
+			return $group->getUsers();
+		} else {
+			return [];
+		}
+	}
 }
