@@ -9,6 +9,7 @@ declare(strict_types=1);
 namespace OCP\OCM;
 
 use JsonSerializable;
+use OCP\AppFramework\Attribute\Consumable;
 use OCP\OCM\Exceptions\OCMArgumentException;
 use OCP\OCM\Exceptions\OCMProviderException;
 
@@ -17,6 +18,7 @@ use OCP\OCM\Exceptions\OCMProviderException;
  * @link https://github.com/cs3org/OCM-API/
  * @since 28.0.0
  */
+#[Consumable(since: '28.0.0')]
 interface IOCMProvider extends JsonSerializable {
 	/**
 	 * enable OCM
@@ -107,6 +109,57 @@ interface IOCMProvider extends JsonSerializable {
 	 */
 	public function getResourceTypes(): array;
 
+	/**
+	 * get the capabilities
+	 *
+	 * @return array
+	 * @since 33.0.0
+	 */
+	public function getCapabilities(): array;
+
+	/**
+	 * return if provider supports $capability
+	 *
+	 * @since 33.0.0
+	 */
+	public function hasCapability(string $capability): bool;
+
+	/**
+	 * get the provider name
+	 *
+	 * @return string
+	 * @since 33.0.0
+	 */
+	public function getProvider(): string;
+
+	/**
+	 * returns the invite accept dialog
+	 *
+	 * @return string
+	 * @since 33.0.0
+	 */
+	public function getInviteAcceptDialog(): string;
+
+	/**
+	 * set the capabilities
+	 *
+	 * @param array $capabilities
+	 *
+	 * @return $this
+	 * @since 33.0.0
+	 */
+	public function setCapabilities(array $capabilities): static;
+
+	/**
+	 * set the invite accept dialog
+	 *
+	 * @param string $inviteAcceptDialog
+	 *
+	 * @return $this
+	 * @since 33.0.0
+	 */
+
+	public function setInviteAcceptDialog(string $inviteAcceptDialog): static;
 	/**
 	 * extract a specific string value from the listing of protocols, based on resource-name and protocol-name
 	 *
