@@ -45,7 +45,15 @@ interface ITeamManager {
 	 * @param string[] $teams
 	 * @return array<string, list<TeamResource>>
 	 *
-	 * @since 32.0.2
+	 * @since 33.0.0
 	 */
 	public function getSharedWithList(array $teams, string $userId): array;
+
+	/**
+	 * Returns all teams that a given user is a member of
+	 *
+	 * @return list<Team>
+	 * @since 33.0.0
+	 */
+	public function getTeamsForUser(string $userId): array;
 }
